(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    312916,      10972]*)
(*NotebookOutlinePosition[    313622,      10996]*)
(*  CellTagsIndexPosition[    313578,      10992]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Inequality and growth:
Why fertility differential matters\
\>", "Title"],

Cell["\<\

Dynamic analysis\
\>", "Subtitle"],

Cell["Loading useful packages", "Subtitle"],

Cell[BoxData[{
    \(<< Statistics`ContinuousDistributions`\), "\[IndentingNewLine]", 
    \(<< Graphics`FilledPlot`\), "\[IndentingNewLine]", 
    \(<< Graphics`Graphics`\), "\[IndentingNewLine]", 
    \(<< Graphics`Graphics3D`\), "\[IndentingNewLine]", 
    \(<< Graphics`MultipleListPlot`\), "\[IndentingNewLine]", 
    \(<< Statistics`DescriptiveStatistics`\)}], "Input"],

Cell[BoxData[{
    \(\(SetOptions[ListPlot, PlotRange \[Rule] All, 
        PlotJoined \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[MultipleListPlot, PlotJoined \[Rule] True];\)\)}], "Input"],

Cell[CellGroupData[{

Cell["Procedures", "Subtitle"],

Cell[CellGroupData[{

Cell["Defining the variables", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(defvar := 
      Module[{a}, \[IndentingNewLine]Clear[cN, cNf, cn, cx, cxf, ce, pN, pn, 
          px, pe, growth, cap, popgrowth, income, ginix, fd, 
          cfd]; \[IndentingNewLine]Clear[Nh, Nhf, n, x, xf, e, plN, pln, plx, 
          ple, gag, k, nag, inc, gix, ct, pct]; \[IndentingNewLine]cN = 
          Array[Nh, dim]; 
        cNf = Array[Nhf, dim]; \[IndentingNewLine]cn = Array[n, dim]; 
        cx = Array[x, dim]; cxf = Array[xf, dim]; \ 
        ce = Array[e, dim]; \[IndentingNewLine]income = 
          Array[inc, dim]; \[IndentingNewLine]pN = Array[plN, steps]; 
        pn = Array[pln, steps]; 
        ct = Array[pct, steps]; \[IndentingNewLine]px = Array[plx, steps]; 
        pe = Array[ple, steps]; \[IndentingNewLine]growth = 
          Array[gag, steps]; popgrowth = Array[nag, steps]; 
        cap = Array[k, steps + 1]; \[IndentingNewLine]ginix = 
          Array[gix, steps]; cfd = Array[fd, steps];]\)], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(pln\)\" is similar to \
existing symbol \"\!\(plN\)\"."\)], "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Setting the initial conditions", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"initcond", ":=", 
        RowBox[{"Module", "[", 
          RowBox[{\({scal, cxtemp, glt, Nlt}\), ",", "\[IndentingNewLine]", 
            
            RowBox[{\(Do[Nh[i] = 1/dim, {i, 1, dim}]\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"gdist", "=", 
                StyleBox[\(LogNormalDistribution[0, \[Sigma]]\),
                  "MR"]}], ";", 
              "\[IndentingNewLine]", \(cdfunction = CDF[gdist, y]\), ";", 
              "\[IndentingNewLine]", \(pdfunction = PDF[gdist, y]\), ";", 
              "\[IndentingNewLine]", \(inversecdf[z_] = 
                y /. \(Solve[cdfunction \[Equal] z, y]\)[\([1]\)]\), ";", 
              "\[IndentingNewLine]", \(Do[
                x[i] = inversecdf[\((i -  .5)\)/dim]\ , {i, 1, dim}]\), ";", 
              "\[IndentingNewLine]", \(scal = Sum[x[i]\ Nh[i], {i, 1, dim}]\),
               ";", "\[IndentingNewLine]", \(Do[
                x[i] = x[i]/scal\ , {i, 1, dim}]\), ";", 
              "\[IndentingNewLine]", \(Nlt = \(\((1 - \[Eta])\) \
\[Gamma]\)\/\(\((\[Phi] - \[Theta])\) \((1 + \[Beta] + \[Gamma])\)\)\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"glt", "=", 
                RowBox[{"If", "[", 
                  
                  RowBox[{\(\[Kappa] < 1 - \[Tau]\), ",", \(1 + \[CurlyRho]\),
                     ",", " ", 
                    RowBox[{
                      StyleBox["B",
                        
                        FontWeight->
                          "Plain"], \(\((\(\[Eta] \((\[Phi] - \[Theta])\)\)\/\
\(1 - \[Eta]\))\)\^\[Eta]\)}]}], "]"}]}], ";", 
              "\[IndentingNewLine]", \(k[
                  1] = \((\(\[Beta]\/\(1 + \[Beta]\)\) \(1\/\(glt\ Nlt\)\) \
\((1 - \[Alpha])\))\)\^\(1\/\(1 - \[Alpha]\)\)\), ";", "\[IndentingNewLine]", 
              
              RowBox[{\(hh[1]\), "=", 
                RowBox[{"If", "[", 
                  RowBox[{\(\[Kappa] < 1 - \[Tau]\), ",", 
                    RowBox[{
                      FractionBox[
                        StyleBox["B",
                          FontWeight->"Plain"], 
                        "glt"], \(\((\(\[Eta] \((\[Phi] - \[Theta])\)\)\/\(1 \
- \[Eta]\))\)\^\[Eta]\)}], ",", "1"}], "]"}]}], ";"}]}], "]"}]}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"pictdist", ":=", 
      RowBox[{"Module", "[", 
        RowBox[{\({dis1, dis2}\), ",", "\[IndentingNewLine]", 
          
          RowBox[{\(dis1 = 
              FilledPlot[pdfunction, {y, 0, 4}, PlotRange \[Rule] All, 
                DisplayFunction \[Rule] Identity]\), ";", 
            "\[IndentingNewLine]", 
            RowBox[{"dis2", "=", 
              RowBox[{"Histogram", "[", 
                RowBox[{"cx", ",", 
                  RowBox[{
                    StyleBox["HistogramScale",
                      "MR"], " ", 
                    StyleBox["->",
                      "MR"], 
                    StyleBox["1",
                      "MR"]}], 
                  StyleBox[",",
                    "MR"], 
                  StyleBox[\(HistogramRange -> {0, 4}\),
                    "MR"], ",", \(DisplayFunction \[Rule] Identity\)}], 
                "]"}]}], ";", 
            "\[IndentingNewLine]", \(Show[dis1, dis2, 
              DisplayFunction \[Rule] $DisplayFunction]\), ";"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(pdfunction\)\" is \
similar to existing symbol \"\!\(cdfunction\)\"."\)], "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dynamic simulation", "Section"],

Cell[BoxData[
    \(simul := 
      Module[{a, 
          q}, \[IndentingNewLine]Do[\[IndentingNewLine]Print["\<Start \
simulation \>", Date[]]; 
          Do[n[i] = 
              If[x[i] > \[Theta]/\((\[Eta]\ \[Phi])\), \(\((1 - \[Eta])\)\ \
\[Gamma]\ x[i]\)\/\(\((\[Phi]\ x[i] - \[Theta])\) \((1 + \[Beta] + \
\[Gamma])\)\), \(\(\[Gamma]\)\(\ \)\)\/\(\[Phi]\ \((1 + \[Beta] + \[Gamma])\)\
\)], {i, 1, dim}]; \[IndentingNewLine]\[IndentingNewLine]nsort = 
            Sort[Array[n, dim]]; \[IndentingNewLine]fd[
              j] = \(-Mean[Take[nsort, dim/5]]\) + 
              Mean[Take[nsort, \(-dim\)/5]]; \[IndentingNewLine]nag[j] = 
            Sum[n[i]\ Nh[i], {i, 1, dim}]; \[IndentingNewLine]Do[
            Nhf[i] = n[i]\/nag[j]\ Nh[i], {i, 1, dim}]; \[IndentingNewLine]Do[
            e[i] = Max[\(\[Eta]\ \[Phi]\ x[i] - \[Theta]\)\/\(1 - \[Eta]\), 
                0], {i, 1, dim}]; \[IndentingNewLine]gag[j] = 
            Sum[\ Nhf[
                  i]\ B\ \(\((\[Theta] + e[i])\)\^\[Eta]\) \(x[i]\^\[Tau]\) 
                hh[j]\^\(\[Kappa] + \[Tau] - 1\), {i, 1, 
                dim}]; \[IndentingNewLine]hh[j + 1] = 
            hh[j]\ gag[j]/\((1 + \[CurlyRho])\); \[IndentingNewLine]Do[
            inc[i] = \((x[i] \((1 - \[Phi]\ n[i])\) - 
                    e[i] n[i])\) \((1 - \[Alpha])\) k[j]\^\[Alpha], {i, 1, 
              dim}]; \[IndentingNewLine]sd = 
            Sort[income]; \[IndentingNewLine]gix[j] = 
            N[\(Length[
                      sd]\/\((Length[sd] - 
                        1)\)\) \(2  Apply[Plus, Table[\((2  q - Length[sd] - \
1)\) sd[\([q]\)], {q, 1, Length[sd]}]]\)\/\(2\ Length[sd]\^2\ Mean[sd]\)]; \
\[IndentingNewLine]k[
              j + 1] = \(\[Beta]\/\(1 + \[Beta]\)\) \(1\/\(gag[j]\ nag[
                      j]\)\) \((1 - \[Alpha])\) 
              k[j]\^\[Alpha]; \[IndentingNewLine]pct[j] = 
            Sum[If[x[i] < \[Theta]/\((\[Eta]\ \[Phi])\), Nh[i], 0]\ , {i, 1, 
                dim}]; \[IndentingNewLine]Do[
            xf[i] = B\ \(\((\[Theta] + e[i])\)\^\[Eta]\) 
                x[i]\^\[Tau]\ hh[j]\^\(\[Kappa] + \[Tau] - 1\)/\ gag[j], {i, 
              1, dim}]; \[IndentingNewLine]Print["\<Start sorting households \
\>", Date[]]; \[IndentingNewLine]Clear[tp]; \[IndentingNewLine]tp = 
            Dot[Transpose[{Array[xf, dim]}], {{1, 0}}] + 
              Dot[Transpose[{Array[Nhf, dim]}], {{0, 
                    1}}]; \[IndentingNewLine]tp2 = 
            Transpose[Sort[tp]]; \[IndentingNewLine]Do[
            Nhf[i] = \(tp2[\([2]\)]\)[\([i]\)]; 
            xf[i] = \(tp2[\([1]\)]\)[\([i]\)], {i, 1, 
              dim}]; \[IndentingNewLine]Print["\<Start computing the \
cumulative distribution \>", Date[]]; \[IndentingNewLine]Clear[
            CuNhf]; \[IndentingNewLine]CuNhf[1] = 
            Nhf[1]; \[IndentingNewLine]Do[
            CuNhf[i] = CuNhf[i - 1] + Nhf[i], {i, 2, 
              dim}]; \[IndentingNewLine]Print["\<Start drawing random numbers \
\>", Date[]]; \[IndentingNewLine]Do[
            zNh[i] = 1/dim; \[IndentingNewLine]Clear[z1, tp]; 
            tp = Random[]; \[IndentingNewLine]z1 = \(Ordering[
                  Abs[Table[tp, {dim}] - Array[CuNhf, dim]], 
                  1]\)[\([1]\)]; \[IndentingNewLine]zx[i] = xf[z1], {i, 1, 
              dim}]; \[IndentingNewLine]Print["\<Start computing the error of \
approximation \>", Date[]]; \[IndentingNewLine]corr = 
            Sum[zx[i] zNh[i], {i, 1, 
                dim}]; \[IndentingNewLine]Print["\<step\>", \ 
            j]; \[IndentingNewLine]Do[x[i] = zx[i]/corr; 
            Nh[i] = zNh[i], {i, 1, dim}], {j, 1, steps}]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Results", "Section"],

Cell[BoxData[
    \(result2 := 
      Module[{p1, p2, p3, p4}, \[IndentingNewLine]Clear[p5, p6, p7, p8, p9, 
          p10]; \[IndentingNewLine]p5 = 
          ListPlot[growth, PlotJoined \[Rule] True, AxesLabel \[Rule] {t, g}, 
            DisplayFunction \[Rule] Identity, 
            AxesOrigin \[Rule] {1, 1}]; \[IndentingNewLine]p6 = 
          ListPlot[popgrowth, PlotJoined \[Rule] True, 
            AxesLabel \[Rule] {t, n}, DisplayFunction \[Rule] Identity, 
            AxesOrigin \[Rule] {1, 1}]; \[IndentingNewLine]p7 = 
          ListPlot[cap, PlotJoined \[Rule] True, 
            AxesLabel \[Rule] {t, "\<k\>"}, 
            DisplayFunction \[Rule] Identity]; \[IndentingNewLine]p8 = 
          ListPlot[ginix, PlotJoined \[Rule] True, 
            AxesLabel \[Rule] {t, "\<gini\>"}, 
            DisplayFunction \[Rule] Identity]; \[IndentingNewLine]p9 = 
          ListPlot[ct, PlotJoined \[Rule] True, 
            AxesLabel \[Rule] {t, "\<% const\>"}, 
            DisplayFunction \[Rule] Identity, 
            AxesOrigin \[Rule] {1, 0}]; \[IndentingNewLine]p10 = 
          ListPlot[cfd, PlotJoined \[Rule] True, 
            AxesLabel \[Rule] {t, "\<dif fert\>"}, 
            DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[
          GraphicsArray[{{p5, p6}, {p7, p8}, {p9, p10}}]]]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Main program", "Subtitle"],

Cell[BoxData[{
    \(\[IndentingNewLine]\[Phi] =  .15/
        2; \[Eta] =  .634522; \[Beta] =  .99\^120; \[Alpha] = 1/3; \[Theta] = 
      0.01187433277439054; \[Gamma] = 
      0.2712867133790373;\), "\[IndentingNewLine]", 
    \(B = 7.3667967472312402219159866854; \[CurlyRho] = 
      1.02\^30 - 1;\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(ou = Array[plou, {4, 4}];\)\)}], "Input"],

Cell["Basis Simulations", "Section"],

Cell[CellGroupData[{

Cell["Endogenous versus exogenous growth", "Subsubtitle"],

Cell[BoxData[
    \(dim = 10000; steps = 8;\)], "Input"],

Cell[BoxData[
    \(\(\[Sigma] = 1;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Tau] =  .2; \[Kappa] = 1 - \[Tau]; defvar; initcond; simul; 
    result2;\), "\[IndentingNewLine]", 
    \(plou[2, 1] = \@growth\%30 - 1; plou[2, 2] = \@popgrowth\%30 - 1; 
    plou[2, 3] = ginix; plou[2, 4] = 2\ cfd;\[IndentingNewLine]\)}], "Input"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 8, 23, 
          3, 35}\),
      SequenceForm[ "Start simulation ", {2002, 6, 8, 23, 3, 35}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          8, 23, 3, 46}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 8, 23, 3, 46}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 8, 23, 4, 11}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 8, 23, 4, 
        11}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 8, 23, 4, 11}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 8, 23, 4, 11}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 8, 23, 24, 15}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 8, 23, 24, 
        15}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 8, 23, 
          24, 16}\),
      SequenceForm[ "Start simulation ", {2002, 6, 8, 23, 24, 16}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          8, 23, 24, 26}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 8, 23, 24, 26}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 8, 23, 24, 53}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 8, 23, 24, 
        53}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 8, 23, 24, 54}\),
      SequenceForm[ 
      "Start drawing random numbers ", {2002, 6, 8, 23, 24, 54}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 8, 23, 47, 21}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 8, 23, 47, 
        21}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]2\),
      SequenceForm[ "step", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 8, 23, 
          47, 22}\),
      SequenceForm[ "Start simulation ", {2002, 6, 8, 23, 47, 22}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          8, 23, 47, 32}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 8, 23, 47, 32}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 8, 23, 48, 0}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 8, 23, 48, 
        0}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 8, 23, 48, 1}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 8, 23, 48, 1}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 0, 10, 22}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 0, 10, 22}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]3\),
      SequenceForm[ "step", 3],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 9, 0, 
          10, 24}\),
      SequenceForm[ "Start simulation ", {2002, 6, 9, 0, 10, 24}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          9, 0, 10, 34}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 9, 0, 10, 34}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 9, 0, 11, 2}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 9, 0, 11, 2}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 9, 0, 11, 3}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 9, 0, 11, 3}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 0, 33, 23}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 0, 33, 23}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]4\),
      SequenceForm[ "step", 4],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 9, 0, 
          33, 25}\),
      SequenceForm[ "Start simulation ", {2002, 6, 9, 0, 33, 25}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          9, 0, 33, 35}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 9, 0, 33, 35}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 9, 0, 34, 2}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 9, 0, 34, 2}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 9, 0, 34, 3}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 9, 0, 34, 3}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 0, 56, 24}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 0, 56, 24}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]5\),
      SequenceForm[ "step", 5],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 9, 0, 
          56, 25}\),
      SequenceForm[ "Start simulation ", {2002, 6, 9, 0, 56, 25}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          9, 0, 56, 35}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 9, 0, 56, 35}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 9, 0, 57, 3}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 9, 0, 57, 3}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 9, 0, 57, 4}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 9, 0, 57, 4}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 1, 19, 40}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 1, 19, 40}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]6\),
      SequenceForm[ "step", 6],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 9, 1, 
          19, 41}\),
      SequenceForm[ "Start simulation ", {2002, 6, 9, 1, 19, 41}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          9, 1, 19, 51}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 9, 1, 19, 51}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 9, 1, 20, 19}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 9, 1, 20, 
        19}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 9, 1, 20, 20}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 9, 1, 20, 20}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 1, 42, 37}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 1, 42, 37}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]7\),
      SequenceForm[ "step", 7],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 9, 1, 
          42, 38}\),
      SequenceForm[ "Start simulation ", {2002, 6, 9, 1, 42, 38}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          9, 1, 42, 49}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 9, 1, 42, 49}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 9, 1, 43, 17}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 9, 1, 43, 
        17}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 9, 1, 43, 18}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 9, 1, 43, 18}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 2, 5, 57}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 2, 5, 57}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]8\),
      SequenceForm[ "step", 8],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .94177 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.022423 0.47619 [
[ 0 0 0 0 ]
[ 1 .94177 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .94177 L
0 .94177 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.022423 0.477324 0.302711 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112245 0.136054 0.0147151 3.03248 [
[.15986 .00222 -3 -9 ]
[.15986 .00222 3 0 ]
[.29592 .00222 -3 -9 ]
[.29592 .00222 3 0 ]
[.43197 .00222 -3 -9 ]
[.43197 .00222 3 0 ]
[.56803 .00222 -3 -9 ]
[.56803 .00222 3 0 ]
[.70408 .00222 -3 -9 ]
[.70408 .00222 3 0 ]
[.84014 .00222 -3 -9 ]
[.84014 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6.28125 ]
[1.025 .01472 10 6.28125 ]
[.01131 .16634 -24 -4.5 ]
[.01131 .16634 0 4.5 ]
[.01131 .31796 -18 -4.5 ]
[.01131 .31796 0 4.5 ]
[.01131 .46959 -24 -4.5 ]
[.01131 .46959 0 4.5 ]
[.02381 .64303 -23 0 ]
[.02381 .64303 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 .01472 m
.15986 .02097 L
s
[(2)] .15986 .00222 0 1 Mshowa
.29592 .01472 m
.29592 .02097 L
s
[(3)] .29592 .00222 0 1 Mshowa
.43197 .01472 m
.43197 .02097 L
s
[(4)] .43197 .00222 0 1 Mshowa
.56803 .01472 m
.56803 .02097 L
s
[(5)] .56803 .00222 0 1 Mshowa
.70408 .01472 m
.70408 .02097 L
s
[(6)] .70408 .00222 0 1 Mshowa
.84014 .01472 m
.84014 .02097 L
s
[(7)] .84014 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(8)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05102 .01472 m
.05102 .01847 L
s
.07823 .01472 m
.07823 .01847 L
s
.10544 .01472 m
.10544 .01847 L
s
.13265 .01472 m
.13265 .01847 L
s
.18707 .01472 m
.18707 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.2415 .01472 m
.2415 .01847 L
s
.26871 .01472 m
.26871 .01847 L
s
.32313 .01472 m
.32313 .01847 L
s
.35034 .01472 m
.35034 .01847 L
s
.37755 .01472 m
.37755 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45918 .01472 m
.45918 .01847 L
s
.48639 .01472 m
.48639 .01847 L
s
.51361 .01472 m
.51361 .01847 L
s
.54082 .01472 m
.54082 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62245 .01472 m
.62245 .01847 L
s
.64966 .01472 m
.64966 .01847 L
s
.67687 .01472 m
.67687 .01847 L
s
.73129 .01472 m
.73129 .01847 L
s
.7585 .01472 m
.7585 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.81293 .01472 m
.81293 .01847 L
s
.86735 .01472 m
.86735 .01847 L
s
.89456 .01472 m
.89456 .01847 L
s
.92177 .01472 m
.92177 .01847 L
s
.94898 .01472 m
.94898 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.02381 .16634 m
.03006 .16634 L
s
[(0.05)] .01131 .16634 1 0 Mshowa
.02381 .31796 m
.03006 .31796 L
s
[(0.1)] .01131 .31796 1 0 Mshowa
.02381 .46959 m
.03006 .46959 L
s
[(0.15)] .01131 .46959 1 0 Mshowa
.125 Mabswid
.02381 .04504 m
.02756 .04504 L
s
.02381 .07536 m
.02756 .07536 L
s
.02381 .10569 m
.02756 .10569 L
s
.02381 .13601 m
.02756 .13601 L
s
.02381 .19666 m
.02756 .19666 L
s
.02381 .22699 m
.02756 .22699 L
s
.02381 .25731 m
.02756 .25731 L
s
.02381 .28764 m
.02756 .28764 L
s
.02381 .34829 m
.02756 .34829 L
s
.02381 .37861 m
.02756 .37861 L
s
.02381 .40894 m
.02756 .40894 L
s
.02381 .43926 m
.02756 .43926 L
s
.02381 .49991 m
.02756 .49991 L
s
.02381 .53024 m
.02756 .53024 L
s
.02381 .56056 m
.02756 .56056 L
s
.02381 .59089 m
.02756 .59089 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(%) show
75.000 12.813 moveto
(const) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .58209 m
.15986 .60332 L
.29592 .01472 L
.43197 .01472 L
.56803 .01472 L
.70408 .01472 L
.84014 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.022423 0.97619 0.302711 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112245 0.136054 -0.079624 0.487879 [
[.15986 .39575 -3 -9 ]
[.15986 .39575 3 0 ]
[.29592 .39575 -3 -9 ]
[.29592 .39575 3 0 ]
[.43197 .39575 -3 -9 ]
[.43197 .39575 3 0 ]
[.56803 .39575 -3 -9 ]
[.56803 .39575 3 0 ]
[.70408 .39575 -3 -9 ]
[.70408 .39575 3 0 ]
[.84014 .39575 -3 -9 ]
[.84014 .39575 3 0 ]
[.97619 .39575 -3 -9 ]
[.97619 .39575 3 0 ]
[1.025 .40825 0 -6.28125 ]
[1.025 .40825 10 6.28125 ]
[.01131 .01795 -18 -4.5 ]
[.01131 .01795 0 4.5 ]
[.01131 .11553 -18 -4.5 ]
[.01131 .11553 0 4.5 ]
[.01131 .2131 -18 -4.5 ]
[.01131 .2131 0 4.5 ]
[.01131 .31068 -18 -4.5 ]
[.01131 .31068 0 4.5 ]
[.01131 .50583 -18 -4.5 ]
[.01131 .50583 0 4.5 ]
[.01131 .60341 -18 -4.5 ]
[.01131 .60341 0 4.5 ]
[.02381 .64303 -26 0 ]
[.02381 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 .40825 m
.15986 .4145 L
s
[(2)] .15986 .39575 0 1 Mshowa
.29592 .40825 m
.29592 .4145 L
s
[(3)] .29592 .39575 0 1 Mshowa
.43197 .40825 m
.43197 .4145 L
s
[(4)] .43197 .39575 0 1 Mshowa
.56803 .40825 m
.56803 .4145 L
s
[(5)] .56803 .39575 0 1 Mshowa
.70408 .40825 m
.70408 .4145 L
s
[(6)] .70408 .39575 0 1 Mshowa
.84014 .40825 m
.84014 .4145 L
s
[(7)] .84014 .39575 0 1 Mshowa
.97619 .40825 m
.97619 .4145 L
s
[(8)] .97619 .39575 0 1 Mshowa
.125 Mabswid
.05102 .40825 m
.05102 .412 L
s
.07823 .40825 m
.07823 .412 L
s
.10544 .40825 m
.10544 .412 L
s
.13265 .40825 m
.13265 .412 L
s
.18707 .40825 m
.18707 .412 L
s
.21429 .40825 m
.21429 .412 L
s
.2415 .40825 m
.2415 .412 L
s
.26871 .40825 m
.26871 .412 L
s
.32313 .40825 m
.32313 .412 L
s
.35034 .40825 m
.35034 .412 L
s
.37755 .40825 m
.37755 .412 L
s
.40476 .40825 m
.40476 .412 L
s
.45918 .40825 m
.45918 .412 L
s
.48639 .40825 m
.48639 .412 L
s
.51361 .40825 m
.51361 .412 L
s
.54082 .40825 m
.54082 .412 L
s
.59524 .40825 m
.59524 .412 L
s
.62245 .40825 m
.62245 .412 L
s
.64966 .40825 m
.64966 .412 L
s
.67687 .40825 m
.67687 .412 L
s
.73129 .40825 m
.73129 .412 L
s
.7585 .40825 m
.7585 .412 L
s
.78571 .40825 m
.78571 .412 L
s
.81293 .40825 m
.81293 .412 L
s
.86735 .40825 m
.86735 .412 L
s
.89456 .40825 m
.89456 .412 L
s
.92177 .40825 m
.92177 .412 L
s
.94898 .40825 m
.94898 .412 L
s
.25 Mabswid
0 .40825 m
1 .40825 L
s
gsave
1.025 .40825 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.02381 .01795 m
.03006 .01795 L
s
[(0.2)] .01131 .01795 1 0 Mshowa
.02381 .11553 m
.03006 .11553 L
s
[(0.4)] .01131 .11553 1 0 Mshowa
.02381 .2131 m
.03006 .2131 L
s
[(0.6)] .01131 .2131 1 0 Mshowa
.02381 .31068 m
.03006 .31068 L
s
[(0.8)] .01131 .31068 1 0 Mshowa
.02381 .50583 m
.03006 .50583 L
s
[(1.2)] .01131 .50583 1 0 Mshowa
.02381 .60341 m
.03006 .60341 L
s
[(1.4)] .01131 .60341 1 0 Mshowa
.125 Mabswid
.02381 .04235 m
.02756 .04235 L
s
.02381 .06674 m
.02756 .06674 L
s
.02381 .09113 m
.02756 .09113 L
s
.02381 .13992 m
.02756 .13992 L
s
.02381 .16432 m
.02756 .16432 L
s
.02381 .18871 m
.02756 .18871 L
s
.02381 .2375 m
.02756 .2375 L
s
.02381 .26189 m
.02756 .26189 L
s
.02381 .28629 m
.02756 .28629 L
s
.02381 .33507 m
.02756 .33507 L
s
.02381 .35947 m
.02756 .35947 L
s
.02381 .38386 m
.02756 .38386 L
s
.02381 .43265 m
.02756 .43265 L
s
.02381 .45704 m
.02756 .45704 L
s
.02381 .48144 m
.02756 .48144 L
s
.02381 .53022 m
.02756 .53022 L
s
.02381 .55462 m
.02756 .55462 L
s
.02381 .57901 m
.02756 .57901 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dif) show
87.000 12.813 moveto
(fert) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .59904 m
.15986 .60332 L
.29592 .45213 L
.43197 .27647 L
.56803 .1578 L
.70408 .08711 L
.84014 .04242 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.330739 0.477324 0.611027 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.119048 -7.6068 308.642 [
[.38095 .09675 -3 -9 ]
[.38095 .09675 3 0 ]
[.61905 .09675 -3 -9 ]
[.61905 .09675 3 0 ]
[.85714 .09675 -3 -9 ]
[.85714 .09675 3 0 ]
[1.025 .10925 0 -6.28125 ]
[1.025 .10925 10 6.28125 ]
[.13036 .26357 -36 -4.5 ]
[.13036 .26357 0 4.5 ]
[.13036 .41789 -30 -4.5 ]
[.13036 .41789 0 4.5 ]
[.13036 .57221 -36 -4.5 ]
[.13036 .57221 0 4.5 ]
[.14286 .64303 -5 0 ]
[.14286 .64303 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.38095 .10925 m
.38095 .1155 L
s
[(4)] .38095 .09675 0 1 Mshowa
.61905 .10925 m
.61905 .1155 L
s
[(6)] .61905 .09675 0 1 Mshowa
.85714 .10925 m
.85714 .1155 L
s
[(8)] .85714 .09675 0 1 Mshowa
.125 Mabswid
.20238 .10925 m
.20238 .113 L
s
.2619 .10925 m
.2619 .113 L
s
.32143 .10925 m
.32143 .113 L
s
.44048 .10925 m
.44048 .113 L
s
.5 .10925 m
.5 .113 L
s
.55952 .10925 m
.55952 .113 L
s
.67857 .10925 m
.67857 .113 L
s
.7381 .10925 m
.7381 .113 L
s
.79762 .10925 m
.79762 .113 L
s
.08333 .10925 m
.08333 .113 L
s
.02381 .10925 m
.02381 .113 L
s
.91667 .10925 m
.91667 .113 L
s
.97619 .10925 m
.97619 .113 L
s
.25 Mabswid
0 .10925 m
1 .10925 L
s
gsave
1.025 .10925 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.14286 .26357 m
.14911 .26357 L
s
[(0.0255)] .13036 .26357 1 0 Mshowa
.14286 .41789 m
.14911 .41789 L
s
[(0.026)] .13036 .41789 1 0 Mshowa
.14286 .57221 m
.14911 .57221 L
s
[(0.0265)] .13036 .57221 1 0 Mshowa
.125 Mabswid
.14286 .14011 m
.14661 .14011 L
s
.14286 .17098 m
.14661 .17098 L
s
.14286 .20184 m
.14661 .20184 L
s
.14286 .23271 m
.14661 .23271 L
s
.14286 .29443 m
.14661 .29443 L
s
.14286 .3253 m
.14661 .3253 L
s
.14286 .35616 m
.14661 .35616 L
s
.14286 .38703 m
.14661 .38703 L
s
.14286 .44875 m
.14661 .44875 L
s
.14286 .47962 m
.14661 .47962 L
s
.14286 .51048 m
.14661 .51048 L
s
.14286 .54135 m
.14661 .54135 L
s
.14286 .07838 m
.14661 .07838 L
s
.14286 .04752 m
.14661 .04752 L
s
.14286 .01666 m
.14661 .01666 L
s
.14286 .60308 m
.14661 .60308 L
s
.25 Mabswid
.14286 0 m
.14286 .61803 L
s
gsave
.14286 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .01472 m
.14286 .26248 L
.2619 .36389 L
.38095 .4801 L
.5 .58192 L
.61905 .60332 L
.7381 .53886 L
.85714 .44821 L
.97619 .34913 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.330739 0.97619 0.611027 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112245 0.136054 -0.695227 2.38975 [
[.15986 .0092 -3 -9 ]
[.15986 .0092 3 0 ]
[.29592 .0092 -3 -9 ]
[.29592 .0092 3 0 ]
[.43197 .0092 -3 -9 ]
[.43197 .0092 3 0 ]
[.56803 .0092 -3 -9 ]
[.56803 .0092 3 0 ]
[.70408 .0092 -3 -9 ]
[.70408 .0092 3 0 ]
[.84014 .0092 -3 -9 ]
[.84014 .0092 3 0 ]
[.97619 .0092 -3 -9 ]
[.97619 .0092 3 0 ]
[1.025 .0217 0 -6.28125 ]
[1.025 .0217 10 6.28125 ]
[.01131 .14119 -24 -4.5 ]
[.01131 .14119 0 4.5 ]
[.01131 .26067 -18 -4.5 ]
[.01131 .26067 0 4.5 ]
[.01131 .38016 -24 -4.5 ]
[.01131 .38016 0 4.5 ]
[.01131 .49965 -18 -4.5 ]
[.01131 .49965 0 4.5 ]
[.02381 .64303 -14 0 ]
[.02381 .64303 14 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 .0217 m
.15986 .02795 L
s
[(2)] .15986 .0092 0 1 Mshowa
.29592 .0217 m
.29592 .02795 L
s
[(3)] .29592 .0092 0 1 Mshowa
.43197 .0217 m
.43197 .02795 L
s
[(4)] .43197 .0092 0 1 Mshowa
.56803 .0217 m
.56803 .02795 L
s
[(5)] .56803 .0092 0 1 Mshowa
.70408 .0217 m
.70408 .02795 L
s
[(6)] .70408 .0092 0 1 Mshowa
.84014 .0217 m
.84014 .02795 L
s
[(7)] .84014 .0092 0 1 Mshowa
.97619 .0217 m
.97619 .02795 L
s
[(8)] .97619 .0092 0 1 Mshowa
.125 Mabswid
.05102 .0217 m
.05102 .02545 L
s
.07823 .0217 m
.07823 .02545 L
s
.10544 .0217 m
.10544 .02545 L
s
.13265 .0217 m
.13265 .02545 L
s
.18707 .0217 m
.18707 .02545 L
s
.21429 .0217 m
.21429 .02545 L
s
.2415 .0217 m
.2415 .02545 L
s
.26871 .0217 m
.26871 .02545 L
s
.32313 .0217 m
.32313 .02545 L
s
.35034 .0217 m
.35034 .02545 L
s
.37755 .0217 m
.37755 .02545 L
s
.40476 .0217 m
.40476 .02545 L
s
.45918 .0217 m
.45918 .02545 L
s
.48639 .0217 m
.48639 .02545 L
s
.51361 .0217 m
.51361 .02545 L
s
.54082 .0217 m
.54082 .02545 L
s
.59524 .0217 m
.59524 .02545 L
s
.62245 .0217 m
.62245 .02545 L
s
.64966 .0217 m
.64966 .02545 L
s
.67687 .0217 m
.67687 .02545 L
s
.73129 .0217 m
.73129 .02545 L
s
.7585 .0217 m
.7585 .02545 L
s
.78571 .0217 m
.78571 .02545 L
s
.81293 .0217 m
.81293 .02545 L
s
.86735 .0217 m
.86735 .02545 L
s
.89456 .0217 m
.89456 .02545 L
s
.92177 .0217 m
.92177 .02545 L
s
.94898 .0217 m
.94898 .02545 L
s
.25 Mabswid
0 .0217 m
1 .0217 L
s
gsave
1.025 .0217 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.02381 .14119 m
.03006 .14119 L
s
[(0.35)] .01131 .14119 1 0 Mshowa
.02381 .26067 m
.03006 .26067 L
s
[(0.4)] .01131 .26067 1 0 Mshowa
.02381 .38016 m
.03006 .38016 L
s
[(0.45)] .01131 .38016 1 0 Mshowa
.02381 .49965 m
.03006 .49965 L
s
[(0.5)] .01131 .49965 1 0 Mshowa
.125 Mabswid
.02381 .0456 m
.02756 .0456 L
s
.02381 .06949 m
.02756 .06949 L
s
.02381 .09339 m
.02756 .09339 L
s
.02381 .11729 m
.02756 .11729 L
s
.02381 .16508 m
.02756 .16508 L
s
.02381 .18898 m
.02756 .18898 L
s
.02381 .21288 m
.02756 .21288 L
s
.02381 .23678 m
.02756 .23678 L
s
.02381 .28457 m
.02756 .28457 L
s
.02381 .30847 m
.02756 .30847 L
s
.02381 .33237 m
.02756 .33237 L
s
.02381 .35626 m
.02756 .35626 L
s
.02381 .40406 m
.02756 .40406 L
s
.02381 .42796 m
.02756 .42796 L
s
.02381 .45185 m
.02756 .45185 L
s
.02381 .47575 m
.02756 .47575 L
s
.02381 .52355 m
.02756 .52355 L
s
.02381 .54745 m
.02756 .54745 L
s
.02381 .57134 m
.02756 .57134 L
s
.02381 .59524 m
.02756 .59524 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(gini) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .54839 m
.15986 .55628 L
.29592 .60332 L
.43197 .58359 L
.56803 .47196 L
.70408 .31353 L
.84014 .16201 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.639056 0.477324 0.919343 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112245 0.136054 -1.45315 1.23649 [
[.15986 -0.22916 -3 -9 ]
[.15986 -0.22916 3 0 ]
[.29592 -0.22916 -3 -9 ]
[.29592 -0.22916 3 0 ]
[.43197 -0.22916 -3 -9 ]
[.43197 -0.22916 3 0 ]
[.56803 -0.22916 -3 -9 ]
[.56803 -0.22916 3 0 ]
[.70408 -0.22916 -3 -9 ]
[.70408 -0.22916 3 0 ]
[.84014 -0.22916 -3 -9 ]
[.84014 -0.22916 3 0 ]
[.97619 -0.22916 -3 -9 ]
[.97619 -0.22916 3 0 ]
[1.025 -0.21666 0 -6.28125 ]
[1.025 -0.21666 10 6.28125 ]
[.01131 .03064 -18 -4.5 ]
[.01131 .03064 0 4.5 ]
[.01131 .15429 -18 -4.5 ]
[.01131 .15429 0 4.5 ]
[.01131 .27794 -18 -4.5 ]
[.01131 .27794 0 4.5 ]
[.01131 .40159 -18 -4.5 ]
[.01131 .40159 0 4.5 ]
[.01131 .52523 -18 -4.5 ]
[.01131 .52523 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12.5625 ]
[ 0 -0.21666 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 -0.21666 m
.15986 -0.21041 L
s
[(2)] .15986 -0.22916 0 1 Mshowa
.29592 -0.21666 m
.29592 -0.21041 L
s
[(3)] .29592 -0.22916 0 1 Mshowa
.43197 -0.21666 m
.43197 -0.21041 L
s
[(4)] .43197 -0.22916 0 1 Mshowa
.56803 -0.21666 m
.56803 -0.21041 L
s
[(5)] .56803 -0.22916 0 1 Mshowa
.70408 -0.21666 m
.70408 -0.21041 L
s
[(6)] .70408 -0.22916 0 1 Mshowa
.84014 -0.21666 m
.84014 -0.21041 L
s
[(7)] .84014 -0.22916 0 1 Mshowa
.97619 -0.21666 m
.97619 -0.21041 L
s
[(8)] .97619 -0.22916 0 1 Mshowa
.125 Mabswid
.05102 -0.21666 m
.05102 -0.21291 L
s
.07823 -0.21666 m
.07823 -0.21291 L
s
.10544 -0.21666 m
.10544 -0.21291 L
s
.13265 -0.21666 m
.13265 -0.21291 L
s
.18707 -0.21666 m
.18707 -0.21291 L
s
.21429 -0.21666 m
.21429 -0.21291 L
s
.2415 -0.21666 m
.2415 -0.21291 L
s
.26871 -0.21666 m
.26871 -0.21291 L
s
.32313 -0.21666 m
.32313 -0.21291 L
s
.35034 -0.21666 m
.35034 -0.21291 L
s
.37755 -0.21666 m
.37755 -0.21291 L
s
.40476 -0.21666 m
.40476 -0.21291 L
s
.45918 -0.21666 m
.45918 -0.21291 L
s
.48639 -0.21666 m
.48639 -0.21291 L
s
.51361 -0.21666 m
.51361 -0.21291 L
s
.54082 -0.21666 m
.54082 -0.21291 L
s
.59524 -0.21666 m
.59524 -0.21291 L
s
.62245 -0.21666 m
.62245 -0.21291 L
s
.64966 -0.21666 m
.64966 -0.21291 L
s
.67687 -0.21666 m
.67687 -0.21291 L
s
.73129 -0.21666 m
.73129 -0.21291 L
s
.7585 -0.21666 m
.7585 -0.21291 L
s
.78571 -0.21666 m
.78571 -0.21291 L
s
.81293 -0.21666 m
.81293 -0.21291 L
s
.86735 -0.21666 m
.86735 -0.21291 L
s
.89456 -0.21666 m
.89456 -0.21291 L
s
.92177 -0.21666 m
.92177 -0.21291 L
s
.94898 -0.21666 m
.94898 -0.21291 L
s
.25 Mabswid
0 -0.21666 m
1 -0.21666 L
s
gsave
1.025 -0.21666 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.02381 .03064 m
.03006 .03064 L
s
[(1.2)] .01131 .03064 1 0 Mshowa
.02381 .15429 m
.03006 .15429 L
s
[(1.3)] .01131 .15429 1 0 Mshowa
.02381 .27794 m
.03006 .27794 L
s
[(1.4)] .01131 .27794 1 0 Mshowa
.02381 .40159 m
.03006 .40159 L
s
[(1.5)] .01131 .40159 1 0 Mshowa
.02381 .52523 m
.03006 .52523 L
s
[(1.6)] .01131 .52523 1 0 Mshowa
.125 Mabswid
.02381 .05537 m
.02756 .05537 L
s
.02381 .0801 m
.02756 .0801 L
s
.02381 .10483 m
.02756 .10483 L
s
.02381 .12956 m
.02756 .12956 L
s
.02381 .17902 m
.02756 .17902 L
s
.02381 .20375 m
.02756 .20375 L
s
.02381 .22848 m
.02756 .22848 L
s
.02381 .25321 m
.02756 .25321 L
s
.02381 .30267 m
.02756 .30267 L
s
.02381 .3274 m
.02756 .3274 L
s
.02381 .35213 m
.02756 .35213 L
s
.02381 .37686 m
.02756 .37686 L
s
.02381 .42632 m
.02756 .42632 L
s
.02381 .45105 m
.02756 .45105 L
s
.02381 .47578 m
.02756 .47578 L
s
.02381 .5005 m
.02756 .5005 L
s
.02381 .00591 m
.02756 .00591 L
s
.02381 .54996 m
.02756 .54996 L
s
.02381 .57469 m
.02756 .57469 L
s
.02381 .59942 m
.02756 .59942 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(g) show
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .11617 m
.15986 .01472 L
.29592 .0179 L
.43197 .14124 L
.56803 .29819 L
.70408 .43504 L
.84014 .52973 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.639056 0.97619 0.919343 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112245 0.136054 -1.50401 1.42904 [
[.15986 -0.08746 -3 -9 ]
[.15986 -0.08746 3 0 ]
[.29592 -0.08746 -3 -9 ]
[.29592 -0.08746 3 0 ]
[.43197 -0.08746 -3 -9 ]
[.43197 -0.08746 3 0 ]
[.56803 -0.08746 -3 -9 ]
[.56803 -0.08746 3 0 ]
[.70408 -0.08746 -3 -9 ]
[.70408 -0.08746 3 0 ]
[.84014 -0.08746 -3 -9 ]
[.84014 -0.08746 3 0 ]
[.97619 -0.08746 -3 -9 ]
[.97619 -0.08746 3 0 ]
[1.025 -0.07496 0 -6.28125 ]
[1.025 -0.07496 10 6.28125 ]
[.01131 .06794 -18 -4.5 ]
[.01131 .06794 0 4.5 ]
[.01131 .21085 -18 -4.5 ]
[.01131 .21085 0 4.5 ]
[.01131 .35375 -18 -4.5 ]
[.01131 .35375 0 4.5 ]
[.01131 .49666 -18 -4.5 ]
[.01131 .49666 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12.5625 ]
[ 0 -0.07496 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 -0.07496 m
.15986 -0.06871 L
s
[(2)] .15986 -0.08746 0 1 Mshowa
.29592 -0.07496 m
.29592 -0.06871 L
s
[(3)] .29592 -0.08746 0 1 Mshowa
.43197 -0.07496 m
.43197 -0.06871 L
s
[(4)] .43197 -0.08746 0 1 Mshowa
.56803 -0.07496 m
.56803 -0.06871 L
s
[(5)] .56803 -0.08746 0 1 Mshowa
.70408 -0.07496 m
.70408 -0.06871 L
s
[(6)] .70408 -0.08746 0 1 Mshowa
.84014 -0.07496 m
.84014 -0.06871 L
s
[(7)] .84014 -0.08746 0 1 Mshowa
.97619 -0.07496 m
.97619 -0.06871 L
s
[(8)] .97619 -0.08746 0 1 Mshowa
.125 Mabswid
.05102 -0.07496 m
.05102 -0.07121 L
s
.07823 -0.07496 m
.07823 -0.07121 L
s
.10544 -0.07496 m
.10544 -0.07121 L
s
.13265 -0.07496 m
.13265 -0.07121 L
s
.18707 -0.07496 m
.18707 -0.07121 L
s
.21429 -0.07496 m
.21429 -0.07121 L
s
.2415 -0.07496 m
.2415 -0.07121 L
s
.26871 -0.07496 m
.26871 -0.07121 L
s
.32313 -0.07496 m
.32313 -0.07121 L
s
.35034 -0.07496 m
.35034 -0.07121 L
s
.37755 -0.07496 m
.37755 -0.07121 L
s
.40476 -0.07496 m
.40476 -0.07121 L
s
.45918 -0.07496 m
.45918 -0.07121 L
s
.48639 -0.07496 m
.48639 -0.07121 L
s
.51361 -0.07496 m
.51361 -0.07121 L
s
.54082 -0.07496 m
.54082 -0.07121 L
s
.59524 -0.07496 m
.59524 -0.07121 L
s
.62245 -0.07496 m
.62245 -0.07121 L
s
.64966 -0.07496 m
.64966 -0.07121 L
s
.67687 -0.07496 m
.67687 -0.07121 L
s
.73129 -0.07496 m
.73129 -0.07121 L
s
.7585 -0.07496 m
.7585 -0.07121 L
s
.78571 -0.07496 m
.78571 -0.07121 L
s
.81293 -0.07496 m
.81293 -0.07121 L
s
.86735 -0.07496 m
.86735 -0.07121 L
s
.89456 -0.07496 m
.89456 -0.07121 L
s
.92177 -0.07496 m
.92177 -0.07121 L
s
.94898 -0.07496 m
.94898 -0.07121 L
s
.25 Mabswid
0 -0.07496 m
1 -0.07496 L
s
gsave
1.025 -0.07496 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.02381 .06794 m
.03006 .06794 L
s
[(1.1)] .01131 .06794 1 0 Mshowa
.02381 .21085 m
.03006 .21085 L
s
[(1.2)] .01131 .21085 1 0 Mshowa
.02381 .35375 m
.03006 .35375 L
s
[(1.3)] .01131 .35375 1 0 Mshowa
.02381 .49666 m
.03006 .49666 L
s
[(1.4)] .01131 .49666 1 0 Mshowa
.125 Mabswid
.02381 .09652 m
.02756 .09652 L
s
.02381 .1251 m
.02756 .1251 L
s
.02381 .15369 m
.02756 .15369 L
s
.02381 .18227 m
.02756 .18227 L
s
.02381 .23943 m
.02756 .23943 L
s
.02381 .26801 m
.02756 .26801 L
s
.02381 .29659 m
.02756 .29659 L
s
.02381 .32517 m
.02756 .32517 L
s
.02381 .38233 m
.02756 .38233 L
s
.02381 .41091 m
.02756 .41091 L
s
.02381 .43949 m
.02756 .43949 L
s
.02381 .46808 m
.02756 .46808 L
s
.02381 .03936 m
.02756 .03936 L
s
.02381 .01078 m
.02756 .01078 L
s
.02381 .52524 m
.02756 .52524 L
s
.02381 .55382 m
.02756 .55382 L
s
.02381 .5824 m
.02756 .5824 L
s
.02381 .61098 m
.02756 .61098 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .47131 m
.15986 .60332 L
.29592 .5774 L
.43197 .40168 L
.56803 .23361 L
.70408 .12185 L
.84014 .05752 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 271.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00013a000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol002]oo`@000Yo
o`8000]oo`<000Uoo`8000Uoo`<000aoo`03001oogoo00Qoo`800:Moo`00:goo00<007ooOol02Woo
00@007ooOol000]oo`03001oogoo00Moo`04001oogoo0008Ool01000Oomoo`002goo00<007ooOol0
1goo00@007ooOol00:Ioo`00;7oo00<007ooOol02goo00<007ooOol01goo1@002goo00<007ooOol0
1Woo00@007ooOol000]oo`03001oogoo00Moo`04001oogoo002VOol002eoo`03001oogoo00]oo`03
001oogoo00Ioo`04001oogoo000:Ool20009Ool3000=Ool00`00Oomoo`07Ool2002WOol002]oo`04
001oogoo0009Ool01000Oomoo`002Goo00<007oo00002Woo00<007ooOol02Goo00<007ooOol02Goo
00@007ooOol000Qoo`04001oogoo000TOol20004Ool20003Ool40003Ool00`00Oomoo`1]Ool002ao
o`8000]oo`8000]oo`8000Yoo`<000Uoo`<000Uoo`@000Uoo`8002Aoo`04001oogoo0008Ool00`00
Oomoo`04Ool00`00Oomoo`1DOol3000FOol009eoo`04001oogoo0009Ool00`00Oomoo`03Ool00`00
Oomoo`1@Ool4000IOol0085oo`8001Yoo`04001oogoo000:Ool00`00Oomoo`02Ool00`00Oomoo`1<
Ool4000MOol0025oo`03001oogoo05aoo`04001oogoo000IOol01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo04Qoo`@0025oo`007gooG@0017oo00<007ooOol06goo0P002Woo0P0017oo00<0
07ooOol0AGoo0`009Goo000QOol00`00Oomoo`0FOol00`00Oomoo`12Ool5000/Ool00`00Oomoo`11
Ool4000XOol0025oo`03001oogoo01Ioo`03001oogoo04=oo`03001oogoo02eoo`03001oogoo03io
o`<002aoo`008Goo00<007ooOol05Goo00<007ooOol0M7oo00<007ooOol0?7oo0P00;goo000QOol0
0`00Oomoo`0EOol00`00Oomoo`1ROol20004Ool20005Ool30002Ool00`00Oomoo`0jOol2000aOol0
025oo`03001oogoo01Eoo`03001oogoo065oo`04001oogoo000;Ool01@00Oomoogoo0000>Woo0P00
<goo000QOol00`00Oomoo`0EOol00`00Oomoo`1QOol01000Oomoo`0027oo1@000Woo00<007ooOol0
=goo00<007ooOol0<goo000QOol00`00Oomoo`0DOol00`00Oomoo`1ROol01000Oomoo`0027oo00@0
07ooOol000=oo`03001oogoo03Eoo`8003Ioo`008Goo00<007ooOol057oo00<007ooOol0HWoo00@0
07ooOol000Uoo`03001oo`0000=oo`03001oogoo03=oo`8003Qoo`008Goo00<007ooOol057oo00<0
07ooOol0Hgoo0P002goo0P000goo00<007ooOol0<Goo0P00>Woo000QOol00`00Oomoo`0DOol00`00
Oomoo`1eOol00`00Oomoo`0`Ool00`00Oomoo`0jOol0025oo`03001oogoo01=oo`03001oogoo07Io
o`03001oogoo02moo`03001oogoo03]oo`002Woo0P0017oo0P0017oo0P0017oo0P000goo00<007oo
Ool04goo00<007ooOol0MWoo00<007ooOol0;Woo00<007ooOol0?7oo0009Ool01000Oomoo`0027oo
00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`0COol00`00Oomoo`1TOol20004Ool20003
Ool30004Ool00`00Oomoo`0/Ool2000oOol000Uoo`04001oogoo0008Ool01000Oomoo`001Goo00<0
07ooOol00P0057oo00<007ooOol0Hgoo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`0[
Ool00`00Oomoo`0oOol000Uoo`04001oogoo0008Ool01000Oomoo`000goo0P000goo00<007ooOol0
4Woo00<007ooOol0I7oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`0ZOol00`00Oomo
o`10Ool000Uoo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol04Woo
00<007ooOol0I7oo00@007ooOol000Qoo`<000Aoo`03001oogoo02Uoo`03001oogoo045oo`002Woo
0P002Woo0P0017oo0`000Woo00<007ooOol04Woo00<007ooOol0I7oo00@007ooOol000Uoo`03001o
ogoo00=oo`03001oogoo02Qoo`03001oogoo049oo`008Goo00<007ooOol04Woo00<007ooOol0IGoo
0P002Woo0`000goo00<007ooOol09Woo0P00AGoo000QOol00`00Oomoo`0AOol00`00Oomoo`1hOol0
0`00Oomoo`0UOol00`00Oomoo`15Ool0025oo`03001oogoo015oo`03001oogoo07Qoo`03001oogoo
02Aoo`03001oogoo04Ioo`008Goo00<007ooOol04Goo00<007ooOol0N7oo00<007ooOol08goo00<0
07ooOol0Agoo000QOol00`00Oomoo`0AOol00`00Oomoo`1VOol20004Ool20004Ool20004Ool00`00
Oomoo`0ROol00`00Oomoo`18Ool0025oo`03001oogoo011oo`03001oogoo06Ioo`04001oogoo0008
Ool01000Oomoo`000goo00<007ooOol08Goo00<007ooOol0BGoo000QOol00`00Oomoo`0@Ool00`00
Oomoo`1VOol01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Moo`@000Yoo`8000Yoo`03
001oo`00008000Uoo`8000Uoo`<000aoo`03001oogoo00Uoo`8001Ioo`008Goo00<007ooOol047oo
00<007ooOol0IWoo00@007ooOol000Uoo`8000Aoo`03001oogoo00Moo`03001oogoo00Yoo`04001o
ogoo0008Ool01@00Oomoogoo00002Goo00@007ooOol000Qoo`04001oogoo000;Ool00`00Oomoo`08
Ool01000Oomoo`005Goo000@Ool20004Ool20003Ool500000goo001oo`0AOol00`00Oomoo`1VOol0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Qoo`03001oogoo00]oo`03001oogoo00Io
o`03001oo`0000@000]oo`03001oogoo00Ioo`04001oogoo000;Ool00`00Oomoo`08Ool01000Oomo
o`005Goo000?Ool01000Oomoo`002Woo00D007ooOomoo`00015oo`03001oogoo06Qoo`8000Yoo`80
00Aoo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomo
o`08Ool20009Ool3000=Ool00`00Oomoo`08Ool2000FOol000moo`04001oogoo000:Ool01000Oomo
ogoo0P0047oo00<007ooOol0NWoo00<007ooOol01goo00@007ooOol000Uoo`04001oogoo0005Ool0
0`00Oomoo`02Ool00`00Ool0000:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool01000Oomoo`002Goo
00@007ooOol001Eoo`003goo00@007ooOol000Yoo`05001oogooOol0000AOol00`00Oomoo`1jOol0
0`00Oomoo`08Ool2000;Ool20005Ool00`00Oomoo`04Ool2000:Ool30009Ool30009Ool4000:Ool2
000FOol000moo`04001oogoo000:Ool01@00Oomoogoo00004Goo00<007ooOol0NWoo00<007ooOol0
77oo00<007ooOol0CWoo000@Ool2000:Ool20003Ool00`00Oomoo`0?Ool00`00Oomoo`1jOol00`00
Oomoo`0KOol00`00Oomoo`1?Ool0025oo`03001oogoo00ioo`03001oogoo07]oo`03001oogoo01Yo
o`03001oogoo049oo`8000aoo`008Goo00<007ooOol03Woo00<007ooOol0N7ooG`001Goo00@007oo
Ool000]oo`008Goo00<007ooOol03Woo00<007ooOol0Ngoo00<007oo00000Woo00<007oo00000Woo
00<007oo00000Woo00<007oo00000Woo00L007ooOol007oo001oo`0200001goo001oogoo001oo`00
009oo`03001oo`00009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<007oo00000Woo00<0
07oo00000Woo00H007ooOol007oo0002Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00002
Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool0025oo`03001oogoo00ioo`03001oogoo07]oo`03001o
ogoo01Qoo`03001oogoo049oo`D000]oo`008Goo00<007ooOol03Goo00<007ooOol0O7oo00<007oo
Ool05goo00<007ooOol0A7oo00<007ooOol037oo000QOol00`00Oomoo`0=Ool00`00Oomoo`1lOol0
0`00Oomoo`0FOol00`00Oomoo`1DOol0025oo`03001oogoo00eoo`03001oogoo07aoo`03001oogoo
01Eoo`03001oogoo05Eoo`008Goo00<007ooOol03Goo00<007ooOol0O7oo00<007ooOol057oo00<0
07ooOol0EWoo000:Ool20004Ool20003Ool50002Ool20003Ool00`00Oomoo`0<Ool00`00Oomoo`1Z
Ool50002Ool20003Ool40003Ool00`00Oomoo`0COol00`00Oomoo`1GOol000Uoo`04001oogoo000:
Ool01@00Oomoogoo00000Woo00@007ooOol000ioo`03001oogoo06aoo`03001oogoo00Moo`03001o
ogoo00Aoo`03001oogoo01=oo`03001oogoo05Moo`002Goo00@007ooOol000Yoo`03001oogoo00Ao
o`03001oogoo008000eoo`03001oogoo06aoo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo
019oo`03001oogoo05Qoo`002Goo00@007ooOol000Yoo`03001oogoo009oo`8000=oo`03001oogoo
00aoo`03001oogoo06aoo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo015oo`03001oogoo
05Uoo`002Goo00@007ooOol000Yoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00]oo`03
001oogoo06eoo`03001oogoo00Moo`04001oogoo0003Ool00`00Oomoo`0@Ool00`00Oomoo`1JOol0
00Yoo`8000Yoo`8000Aoo`<0009oo`03001oogoo00]oo`03001oogoo06aoo`8000Yoo`8000Aoo`03
001oogoo00moo`03001oogoo05]oo`008Goo00<007ooOol02goo00<007ooOol0OWoo00<007ooOol0
3Woo00<007ooOol0G7oo000QOol00`00Oomoo`0;Ool00`00Oomoo`1nOol00`00Oomoo`0=Ool00`00
Oomoo`1MOol0025oo`03001oogoo00Yoo`03001oogoo07moo`03001oogoo00aoo`03001oogoo05io
o`008Goo00<007ooOol02Woo00<007ooOol0Ogoo00<007ooOol037oo00<007ooOol0GWoo000QOol0
0`00Oomoo`0:Ool00`00Oomoo`1/Ool50002Ool20005Ool30002Ool00`00Oomoo`0;Ool00`00Oomo
o`1OOol0025oo`03001oogoo00Yoo`03001oogoo06ioo`03001oogoo00Yoo`04001oogooOol60007
Ool00`00Oomoo`1POol0025oo`<000Uoo`03001oogoo06moo`03001oogoo00Moo`D0009oo`03001o
ogoo00=oo`L006=oo`008Goo00<007ooOol01P000goo00<007ooOol0Kgoo00<007ooOol01goo00@0
07ooOol000=oo`03001oogoo06eoo`008Goo00<007ooOol01Woo1000LGoo00<007ooOol027oo00<0
07oo0000Lgoo000QOol00`00Oomoo`1jOol2000;Ool2001cOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00VWoo10000Woo0`000Woo100027oo10000goo0`000Woo10000goo0P00FWoo002I
Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol0
17oo00<007ooOol00Woo00@007ooOol005Uoo`003goo00<007ooOol027oo0`000goo0P000Woo0P00
0Woo0P0000Aoo`00000000Aoo`8006Eoo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`09
Ool00`00Oomoo`02Ool40003Ool00`00Oomoo`02Ool00`00Oomoo`1JOol000ioo`03001oo`0000Qo
o`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol0009oo`03001oogoo
06=oo`<000=oo`8000=oo`@000Qoo`@000=oo`8000=oo`@00003Ool0000000<005Uoo`003Goo0`00
2Goo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool30003Ool00`00Oomoo`1XOol0
0`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`0>Ool00`00Oomoo`1JOol000ioo`<000Uoo`<0
00=oo`80009oo`@000=oo`@00003Ool0000000<006Ioo`8000Aoo`03001oogoo00=oo`8000Yoo`80
06]oo`003Goo00<007oo00008Goo00<007ooOol0k7oo000>Ool00`00Oomoo`3oOol@Ool00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo002jOol4000:Ool2000<Ool30008Ool2000:Ool3000;Ool00`00
Oomoo`09Ool2000GOol00;Yoo`03001oogoo00Yoo`04001oogoo000<Ool00`00Oomoo`06Ool01000
Oomoo`002Goo00@007ooOol000Yoo`03001oogoo00Qoo`04001oogoo000FOol00;]oo`03001oogoo
00]oo`03001oogoo00Qoo`D000Yoo`03001oogoo00Moo`04001oogoo000:Ool00`00Oomoo`08Ool0
1000Oomoo`005Woo000/Ool00`00Oomoo`2=Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool01000Oomo
o`002Goo0P002Woo0`0037oo00<007ooOol027oo0P005goo000POol00`00Oomoo`09Ool00`00Oomo
o`0COol3000AOol3000EOol2001:Ool01000Oomoo`002Goo00@007ooOol000Yoo`03001oo`0000Uo
o`03001oogoo00Yoo`03001oogoo00Qoo`04001oogoo0009Ool01000Oomoo`005Woo000POol00`00
Oomoo`09Ool00`00Oomoo`0DOol00`00Oomoo`0@Ool01000Oomoo`004goo00@007ooOol004Yoo`80
00]oo`8000aoo`8000Uoo`<000Yoo`<000Qoo`@000Yoo`8001Moo`008Goo00<007ooOol027oo00<0
07ooOol04Goo1@004Goo00@007ooOol001=oo`04001oogoo002_Ool0025oo`03001oogoo00Qoo`03
001oogoo015oo`04001oogoo000BOol3000EOol20010Ool00`00Oomoo`1]Ool0029oo`03001oogoo
00Moo`03001oogoo019oo`03001oo`0001=oo`03001oogoo01=oo`04001oogoo000oOol00`00Oomo
o`1NOol2000=Ool0029oo`03001oogoo00Moo`03001oogoo01=oo`8001=oo`<001Aoo`8003eooeh0
00Eoo`04001oogoo000<Ool002=oo`03001oogoo00Ioo`03001oogoo085oo`03001oo`00009oo`03
001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03
001oo`00009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<007oo00000Woo00<007oo0000
0Woo00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo00<007oo0000
0Woo00<007ooOol00`001goo00<007ooOol03Goo000SOol00`00Oomoo`06Ool00`00Oomoo`21Ool0
0`00Oomoo`1COol00`00Oomoo`06Ool5000<Ool002Aoo`03001oogoo00Eoo`03001oogoo05=oo`80
02aoo`03001oogoo059oo`03001oogoo00Qoo`03001oogoo00eoo`007WooG`0017oo00@007ooOol0
02]oo`03001oogoo055oo`03001oogoo01Uoo`0087oo00<007ooOol00Woo0P001Goo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol017oo00<007ooOol0
;7oo00<007ooOol0D7oo00<007ooOol06Woo000UOol00`00Oomoo`04Ool00`00Oomoo`1AOol5000[
Ool00`00Oomoo`1?Ool00`00Oomoo`0KOol002Ioo`03001oogoo00=oo`03001oogoo059oo`03001o
ogoo02aoo`03001oogoo04ioo`03001oogoo01aoo`009Woo00<007ooOol00goo00<007ooOol0PGoo
00<007ooOol0CGoo00<007ooOol07Goo000WOol00`00Oomoo`02Ool00`00Oomoo`1ZOol20004Ool2
0004Ool20004Ool20003Ool00`00Oomoo`1<Ool00`00Oomoo`0NOol002Moo`03001oogoo009oo`03
001oogoo06Uoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo04]o
o`03001oogoo01moo`00:7oo00D007ooOomoo`0006]oo`04001oogoo000:Ool00`00Oomoo`04Ool0
1000Oomoo`00C7oo00<007ooOol087oo000XOol01@00Oomoogoo0000Jgoo00@007ooOol000]oo`04
001oogooOol20003Ool00`00Oomoo`19Ool00`00Oomoo`0QOol002Uoo`04001oogoo001[Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo04Qoo`03001oogoo029oo`00
:Goo00@007ooOol006aoo`8000Yoo`8000Aoo`<0009oo`03001oogoo04Moo`03001oogoo02=oo`00
:Woo00<007oo0000Pgoo00<007ooOol0AWoo00<007ooOol097oo000ZOol00`00Ool00023Ool00`00
Oomoo`15Ool00`00Oomoo`0UOol000Qoo`8000Aoo`8000Aoo`8000=oo`@000=oo`8000Aoo`8000=o
o`8008=oo`03001oogoo04Eoo`03001oogoo02Eoo`001goo00@007ooOol000Qoo`04001oogoo0002
Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol0009oo`8008=oo`03001oogoo04Aoo`03
001oogoo02Ioo`001goo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomo
o`03Ool01@00Oomoogoo0000Pgoo00<007ooOol0@goo00<007ooOol09goo0007Ool01000Oomoo`00
27oo00@007ooOol000Aoo`03001oogoo009oo`8000Aoo`8000Aoo`80089oo`03001oogoo049oo`03
001oogoo02Qoo`001goo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000goo00<007oo
Ool00goo00<007ooOol00goo00@007oo000006moo`8000Aoo`8000Eoo`<00003Ool007oo049oo`03
001oogoo02Uoo`0027oo0P002Woo0P0017oo0P0017oo0`000goo0`000goo00D007ooOomoo`0006eo
o`04001oogoo000;Ool01000Oomoo`00@Woo00<007ooOol0:Woo000/Ool00`00Oomoo`02Ool00`00
Oomoo`1ZOol01000Oomoo`0027oo1@0000=oo`00Ool0@7oo00<007ooOol0:goo000/Ool00`00Oomo
o`03Ool00`00Oomoo`1YOol01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo03moo`03001o
ogoo02]oo`00;7oo00<007ooOol017oo00<007ooOol0J7oo00@007ooOol000Uoo`03001oo`00009o
o`03001oogoo03ioo`03001oogoo02aoo`00;7oo00<007ooOol01Goo0P00JGoo0P002goo0P000Woo
00<007ooOol0?Goo00<007ooOol0;Goo000/Ool00`00Oomoo`07Ool00`00Oomoo`11Ool00`00Oomo
o`0cOol00`00Oomoo`0lOol00`00Oomoo`0^Ool002aoo`03001oogoo00Qoo`03001oogoo03moo`03
001oogoo03Aoo`03001oogoo03]oo`03001oogoo02moo`00;7oo00<007ooOol02Goo00<007ooOol0
?7oo0P00=goo00<007ooOol0>Woo00<007ooOol0<7oo000/Ool00`00Oomoo`0:Ool00`00Oomoo`0j
Ool00`00Oomoo`0gOol00`00Oomoo`0iOol00`00Oomoo`0aOol000ioo`8000Aoo`8000Aoo`8000=o
o`@0009oo`<000Aoo`03001oogoo00]oo`03001oogoo03Qoo`03001oogoo03Qoo`03001oogoo03Uo
o`03001oogoo035oo`003Goo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`03Ool01000
Oomoo`000goo00<007ooOol037oo00<007ooOol0=Woo00<007ooOol08Woo0P0017oo0P001Goo0`00
0Woo0P000goo00<007ooOol0>7oo00<007ooOol0<Woo000=Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`0=Ool00`00Oomoo`0dOol00`00Oomo
o`0ROol01000Oomoo`002goo00@007ooOol0009oo`04001oogoo000iOol00`00Oomoo`0cOol000eo
o`04001oogoo0008Ool01000Oomoo`0017oo00@007ooOomoo`<000Aoo`03001oogoo00ioo`03001o
ogoo035oo`8002Eoo`04001oogoo0008Ool50004Ool01000Oomoo`00>7oo00<007ooOol0=7oo000=
Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`03Ool00`00Oomo
o`0?Ool00`00Oomoo`0_Ool00`00Oomoo`0UOol01000Oomoo`0027oo00@007ooOol000=oo`8000=o
o`03001oogoo03Eoo`03001oogoo03Eoo`003Woo0P002Woo0P0017oo0P0017oo0`000goo00<007oo
Ool047oo00<007ooOol0;Goo00<007ooOol09Woo00@007ooOol000Uoo`03001oo`0000=oo`03001o
ogoo009oo`03001oogoo03Aoo`03001oogoo03Ioo`00;7oo00<007ooOol04Goo00<007ooOol0:goo
00<007ooOol0:7oo0P002goo0P000goo0`000Woo00<007ooOol0<goo00<007ooOol0=goo000/Ool0
0`00Oomoo`0BOol00`00Oomoo`0XOol20012Ool00`00Oomoo`0bOol00`00Oomoo`0hOol002aoo`03
001oogoo01=oo`03001oogoo02Ioo`03001oogoo049oo`03001oogoo039oo`03001oogoo03Qoo`00
;7oo00<007ooOol057oo00<007ooOol097oo00<007ooOol0@goo00<007ooOol0<Goo00<007ooOol0
>Goo000/Ool00`00Oomoo`0EOol00`00Oomoo`0QOol20016Ool00`00Oomoo`0`Ool00`00Oomoo`0j
Ool002aoo`03001oogoo01Ioo`03001oogoo01moo`03001oogoo04Ioo`03001oogoo02moo`03001o
ogoo03]oo`00;7oo00<007ooOol05goo00<007ooOol07Goo00<007ooOol0=Woo0P0017oo0P0017oo
0P000goo00<007ooOol0;Woo00<007ooOol0?7oo000/Ool00`00Oomoo`0HOol2000KOol2000hOol0
1000Oomoo`0027oo00@007ooOol0009oo`03001oogoo02eoo`03001oogoo03eoo`00;7oo00<007oo
Ool06Woo00<007ooOol05goo00<007ooOol0>7oo00@007ooOol000]oo`04001oogoo000^Ool00`00
Oomoo`0nOol000Qoo`8000Aoo`8000Aoo`8000=oo`@0009oo`<000Aoo`8000Aoo`03001oogoo01]o
o`03001oogoo01Aoo`8003]oo`04001oogoo0009Ool20003Ool00`00Oomoo`0[Ool00`00Oomoo`0o
Ool000Moo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`04
001oogoo0003Ool00`00Oomoo`0LOol00`00Oomoo`0AOol2000mOol01000Oomoo`002Goo00<007oo
Ool00Woo00<007ooOol0:Woo00<007ooOol0@7oo0007Ool01000Oomoo`0027oo00@007ooOol000=o
o`03001oogoo009oo`04001oogoo0005Ool01@00Oomoogoo00007goo00<007ooOol03Woo0P00@7oo
0P002Woo0`000Woo00<007ooOol0:7oo0P00@goo0007Ool01000Oomoo`0027oo00@007ooOol000Ao
o`04001oogooOol30004Ool20004Ool00`00Oomoo`0NOol3000;Ool2001COol6000TOol00`00Oomo
o`13Ool000Moo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00=o
o`03001oogoo00=oo`03001oogoo025oo`H000=oo`8005Eoo`03001oogoo00=oo`P001]oo`03001o
ogoo04Aoo`0027oo0P002Woo0P0017oo0P0017oo0`000goo0`000goo00<007ooOol09goo0`00Egoo
00<007ooOol02goo0`005goo00<007ooOol0AGoo000/Ool00`00Oomoo`21Ool00`00Oomoo`0>Ool4
000BOol00`00Oomoo`16Ool00;1oo`03001oogoo019oo`<000Qoo`L004Uoo`00/7oo00<007ooOol0
5Goo2000D7oo002`Ool00`00Oomoo`1]Ool00;1oo`03001oogoo06eoo`00ogoo8Goo003oOolQOol0
02Uoo`800003Ool000000?9oo`00:Woo00<007oo0000lgoo000ZOol3001hOol3001hOol002Yoo`04
001oo`00001jOol00`00Oomoo`1eOol002Yoo`03001oogoo07Uoo`<000=oo`<00003Ool00000009o
o`80009oo`<006Eoo`00:Goo0P00NWoo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomo
o`02Ool00`00Oomoo`1TOol00:Eoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00<007ooOol0
0Woo00<007ooOol0I7oo002VOol40002Ool20002Ool40004Ool2001VOol00?moob5oo`00[Goo00<0
07ooOol02Goo00<007ooOol0I7oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00<Goo10001Woo
0P002Goo0`001Goo0P001Woo0`0027oo00<007ooOol01Goo0P00DGoo100027oo0P002Woo0`001goo
0P0027oo0`002Goo00<007ooOol01goo0P0087oo000aOol00`00Oomoo`06Ool01000Oomoo`002Goo
00<007ooOol00goo00@007ooOol000Eoo`04001oogoo0007Ool00`00Oomoo`04Ool01000Oomoo`00
D7oo00<007ooOol027oo00@007ooOol000Yoo`03001oogoo00Eoo`04001oogoo0007Ool01000Oomo
o`0027oo00<007ooOol01Woo00@007ooOol001moo`00<Woo00<007ooOol01goo00<007ooOol01Goo
1@001goo00<007ooOol00goo00@007ooOol000Moo`03001oogoo00Aoo`04001oogoo001AOol00`00
Oomoo`09Ool00`00Oomoo`06Ool50009Ool00`00Oomoo`05Ool01000Oomoo`0027oo00<007ooOol0
1Woo00@007ooOol001moo`00<goo00<007ooOol01goo00<007ooOol017oo00@007ooOol000Ioo`80
00Ioo`<000Uoo`03001oogoo00Aoo`8005=oo`03001oogoo00Uoo`03001oogoo00Eoo`04001oogoo
0008Ool20008Ool3000:Ool00`00Oomoo`06Ool2000POol0035oo`04001oogoo0005Ool01000Oomo
o`001goo00<007oo00001Woo00<007ooOol01Woo00<007ooOol01Goo00@007ooOol000Eoo`04001o
ogoo001@Ool01000Oomoo`001goo00@007ooOol000Qoo`03001oo`0000Qoo`03001oogoo00Qoo`03
001oogoo00Ioo`04001oogoo0007Ool01000Oomoo`007goo000bOol20007Ool20009Ool20006Ool3
0006Ool30005Ool40006Ool2001BOol20009Ool2000:Ool20008Ool30008Ool30006Ool40008Ool2
000POol00?moob5oo`00LWoo0P00Tgoo0P005goo001aOol01000Oomoo`00TGoo00@007ooOol001Io
o`00:7ooA@0017oo00<007ooOol0?GooD@0017oo00<007ooOol05goo001`Ool5002@Ool5000FOol0
075oo`03001oogoo099oo`03001oogoo01Moo`00ogoo8Goo003oOolQOol00?moob5oo`00/goo00<0
07ooOol0JWoo002cOol00`00Oomoo`18Ool2000POol00;=oo`03001oogoo04Aoo`@0029oo`00XGoo
1@000Woo0P000goo1@0000=oo`00Ool0@Goo10009Woo002SOol00`00Oomoo`09Ool01@00Oomoogoo
0000@7oo0P00:Woo002SOol00`00Oomoo`09Ool01@00Oomoogoo0000?Woo0P00;7oo002SOol00`00
Oomoo`09Ool01@00Oomoogoo0000?7oo0P00;Woo002SOol00`00Oomoo`09Ool01@00Oomoogoo0000
>goo00<007ooOol0;Woo000HOol50002Ool20003Ool40002Ool00`00Oomoo`1eOol2000:Ool20003
Ool00`00Oomoo`0gOol2000aOol001Yoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Io
o`X007Ioo`03001oogoo03Eoo`8003=oo`006Woo00<007ooOol027oo00<007ooOol00Woo00<007oo
Ool01Goo00<007ooOol027oo00<007ooOol0Lgoo00<007ooOol0=7oo00<007ooOol0<goo000JOol0
0`00Oomoo`09Ool01@00Oomoogoo00001Goo0P0037oo00<007ooOol0LWoo00<007ooOol0<goo00<0
07ooOol0=7oo000JOol00`00Oomoo`07Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol0
3Goo00<007ooOol0LGoo00<007ooOol0<Goo0P00=goo000IOol2000:Ool20003Ool01@00Oomoogoo
00004Goo00<007ooOol0L7oo00<007ooOol0<7oo00<007ooOol0=goo000ZOol01000Ool000004goo
0P00L7oo00<007ooOol0;goo00<007ooOol0>7oo000ZOol2000GOol00`00Oomoo`1KOol50002Ool2
0003Ool40002Ool00`00Oomoo`0^Ool00`00Oomoo`0iOol002Yoo`03001oogoo01Moo`03001oogoo
05aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo02eoo`03001oogoo03Yoo`0067oo1@00
0Woo0P0017oo0P000goo00<007ooOol067oo00<007ooOol0Fgoo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol0:goo0P00?Goo000JOol00`00Oomoo`07Ool01000Oomoo`000Woo00<007ooOol0
6Goo00<007ooOol0FWoo00<007ooOol02Goo00D007ooOomoo`0002aoo`03001oogoo03eoo`006Woo
00<007ooOol02Goo00D007ooOomoo`0001aoo`03001oogoo05Uoo`03001oogoo00Moo`04001oogoo
0002Ool00`00Oomoo`0YOol00`00Oomoo`0nOol001Yoo`03001oogoo00Yoo`04001oogoo000MOol0
0`00Oomoo`1GOol2000:Ool20003Ool00`00Oomoo`0XOol00`00Oomoo`0oOol001Yoo`03001oogoo
00Moo`04001oogoo0002Ool00`00Oomoo`0LOol00`00Oomoo`1WOol00`00Oomoo`0WOol00`00Oomo
o`10Ool001Uoo`8000Yoo`8000=oo`03001oogoo01eoo`03001oogoo06Ioo`03001oogoo02Ioo`03
001oogoo045oo`00:Woo00<007ooOol07Goo00<007ooOol0IWoo00<007ooOol09Woo00<007ooOol0
@Goo000ZOol00`00Oomoo`0NOol00`00Oomoo`1UOol00`00Oomoo`0UOol00`00Oomoo`12Ool001Qo
o`D0009oo`8000Eoo`<00003Ool007oo021oo`03001oogoo06Aoo`03001oogoo02Aoo`03001oogoo
04=oo`006Woo00<007ooOol02Woo00@007ooOol0029oo`03001oogoo055oo`D0009oo`8000Aoo`80
00=oo`03001oogoo02=oo`03001oogoo04Aoo`006Woo00<007ooOol01goo1@0000=oo`00Ool08Woo
00<007ooOol0DWoo00<007ooOol01goo00@007ooOol0009oo`03001oogoo029oo`03001oogoo04Eo
o`006Woo00<007ooOol01goo00@007ooOol0009oo`03001oogoo029oo`03001oogoo055oo`03001o
ogoo00Uoo`05001oogooOol0000SOol00`00Oomoo`16Ool001Yoo`03001oogoo00Qoo`03001oo`00
009oo`03001oogoo02=oo`03001oogoo051oo`03001oogoo00Yoo`04001oogoo000SOol00`00Oomo
o`16Ool001Uoo`8000]oo`80009oo`03001oogoo02Aoo`03001oogoo04moo`03001oogoo00Moo`04
001oogoo0002Ool00`00Oomoo`0POol00`00Oomoo`17Ool002Yoo`03001oogoo02Eoo`03001oogoo
04eoo`8000Yoo`8000=oo`03001oogoo01moo`03001oogoo04Qoo`00:Woo00<007ooOol09Woo00<0
07ooOol0GGoo00<007ooOol07Woo00<007ooOol0BGoo000HOol50002Ool20004Ool20003Ool00`00
Oomoo`0VOol00`00Oomoo`1MOol00`00Oomoo`0MOol00`00Oomoo`1:Ool001Yoo`03001oogoo00Mo
o`04001oogoo0002Ool00`00Oomoo`0WOol00`00Oomoo`1LOol00`00Oomoo`0LOol00`00Oomoo`1;
Ool001Yoo`03001oogoo00Yoo`04001oogoo000ZOol00`00Oomoo`1KOol00`00Oomoo`0LOol00`00
Oomoo`1;Ool001Yoo`03001oogoo00Qoo`8000=oo`03001oogoo02Uoo`03001oogoo05Yoo`03001o
ogoo01]oo`03001oogoo04aoo`006Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0:Woo
00<007ooOol0FGoo00<007ooOol06Woo00<007ooOol0CGoo000IOol2000:Ool30002Ool00`00Oomo
o`0[Ool00`00Oomoo`16Ool50002Ool20005Ool300000goo001oo`0JOol00`00Oomoo`1>Ool002Yo
o`03001oogoo02aoo`8004Qoo`03001oogoo00Yoo`03001oogoo008001Uoo`03001oogoo04moo`00
:Woo00<007ooOol0;Woo00<007ooOol0AGoo00<007ooOol01goo1@0000Aoo`00Ool001Qoo`03001o
ogoo04moo`00:Woo00<007ooOol0;goo0P00AGoo00<007ooOol01goo00@007ooOol0009oo`04001o
ogoo000FOol00`00Oomoo`1@Ool001Qoo`D0009oo`8000=oo`<000=oo`03001oogoo035oo`03001o
ogoo049oo`03001oogoo00Qoo`03001oo`00009oo`05001oogooOol0000DOol00`00Oomoo`1AOol0
01Yoo`03001oogoo00Moo`04001oogoo0002Ool00`00Oomoo`0bOol20011Ool2000;Ool20002Ool0
0`00Oomoo`02Ool2000AOol00`00Oomoo`1BOol001Yoo`03001oogoo00Moo`04001oogoo0002Ool0
0`00Oomoo`0dOol00`00Oomoo`1?Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`1BOol0
01Yoo`03001oogoo00Moo`<000=oo`03001oogoo03Eoo`8004moo`03001oogoo00Eoo`03001oogoo
00aoo`03001oogoo05=oo`006Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0=goo0P00
CGoo00<007ooOol01Woo00<007ooOol027oo0`00EWoo000IOol2000:Ool30002Ool00`00Oomoo`0i
Ool2001;Ool00`00Oomoo`07Ool01000Oomoogoo1P00FGoo000ZOol00`00Oomoo`0kOol20019Ool0
0`00Oomoo`08Ool3001OOol002Yoo`03001oogoo03eoo`03001oogoo04Ioo`03001oogoo06Yoo`00
:Woo00<007ooOol0QWoo00<007ooOol0JWoo003oOolQOol00?moob5oo`00ogoo8Goo000XOol3003e
Ool002]oo`03001oogoo0?9oo`00:Goo0`00Q7oo0P000Woo0P00JWoo000XOol01000Oomoo`00QGoo
00@007ooOol006]oo`00:7oo00@007ooOol008Eoo`04001oogoo001[Ool002Uoo`@008=oo`@006ao
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {270.188, 0}} -> {-0.050401, -0.0470982, \
0.00731988, 0.00731988}, {{6.875, 136.938}, {263.75, 183.313}} -> {-1.67907, \
-0.0595307, 0.0800003, 0.00358926}, {{150, 280.063}, {263.75, 183.313}} -> \
{-12.7691, -0.0893376, 0.0782335, 0.0218169}, {{6.875, 136.938}, {175.25, \
94.875}} -> {-1.93796, 0.0212449, 0.0893981, 3.44822*^-05}, {{150, 280.063}, \
{175.25, 94.875}} -> {-12.9543, -0.173966, 0.0792129, 0.00450978}, {{6.875, \
136.938}, {86.8125, 6.375}} -> {-3.6317, -1.31496, 0.108886, 0.011981}, \
{{150, 280.063}, {86.8125, 6.375}} -> {-15.3413, -0.679033, 0.0911961, \
0.00868247}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Tau] =  .05; \[Kappa] =  .1; defvar; initcond; simul; 
    result2;\), "\[IndentingNewLine]", 
    \(\(\(plou[3, 1] = \@growth\%30 - 1\) \); \(\(plou[3, 
          2] = \@popgrowth\%30 - 1\) \); \(\(plou[3, 3] = 
        ginix\) \); \(\(plou[3, 4] = 
        2\ cfd\) \);\[IndentingNewLine]\)}], "Input"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 9, 2, 
          6, 11}\),
      SequenceForm[ "Start simulation ", {2002, 6, 9, 2, 6, 11}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          9, 2, 6, 23}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 9, 2, 6, 23}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 9, 2, 6, 49}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 9, 2, 6, 49}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 9, 2, 6, 50}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 9, 2, 6, 50}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 2, 29, 21}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 2, 29, 21}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 9, 2, 
          29, 23}\),
      SequenceForm[ "Start simulation ", {2002, 6, 9, 2, 29, 23}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          9, 2, 29, 33}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 9, 2, 29, 33}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 9, 2, 30, 0}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 9, 2, 30, 0}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 9, 2, 30, 1}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 9, 2, 30, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 2, 52, 35}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 2, 52, 35}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]2\),
      SequenceForm[ "step", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 9, 2, 
          52, 36}\),
      SequenceForm[ "Start simulation ", {2002, 6, 9, 2, 52, 36}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          9, 2, 52, 46}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 9, 2, 52, 46}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 9, 2, 53, 14}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 9, 2, 53, 
        14}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 9, 2, 53, 15}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 9, 2, 53, 15}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 3, 15, 37}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 3, 15, 37}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]3\),
      SequenceForm[ "step", 3],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 9, 3, 
          15, 39}\),
      SequenceForm[ "Start simulation ", {2002, 6, 9, 3, 15, 39}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          9, 3, 15, 49}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 9, 3, 15, 49}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 9, 3, 16, 17}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 9, 3, 16, 
        17}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 9, 3, 16, 18}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 9, 3, 16, 18}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 3, 38, 56}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 3, 38, 56}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]4\),
      SequenceForm[ "step", 4],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 9, 3, 
          38, 58}\),
      SequenceForm[ "Start simulation ", {2002, 6, 9, 3, 38, 58}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          9, 3, 39, 8}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 9, 3, 39, 8}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 9, 3, 39, 35}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 9, 3, 39, 
        35}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 9, 3, 39, 36}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 9, 3, 39, 36}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 4, 1, 55}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 4, 1, 55}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]5\),
      SequenceForm[ "step", 5],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 9, 4, 
          1, 56}\),
      SequenceForm[ "Start simulation ", {2002, 6, 9, 4, 1, 56}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          9, 4, 2, 7}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 9, 4, 2, 7}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 9, 4, 2, 34}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 9, 4, 2, 34}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 9, 4, 2, 35}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 9, 4, 2, 35}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 4, 25, 15}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 4, 25, 15}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]6\),
      SequenceForm[ "step", 6],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 9, 4, 
          25, 17}\),
      SequenceForm[ "Start simulation ", {2002, 6, 9, 4, 25, 17}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          9, 4, 25, 27}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 9, 4, 25, 27}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 9, 4, 25, 55}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 9, 4, 25, 
        55}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 9, 4, 25, 56}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 9, 4, 25, 56}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 4, 48, 37}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 4, 48, 37}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]7\),
      SequenceForm[ "step", 7],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 9, 4, 
          48, 39}\),
      SequenceForm[ "Start simulation ", {2002, 6, 9, 4, 48, 39}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          9, 4, 48, 49}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 9, 4, 48, 49}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 9, 4, 49, 17}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 9, 4, 49, 
        17}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 9, 4, 49, 18}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 9, 4, 49, 18}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 5, 12, 4}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 5, 12, 4}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]8\),
      SequenceForm[ "step", 8],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .94177 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.022423 0.47619 [
[ 0 0 0 0 ]
[ 1 .94177 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .94177 L
0 .94177 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.022423 0.477324 0.302711 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112245 0.136054 0.0147151 3.14593 [
[.15986 .00222 -3 -9 ]
[.15986 .00222 3 0 ]
[.29592 .00222 -3 -9 ]
[.29592 .00222 3 0 ]
[.43197 .00222 -3 -9 ]
[.43197 .00222 3 0 ]
[.56803 .00222 -3 -9 ]
[.56803 .00222 3 0 ]
[.70408 .00222 -3 -9 ]
[.70408 .00222 3 0 ]
[.84014 .00222 -3 -9 ]
[.84014 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6.28125 ]
[1.025 .01472 10 6.28125 ]
[.01131 .09336 -30 -4.5 ]
[.01131 .09336 0 4.5 ]
[.01131 .17201 -24 -4.5 ]
[.01131 .17201 0 4.5 ]
[.01131 .25066 -30 -4.5 ]
[.01131 .25066 0 4.5 ]
[.01131 .32931 -18 -4.5 ]
[.01131 .32931 0 4.5 ]
[.01131 .40796 -30 -4.5 ]
[.01131 .40796 0 4.5 ]
[.01131 .4866 -24 -4.5 ]
[.01131 .4866 0 4.5 ]
[.01131 .56525 -30 -4.5 ]
[.01131 .56525 0 4.5 ]
[.02381 .64303 -23 0 ]
[.02381 .64303 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 .01472 m
.15986 .02097 L
s
[(2)] .15986 .00222 0 1 Mshowa
.29592 .01472 m
.29592 .02097 L
s
[(3)] .29592 .00222 0 1 Mshowa
.43197 .01472 m
.43197 .02097 L
s
[(4)] .43197 .00222 0 1 Mshowa
.56803 .01472 m
.56803 .02097 L
s
[(5)] .56803 .00222 0 1 Mshowa
.70408 .01472 m
.70408 .02097 L
s
[(6)] .70408 .00222 0 1 Mshowa
.84014 .01472 m
.84014 .02097 L
s
[(7)] .84014 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(8)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05102 .01472 m
.05102 .01847 L
s
.07823 .01472 m
.07823 .01847 L
s
.10544 .01472 m
.10544 .01847 L
s
.13265 .01472 m
.13265 .01847 L
s
.18707 .01472 m
.18707 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.2415 .01472 m
.2415 .01847 L
s
.26871 .01472 m
.26871 .01847 L
s
.32313 .01472 m
.32313 .01847 L
s
.35034 .01472 m
.35034 .01847 L
s
.37755 .01472 m
.37755 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45918 .01472 m
.45918 .01847 L
s
.48639 .01472 m
.48639 .01847 L
s
.51361 .01472 m
.51361 .01847 L
s
.54082 .01472 m
.54082 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62245 .01472 m
.62245 .01847 L
s
.64966 .01472 m
.64966 .01847 L
s
.67687 .01472 m
.67687 .01847 L
s
.73129 .01472 m
.73129 .01847 L
s
.7585 .01472 m
.7585 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.81293 .01472 m
.81293 .01847 L
s
.86735 .01472 m
.86735 .01847 L
s
.89456 .01472 m
.89456 .01847 L
s
.92177 .01472 m
.92177 .01847 L
s
.94898 .01472 m
.94898 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.02381 .09336 m
.03006 .09336 L
s
[(0.025)] .01131 .09336 1 0 Mshowa
.02381 .17201 m
.03006 .17201 L
s
[(0.05)] .01131 .17201 1 0 Mshowa
.02381 .25066 m
.03006 .25066 L
s
[(0.075)] .01131 .25066 1 0 Mshowa
.02381 .32931 m
.03006 .32931 L
s
[(0.1)] .01131 .32931 1 0 Mshowa
.02381 .40796 m
.03006 .40796 L
s
[(0.125)] .01131 .40796 1 0 Mshowa
.02381 .4866 m
.03006 .4866 L
s
[(0.15)] .01131 .4866 1 0 Mshowa
.02381 .56525 m
.03006 .56525 L
s
[(0.175)] .01131 .56525 1 0 Mshowa
.125 Mabswid
.02381 .03044 m
.02756 .03044 L
s
.02381 .04617 m
.02756 .04617 L
s
.02381 .0619 m
.02756 .0619 L
s
.02381 .07763 m
.02756 .07763 L
s
.02381 .10909 m
.02756 .10909 L
s
.02381 .12482 m
.02756 .12482 L
s
.02381 .14055 m
.02756 .14055 L
s
.02381 .15628 m
.02756 .15628 L
s
.02381 .18774 m
.02756 .18774 L
s
.02381 .20347 m
.02756 .20347 L
s
.02381 .2192 m
.02756 .2192 L
s
.02381 .23493 m
.02756 .23493 L
s
.02381 .26639 m
.02756 .26639 L
s
.02381 .28212 m
.02756 .28212 L
s
.02381 .29785 m
.02756 .29785 L
s
.02381 .31358 m
.02756 .31358 L
s
.02381 .34504 m
.02756 .34504 L
s
.02381 .36077 m
.02756 .36077 L
s
.02381 .3765 m
.02756 .3765 L
s
.02381 .39223 m
.02756 .39223 L
s
.02381 .42369 m
.02756 .42369 L
s
.02381 .43942 m
.02756 .43942 L
s
.02381 .45515 m
.02756 .45515 L
s
.02381 .47088 m
.02756 .47088 L
s
.02381 .50233 m
.02756 .50233 L
s
.02381 .51806 m
.02756 .51806 L
s
.02381 .53379 m
.02756 .53379 L
s
.02381 .54952 m
.02756 .54952 L
s
.02381 .58098 m
.02756 .58098 L
s
.02381 .59671 m
.02756 .59671 L
s
.02381 .61244 m
.02756 .61244 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(%) show
75.000 12.813 moveto
(const) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .60332 m
.15986 .01472 L
.29592 .01472 L
.43197 .01472 L
.56803 .01472 L
.70408 .01472 L
.84014 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.022423 0.97619 0.302711 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112245 0.136054 -0.0235469 0.450641 [
[.15986 .41459 -3 -9 ]
[.15986 .41459 3 0 ]
[.29592 .41459 -3 -9 ]
[.29592 .41459 3 0 ]
[.43197 .41459 -3 -9 ]
[.43197 .41459 3 0 ]
[.56803 .41459 -3 -9 ]
[.56803 .41459 3 0 ]
[.70408 .41459 -3 -9 ]
[.70408 .41459 3 0 ]
[.84014 .41459 -3 -9 ]
[.84014 .41459 3 0 ]
[.97619 .41459 -3 -9 ]
[.97619 .41459 3 0 ]
[1.025 .42709 0 -6.28125 ]
[1.025 .42709 10 6.28125 ]
[.01131 .06658 -18 -4.5 ]
[.01131 .06658 0 4.5 ]
[.01131 .15671 -18 -4.5 ]
[.01131 .15671 0 4.5 ]
[.01131 .24684 -18 -4.5 ]
[.01131 .24684 0 4.5 ]
[.01131 .33697 -18 -4.5 ]
[.01131 .33697 0 4.5 ]
[.01131 .51722 -18 -4.5 ]
[.01131 .51722 0 4.5 ]
[.01131 .60735 -18 -4.5 ]
[.01131 .60735 0 4.5 ]
[.02381 .64303 -26 0 ]
[.02381 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 .42709 m
.15986 .43334 L
s
[(2)] .15986 .41459 0 1 Mshowa
.29592 .42709 m
.29592 .43334 L
s
[(3)] .29592 .41459 0 1 Mshowa
.43197 .42709 m
.43197 .43334 L
s
[(4)] .43197 .41459 0 1 Mshowa
.56803 .42709 m
.56803 .43334 L
s
[(5)] .56803 .41459 0 1 Mshowa
.70408 .42709 m
.70408 .43334 L
s
[(6)] .70408 .41459 0 1 Mshowa
.84014 .42709 m
.84014 .43334 L
s
[(7)] .84014 .41459 0 1 Mshowa
.97619 .42709 m
.97619 .43334 L
s
[(8)] .97619 .41459 0 1 Mshowa
.125 Mabswid
.05102 .42709 m
.05102 .43084 L
s
.07823 .42709 m
.07823 .43084 L
s
.10544 .42709 m
.10544 .43084 L
s
.13265 .42709 m
.13265 .43084 L
s
.18707 .42709 m
.18707 .43084 L
s
.21429 .42709 m
.21429 .43084 L
s
.2415 .42709 m
.2415 .43084 L
s
.26871 .42709 m
.26871 .43084 L
s
.32313 .42709 m
.32313 .43084 L
s
.35034 .42709 m
.35034 .43084 L
s
.37755 .42709 m
.37755 .43084 L
s
.40476 .42709 m
.40476 .43084 L
s
.45918 .42709 m
.45918 .43084 L
s
.48639 .42709 m
.48639 .43084 L
s
.51361 .42709 m
.51361 .43084 L
s
.54082 .42709 m
.54082 .43084 L
s
.59524 .42709 m
.59524 .43084 L
s
.62245 .42709 m
.62245 .43084 L
s
.64966 .42709 m
.64966 .43084 L
s
.67687 .42709 m
.67687 .43084 L
s
.73129 .42709 m
.73129 .43084 L
s
.7585 .42709 m
.7585 .43084 L
s
.78571 .42709 m
.78571 .43084 L
s
.81293 .42709 m
.81293 .43084 L
s
.86735 .42709 m
.86735 .43084 L
s
.89456 .42709 m
.89456 .43084 L
s
.92177 .42709 m
.92177 .43084 L
s
.94898 .42709 m
.94898 .43084 L
s
.25 Mabswid
0 .42709 m
1 .42709 L
s
gsave
1.025 .42709 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.02381 .06658 m
.03006 .06658 L
s
[(0.2)] .01131 .06658 1 0 Mshowa
.02381 .15671 m
.03006 .15671 L
s
[(0.4)] .01131 .15671 1 0 Mshowa
.02381 .24684 m
.03006 .24684 L
s
[(0.6)] .01131 .24684 1 0 Mshowa
.02381 .33697 m
.03006 .33697 L
s
[(0.8)] .01131 .33697 1 0 Mshowa
.02381 .51722 m
.03006 .51722 L
s
[(1.2)] .01131 .51722 1 0 Mshowa
.02381 .60735 m
.03006 .60735 L
s
[(1.4)] .01131 .60735 1 0 Mshowa
.125 Mabswid
.02381 .08911 m
.02756 .08911 L
s
.02381 .11165 m
.02756 .11165 L
s
.02381 .13418 m
.02756 .13418 L
s
.02381 .17924 m
.02756 .17924 L
s
.02381 .20177 m
.02756 .20177 L
s
.02381 .22431 m
.02756 .22431 L
s
.02381 .26937 m
.02756 .26937 L
s
.02381 .2919 m
.02756 .2919 L
s
.02381 .31443 m
.02756 .31443 L
s
.02381 .3595 m
.02756 .3595 L
s
.02381 .38203 m
.02756 .38203 L
s
.02381 .40456 m
.02756 .40456 L
s
.02381 .44963 m
.02756 .44963 L
s
.02381 .47216 m
.02756 .47216 L
s
.02381 .49469 m
.02756 .49469 L
s
.02381 .53975 m
.02756 .53975 L
s
.02381 .56229 m
.02756 .56229 L
s
.02381 .58482 m
.02756 .58482 L
s
.02381 .04405 m
.02756 .04405 L
s
.02381 .02152 m
.02756 .02152 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dif) show
87.000 12.813 moveto
(fert) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .60332 m
.15986 .33008 L
.29592 .17564 L
.43197 .10314 L
.56803 .06378 L
.70408 .04125 L
.84014 .02588 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.330739 0.477324 0.611027 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.119048 -1.26927 72.1126 [
[.38095 .16048 -3 -9 ]
[.38095 .16048 3 0 ]
[.61905 .16048 -3 -9 ]
[.61905 .16048 3 0 ]
[.85714 .16048 -3 -9 ]
[.85714 .16048 3 0 ]
[1.025 .17298 0 -6.28125 ]
[1.025 .17298 10 6.28125 ]
[.13036 .02876 -30 -4.5 ]
[.13036 .02876 0 4.5 ]
[.13036 .31721 -30 -4.5 ]
[.13036 .31721 0 4.5 ]
[.13036 .46144 -30 -4.5 ]
[.13036 .46144 0 4.5 ]
[.13036 .60566 -30 -4.5 ]
[.13036 .60566 0 4.5 ]
[.14286 .64303 -5 0 ]
[.14286 .64303 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.38095 .17298 m
.38095 .17923 L
s
[(4)] .38095 .16048 0 1 Mshowa
.61905 .17298 m
.61905 .17923 L
s
[(6)] .61905 .16048 0 1 Mshowa
.85714 .17298 m
.85714 .17923 L
s
[(8)] .85714 .16048 0 1 Mshowa
.125 Mabswid
.20238 .17298 m
.20238 .17673 L
s
.2619 .17298 m
.2619 .17673 L
s
.32143 .17298 m
.32143 .17673 L
s
.44048 .17298 m
.44048 .17673 L
s
.5 .17298 m
.5 .17673 L
s
.55952 .17298 m
.55952 .17673 L
s
.67857 .17298 m
.67857 .17673 L
s
.7381 .17298 m
.7381 .17673 L
s
.79762 .17298 m
.79762 .17673 L
s
.08333 .17298 m
.08333 .17673 L
s
.02381 .17298 m
.02381 .17673 L
s
.91667 .17298 m
.91667 .17673 L
s
.97619 .17298 m
.97619 .17673 L
s
.25 Mabswid
0 .17298 m
1 .17298 L
s
gsave
1.025 .17298 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.14286 .02876 m
.14911 .02876 L
s
[(0.018)] .13036 .02876 1 0 Mshowa
.14286 .31721 m
.14911 .31721 L
s
[(0.022)] .13036 .31721 1 0 Mshowa
.14286 .46144 m
.14911 .46144 L
s
[(0.024)] .13036 .46144 1 0 Mshowa
.14286 .60566 m
.14911 .60566 L
s
[(0.026)] .13036 .60566 1 0 Mshowa
.125 Mabswid
.14286 .06482 m
.14661 .06482 L
s
.14286 .10087 m
.14661 .10087 L
s
.14286 .13693 m
.14661 .13693 L
s
.14286 .20904 m
.14661 .20904 L
s
.14286 .2451 m
.14661 .2451 L
s
.14286 .28115 m
.14661 .28115 L
s
.14286 .35327 m
.14661 .35327 L
s
.14286 .38932 m
.14661 .38932 L
s
.14286 .42538 m
.14661 .42538 L
s
.14286 .49749 m
.14661 .49749 L
s
.14286 .53355 m
.14661 .53355 L
s
.14286 .5696 m
.14661 .5696 L
s
.25 Mabswid
.14286 0 m
.14286 .61803 L
s
gsave
.14286 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .51146 m
.14286 .60332 L
.2619 .11367 L
.38095 .01472 L
.5 .09226 L
.61905 .21071 L
.7381 .31506 L
.85714 .3893 L
.97619 .4374 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.330739 0.97619 0.611027 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112245 0.136054 -0.133119 1.41516 [
[.15986 -0.0041 -3 -9 ]
[.15986 -0.0041 3 0 ]
[.29592 -0.0041 -3 -9 ]
[.29592 -0.0041 3 0 ]
[.43197 -0.0041 -3 -9 ]
[.43197 -0.0041 3 0 ]
[.56803 -0.0041 -3 -9 ]
[.56803 -0.0041 3 0 ]
[.70408 -0.0041 -3 -9 ]
[.70408 -0.0041 3 0 ]
[.84014 -0.0041 -3 -9 ]
[.84014 -0.0041 3 0 ]
[.97619 -0.0041 -3 -9 ]
[.97619 -0.0041 3 0 ]
[1.025 .0084 0 -6.28125 ]
[1.025 .0084 10 6.28125 ]
[.01131 .14991 -18 -4.5 ]
[.01131 .14991 0 4.5 ]
[.01131 .29143 -18 -4.5 ]
[.01131 .29143 0 4.5 ]
[.01131 .43294 -18 -4.5 ]
[.01131 .43294 0 4.5 ]
[.01131 .57446 -18 -4.5 ]
[.01131 .57446 0 4.5 ]
[.02381 .64303 -14 0 ]
[.02381 .64303 14 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 .0084 m
.15986 .01465 L
s
[(2)] .15986 -0.0041 0 1 Mshowa
.29592 .0084 m
.29592 .01465 L
s
[(3)] .29592 -0.0041 0 1 Mshowa
.43197 .0084 m
.43197 .01465 L
s
[(4)] .43197 -0.0041 0 1 Mshowa
.56803 .0084 m
.56803 .01465 L
s
[(5)] .56803 -0.0041 0 1 Mshowa
.70408 .0084 m
.70408 .01465 L
s
[(6)] .70408 -0.0041 0 1 Mshowa
.84014 .0084 m
.84014 .01465 L
s
[(7)] .84014 -0.0041 0 1 Mshowa
.97619 .0084 m
.97619 .01465 L
s
[(8)] .97619 -0.0041 0 1 Mshowa
.125 Mabswid
.05102 .0084 m
.05102 .01215 L
s
.07823 .0084 m
.07823 .01215 L
s
.10544 .0084 m
.10544 .01215 L
s
.13265 .0084 m
.13265 .01215 L
s
.18707 .0084 m
.18707 .01215 L
s
.21429 .0084 m
.21429 .01215 L
s
.2415 .0084 m
.2415 .01215 L
s
.26871 .0084 m
.26871 .01215 L
s
.32313 .0084 m
.32313 .01215 L
s
.35034 .0084 m
.35034 .01215 L
s
.37755 .0084 m
.37755 .01215 L
s
.40476 .0084 m
.40476 .01215 L
s
.45918 .0084 m
.45918 .01215 L
s
.48639 .0084 m
.48639 .01215 L
s
.51361 .0084 m
.51361 .01215 L
s
.54082 .0084 m
.54082 .01215 L
s
.59524 .0084 m
.59524 .01215 L
s
.62245 .0084 m
.62245 .01215 L
s
.64966 .0084 m
.64966 .01215 L
s
.67687 .0084 m
.67687 .01215 L
s
.73129 .0084 m
.73129 .01215 L
s
.7585 .0084 m
.7585 .01215 L
s
.78571 .0084 m
.78571 .01215 L
s
.81293 .0084 m
.81293 .01215 L
s
.86735 .0084 m
.86735 .01215 L
s
.89456 .0084 m
.89456 .01215 L
s
.92177 .0084 m
.92177 .01215 L
s
.94898 .0084 m
.94898 .01215 L
s
.25 Mabswid
0 .0084 m
1 .0084 L
s
gsave
1.025 .0084 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.02381 .14991 m
.03006 .14991 L
s
[(0.2)] .01131 .14991 1 0 Mshowa
.02381 .29143 m
.03006 .29143 L
s
[(0.3)] .01131 .29143 1 0 Mshowa
.02381 .43294 m
.03006 .43294 L
s
[(0.4)] .01131 .43294 1 0 Mshowa
.02381 .57446 m
.03006 .57446 L
s
[(0.5)] .01131 .57446 1 0 Mshowa
.125 Mabswid
.02381 .0367 m
.02756 .0367 L
s
.02381 .065 m
.02756 .065 L
s
.02381 .09331 m
.02756 .09331 L
s
.02381 .12161 m
.02756 .12161 L
s
.02381 .17822 m
.02756 .17822 L
s
.02381 .20652 m
.02756 .20652 L
s
.02381 .23482 m
.02756 .23482 L
s
.02381 .26312 m
.02756 .26312 L
s
.02381 .31973 m
.02756 .31973 L
s
.02381 .34803 m
.02756 .34803 L
s
.02381 .37634 m
.02756 .37634 L
s
.02381 .40464 m
.02756 .40464 L
s
.02381 .46125 m
.02756 .46125 L
s
.02381 .48955 m
.02756 .48955 L
s
.02381 .51785 m
.02756 .51785 L
s
.02381 .54616 m
.02756 .54616 L
s
.02381 .60276 m
.02756 .60276 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(gini) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .60332 m
.15986 .50611 L
.29592 .41608 L
.43197 .30955 L
.56803 .20801 L
.70408 .12655 L
.84014 .06285 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.639056 0.477324 0.919343 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112245 0.136054 -0.924967 0.75407 [
[.15986 -0.1834 -3 -9 ]
[.15986 -0.1834 3 0 ]
[.29592 -0.1834 -3 -9 ]
[.29592 -0.1834 3 0 ]
[.43197 -0.1834 -3 -9 ]
[.43197 -0.1834 3 0 ]
[.56803 -0.1834 -3 -9 ]
[.56803 -0.1834 3 0 ]
[.70408 -0.1834 -3 -9 ]
[.70408 -0.1834 3 0 ]
[.84014 -0.1834 -3 -9 ]
[.84014 -0.1834 3 0 ]
[.97619 -0.1834 -3 -9 ]
[.97619 -0.1834 3 0 ]
[1.025 -0.1709 0 -6.28125 ]
[1.025 -0.1709 10 6.28125 ]
[.01131 .13073 -18 -4.5 ]
[.01131 .13073 0 4.5 ]
[.01131 .28154 -18 -4.5 ]
[.01131 .28154 0 4.5 ]
[.01131 .43236 -18 -4.5 ]
[.01131 .43236 0 4.5 ]
[.01131 .58317 -6 -4.5 ]
[.01131 .58317 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12.5625 ]
[ 0 -0.1709 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 -0.1709 m
.15986 -0.16465 L
s
[(2)] .15986 -0.1834 0 1 Mshowa
.29592 -0.1709 m
.29592 -0.16465 L
s
[(3)] .29592 -0.1834 0 1 Mshowa
.43197 -0.1709 m
.43197 -0.16465 L
s
[(4)] .43197 -0.1834 0 1 Mshowa
.56803 -0.1709 m
.56803 -0.16465 L
s
[(5)] .56803 -0.1834 0 1 Mshowa
.70408 -0.1709 m
.70408 -0.16465 L
s
[(6)] .70408 -0.1834 0 1 Mshowa
.84014 -0.1709 m
.84014 -0.16465 L
s
[(7)] .84014 -0.1834 0 1 Mshowa
.97619 -0.1709 m
.97619 -0.16465 L
s
[(8)] .97619 -0.1834 0 1 Mshowa
.125 Mabswid
.05102 -0.1709 m
.05102 -0.16715 L
s
.07823 -0.1709 m
.07823 -0.16715 L
s
.10544 -0.1709 m
.10544 -0.16715 L
s
.13265 -0.1709 m
.13265 -0.16715 L
s
.18707 -0.1709 m
.18707 -0.16715 L
s
.21429 -0.1709 m
.21429 -0.16715 L
s
.2415 -0.1709 m
.2415 -0.16715 L
s
.26871 -0.1709 m
.26871 -0.16715 L
s
.32313 -0.1709 m
.32313 -0.16715 L
s
.35034 -0.1709 m
.35034 -0.16715 L
s
.37755 -0.1709 m
.37755 -0.16715 L
s
.40476 -0.1709 m
.40476 -0.16715 L
s
.45918 -0.1709 m
.45918 -0.16715 L
s
.48639 -0.1709 m
.48639 -0.16715 L
s
.51361 -0.1709 m
.51361 -0.16715 L
s
.54082 -0.1709 m
.54082 -0.16715 L
s
.59524 -0.1709 m
.59524 -0.16715 L
s
.62245 -0.1709 m
.62245 -0.16715 L
s
.64966 -0.1709 m
.64966 -0.16715 L
s
.67687 -0.1709 m
.67687 -0.16715 L
s
.73129 -0.1709 m
.73129 -0.16715 L
s
.7585 -0.1709 m
.7585 -0.16715 L
s
.78571 -0.1709 m
.78571 -0.16715 L
s
.81293 -0.1709 m
.81293 -0.16715 L
s
.86735 -0.1709 m
.86735 -0.16715 L
s
.89456 -0.1709 m
.89456 -0.16715 L
s
.92177 -0.1709 m
.92177 -0.16715 L
s
.94898 -0.1709 m
.94898 -0.16715 L
s
.25 Mabswid
0 -0.1709 m
1 -0.1709 L
s
gsave
1.025 -0.1709 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.02381 .13073 m
.03006 .13073 L
s
[(1.4)] .01131 .13073 1 0 Mshowa
.02381 .28154 m
.03006 .28154 L
s
[(1.6)] .01131 .28154 1 0 Mshowa
.02381 .43236 m
.03006 .43236 L
s
[(1.8)] .01131 .43236 1 0 Mshowa
.02381 .58317 m
.03006 .58317 L
s
[(2)] .01131 .58317 1 0 Mshowa
.125 Mabswid
.02381 .16843 m
.02756 .16843 L
s
.02381 .20614 m
.02756 .20614 L
s
.02381 .24384 m
.02756 .24384 L
s
.02381 .31925 m
.02756 .31925 L
s
.02381 .35695 m
.02756 .35695 L
s
.02381 .39465 m
.02756 .39465 L
s
.02381 .47006 m
.02756 .47006 L
s
.02381 .50776 m
.02756 .50776 L
s
.02381 .54547 m
.02756 .54547 L
s
.02381 .09303 m
.02756 .09303 L
s
.02381 .05532 m
.02756 .05532 L
s
.02381 .01762 m
.02756 .01762 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(g) show
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .01472 m
.15986 .5023 L
.29592 .60332 L
.43197 .56451 L
.56803 .51816 L
.70408 .485 L
.84014 .46633 L
.97619 .45566 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.639056 0.97619 0.919343 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112245 0.136054 -1.57108 1.57307 [
[.15986 -0.01051 -3 -9 ]
[.15986 -0.01051 3 0 ]
[.29592 -0.01051 -3 -9 ]
[.29592 -0.01051 3 0 ]
[.43197 -0.01051 -3 -9 ]
[.43197 -0.01051 3 0 ]
[.56803 -0.01051 -3 -9 ]
[.56803 -0.01051 3 0 ]
[.70408 -0.01051 -3 -9 ]
[.70408 -0.01051 3 0 ]
[.84014 -0.01051 -3 -9 ]
[.84014 -0.01051 3 0 ]
[.97619 -0.01051 -3 -9 ]
[.97619 -0.01051 3 0 ]
[1.025 .00199 0 -6.28125 ]
[1.025 .00199 10 6.28125 ]
[.01131 .08064 -24 -4.5 ]
[.01131 .08064 0 4.5 ]
[.01131 .1593 -18 -4.5 ]
[.01131 .1593 0 4.5 ]
[.01131 .23795 -24 -4.5 ]
[.01131 .23795 0 4.5 ]
[.01131 .31661 -18 -4.5 ]
[.01131 .31661 0 4.5 ]
[.01131 .39526 -24 -4.5 ]
[.01131 .39526 0 4.5 ]
[.01131 .47391 -18 -4.5 ]
[.01131 .47391 0 4.5 ]
[.01131 .55257 -24 -4.5 ]
[.01131 .55257 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 .00199 m
.15986 .00824 L
s
[(2)] .15986 -0.01051 0 1 Mshowa
.29592 .00199 m
.29592 .00824 L
s
[(3)] .29592 -0.01051 0 1 Mshowa
.43197 .00199 m
.43197 .00824 L
s
[(4)] .43197 -0.01051 0 1 Mshowa
.56803 .00199 m
.56803 .00824 L
s
[(5)] .56803 -0.01051 0 1 Mshowa
.70408 .00199 m
.70408 .00824 L
s
[(6)] .70408 -0.01051 0 1 Mshowa
.84014 .00199 m
.84014 .00824 L
s
[(7)] .84014 -0.01051 0 1 Mshowa
.97619 .00199 m
.97619 .00824 L
s
[(8)] .97619 -0.01051 0 1 Mshowa
.125 Mabswid
.05102 .00199 m
.05102 .00574 L
s
.07823 .00199 m
.07823 .00574 L
s
.10544 .00199 m
.10544 .00574 L
s
.13265 .00199 m
.13265 .00574 L
s
.18707 .00199 m
.18707 .00574 L
s
.21429 .00199 m
.21429 .00574 L
s
.2415 .00199 m
.2415 .00574 L
s
.26871 .00199 m
.26871 .00574 L
s
.32313 .00199 m
.32313 .00574 L
s
.35034 .00199 m
.35034 .00574 L
s
.37755 .00199 m
.37755 .00574 L
s
.40476 .00199 m
.40476 .00574 L
s
.45918 .00199 m
.45918 .00574 L
s
.48639 .00199 m
.48639 .00574 L
s
.51361 .00199 m
.51361 .00574 L
s
.54082 .00199 m
.54082 .00574 L
s
.59524 .00199 m
.59524 .00574 L
s
.62245 .00199 m
.62245 .00574 L
s
.64966 .00199 m
.64966 .00574 L
s
.67687 .00199 m
.67687 .00574 L
s
.73129 .00199 m
.73129 .00574 L
s
.7585 .00199 m
.7585 .00574 L
s
.78571 .00199 m
.78571 .00574 L
s
.81293 .00199 m
.81293 .00574 L
s
.86735 .00199 m
.86735 .00574 L
s
.89456 .00199 m
.89456 .00574 L
s
.92177 .00199 m
.92177 .00574 L
s
.94898 .00199 m
.94898 .00574 L
s
.25 Mabswid
0 .00199 m
1 .00199 L
s
gsave
1.025 .00199 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.02381 .08064 m
.03006 .08064 L
s
[(1.05)] .01131 .08064 1 0 Mshowa
.02381 .1593 m
.03006 .1593 L
s
[(1.1)] .01131 .1593 1 0 Mshowa
.02381 .23795 m
.03006 .23795 L
s
[(1.15)] .01131 .23795 1 0 Mshowa
.02381 .31661 m
.03006 .31661 L
s
[(1.2)] .01131 .31661 1 0 Mshowa
.02381 .39526 m
.03006 .39526 L
s
[(1.25)] .01131 .39526 1 0 Mshowa
.02381 .47391 m
.03006 .47391 L
s
[(1.3)] .01131 .47391 1 0 Mshowa
.02381 .55257 m
.03006 .55257 L
s
[(1.35)] .01131 .55257 1 0 Mshowa
.125 Mabswid
.02381 .01772 m
.02756 .01772 L
s
.02381 .03345 m
.02756 .03345 L
s
.02381 .04918 m
.02756 .04918 L
s
.02381 .06491 m
.02756 .06491 L
s
.02381 .09638 m
.02756 .09638 L
s
.02381 .11211 m
.02756 .11211 L
s
.02381 .12784 m
.02756 .12784 L
s
.02381 .14357 m
.02756 .14357 L
s
.02381 .17503 m
.02756 .17503 L
s
.02381 .19076 m
.02756 .19076 L
s
.02381 .20649 m
.02756 .20649 L
s
.02381 .22222 m
.02756 .22222 L
s
.02381 .25368 m
.02756 .25368 L
s
.02381 .26941 m
.02756 .26941 L
s
.02381 .28514 m
.02756 .28514 L
s
.02381 .30087 m
.02756 .30087 L
s
.02381 .33234 m
.02756 .33234 L
s
.02381 .34807 m
.02756 .34807 L
s
.02381 .3638 m
.02756 .3638 L
s
.02381 .37953 m
.02756 .37953 L
s
.02381 .41099 m
.02756 .41099 L
s
.02381 .42672 m
.02756 .42672 L
s
.02381 .44245 m
.02756 .44245 L
s
.02381 .45818 m
.02756 .45818 L
s
.02381 .48964 m
.02756 .48964 L
s
.02381 .50537 m
.02756 .50537 L
s
.02381 .5211 m
.02756 .5211 L
s
.02381 .53683 m
.02756 .53683 L
s
.02381 .5683 m
.02756 .5683 L
s
.02381 .58403 m
.02756 .58403 L
s
.02381 .59976 m
.02756 .59976 L
s
.02381 .61549 m
.02756 .61549 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .60332 m
.15986 .40015 L
.29592 .22117 L
.43197 .12075 L
.56803 .06703 L
.70408 .0393 L
.84014 .02367 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 271.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00013a000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
<7oo10002Goo0P002goo0`0027oo0P002Goo0`002goo00<007ooOol027oo0P00YGoo000`Ool00`00
Oomoo`09Ool01000Oomoo`002goo00<007ooOol01Woo00@007ooOol000Qoo`04001oogoo000:Ool0
0`00Oomoo`07Ool01000Oomoo`00=7oo00<007ooOol0KGoo000aOol00`00Oomoo`0:Ool00`00Oomo
o`07Ool5000:Ool00`00Oomoo`06Ool01000Oomoo`002Woo00<007ooOol01goo00@007ooOol003Ao
o`03001oogoo06eoo`00<Woo00<007ooOol02Woo00<007ooOol01Woo00@007ooOol000Uoo`8000Uo
o`<000aoo`03001oogoo00Moo`8003Eoo`03001oogoo051oo`L001Ioo`00<7oo00@007ooOol000Qo
o`04001oogoo0009Ool00`00Ool00009Ool00`00Oomoo`09Ool00`00Oomoo`08Ool01000Oomoo`00
27oo00@007ooOol003Aoo`03001oogoo04=oo`d001eoo`00<Goo0P002Woo0P002goo0P002Goo0`00
2Goo0`0027oo10002Goo0P00=Goo00<007ooOol0>Woo2@00:Woo002NOol20004Ool20003Ool40003
Ool00`00Oomoo`0dOol6000cOol0089oo`8001Uoo`04001oogoo0008Ool00`00Oomoo`04Ool00`00
Oomoo`0_Ool5000iOol002Eoo`03001oogoo05Uoo`04001oogoo000HOol01000Oomoo`002Goo00<0
07ooOol00goo00<007ooOol0;7oo0`00?Woo000SOomJ0004Ool00`00Oomoo`0IOol01000Oomoo`00
2Woo00<007ooOol00Woo00<007ooOol0:7oo1000@Goo000UOol2000;Ool00`00Oomoo`1;Ool5000H
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo02Eoo`<004Eoo`009Goo00<007ooOol0
2Goo00<007ooOol0CGoo00<007ooOol06Woo0P002Woo0P0017oo00<007ooOol08goo0P00B7oo000U
Ool2000:Ool00`00Oomoo`1lOol00`00Oomoo`0QOol2001:Ool002Eoo`8000Yoo`03001oogoo07ao
o`03001oogoo01moo`8004aoo`0027oo0P0017oo0P0017oo0P000goo10000goo0P000goo0P002Woo
00<007ooOol0JWoo0P0017oo0P001Goo0`000Woo00<007ooOol07Goo0P00CWoo0007Ool01000Oomo
o`0027oo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool00`00Oomoo`08Ool00`00
Oomoo`1ZOol01000Oomoo`002goo00D007ooOomoo`0001eoo`80051oo`001goo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`020009Ool00`00Oomoo`1ZOol01000Oomo
o`0027oo1@000Woo00<007ooOol06Goo0P00DWoo0007Ool01000Oomoo`0027oo00@007ooOol000Ao
o`03001oogoo009oo`8000=oo`8000Uoo`03001oogoo06Yoo`04001oogoo0008Ool01000Oomoo`00
0goo00<007ooOol05goo0P00E7oo0007Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`1ZOol01000Oomoo`002Goo00<007oo
00000goo00<007ooOol05Woo00<007ooOol0E7oo0008Ool2000:Ool20004Ool20004Ool30002Ool2
0008Ool00`00Oomoo`1/Ool2000;Ool20003Ool00`00Oomoo`0EOol00`00Oomoo`1EOol002Eoo`80
00Qoo`03001oogoo07ioo`03001oogoo01Aoo`03001oogoo05Ioo`003Woo0P0017oo0P0017oo0P00
17oo0P000goo0P0027oo00<007ooOol0OWoo00<007ooOol04goo00<007ooOol0Egoo000=Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`1nOol0
0`00Oomoo`0BOol00`00Oomoo`1HOol000eoo`04001oogoo0008Ool01000Oomoo`001Goo00<007oo
Ool00P001goo00<007ooOol0KGoo0P0017oo0P000goo0`0017oo00<007ooOol04Goo00<007ooOol0
FGoo000=Ool01000Oomoo`0027oo00@007ooOol000=oo`8000=oo`8000Moo`03001oogoo06aoo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol047oo00<007ooOol0FWoo000=Ool01000Oomo
o`0027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo06aoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol03goo00<007ooOol0Fgoo000>Ool2000:Ool20004
Ool30002Ool20007Ool00`00Oomoo`1/Ool01000Oomoo`0027oo0`0017oo00<007ooOol03goo00<0
07ooOol0Fgoo000UOol20006Ool00`00Oomoo`1]Ool01000Oomoo`002Goo00<007ooOol00goo00<0
07ooOol03Woo00<007ooOol0G7oo0008Ool20004Ool20004Ool20005Ool00`00Oomoo`02Ool20003
Ool20006Ool00`00Oomoo`1^Ool2000:Ool30003Ool00`00Oomoo`0=Ool00`00Oomoo`1MOol000Mo
o`04001oogoo0008Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00
Oomoo`20Ool00`00Oomoo`0<Ool00`00Oomoo`1NOol000Moo`04001oogoo0008Ool01000Oomoo`00
17oo00<007ooOol017oo00<007ooOol00P001Woo00<007ooOol0P7oo00<007ooOol02goo00<007oo
Ool0Ggoo0007Ool01000Oomoo`0027oo00@007ooOol000Eoo`04001oogooOol20003Ool20005Ool0
0`00Oomoo`1_Ool20004Ool20004Ool20004Ool00`00Oomoo`0:Ool00`00Oomoo`1POol000Moo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00Ao
o`03001oogoo06ioo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol01goo10002Woo0P00
37oo0`002Goo0P002Goo0`0037oo00<007ooOol02Goo0P005Woo0008Ool2000:Ool20003Ool40003
Ool30002Ool20005Ool00`00Oomoo`1^Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Moo`03001oo`0000Yoo`04001oogoo000<Ool00`00Oomoo`07Ool01000Oomoo`0027oo00@007oo
Ool000]oo`03001oogoo00Qoo`04001oogoo000EOol002Eoo`8000Eoo`03001oogoo06ioo`04001o
ogoo0009Ool20004Ool00`00Oomoo`08Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool5000;Ool00`00
Oomoo`06Ool01000Oomoo`002goo00<007ooOol027oo00@007ooOol001Eoo`0057oo0P0017oo0P00
0goo1@0000=oo`00000017oo00<007ooOol0Kgoo00@007ooOol000Qoo`04001oogoo0003Ool00`00
Oomoo`08Ool2000=Ool00`00Oomoo`07Ool01000Oomoo`002Woo0P002Goo0`003Goo00<007ooOol0
27oo0P005Woo000COol01000Oomoo`002Woo00D007ooOomoo`0000Eoo`03001oogoo071oo`8000Yo
o`8000Aoo`03001oogoo00Moo`04001oogoo0009Ool01000Oomoo`002Woo00<007oo00002Woo00<0
07ooOol02Goo00<007ooOol02Goo00@007ooOol000Uoo`04001oogoo000EOol001=oo`04001oogoo
000:Ool01000Oomoogoo0P0017oo00<007ooOol0PWoo00<007ooOol01goo0`002goo0P0037oo0P00
2Woo0`002Goo0`002Goo10002Woo0P005Woo000COol01000Oomoo`002Woo00@007ooOomoo`8000Ao
o`03001oogoo089oo`03001oogoo00Ioo`03001oogoo06Aoo`004goo00@007ooOol000Yoo`05001o
ogooOol00004Ool00`00Oomoo`23Ool00`00Oomoo`06Ool00`00Oomoo`1TOol001Aoo`8000Yoo`80
00=oo`8000=oo`03001oogoo08=oo`03001oogoo00Eoo`03001oogoo05Moo`8000aoo`009Goo0P00
0goo00<007ooOol0Pgoo00<007ooOol01Goo00<007ooOol0EWoo00@007ooOol000]oo`0027oo0P00
17oo0P000goo1@0000=oo`0000000P000goo0P000goo0P000goo00<007ooOol0P7ooG`001Goo00<0
07ooOol037oo0007Ool01000Oomoo`002Woo00D007ooOomoo`0000Eoo`04001oogoo0002Ool01@00
Oomoogoo0000QWoo00<007ooOol017oo00<007ooOol0EWoo1@002goo0007Ool01000Oomoo`002Woo
00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00P000Woo00<007ooOol0Q7oo00<007ooOol0
0goo00<007ooOol0F7oo00<007ooOol037oo0007Ool01000Oomoo`002Woo00<007ooOol00goo00<0
07ooOol00Woo0P000goo0P000Woo00<007ooOol0Q7oo00<007ooOol00goo00<007ooOol0Igoo0007
Ool01000Oomoo`002Woo00D007ooOomoo`00009oo`05001oogooOol00004Ool01@00Oomoogoo0000
QWoo00<007ooOol00goo00<007ooOol0Igoo0008Ool2000:Ool20004Ool20004Ool30002Ool20000
0goo001oo`26Ool00`00Oomoo`02Ool00`00Oomoo`1XOol002Eoo`800003Ool007oo07=oo`D0009o
o`8000=oo`@000=oo`03001oogoo009oo`03001oogoo06Qoo`003Woo0P0017oo0P000goo1@000Woo
0P000goo0P0000=oo`00Ool0MGoo00<007ooOol01goo00<007ooOol017oo00D007ooOomoo`0006]o
o`003Goo00@007ooOol000Yoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0M7oo
00<007ooOol027oo00<007ooOol00goo00D007ooOomoo`0006]oo`003Goo00@007ooOol000Yoo`03
001oogoo00Aoo`03001oogoo00<007Moo`03001oogoo00Uoo`03001oogoo009oo`04001oogoo001/
Ool000eoo`04001oogoo000:Ool00`00Oomoo`02Ool20003Ool3001gOol00`00Oomoo`07Ool01000
Oomoo`000goo00@007ooOol006aoo`003Goo00@007ooOol000Yoo`03001oogoo009oo`03001oogoo
009oo`03001oo`0007Ioo`8000Yoo`8000Aoo`03001oo`0006eoo`003Woo0P002Woo0P0017oo0`00
0Woo0`00R7oo00<007oo0000KGoo000UOol20029Ool2001^Ool000Qoo`8000Aoo`8000=oo`D000=o
o`03001oogoo009oo`8000=oo`8008Uoo`8006ioo`001goo00@007ooOol000Yoo`03001oogoo00=o
o`05001oogooOol00002Ool00`00Oomoo`02001fOol50002Ool20005Ool30002Ool00`00Oomoo`1]
Ool000Moo`04001oogoo000:Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`02001hOol0
0`00Oomoo`0:Ool01@00Oomoogoo0000Kgoo0007Ool01000Oomoo`002Woo00<007ooOol017oo00@0
07ooOomoo`8000=oo`8007Qoo`03001oogoo00Moo`D0009oo`03001oogoo06eoo`001goo00@007oo
Ool000Yoo`05001oogooOol00002Ool01@00Oomoogoo000017oo00<007ooOol0Mgoo00<007ooOol0
1goo00@007ooOol000=oo`03001oogoo06eoo`0027oo0P002Woo0P000goo10000goo0`000Woo0P00
N7oo00<007ooOol027oo00<007oo0000Lgoo000UOol2001gOol2000;Ool2001cOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00VWoo10000Woo0`000Woo100027oo10000goo0`000Woo1000
0goo0P00FWoo002IOol01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0
0Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol005Uoo`0057oo00<007ooOol027oo0`00
0goo0P000Woo0P000Woo0P0000Aoo`00000000Aoo`80061oo`04001oogoo0004Ool00`00Oomoo`02
Ool00`00Oomoo`09Ool00`00Oomoo`02Ool40003Ool00`00Oomoo`02Ool00`00Oomoo`1JOol001=o
o`03001oo`0000Qoo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol0
009oo`03001oogoo05ioo`<000=oo`8000=oo`@000Qoo`@000=oo`8000=oo`@00003Ool0000000<0
05Uoo`004Woo0`002Goo00<007ooOol00goo00@007ooOol0009oo`04001oogoo0002Ool30003Ool0
0`00Oomoo`1SOol00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`0>Ool00`00Oomoo`1JOol0
01=oo`<000Uoo`<000=oo`80009oo`@000=oo`@00003Ool0000000<0065oo`8000Aoo`03001oogoo
00=oo`8000Yoo`8006]oo`004Woo00<007oo00008Goo00<007ooOol0igoo000COol00`00Oomoo`3o
Ool;Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00;Qoo`@000Uoo`8000aoo`<0
00Qoo`8000Uoo`<000aoo`03001oogoo00Qoo`8001]oo`00^7oo00<007ooOol02Goo00@007ooOol0
00aoo`03001oogoo00Ioo`04001oogoo0008Ool01000Oomoo`002goo00<007ooOol01goo00@007oo
Ool001Yoo`0027oo0P0017oo0P0017oo0P000goo1@000Woo0P0017oo00<007ooOol0T7oo00<007oo
Ool02Woo00<007ooOol027oo1@002Woo00<007ooOol01Woo00@007ooOol000]oo`03001oogoo00Mo
o`04001oogoo000JOol000Moo`04001oogoo0008Ool01000Oomoo`0017oo00D007ooOomoo`00009o
o`05001oogooOol0000GOol00`00Oomoo`1iOol00`00Oomoo`0:Ool00`00Oomoo`07Ool01000Oomo
o`002Goo0P002Goo0`003Goo00<007ooOol01goo0P006goo0007Ool01000Oomoo`0027oo00@007oo
Ool000Aoo`05001oogooOol00002Ool01@00Oomoogoo00005Woo00@007oo000007Moo`04001oogoo
0008Ool01000Oomoo`002Woo00<007oo00002Goo00<007ooOol02Goo00<007ooOol02Goo00@007oo
Ool000Qoo`04001oogoo000JOol000Moo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol0
0Woo0P0017oo00<007ooOol04goo00<007ooOol00Woo00<007ooOol0MGoo0P002Woo0P0037oo0P00
2Goo0`002Goo0`002Goo10002Goo0P006goo0007Ool01000Oomoo`0027oo00@007ooOol000Aoo`05
001oogooOol00002Ool01@00Oomoogoo00004goo0P001Woo0P00g7oo0008Ool2000:Ool20004Ool2
0004Ool20004Ool00`00Oomoo`0@Ool00`00Oomoo`08Ool00`00Oomoo`3IOol002Ioo`03001oogoo
00moo`03001oogoo00Yoo`800<Ioo`80015oo`009Woo00<007ooOol03Woo00<007ooOol03Goo00<0
07ooOol0HGooG0001Goo00@007ooOol0011oo`009Woo00<007ooOol03Goo00<007ooOol01Goo0`00
1goo0P002Woo0`005Woo0P00?goo00<007oo00000Woo00D007oo001oo`00009oo`03001oo`00009o
o`03001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03001oo`00009o
o`03001oo`00009oo`03001oo`00009oo`05001oo`00Ool00002Ool00`00Ool00002Ool00`00Ool0
0002Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00002Ool30007Ool00`00Oomoo`0AOol0
02Ioo`03001oogoo00]oo`8000Uoo`03001oogoo00Qoo`03001oogoo00Moo`04001oogoo000DOol0
1000Oomoo`00?Woo00<007ooOol0Cgoo0`0027oo1@0047oo000VOol00`00Oomoo`0:Ool00`00Oomo
o`06Ool5000:Ool00`00Oomoo`06Ool01000Oomoo`0057oo00@007ooOol003ioo`03001oogoo04ao
o`<000aoo`03001oogoo015oo`009Woo00<007ooOol02Goo00<007ooOol01goo00@007ooOol000ao
o`03001oogoo00Eoo`<001Ioo`8003moo`03001oogoo04Uoo`<002=oo`009Woo00<007ooOol02Goo
00<007ooOol027oo00<007oo00003Goo00<007ooOol01Goo00<007ooOol057oo00@007ooOol003io
o`03001oogoo04Ioo`<002Ioo`009Woo00<007ooOol02Goo00<007ooOol02Goo0P003Woo00<007oo
Ool017oo0`005Goo0P00?goo00<007ooOol0A7oo0P00:Goo000VOol00`00Oomoo`08Ool00`00Oomo
o`0KOol00`00Oomoo`1LOol00`00Oomoo`12Ool2000[Ool002Ioo`03001oogoo00Qoo`03001oogoo
01aoo`03001oogoo02moo`8002Yoo`03001oogoo041oo`8002eoo`009Woo00<007ooOol027oo00<0
07ooOol07Goo00<007ooOol0;Goo00@007ooOol002Uoo`03001oogoo03ioo`8002moo`005gooIP00
17oo00<007ooOol0:Woo00<007ooOol0?7oo0P00<Goo000VOol00`00Oomoo`07Ool00`00Oomoo`0;
Ool00`00Oomoo`0BOol01000Oomoo`005goo00<007ooOol03goo1@005goo0P0017oo0P000goo1000
0goo00<007ooOol0>Woo0P00<goo000VOol00`00Oomoo`07Ool00`00Oomoo`0QOol00`00Oomoo`0Z
Ool00`00Oomoo`0GOol01000Oomoo`0027oo00<007ooOol017oo00<007ooOol0>7oo0P00=Goo000V
Ool00`00Oomoo`07Ool00`00Oomoo`0ROol00`00Oomoo`13Ool01000Oomoo`002Goo00<007ooOol0
0goo00<007ooOol0=goo00<007ooOol0=Goo000VOol00`00Oomoo`07Ool00`00Oomoo`0SOol00`00
Oomoo`12Ool01000Oomoo`002Woo00<007ooOol00Woo00<007ooOol0=Goo0P00>7oo000VOol00`00
Oomoo`06Ool00`00Oomoo`0UOol00`00Oomoo`11Ool01000Oomoo`0027oo00@007ooOol000=oo`03
001oogoo03Aoo`03001oogoo03Qoo`009Woo00<007ooOol01Woo00<007ooOol09Woo00<007ooOol0
@Goo0P002Woo0P0017oo00<007ooOol0<Woo0P00>goo000VOol00`00Oomoo`06Ool00`00Oomoo`0W
Ool2001COol00`00Oomoo`0aOol00`00Oomoo`0kOol002Ioo`03001oogoo00Ioo`03001oogoo02Uo
o`03001oogoo051oo`03001oogoo02moo`8003ioo`009Woo00<007ooOol01Goo00<007ooOol0:goo
00<007ooOol0Cgoo00<007ooOol0;Woo00<007ooOol0?Woo000VOol00`00Oomoo`05Ool00`00Oomo
o`0/Ool00`00Oomoo`1>Ool00`00Oomoo`0]Ool00`00Oomoo`0oOol002Ioo`03001oogoo00Eoo`03
001oogoo02eoo`03001oogoo04eoo`03001oogoo02]oo`80049oo`009Woo00<007ooOol01Goo00<0
07ooOol0;Woo0P00CGoo00<007ooOol0:Woo00<007ooOol0@Woo0008Ool20004Ool20004Ool20003
Ool40002Ool40003Ool00`00Oomoo`04Ool00`00Oomoo`0aOol00`00Oomoo`1:Ool00`00Oomoo`0Y
Ool00`00Oomoo`13Ool000Moo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol00goo00<0
07ooOol017oo00<007ooOol017oo00<007ooOol0<Woo00<007ooOol0=goo0P0017oo0P0017oo0P00
17oo00<007ooOol09goo0P00AWoo0007Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00=oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo03=oo`8003Ioo`04001oogoo0008Ool0
1000Oomoo`000goo00<007ooOol09Woo00<007ooOol0AWoo0007Ool01000Oomoo`0027oo00@007oo
Ool000Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Eoo`03001o
ogoo03=oo`04001oogoo000:Ool00`00Oomoo`02Ool00`00Oomoo`0UOol00`00Oomoo`17Ool000Mo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomo
o`03Ool00`00Oomoo`0gOol2000cOol01000Oomoo`002goo00D007ooOomoo`0002Eoo`8004Yoo`00
27oo0P002Woo0P0017oo0P0017oo0P0017oo00<007ooOol00goo00<007ooOol0>Goo00<007ooOol0
<7oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`0ROol00`00Oomoo`1:Ool002Ioo`03
001oogoo00=oo`03001oogoo03Yoo`80035oo`8000Yoo`8000Aoo`03001oogoo021oo`8004eoo`00
9Woo00<007ooOol00goo00<007ooOol0?7oo00<007ooOol0@7oo00<007ooOol07goo00<007ooOol0
CGoo000VOol00`00Oomoo`02Ool00`00Oomoo`0nOol20010Ool00`00Oomoo`0MOol2001@Ool002Io
o`03001oogoo009oo`03001oogoo041oo`8003ioo`03001oogoo01aoo`03001oogoo051oo`009Woo
00<007ooOol00Woo00<007ooOol0@Woo0P00?7oo00<007ooOol06goo00<007ooOol0DGoo000VOol0
0`00Oomoo`02Ool00`00Oomoo`14Ool2000jOol00`00Oomoo`0IOol2001DOol002Ioo`05001oogoo
Ool00019Ool3000gOol00`00Oomoo`0HOol00`00Oomoo`1DOol002Ioo`05001oogooOol0001<Ool2
000eOol00`00Oomoo`0FOol2001GOol000Qoo`8000Aoo`8000Aoo`8000=oo`@000Aoo`<0009oo`05
001oogooOol0001>Ool2000QOol20004Ool20005Ool30002Ool00`00Oomoo`0EOol00`00Oomoo`1G
Ool000Moo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol01Woo00D007ooOomoo`0000=o
o`03001oogoo06ioo`04001oogoo000;Ool01@00Oomoogoo00005Woo00<007ooOol0F7oo0007Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`D0009oo`04001oogoo001aOol01000
Oomoo`0027oo1@000Woo00<007ooOol04Woo0P00Fgoo0007Ool01000Oomoo`0027oo00@007ooOol0
00Aoo`05001oogooOol00002Ool01@00Oomoogoo00000Woo00<007ooOol0Kgoo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`0AOol00`00Oomoo`1KOol000Moo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol000=oo`03001oo`0000=oo`04001oogoo001aOol01000Oomoo`002Goo
00<007oo00000goo00<007ooOol047oo00<007ooOol0G7oo0008Ool2000:Ool20004Ool20005Ool2
0003Ool01000Oomoo`00LWoo0P002goo0P000goo00<007ooOol03Woo0P00Ggoo000VOol00`00Ool0
0025Ool00`00Oomoo`0=Ool00`00Oomoo`1OOol001Yoo`03001oogoo00Uoo`03001oo`0008Eoo`03
001oogoo00aoo`03001oogoo061oo`006goo00<007ooOol027oo00<007oo0000QGoo00<007ooOol0
2Woo0P00Hgoo000LOol20008Ool00`00Ool00025Ool00`00Oomoo`09Ool00`00Oomoo`1SOol001io
o`03001oogoo00Eoo`8008Ioo`03001oogoo00Moo`8006Ioo`007goo00<007ooOol017oo0P00QWoo
00<007ooOol01Woo00<007ooOol0IWoo000POol20004Ool20026Ool00`00Oomoo`04Ool2001YOol0
029oo`04001oogooOol2001dOol20004Ool20004Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`1Y
Ool002=oo`04001oogoo001dOol01000Oomoo`0027oo00@007ooOol000=oo`04001oogooOol2001/
Ool000Qoo`8000Aoo`8000Aoo`8000=oo`@0009oo`<0009oo`<007Aoo`04001oogoo000;Ool01@00
Oomoogoo00000Woo00<007ooOol0K7oo0007Ool01000Oomoo`0027oo00@007ooOol0009oo`03001o
ogoo00=oo`04001oogoo0003Ool00`00Oomoo`1bOol01000Oomoo`002Goo0P0017oo0`00Kgoo0007
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo009oo`04001oogoo0003Ool00`00Oomo
o`1bOol01000Oomoo`002Goo00<007ooOol00goo00<007ooOol0Kgoo0007Ool01000Oomoo`0027oo
00@007ooOol000Aoo`04001oogooOol30004Ool00`00Oomoo`1cOol2000:Ool30003Ool00`00Oomo
o`1_Ool000Moo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo08]o
o`03001oogoo06moo`0027oo0P002Woo0P0017oo0P0017oo0`00oGoo003oOolQOol00?moob5oo`00
ogoo8Goo002SOol3001jOol002=oo`800003Ool0000007ioo`03001oogoo07Moo`0097oo00<007oo
0000OGoo0`000goo0`0000=oo`0000000Woo0P000Woo0`00Igoo000TOol3001lOol01000Oomoo`00
17oo00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo06Ioo`0097oo00@007oo000007]o
o`04001oogoo0004Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol0IWoo000TOol0
0`00Oomoo`1mOol40002Ool20002Ool40004Ool2001XOol002=oo`800?]oo`00Zgoo00<007ooOol0
2Goo00<007ooOol0IWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00<7oo10001goo0P0027oo
0`001Woo0P001goo0`0027oo00<007ooOol01Woo0P00CWoo10002Woo0P002goo0`0027oo0P002Goo
0`0037oo00<007ooOol027oo0P0067oo000`Ool00`00Oomoo`07Ool01000Oomoo`0027oo00<007oo
Ool017oo00@007ooOol000Ioo`04001oogoo0007Ool00`00Oomoo`05Ool01000Oomoo`00CGoo00<0
07ooOol02Woo00@007ooOol000]oo`03001oogoo00Ioo`04001oogoo0008Ool01000Oomoo`002goo
00<007ooOol01goo00@007ooOol001Moo`00<Goo00<007ooOol027oo00<007ooOol017oo1@0027oo
00<007ooOol017oo00@007ooOol000Moo`03001oogoo00Eoo`04001oogoo001>Ool00`00Oomoo`0;
Ool00`00Oomoo`07Ool5000:Ool00`00Oomoo`06Ool01000Oomoo`002goo00<007ooOol01goo00@0
07ooOol001Moo`00<Woo00<007ooOol027oo00<007ooOol00goo00@007ooOol000Moo`8000Moo`<0
00Uoo`03001oogoo00Eoo`80051oo`03001oogoo00]oo`03001oogoo00Ioo`04001oogoo0009Ool2
0009Ool3000=Ool00`00Oomoo`07Ool2000HOol0031oo`04001oogoo0006Ool01000Oomoo`001Woo
00<007oo00001goo00<007ooOol01goo00<007ooOol01Goo00@007ooOol000Ioo`04001oogoo001=
Ool01000Oomoo`002Goo00@007ooOol000Uoo`03001oo`0000Uoo`03001oogoo00Uoo`03001oogoo
00Uoo`04001oogoo0008Ool01000Oomoo`005goo000aOol20008Ool20008Ool20007Ool30007Ool3
0005Ool40007Ool2001?Ool2000;Ool2000;Ool20009Ool30009Ool30009Ool40009Ool2000HOol0
0?moob5oo`00M7oo0P00VGoo0P003goo001cOol01000Oomoo`00Ugoo00@007ooOol000ioo`009Woo
B@0017oo00<007ooOol0>GooF`0017oo00<007ooOol03goo001bOol5000jOol00`00Oomoo`1>Ool6
0005Ool5000>Ool007=oo`03001oogoo03]oo`03001oogoo045oo`d000aoo`03001oogoo00moo`00
/Goo00<007ooOol0>Goo2000:goo002aOol00`00Oomoo`0eOol4000cOol009Uoo`D0009oo`8000Ao
o`8000Aoo`8000=oo`03001oogoo035oo`@003Moo`00Vgoo00<007ooOol01goo00@007ooOol0009o
o`04001oogoo0002Ool00`00Oomoo`0]Ool4000kOol009]oo`03001oogoo00Moo`04001oogoo0005
Ool00`00Oomoo`02000/Ool2000oOol009]oo`03001oogoo00Moo`04001oogoo0003Ool20003Ool0
0`00Oomoo`0YOol20011Ool009]oo`03001oogoo00Moo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`0VOol30013Ool009Yoo`8000Yoo`8000Aoo`<0009oo`03001oogoo02Aoo`8004Ioo`00
/Goo00<007ooOol08Woo0P00B7oo000XOol00`00Oomoo`1dOol50002Ool20003Ool500000goo001o
o`0ROol00`00Oomoo`18Ool002Qoo`03001oogoo07Ioo`03001oogoo00Uoo`05001oogooOol0000Q
Ool2001;Ool002Qoo`03001oogoo07Ioo`03001oogoo00Uoo`04001oogooOol2000OOol00`00Oomo
o`1;Ool002Qoo`8007Moo`03001oogoo00Uoo`05001oogooOol0000OOol00`00Oomoo`1<Ool002Qo
o`8007Moo`03001oogoo00Uoo`05001oogooOol0000MOol2001?Ool002Qoo`8007Ioo`8000Yoo`80
00=oo`03001oogoo01Yoo`03001oogoo04moo`00:7oo0P00Qgoo00<007ooOol06Goo00<007ooOol0
D7oo000FOol50002Ool20005Ool3000017oo001oo`00KWoo1@000Woo0P000goo1@000Woo0P000goo
00<007ooOol05goo0P00Dgoo000HOol00`00Oomoo`0:Ool01P00Oomoo`00Ool0071oo`03001oogoo
00Uoo`05001oogooOol00002Ool01000Oomoo`0067oo00<007ooOol0Dgoo000HOol00`00Oomoo`07
Ool5000017oo00000000L7oo00<007ooOol02Goo00<007ooOol017oo00<007ooOol00P005Woo00<0
07ooOol0E7oo000HOol00`00Oomoo`07Ool01000Oomoo`000Woo00@007ooOol006moo`03001oogoo
00Uoo`03001oogoo009oo`8000=oo`03001oogoo01Aoo`03001oogoo05Eoo`0067oo00<007ooOol0
27oo00<007oo00000Woo00@007ooOol006moo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo01Aoo`03001oogoo05Eoo`005goo0P002goo0P000Woo00@007ooOol006ioo`80
00Yoo`8000Aoo`<0009oo`03001oogoo01=oo`03001oogoo05Ioo`00:7oo00@007ooOol008Eoo`03
001oogoo019oo`03001oogoo05Moo`00:7oo00D007ooOomoo`00079oo`D0009oo`8000=oo`@0009o
o`03001oogoo015oo`03001oogoo05Qoo`00:7oo00D007ooOomoo`0007Aoo`03001oogoo00Moo`03
001oogoo00=oo`03001oogoo011oo`03001oogoo05Uoo`00:7oo00D007ooOomoo`0007Aoo`03001o
ogoo00Qoo`03001oogoo009oo`80011oo`03001oogoo05Yoo`00:7oo00<007ooOol00Woo00<007oo
Ool0LGoo00<007ooOol02Goo00D007ooOomoo`00015oo`03001oogoo05Yoo`005Woo1@000Woo0P00
0goo0`000goo00<007ooOol00Woo00<007ooOol0LGoo00<007ooOol01goo00@007ooOol0009oo`03
001oogoo00ioo`03001oogoo05]oo`0067oo00<007ooOol01goo00@007ooOol0009oo`03001oogoo
009oo`03001oogoo071oo`8000Yoo`8000=oo`03001oogoo00eoo`03001oogoo05aoo`0067oo00<0
07ooOol01goo00@007ooOol0009oo`8000=oo`03001oogoo085oo`03001oogoo00aoo`03001oogoo
05eoo`0067oo00<007ooOol01goo0`000goo00<007ooOol00goo00<007ooOol0J7oo1@000Woo0P00
0goo10000goo0P000goo00<007ooOol02goo00<007ooOol0GWoo000HOol00`00Oomoo`08Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`1ZOol00`00Oomoo`07Ool00`00Oomoo`03Ool01000
Oomoo`000Woo00<007ooOol02goo00<007ooOol0GWoo000GOol2000:Ool30002Ool00`00Oomoo`03
Ool00`00Oomoo`1ZOol00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`02000;Ool00`00Oomo
o`1OOol002Qoo`03001oogoo00Aoo`03001oogoo06Uoo`03001oogoo00Uoo`03001oogoo009oo`80
00=oo`03001oogoo00Uoo`03001oogoo061oo`00:7oo00<007ooOol017oo00<007ooOol0JGoo00<0
07ooOol01goo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo065oo`00
:7oo00<007ooOol017oo00<007ooOol0J7oo0P002Woo0P0017oo0`000Woo00<007ooOol027oo00<0
07ooOol0HGoo000XOol00`00Oomoo`04Ool00`00Oomoo`1oOol00`00Oomoo`07Ool00`00Oomoo`1R
Ool002Qoo`03001oogoo00Eoo`03001oogoo06aoo`D0009oo`8000Aoo`8000=oo`03001oogoo00Io
o`03001oogoo06=oo`005Woo1@000Woo0P0017oo0P000goo00<007ooOol01Goo00<007ooOol0KWoo
00<007ooOol01goo00@007ooOol0009oo`03001oogoo00Ioo`03001oogoo06=oo`0067oo00<007oo
Ool01goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo06ioo`03001oogoo00Uoo`04001o
ogooOol20006Ool00`00Oomoo`1TOol001Qoo`03001oogoo00Moo`04001oogoo0002Ool20007Ool0
0`00Oomoo`1]Ool00`00Oomoo`0:Ool01000Oomoo`001Woo00<007ooOol0IGoo000HOol00`00Oomo
o`08Ool20003Ool00`00Oomoo`06Ool00`00Oomoo`0dOol5000dOol00`00Oomoo`07Ool01000Oomo
o`000Woo00<007ooOol017oo00<007ooOol0IGoo000HOol00`00Oomoo`07Ool01000Oomoo`000Woo
00<007ooOol01Woo00<007ooOol0:Woo2P00>7oo0P002Woo0P000goo00<007ooOol00goo00<007oo
Ool0IWoo000GOol2000:Ool20003Ool00`00Oomoo`06Ool00`00Oomoo`0TOol6001COol00`00Oomo
o`02Ool00`00Oomoo`1WOol002Qoo`03001oogoo00Moo`03001oogoo021oo`<0045oo`D0009oo`80
00Aoo`8000Aoo`8000=oo`03001oogoo009oo`03001oogoo06Moo`00:7oo00<007ooOol01goo00<0
07ooOol077oo1000AWoo00<007ooOol01goo00@007ooOol0009oo`04001oogoo0002Ool01@00Oomo
ogoo0000JWoo000XOol00`00Oomoo`08Ool2000IOol3001:Ool00`00Oomoo`09Ool00`00Oomoo`04
Ool00`00Oomoo`0200000goo001oo`1ZOol002Qoo`03001oogoo00Yoo`03001oogoo01=oo`<004eo
o`03001oogoo00Yoo`04001oogooOol20003Ool01000Oomoo`00Jgoo000ROol40002Ool00`00Oomo
o`0;Ool00`00Oomoo`0>Ool4001@Ool00`00Oomoo`07Ool01000Oomoo`000goo00<007ooOol00Woo
00<007oo0000K7oo000ROol00`00Oomoo`03Ool00`00Oomoo`0<Ool2000;Ool3001COol2000:Ool2
0004Ool30002Ool2001]Ool002=oo`03001oogoo009oo`8000moo`03001oogoo00Eoo`<006eoo`80
06eoo`0097oo00D007ooOomoo`00015oo`80009oo`<0071oo`03001oogoo06aoo`008Woo00@007oo
Ool0009oo`03001oogoo015oo`8007=oo`03001oogoo06aoo`008goo0P000goo00<007ooOol0mGoo
003oOolQOol00?moob5oo`00ogoo8Goo000VOol3003gOol002Uoo`03001oogoo0?Aoo`009goo0`00
Q7oo0P000Woo0P00K7oo000VOol01000Oomoo`00QGoo00@007ooOol006eoo`009Woo00@007ooOol0
08Eoo`04001oogoo001]Ool002Moo`@008=oo`@006ioo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {270.188, 0}} -> {-0.050401, -0.0470982, \
0.00731988, 0.00731988}, {{6.875, 136.938}, {263.75, 183.313}} -> {-2.14251, \
-0.0626783, 0.0827283, 0.0035778}, {{150, 280.063}, {263.75, 183.313}} -> \
{-12.7691, -0.18793, 0.0782335, 0.0236197}, {{6.875, 136.938}, {175.25, \
94.875}} -> {-1.18196, 0.00420074, 0.0834424, 0.000137752}, {{150, 280.063}, \
{175.25, 94.875}} -> {-13.0807, -0.716985, 0.0808751, 0.00777536}, {{6.875, \
136.938}, {86.8125, 6.375}} -> {-3.19806, -2.59769, 0.103174, 0.0186152}, \
{{150, 280.063}, {86.8125, 6.375}} -> {-13.482, -0.365468, 0.0815895, \
0.00705663}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Tau] =  .2; \[Kappa] =  .1; defvar; initcond; simul; 
    result2;\), "\[IndentingNewLine]", 
    \(plou[4, 1] = \@growth\%30 - 1; plou[4, 2] = \@popgrowth\%30 - 1; 
    plou[4, 3] = ginix; plou[4, 4] = 2\ cfd;\)}], "Input"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 9, 5, 
          12, 16}\),
      SequenceForm[ "Start simulation ", {2002, 6, 9, 5, 12, 16}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          9, 5, 12, 27}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 9, 5, 12, 27}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 9, 5, 12, 55}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 9, 5, 12, 
        55}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 9, 5, 12, 56}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 9, 5, 12, 56}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 5, 35, 37}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 5, 35, 37}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 9, 5, 
          35, 38}\),
      SequenceForm[ "Start simulation ", {2002, 6, 9, 5, 35, 38}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          9, 5, 35, 48}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 9, 5, 35, 48}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 9, 5, 36, 16}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 9, 5, 36, 
        16}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 9, 5, 36, 17}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 9, 5, 36, 17}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 5, 59, 3}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 5, 59, 3}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]2\),
      SequenceForm[ "step", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 9, 5, 
          59, 4}\),
      SequenceForm[ "Start simulation ", {2002, 6, 9, 5, 59, 4}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          9, 5, 59, 14}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 9, 5, 59, 14}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 9, 5, 59, 42}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 9, 5, 59, 
        42}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 9, 5, 59, 43}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 9, 5, 59, 43}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 6, 22, 24}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 6, 22, 24}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]3\),
      SequenceForm[ "step", 3],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 9, 6, 
          22, 26}\),
      SequenceForm[ "Start simulation ", {2002, 6, 9, 6, 22, 26}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          9, 6, 22, 36}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 9, 6, 22, 36}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 9, 6, 23, 4}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 9, 6, 23, 4}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 9, 6, 23, 5}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 9, 6, 23, 5}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 6, 45, 56}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 6, 45, 56}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]4\),
      SequenceForm[ "step", 4],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 9, 6, 
          45, 58}\),
      SequenceForm[ "Start simulation ", {2002, 6, 9, 6, 45, 58}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          9, 6, 46, 8}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 9, 6, 46, 8}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 9, 6, 46, 36}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 9, 6, 46, 
        36}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 9, 6, 46, 37}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 9, 6, 46, 37}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 7, 9, 22}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 7, 9, 22}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]5\),
      SequenceForm[ "step", 5],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 9, 7, 
          9, 24}\),
      SequenceForm[ "Start simulation ", {2002, 6, 9, 7, 9, 24}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          9, 7, 9, 34}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 9, 7, 9, 34}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 9, 7, 10, 1}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 9, 7, 10, 1}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 9, 7, 10, 2}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 9, 7, 10, 2}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 7, 32, 49}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 7, 32, 49}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]6\),
      SequenceForm[ "step", 6],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 9, 7, 
          32, 51}\),
      SequenceForm[ "Start simulation ", {2002, 6, 9, 7, 32, 51}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          9, 7, 33, 1}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 9, 7, 33, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 9, 7, 33, 29}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 9, 7, 33, 
        29}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 9, 7, 33, 30}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 9, 7, 33, 30}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 7, 56, 14}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 7, 56, 14}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]7\),
      SequenceForm[ "step", 7],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start simulation "\[InvisibleSpace]{2002, 6, 9, 7, 
          56, 16}\),
      SequenceForm[ "Start simulation ", {2002, 6, 9, 7, 56, 16}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start sorting households "\[InvisibleSpace]{2002, 6, 
          9, 7, 56, 26}\),
      SequenceForm[ "Start sorting households ", {2002, 6, 9, 7, 56, 26}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the cumulative distribution "\
\[InvisibleSpace]{2002, 6, 9, 7, 56, 54}\),
      SequenceForm[ 
      "Start computing the cumulative distribution ", {2002, 6, 9, 7, 56, 
        54}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start drawing random numbers \
"\[InvisibleSpace]{2002, 6, 9, 7, 56, 55}\),
      SequenceForm[ "Start drawing random numbers ", {2002, 6, 9, 7, 56, 55}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Start computing the error of approximation "\
\[InvisibleSpace]{2002, 6, 9, 8, 19, 45}\),
      SequenceForm[ 
      "Start computing the error of approximation ", {2002, 6, 9, 8, 19, 45}],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]8\),
      SequenceForm[ "step", 8],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .94177 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.022423 0.47619 [
[ 0 0 0 0 ]
[ 1 .94177 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .94177 L
0 .94177 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.022423 0.477324 0.302711 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112245 0.136054 0.0147151 2.90669 [
[.15986 .00222 -3 -9 ]
[.15986 .00222 3 0 ]
[.29592 .00222 -3 -9 ]
[.29592 .00222 3 0 ]
[.43197 .00222 -3 -9 ]
[.43197 .00222 3 0 ]
[.56803 .00222 -3 -9 ]
[.56803 .00222 3 0 ]
[.70408 .00222 -3 -9 ]
[.70408 .00222 3 0 ]
[.84014 .00222 -3 -9 ]
[.84014 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6.28125 ]
[1.025 .01472 10 6.28125 ]
[.01131 .16005 -24 -4.5 ]
[.01131 .16005 0 4.5 ]
[.01131 .30538 -18 -4.5 ]
[.01131 .30538 0 4.5 ]
[.01131 .45072 -24 -4.5 ]
[.01131 .45072 0 4.5 ]
[.01131 .59605 -18 -4.5 ]
[.01131 .59605 0 4.5 ]
[.02381 .64303 -23 0 ]
[.02381 .64303 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 .01472 m
.15986 .02097 L
s
[(2)] .15986 .00222 0 1 Mshowa
.29592 .01472 m
.29592 .02097 L
s
[(3)] .29592 .00222 0 1 Mshowa
.43197 .01472 m
.43197 .02097 L
s
[(4)] .43197 .00222 0 1 Mshowa
.56803 .01472 m
.56803 .02097 L
s
[(5)] .56803 .00222 0 1 Mshowa
.70408 .01472 m
.70408 .02097 L
s
[(6)] .70408 .00222 0 1 Mshowa
.84014 .01472 m
.84014 .02097 L
s
[(7)] .84014 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(8)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05102 .01472 m
.05102 .01847 L
s
.07823 .01472 m
.07823 .01847 L
s
.10544 .01472 m
.10544 .01847 L
s
.13265 .01472 m
.13265 .01847 L
s
.18707 .01472 m
.18707 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.2415 .01472 m
.2415 .01847 L
s
.26871 .01472 m
.26871 .01847 L
s
.32313 .01472 m
.32313 .01847 L
s
.35034 .01472 m
.35034 .01847 L
s
.37755 .01472 m
.37755 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45918 .01472 m
.45918 .01847 L
s
.48639 .01472 m
.48639 .01847 L
s
.51361 .01472 m
.51361 .01847 L
s
.54082 .01472 m
.54082 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62245 .01472 m
.62245 .01847 L
s
.64966 .01472 m
.64966 .01847 L
s
.67687 .01472 m
.67687 .01847 L
s
.73129 .01472 m
.73129 .01847 L
s
.7585 .01472 m
.7585 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.81293 .01472 m
.81293 .01847 L
s
.86735 .01472 m
.86735 .01847 L
s
.89456 .01472 m
.89456 .01847 L
s
.92177 .01472 m
.92177 .01847 L
s
.94898 .01472 m
.94898 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.02381 .16005 m
.03006 .16005 L
s
[(0.05)] .01131 .16005 1 0 Mshowa
.02381 .30538 m
.03006 .30538 L
s
[(0.1)] .01131 .30538 1 0 Mshowa
.02381 .45072 m
.03006 .45072 L
s
[(0.15)] .01131 .45072 1 0 Mshowa
.02381 .59605 m
.03006 .59605 L
s
[(0.2)] .01131 .59605 1 0 Mshowa
.125 Mabswid
.02381 .04378 m
.02756 .04378 L
s
.02381 .07285 m
.02756 .07285 L
s
.02381 .10192 m
.02756 .10192 L
s
.02381 .13098 m
.02756 .13098 L
s
.02381 .18912 m
.02756 .18912 L
s
.02381 .21818 m
.02756 .21818 L
s
.02381 .24725 m
.02756 .24725 L
s
.02381 .27632 m
.02756 .27632 L
s
.02381 .33445 m
.02756 .33445 L
s
.02381 .36352 m
.02756 .36352 L
s
.02381 .39258 m
.02756 .39258 L
s
.02381 .42165 m
.02756 .42165 L
s
.02381 .47978 m
.02756 .47978 L
s
.02381 .50885 m
.02756 .50885 L
s
.02381 .53792 m
.02756 .53792 L
s
.02381 .56699 m
.02756 .56699 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(%) show
75.000 12.813 moveto
(const) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .55856 m
.15986 .60332 L
.29592 .01472 L
.43197 .01472 L
.56803 .01472 L
.70408 .01472 L
.84014 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.022423 0.97619 0.302711 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112245 0.136054 -0.0750224 0.484329 [
[.15986 .39681 -3 -9 ]
[.15986 .39681 3 0 ]
[.29592 .39681 -3 -9 ]
[.29592 .39681 3 0 ]
[.43197 .39681 -3 -9 ]
[.43197 .39681 3 0 ]
[.56803 .39681 -3 -9 ]
[.56803 .39681 3 0 ]
[.70408 .39681 -3 -9 ]
[.70408 .39681 3 0 ]
[.84014 .39681 -3 -9 ]
[.84014 .39681 3 0 ]
[.97619 .39681 -3 -9 ]
[.97619 .39681 3 0 ]
[1.025 .40931 0 -6.28125 ]
[1.025 .40931 10 6.28125 ]
[.01131 .02184 -18 -4.5 ]
[.01131 .02184 0 4.5 ]
[.01131 .11871 -18 -4.5 ]
[.01131 .11871 0 4.5 ]
[.01131 .21557 -18 -4.5 ]
[.01131 .21557 0 4.5 ]
[.01131 .31244 -18 -4.5 ]
[.01131 .31244 0 4.5 ]
[.01131 .50617 -18 -4.5 ]
[.01131 .50617 0 4.5 ]
[.01131 .60304 -18 -4.5 ]
[.01131 .60304 0 4.5 ]
[.02381 .64303 -26 0 ]
[.02381 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 .40931 m
.15986 .41556 L
s
[(2)] .15986 .39681 0 1 Mshowa
.29592 .40931 m
.29592 .41556 L
s
[(3)] .29592 .39681 0 1 Mshowa
.43197 .40931 m
.43197 .41556 L
s
[(4)] .43197 .39681 0 1 Mshowa
.56803 .40931 m
.56803 .41556 L
s
[(5)] .56803 .39681 0 1 Mshowa
.70408 .40931 m
.70408 .41556 L
s
[(6)] .70408 .39681 0 1 Mshowa
.84014 .40931 m
.84014 .41556 L
s
[(7)] .84014 .39681 0 1 Mshowa
.97619 .40931 m
.97619 .41556 L
s
[(8)] .97619 .39681 0 1 Mshowa
.125 Mabswid
.05102 .40931 m
.05102 .41306 L
s
.07823 .40931 m
.07823 .41306 L
s
.10544 .40931 m
.10544 .41306 L
s
.13265 .40931 m
.13265 .41306 L
s
.18707 .40931 m
.18707 .41306 L
s
.21429 .40931 m
.21429 .41306 L
s
.2415 .40931 m
.2415 .41306 L
s
.26871 .40931 m
.26871 .41306 L
s
.32313 .40931 m
.32313 .41306 L
s
.35034 .40931 m
.35034 .41306 L
s
.37755 .40931 m
.37755 .41306 L
s
.40476 .40931 m
.40476 .41306 L
s
.45918 .40931 m
.45918 .41306 L
s
.48639 .40931 m
.48639 .41306 L
s
.51361 .40931 m
.51361 .41306 L
s
.54082 .40931 m
.54082 .41306 L
s
.59524 .40931 m
.59524 .41306 L
s
.62245 .40931 m
.62245 .41306 L
s
.64966 .40931 m
.64966 .41306 L
s
.67687 .40931 m
.67687 .41306 L
s
.73129 .40931 m
.73129 .41306 L
s
.7585 .40931 m
.7585 .41306 L
s
.78571 .40931 m
.78571 .41306 L
s
.81293 .40931 m
.81293 .41306 L
s
.86735 .40931 m
.86735 .41306 L
s
.89456 .40931 m
.89456 .41306 L
s
.92177 .40931 m
.92177 .41306 L
s
.94898 .40931 m
.94898 .41306 L
s
.25 Mabswid
0 .40931 m
1 .40931 L
s
gsave
1.025 .40931 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.02381 .02184 m
.03006 .02184 L
s
[(0.2)] .01131 .02184 1 0 Mshowa
.02381 .11871 m
.03006 .11871 L
s
[(0.4)] .01131 .11871 1 0 Mshowa
.02381 .21557 m
.03006 .21557 L
s
[(0.6)] .01131 .21557 1 0 Mshowa
.02381 .31244 m
.03006 .31244 L
s
[(0.8)] .01131 .31244 1 0 Mshowa
.02381 .50617 m
.03006 .50617 L
s
[(1.2)] .01131 .50617 1 0 Mshowa
.02381 .60304 m
.03006 .60304 L
s
[(1.4)] .01131 .60304 1 0 Mshowa
.125 Mabswid
.02381 .04606 m
.02756 .04606 L
s
.02381 .07028 m
.02756 .07028 L
s
.02381 .09449 m
.02756 .09449 L
s
.02381 .14293 m
.02756 .14293 L
s
.02381 .16714 m
.02756 .16714 L
s
.02381 .19136 m
.02756 .19136 L
s
.02381 .23979 m
.02756 .23979 L
s
.02381 .26401 m
.02756 .26401 L
s
.02381 .28822 m
.02756 .28822 L
s
.02381 .33666 m
.02756 .33666 L
s
.02381 .36087 m
.02756 .36087 L
s
.02381 .38509 m
.02756 .38509 L
s
.02381 .43352 m
.02756 .43352 L
s
.02381 .45774 m
.02756 .45774 L
s
.02381 .48196 m
.02756 .48196 L
s
.02381 .53039 m
.02756 .53039 L
s
.02381 .5546 m
.02756 .5546 L
s
.02381 .57882 m
.02756 .57882 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dif) show
87.000 12.813 moveto
(fert) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .5987 m
.15986 .60332 L
.29592 .42607 L
.43197 .25193 L
.56803 .14471 L
.70408 .07813 L
.84014 .03788 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.330739 0.477324 0.611027 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0952381 0.119048 -0.85827 57.3252 [
[.38095 .27573 -3 -9 ]
[.38095 .27573 3 0 ]
[.61905 .27573 -3 -9 ]
[.61905 .27573 3 0 ]
[.85714 .27573 -3 -9 ]
[.85714 .27573 3 0 ]
[1.025 .28823 0 -6.28125 ]
[1.025 .28823 10 6.28125 ]
[.13036 .05893 -30 -4.5 ]
[.13036 .05893 0 4.5 ]
[.13036 .17358 -30 -4.5 ]
[.13036 .17358 0 4.5 ]
[.13036 .40288 -30 -4.5 ]
[.13036 .40288 0 4.5 ]
[.13036 .51753 -30 -4.5 ]
[.13036 .51753 0 4.5 ]
[.14286 .64303 -5 0 ]
[.14286 .64303 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.38095 .28823 m
.38095 .29448 L
s
[(4)] .38095 .27573 0 1 Mshowa
.61905 .28823 m
.61905 .29448 L
s
[(6)] .61905 .27573 0 1 Mshowa
.85714 .28823 m
.85714 .29448 L
s
[(8)] .85714 .27573 0 1 Mshowa
.125 Mabswid
.20238 .28823 m
.20238 .29198 L
s
.2619 .28823 m
.2619 .29198 L
s
.32143 .28823 m
.32143 .29198 L
s
.44048 .28823 m
.44048 .29198 L
s
.5 .28823 m
.5 .29198 L
s
.55952 .28823 m
.55952 .29198 L
s
.67857 .28823 m
.67857 .29198 L
s
.7381 .28823 m
.7381 .29198 L
s
.79762 .28823 m
.79762 .29198 L
s
.08333 .28823 m
.08333 .29198 L
s
.02381 .28823 m
.02381 .29198 L
s
.91667 .28823 m
.91667 .29198 L
s
.97619 .28823 m
.97619 .29198 L
s
.25 Mabswid
0 .28823 m
1 .28823 L
s
gsave
1.025 .28823 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.14286 .05893 m
.14911 .05893 L
s
[(0.016)] .13036 .05893 1 0 Mshowa
.14286 .17358 m
.14911 .17358 L
s
[(0.018)] .13036 .17358 1 0 Mshowa
.14286 .40288 m
.14911 .40288 L
s
[(0.022)] .13036 .40288 1 0 Mshowa
.14286 .51753 m
.14911 .51753 L
s
[(0.024)] .13036 .51753 1 0 Mshowa
.125 Mabswid
.14286 .08759 m
.14661 .08759 L
s
.14286 .11626 m
.14661 .11626 L
s
.14286 .14492 m
.14661 .14492 L
s
.14286 .20225 m
.14661 .20225 L
s
.14286 .23091 m
.14661 .23091 L
s
.14286 .25957 m
.14661 .25957 L
s
.14286 .3169 m
.14661 .3169 L
s
.14286 .34556 m
.14661 .34556 L
s
.14286 .37422 m
.14661 .37422 L
s
.14286 .43155 m
.14661 .43155 L
s
.14286 .46021 m
.14661 .46021 L
s
.14286 .48887 m
.14661 .48887 L
s
.14286 .03027 m
.14661 .03027 L
s
.14286 .00161 m
.14661 .00161 L
s
.14286 .5462 m
.14661 .5462 L
s
.14286 .57486 m
.14661 .57486 L
s
.14286 .60352 m
.14661 .60352 L
s
.25 Mabswid
.14286 0 m
.14286 .61803 L
s
gsave
.14286 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .5573 m
.14286 .60332 L
.2619 .29693 L
.38095 .08978 L
.5 .01472 L
.61905 .03967 L
.7381 .11464 L
.85714 .20755 L
.97619 .29265 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.330739 0.97619 0.611027 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112245 0.136054 -0.624146 2.26866 [
[.15986 .04395 -3 -9 ]
[.15986 .04395 3 0 ]
[.29592 .04395 -3 -9 ]
[.29592 .04395 3 0 ]
[.43197 .04395 -3 -9 ]
[.43197 .04395 3 0 ]
[.56803 .04395 -3 -9 ]
[.56803 .04395 3 0 ]
[.70408 .04395 -3 -9 ]
[.70408 .04395 3 0 ]
[.84014 .04395 -3 -9 ]
[.84014 .04395 3 0 ]
[.97619 .04395 -3 -9 ]
[.97619 .04395 3 0 ]
[1.025 .05645 0 -6.28125 ]
[1.025 .05645 10 6.28125 ]
[.01131 .16989 -24 -4.5 ]
[.01131 .16989 0 4.5 ]
[.01131 .28332 -18 -4.5 ]
[.01131 .28332 0 4.5 ]
[.01131 .39675 -24 -4.5 ]
[.01131 .39675 0 4.5 ]
[.01131 .51018 -18 -4.5 ]
[.01131 .51018 0 4.5 ]
[.02381 .64303 -14 0 ]
[.02381 .64303 14 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 .05645 m
.15986 .0627 L
s
[(2)] .15986 .04395 0 1 Mshowa
.29592 .05645 m
.29592 .0627 L
s
[(3)] .29592 .04395 0 1 Mshowa
.43197 .05645 m
.43197 .0627 L
s
[(4)] .43197 .04395 0 1 Mshowa
.56803 .05645 m
.56803 .0627 L
s
[(5)] .56803 .04395 0 1 Mshowa
.70408 .05645 m
.70408 .0627 L
s
[(6)] .70408 .04395 0 1 Mshowa
.84014 .05645 m
.84014 .0627 L
s
[(7)] .84014 .04395 0 1 Mshowa
.97619 .05645 m
.97619 .0627 L
s
[(8)] .97619 .04395 0 1 Mshowa
.125 Mabswid
.05102 .05645 m
.05102 .0602 L
s
.07823 .05645 m
.07823 .0602 L
s
.10544 .05645 m
.10544 .0602 L
s
.13265 .05645 m
.13265 .0602 L
s
.18707 .05645 m
.18707 .0602 L
s
.21429 .05645 m
.21429 .0602 L
s
.2415 .05645 m
.2415 .0602 L
s
.26871 .05645 m
.26871 .0602 L
s
.32313 .05645 m
.32313 .0602 L
s
.35034 .05645 m
.35034 .0602 L
s
.37755 .05645 m
.37755 .0602 L
s
.40476 .05645 m
.40476 .0602 L
s
.45918 .05645 m
.45918 .0602 L
s
.48639 .05645 m
.48639 .0602 L
s
.51361 .05645 m
.51361 .0602 L
s
.54082 .05645 m
.54082 .0602 L
s
.59524 .05645 m
.59524 .0602 L
s
.62245 .05645 m
.62245 .0602 L
s
.64966 .05645 m
.64966 .0602 L
s
.67687 .05645 m
.67687 .0602 L
s
.73129 .05645 m
.73129 .0602 L
s
.7585 .05645 m
.7585 .0602 L
s
.78571 .05645 m
.78571 .0602 L
s
.81293 .05645 m
.81293 .0602 L
s
.86735 .05645 m
.86735 .0602 L
s
.89456 .05645 m
.89456 .0602 L
s
.92177 .05645 m
.92177 .0602 L
s
.94898 .05645 m
.94898 .0602 L
s
.25 Mabswid
0 .05645 m
1 .05645 L
s
gsave
1.025 .05645 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.02381 .16989 m
.03006 .16989 L
s
[(0.35)] .01131 .16989 1 0 Mshowa
.02381 .28332 m
.03006 .28332 L
s
[(0.4)] .01131 .28332 1 0 Mshowa
.02381 .39675 m
.03006 .39675 L
s
[(0.45)] .01131 .39675 1 0 Mshowa
.02381 .51018 m
.03006 .51018 L
s
[(0.5)] .01131 .51018 1 0 Mshowa
.125 Mabswid
.02381 .07914 m
.02756 .07914 L
s
.02381 .10183 m
.02756 .10183 L
s
.02381 .12451 m
.02756 .12451 L
s
.02381 .1472 m
.02756 .1472 L
s
.02381 .19257 m
.02756 .19257 L
s
.02381 .21526 m
.02756 .21526 L
s
.02381 .23795 m
.02756 .23795 L
s
.02381 .26063 m
.02756 .26063 L
s
.02381 .306 m
.02756 .306 L
s
.02381 .32869 m
.02756 .32869 L
s
.02381 .35138 m
.02756 .35138 L
s
.02381 .37406 m
.02756 .37406 L
s
.02381 .41944 m
.02756 .41944 L
s
.02381 .44212 m
.02756 .44212 L
s
.02381 .46481 m
.02756 .46481 L
s
.02381 .4875 m
.02756 .4875 L
s
.02381 .53287 m
.02756 .53287 L
s
.02381 .55556 m
.02756 .55556 L
s
.02381 .57824 m
.02756 .57824 L
s
.02381 .60093 m
.02756 .60093 L
s
.02381 .03377 m
.02756 .03377 L
s
.02381 .01108 m
.02756 .01108 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(gini) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .55645 m
.15986 .57664 L
.29592 .60332 L
.43197 .56505 L
.56803 .45363 L
.70408 .29842 L
.84014 .15011 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.639056 0.477324 0.919343 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112245 0.136054 -0.968347 0.77457 [
[.15986 -0.20628 -3 -9 ]
[.15986 -0.20628 3 0 ]
[.29592 -0.20628 -3 -9 ]
[.29592 -0.20628 3 0 ]
[.43197 -0.20628 -3 -9 ]
[.43197 -0.20628 3 0 ]
[.56803 -0.20628 -3 -9 ]
[.56803 -0.20628 3 0 ]
[.70408 -0.20628 -3 -9 ]
[.70408 -0.20628 3 0 ]
[.84014 -0.20628 -3 -9 ]
[.84014 -0.20628 3 0 ]
[.97619 -0.20628 -3 -9 ]
[.97619 -0.20628 3 0 ]
[1.025 -0.19378 0 -6.28125 ]
[1.025 -0.19378 10 6.28125 ]
[.01131 .03859 -18 -4.5 ]
[.01131 .03859 0 4.5 ]
[.01131 .11605 -18 -4.5 ]
[.01131 .11605 0 4.5 ]
[.01131 .19351 -18 -4.5 ]
[.01131 .19351 0 4.5 ]
[.01131 .27096 -18 -4.5 ]
[.01131 .27096 0 4.5 ]
[.01131 .34842 -18 -4.5 ]
[.01131 .34842 0 4.5 ]
[.01131 .42588 -18 -4.5 ]
[.01131 .42588 0 4.5 ]
[.01131 .50334 -18 -4.5 ]
[.01131 .50334 0 4.5 ]
[.01131 .58079 -6 -4.5 ]
[.01131 .58079 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12.5625 ]
[ 0 -0.19378 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 -0.19378 m
.15986 -0.18753 L
s
[(2)] .15986 -0.20628 0 1 Mshowa
.29592 -0.19378 m
.29592 -0.18753 L
s
[(3)] .29592 -0.20628 0 1 Mshowa
.43197 -0.19378 m
.43197 -0.18753 L
s
[(4)] .43197 -0.20628 0 1 Mshowa
.56803 -0.19378 m
.56803 -0.18753 L
s
[(5)] .56803 -0.20628 0 1 Mshowa
.70408 -0.19378 m
.70408 -0.18753 L
s
[(6)] .70408 -0.20628 0 1 Mshowa
.84014 -0.19378 m
.84014 -0.18753 L
s
[(7)] .84014 -0.20628 0 1 Mshowa
.97619 -0.19378 m
.97619 -0.18753 L
s
[(8)] .97619 -0.20628 0 1 Mshowa
.125 Mabswid
.05102 -0.19378 m
.05102 -0.19003 L
s
.07823 -0.19378 m
.07823 -0.19003 L
s
.10544 -0.19378 m
.10544 -0.19003 L
s
.13265 -0.19378 m
.13265 -0.19003 L
s
.18707 -0.19378 m
.18707 -0.19003 L
s
.21429 -0.19378 m
.21429 -0.19003 L
s
.2415 -0.19378 m
.2415 -0.19003 L
s
.26871 -0.19378 m
.26871 -0.19003 L
s
.32313 -0.19378 m
.32313 -0.19003 L
s
.35034 -0.19378 m
.35034 -0.19003 L
s
.37755 -0.19378 m
.37755 -0.19003 L
s
.40476 -0.19378 m
.40476 -0.19003 L
s
.45918 -0.19378 m
.45918 -0.19003 L
s
.48639 -0.19378 m
.48639 -0.19003 L
s
.51361 -0.19378 m
.51361 -0.19003 L
s
.54082 -0.19378 m
.54082 -0.19003 L
s
.59524 -0.19378 m
.59524 -0.19003 L
s
.62245 -0.19378 m
.62245 -0.19003 L
s
.64966 -0.19378 m
.64966 -0.19003 L
s
.67687 -0.19378 m
.67687 -0.19003 L
s
.73129 -0.19378 m
.73129 -0.19003 L
s
.7585 -0.19378 m
.7585 -0.19003 L
s
.78571 -0.19378 m
.78571 -0.19003 L
s
.81293 -0.19378 m
.81293 -0.19003 L
s
.86735 -0.19378 m
.86735 -0.19003 L
s
.89456 -0.19378 m
.89456 -0.19003 L
s
.92177 -0.19378 m
.92177 -0.19003 L
s
.94898 -0.19378 m
.94898 -0.19003 L
s
.25 Mabswid
0 -0.19378 m
1 -0.19378 L
s
gsave
1.025 -0.19378 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.02381 .03859 m
.03006 .03859 L
s
[(1.3)] .01131 .03859 1 0 Mshowa
.02381 .11605 m
.03006 .11605 L
s
[(1.4)] .01131 .11605 1 0 Mshowa
.02381 .19351 m
.03006 .19351 L
s
[(1.5)] .01131 .19351 1 0 Mshowa
.02381 .27096 m
.03006 .27096 L
s
[(1.6)] .01131 .27096 1 0 Mshowa
.02381 .34842 m
.03006 .34842 L
s
[(1.7)] .01131 .34842 1 0 Mshowa
.02381 .42588 m
.03006 .42588 L
s
[(1.8)] .01131 .42588 1 0 Mshowa
.02381 .50334 m
.03006 .50334 L
s
[(1.9)] .01131 .50334 1 0 Mshowa
.02381 .58079 m
.03006 .58079 L
s
[(2)] .01131 .58079 1 0 Mshowa
.125 Mabswid
.02381 .05409 m
.02756 .05409 L
s
.02381 .06958 m
.02756 .06958 L
s
.02381 .08507 m
.02756 .08507 L
s
.02381 .10056 m
.02756 .10056 L
s
.02381 .13154 m
.02756 .13154 L
s
.02381 .14703 m
.02756 .14703 L
s
.02381 .16253 m
.02756 .16253 L
s
.02381 .17802 m
.02756 .17802 L
s
.02381 .209 m
.02756 .209 L
s
.02381 .22449 m
.02756 .22449 L
s
.02381 .23998 m
.02756 .23998 L
s
.02381 .25547 m
.02756 .25547 L
s
.02381 .28646 m
.02756 .28646 L
s
.02381 .30195 m
.02756 .30195 L
s
.02381 .31744 m
.02756 .31744 L
s
.02381 .33293 m
.02756 .33293 L
s
.02381 .36391 m
.02756 .36391 L
s
.02381 .3794 m
.02756 .3794 L
s
.02381 .3949 m
.02756 .3949 L
s
.02381 .41039 m
.02756 .41039 L
s
.02381 .44137 m
.02756 .44137 L
s
.02381 .45686 m
.02756 .45686 L
s
.02381 .47235 m
.02756 .47235 L
s
.02381 .48784 m
.02756 .48784 L
s
.02381 .51883 m
.02756 .51883 L
s
.02381 .53432 m
.02756 .53432 L
s
.02381 .54981 m
.02756 .54981 L
s
.02381 .5653 m
.02756 .5653 L
s
.02381 .0231 m
.02756 .0231 L
s
.02381 .00761 m
.02756 .00761 L
s
.02381 .59628 m
.02756 .59628 L
s
.02381 .61178 m
.02756 .61178 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(g) show
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .01472 m
.15986 .19871 L
.29592 .39056 L
.43197 .55543 L
.56803 .60332 L
.70408 .59068 L
.84014 .54988 L
.97619 .51802 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.639056 0.97619 0.919343 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112245 0.136054 -1.4218 1.36009 [
[.15986 -0.07421 -3 -9 ]
[.15986 -0.07421 3 0 ]
[.29592 -0.07421 -3 -9 ]
[.29592 -0.07421 3 0 ]
[.43197 -0.07421 -3 -9 ]
[.43197 -0.07421 3 0 ]
[.56803 -0.07421 -3 -9 ]
[.56803 -0.07421 3 0 ]
[.70408 -0.07421 -3 -9 ]
[.70408 -0.07421 3 0 ]
[.84014 -0.07421 -3 -9 ]
[.84014 -0.07421 3 0 ]
[.97619 -0.07421 -3 -9 ]
[.97619 -0.07421 3 0 ]
[1.025 -0.06171 0 -6.28125 ]
[1.025 -0.06171 10 6.28125 ]
[.01131 .0743 -18 -4.5 ]
[.01131 .0743 0 4.5 ]
[.01131 .21031 -18 -4.5 ]
[.01131 .21031 0 4.5 ]
[.01131 .34632 -18 -4.5 ]
[.01131 .34632 0 4.5 ]
[.01131 .48233 -18 -4.5 ]
[.01131 .48233 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12.5625 ]
[ 0 -0.06171 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 -0.06171 m
.15986 -0.05546 L
s
[(2)] .15986 -0.07421 0 1 Mshowa
.29592 -0.06171 m
.29592 -0.05546 L
s
[(3)] .29592 -0.07421 0 1 Mshowa
.43197 -0.06171 m
.43197 -0.05546 L
s
[(4)] .43197 -0.07421 0 1 Mshowa
.56803 -0.06171 m
.56803 -0.05546 L
s
[(5)] .56803 -0.07421 0 1 Mshowa
.70408 -0.06171 m
.70408 -0.05546 L
s
[(6)] .70408 -0.07421 0 1 Mshowa
.84014 -0.06171 m
.84014 -0.05546 L
s
[(7)] .84014 -0.07421 0 1 Mshowa
.97619 -0.06171 m
.97619 -0.05546 L
s
[(8)] .97619 -0.07421 0 1 Mshowa
.125 Mabswid
.05102 -0.06171 m
.05102 -0.05796 L
s
.07823 -0.06171 m
.07823 -0.05796 L
s
.10544 -0.06171 m
.10544 -0.05796 L
s
.13265 -0.06171 m
.13265 -0.05796 L
s
.18707 -0.06171 m
.18707 -0.05796 L
s
.21429 -0.06171 m
.21429 -0.05796 L
s
.2415 -0.06171 m
.2415 -0.05796 L
s
.26871 -0.06171 m
.26871 -0.05796 L
s
.32313 -0.06171 m
.32313 -0.05796 L
s
.35034 -0.06171 m
.35034 -0.05796 L
s
.37755 -0.06171 m
.37755 -0.05796 L
s
.40476 -0.06171 m
.40476 -0.05796 L
s
.45918 -0.06171 m
.45918 -0.05796 L
s
.48639 -0.06171 m
.48639 -0.05796 L
s
.51361 -0.06171 m
.51361 -0.05796 L
s
.54082 -0.06171 m
.54082 -0.05796 L
s
.59524 -0.06171 m
.59524 -0.05796 L
s
.62245 -0.06171 m
.62245 -0.05796 L
s
.64966 -0.06171 m
.64966 -0.05796 L
s
.67687 -0.06171 m
.67687 -0.05796 L
s
.73129 -0.06171 m
.73129 -0.05796 L
s
.7585 -0.06171 m
.7585 -0.05796 L
s
.78571 -0.06171 m
.78571 -0.05796 L
s
.81293 -0.06171 m
.81293 -0.05796 L
s
.86735 -0.06171 m
.86735 -0.05796 L
s
.89456 -0.06171 m
.89456 -0.05796 L
s
.92177 -0.06171 m
.92177 -0.05796 L
s
.94898 -0.06171 m
.94898 -0.05796 L
s
.25 Mabswid
0 -0.06171 m
1 -0.06171 L
s
gsave
1.025 -0.06171 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.02381 .0743 m
.03006 .0743 L
s
[(1.1)] .01131 .0743 1 0 Mshowa
.02381 .21031 m
.03006 .21031 L
s
[(1.2)] .01131 .21031 1 0 Mshowa
.02381 .34632 m
.03006 .34632 L
s
[(1.3)] .01131 .34632 1 0 Mshowa
.02381 .48233 m
.03006 .48233 L
s
[(1.4)] .01131 .48233 1 0 Mshowa
.125 Mabswid
.02381 .1015 m
.02756 .1015 L
s
.02381 .12871 m
.02756 .12871 L
s
.02381 .15591 m
.02756 .15591 L
s
.02381 .18311 m
.02756 .18311 L
s
.02381 .23751 m
.02756 .23751 L
s
.02381 .26471 m
.02756 .26471 L
s
.02381 .29192 m
.02756 .29192 L
s
.02381 .31912 m
.02756 .31912 L
s
.02381 .37352 m
.02756 .37352 L
s
.02381 .40072 m
.02756 .40072 L
s
.02381 .42793 m
.02756 .42793 L
s
.02381 .45513 m
.02756 .45513 L
s
.02381 .50953 m
.02756 .50953 L
s
.02381 .53673 m
.02756 .53673 L
s
.02381 .56393 m
.02756 .56393 L
s
.02381 .59114 m
.02756 .59114 L
s
.02381 .0471 m
.02756 .0471 L
s
.02381 .0199 m
.02756 .0199 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .45821 m
.15986 .60332 L
.29592 .53758 L
.43197 .35485 L
.56803 .20743 L
.70408 .10838 L
.84014 .05139 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 271.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00013a000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol002]oo`@000Yo
o`8000]oo`<000Uoo`8000Uoo`<000aoo`03001oogoo00Qoo`800:Moo`00:goo00<007ooOol02Woo
00@007ooOol000]oo`03001oogoo00Moo`04001oogoo0008Ool01000Oomoo`002goo00<007ooOol0
1goo00@007ooOol00:Ioo`00;7oo00<007ooOol02goo00<007ooOol01goo1@002goo00<007ooOol0
1Woo00@007ooOol000]oo`03001oogoo00Moo`04001oogoo002VOol002eoo`03001oogoo00]oo`03
001oogoo00Ioo`04001oogoo000:Ool20009Ool3000=Ool00`00Oomoo`07Ool2002WOol002]oo`04
001oogoo0009Ool01000Oomoo`002Goo00<007oo00002Woo00<007ooOol02Goo00<007ooOol02Goo
00@007ooOol000Qoo`04001oogoo000TOol20004Ool20003Ool40003Ool00`00Oomoo`1]Ool002ao
o`8000]oo`8000]oo`8000Yoo`<000Uoo`<000Uoo`@000Uoo`8002Aoo`04001oogoo0008Ool00`00
Oomoo`04Ool00`00Oomoo`1COol4000FOol009eoo`04001oogoo0009Ool00`00Oomoo`03Ool00`00
Oomoo`1=Ool6000JOol0085oo`8001Yoo`04001oogoo000:Ool00`00Oomoo`02Ool00`00Oomoo`18
Ool5000POol0025oo`03001oogoo05aoo`04001oogoo000IOol01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo04Eoo`<002Eoo`007gooG@0017oo00<007ooOol06goo0P002Woo0P0017oo00<0
07ooOol0@Goo1000:7oo000QOol00`00Oomoo`0FOol00`00Oomoo`12Ool5000/Ool00`00Oomoo`0n
Ool3000/Ool0025oo`03001oogoo01Ioo`03001oogoo04=oo`03001oogoo02eoo`03001oogoo03ao
o`8002moo`008Goo00<007ooOol05Goo00<007ooOol0M7oo00<007ooOol0>Woo0P00<Goo000QOol0
0`00Oomoo`0EOol00`00Oomoo`1ROol20004Ool20005Ool30002Ool00`00Oomoo`0hOol2000cOol0
025oo`03001oogoo01Eoo`03001oogoo065oo`04001oogoo000;Ool01@00Oomoogoo0000>7oo0P00
=Goo000QOol00`00Oomoo`0EOol00`00Oomoo`1QOol01000Oomoo`0027oo1@000Woo00<007ooOol0
=7oo0P00=goo000QOol00`00Oomoo`0DOol00`00Oomoo`1ROol01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo039oo`8003Uoo`008Goo00<007ooOol057oo00<007ooOol0HWoo00@007ooOol0
00Uoo`03001oo`0000=oo`03001oogoo031oo`8003]oo`008Goo00<007ooOol057oo00<007ooOol0
Hgoo0P002goo0P000goo00<007ooOol0;goo00<007ooOol0>goo000QOol00`00Oomoo`0DOol00`00
Oomoo`1eOol00`00Oomoo`0]Ool2000nOol000Yoo`8000Aoo`8000Aoo`8000Aoo`8000=oo`03001o
ogoo01=oo`03001oogoo07Ioo`03001oogoo02aoo`03001oogoo03ioo`002Goo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol04goo00<007ooOol0MWoo00<007ooOol0
:goo00<007ooOol0?goo0009Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo008001Ao
o`03001oogoo06Aoo`8000Aoo`8000=oo`<000Aoo`03001oogoo02Uoo`80049oo`002Goo00@007oo
Ool000Qoo`04001oogoo0003Ool20003Ool00`00Oomoo`0COol00`00Oomoo`1SOol01000Oomoo`00
27oo00@007ooOol000=oo`03001oogoo02Qoo`03001oogoo049oo`002Goo00@007ooOol000Qoo`04
001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`1TOol01000Oomoo`0027oo
00@007ooOol000=oo`03001oogoo02Moo`03001oogoo04=oo`002Woo0P002Woo0P0017oo0`000Woo
00<007ooOol04Woo00<007ooOol0I7oo00@007ooOol000Qoo`<000Aoo`03001oogoo02Eoo`8004Io
o`008Goo00<007ooOol04Woo00<007ooOol0I7oo00@007ooOol000Uoo`03001oogoo00=oo`03001o
ogoo02Aoo`03001oogoo04Ioo`008Goo00<007ooOol04Woo00<007ooOol0IGoo0P002Woo0`000goo
00<007ooOol08goo00<007ooOol0Agoo000QOol00`00Oomoo`0AOol00`00Oomoo`1hOol00`00Oomo
o`0ROol00`00Oomoo`18Ool0025oo`03001oogoo015oo`03001oogoo07Qoo`03001oogoo025oo`03
001oogoo04Uoo`008Goo00<007ooOol04Goo00<007ooOol0N7oo00<007ooOol08Goo00<007ooOol0
BGoo000QOol00`00Oomoo`0AOol00`00Oomoo`1VOol20004Ool20004Ool20004Ool00`00Oomoo`0P
Ool00`00Oomoo`1:Ool0025oo`03001oogoo011oo`03001oogoo06Ioo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol07goo00<007ooOol0Bgoo000QOol00`00Oomoo`0@Ool00`00Oomoo`1V
Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Moo`@000Yoo`8000Moo`03001oogoo
009oo`<000Uoo`8000Uoo`<000aoo`03001oogoo00Uoo`8001Ioo`0047oo0P0017oo0P000goo1@00
00=oo`00Ool04Goo00<007ooOol0IWoo00@007ooOol000Uoo`8000Aoo`03001oogoo00Moo`03001o
ogoo00Yoo`04001oogoo0006Ool00`00Oomoo`03Ool00`00Oomoo`07Ool01000Oomoo`0027oo00@0
07ooOol000]oo`03001oogoo00Qoo`04001oogoo000EOol000moo`04001oogoo000:Ool01@00Oomo
ogoo00004Woo00<007ooOol0IWoo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`08Ool0
0`00Oomoo`0;Ool00`00Oomoo`04Ool01000Oomoogoo1@002goo00<007ooOol01Woo00@007ooOol0
00]oo`03001oogoo00Qoo`04001oogoo000EOol000moo`04001oogoo000:Ool01000Oomoogoo0P00
47oo00<007ooOol0J7oo0P002Woo0P0017oo00<007ooOol02Goo00<007ooOol02goo00<007ooOol0
0Woo00<007ooOol00Woo00@007ooOol000Yoo`8000Uoo`<000eoo`03001oogoo00Qoo`8001Ioo`00
3goo00@007ooOol000Yoo`05001oogooOol0000AOol00`00Oomoo`1jOol00`00Oomoo`07Ool01000
Oomoo`002Goo00@007ooOol000=oo`03001oogoo00Aoo`03001oo`0000Yoo`03001oogoo00Uoo`03
001oogoo00Uoo`04001oogoo0009Ool01000Oomoo`005Goo000?Ool01000Oomoo`002Woo00D007oo
Oomoo`00015oo`03001oogoo07Yoo`03001oogoo00Qoo`8000]oo`8000Aoo`03001oogoo00Eoo`80
00Yoo`<000Uoo`<000Uoo`@000Yoo`8001Ioo`0047oo0P002Woo0P000goo00<007ooOol03goo00<0
07ooOol0NWoo00<007ooOol06Woo00<007ooOol0D7oo000QOol00`00Oomoo`0?Ool00`00Oomoo`1j
Ool00`00Oomoo`0IOol00`00Oomoo`1AOol0025oo`03001oogoo00ioo`03001oogoo07]oo`03001o
ogoo01Qoo`03001oogoo04Aoo`8000aoo`008Goo00<007ooOol03Woo00<007ooOol0N7ooG`001Goo
00@007ooOol000]oo`008Goo00<007ooOol03Woo00<007ooOol0Ngoo00<007oo00000Woo00<007oo
00000Woo00<007oo00000Woo00<007oo00000Woo00D007ooOol007oo00800004Ool007oo0002Ool0
0`00Ool00002Ool00`00Ool00002Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oo`00
009oo`03001oo`00009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<007oo00000Woo00<0
07oo00000Woo00<007ooOol01Goo00<007ooOol037oo000QOol00`00Oomoo`0>Ool00`00Oomoo`1k
Ool00`00Oomoo`0FOol00`00Oomoo`14Ool5000;Ool0025oo`03001oogoo00eoo`03001oogoo07ao
o`03001oogoo01Eoo`03001oogoo04Ioo`03001oogoo00aoo`008Goo00<007ooOol03Goo00<007oo
Ool0O7oo00<007ooOol057oo00<007ooOol0EWoo000:Ool20004Ool20003Ool50002Ool20003Ool0
0`00Oomoo`0=Ool00`00Oomoo`1lOol00`00Oomoo`0DOol00`00Oomoo`1FOol000Uoo`04001oogoo
000:Ool01@00Oomoogoo00000Woo00@007ooOol000moo`03001oogoo07aoo`03001oogoo01=oo`03
001oogoo05Moo`002Goo00@007ooOol000Yoo`03001oogoo00Aoo`03001oogoo008000eoo`03001o
ogoo06Yoo`D0009oo`8000=oo`@000=oo`03001oogoo019oo`03001oogoo05Qoo`002Goo00@007oo
Ool000Yoo`03001oogoo009oo`8000=oo`03001oogoo00aoo`03001oogoo06aoo`03001oogoo00Mo
o`03001oogoo00Aoo`03001oogoo015oo`03001oogoo05Uoo`002Goo00@007ooOol000Yoo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo00aoo`03001oogoo06aoo`03001oogoo00Qoo`03001o
ogoo00=oo`03001oogoo011oo`03001oogoo05Yoo`002Woo0P002Woo0P0017oo0`000Woo00<007oo
Ool037oo00<007ooOol0K7oo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol03goo00<007oo
Ool0Fgoo000QOol00`00Oomoo`0;Ool00`00Oomoo`1]Ool00`00Oomoo`07Ool01000Oomoo`000goo
00<007ooOol03goo00<007ooOol0Fgoo000QOol00`00Oomoo`0;Ool00`00Oomoo`1/Ool2000:Ool2
0004Ool00`00Oomoo`0>Ool00`00Oomoo`1LOol0025oo`03001oogoo00]oo`03001oogoo07ioo`03
001oogoo00eoo`03001oogoo05eoo`008Goo00<007ooOol02goo00<007ooOol0OWoo00<007ooOol0
37oo00<007ooOol0GWoo000QOol00`00Oomoo`0:Ool00`00Oomoo`1oOol00`00Oomoo`0;Ool00`00
Oomoo`1OOol0025oo`03001oogoo00Yoo`03001oogoo06aoo`D0009oo`8000Eoo`<0009oo`03001o
ogoo00]oo`03001oogoo05moo`008Goo0P002goo00<007ooOol0KWoo00<007ooOol02Woo00D007oo
Oomoo`0000aoo`03001oogoo061oo`0047oo0P0017oo0P000goo10000Woo00<007oo00000P0027oo
00<007ooOol0KWoo00<007ooOol01goo1@000Woo3@00Hgoo000?Ool01000Oomoo`0027oo00<007oo
Ool00goo00<007ooOol00Woo0`0017oo00<007ooOol0Kgoo00<007ooOol01goo00@007ooOol000=o
o`03001oogoo06eoo`003goo00@007ooOol000Uoo`03001oogoo009oo`8000Ioo`<00003Ool007oo
071oo`03001oogoo00Qoo`03001oo`0000=oo`03001oogoo06eoo`003goo00@007ooOol000Yoo`05
001oogooOol0000:Ool2001`Ool2000;Ool2001cOol000moo`04001oogoo0008Ool01000Oomoo`00
0Woo00<007ooOol0o7oo000@Ool2000:Ool2003oOol3Ool00?moob5oo`00ogoo8Goo003oOolQOol0
09Yoo`@0009oo`<0009oo`@000Qoo`@000=oo`<0009oo`@000=oo`8005Yoo`00VGoo00@007ooOol0
00Aoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
009oo`04001oogoo001IOol000moo`03001oogoo00Qoo`<000=oo`80009oo`80009oo`800004Ool0
00000004Ool2001UOol01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0
0Woo10000goo00<007ooOol00Woo00<007ooOol0FWoo000>Ool00`00Ool00008Ool00`00Oomoo`03
Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo0002Ool00`00Oomoo`1SOol30003Ool2
0003Ool40008Ool40003Ool20003Ool400000goo00000003001IOol000eoo`<000Uoo`03001oogoo
00=oo`04001oogoo0002Ool01000Oomoo`000Woo0`000goo00<007ooOol0J7oo00<007ooOol01goo
00<007ooOol02Goo00<007ooOol03Woo00<007ooOol0FWoo000>Ool30009Ool30003Ool20002Ool4
0003Ool400000goo00000003001VOol20004Ool00`00Oomoo`03Ool2000:Ool2001[Ool000eoo`03
001oo`00025oo`03001oogoo0>aoo`003Woo00<007ooOol0ogoo47oo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo000VOol00`00Oomoo`2AOol40009Ool2000<Ool30009Ool2000:Ool3
000<Ool00`00Oomoo`09Ool2000FOol002Ioo`03001oogoo025oo`8006ioo`03001oogoo00Uoo`04
001oogoo000<Ool00`00Oomoo`07Ool01000Oomoo`002Goo00@007ooOol000]oo`03001oogoo00Qo
o`04001oogoo000EOol002Ioo`03001oogoo01moo`80009oo`@006]oo`03001oogoo00Yoo`03001o
ogoo00Qoo`D000]oo`03001oogoo00Moo`04001oogoo000;Ool00`00Oomoo`08Ool01000Oomoo`00
5Goo000VOol00`00Oomoo`0NOol00`00Oomoo`06Ool4001XOol00`00Oomoo`0:Ool00`00Oomoo`07
Ool01000Oomoo`002Woo0P002Woo0`003Goo00<007ooOol027oo0P005Woo0008Ool20004Ool20004
Ool20003Ool5000017oo0000000017oo00<007ooOol077oo0P003Goo0`00F7oo00<007ooOol027oo
00@007ooOol000Qoo`04001oogoo000:Ool00`00Ool0000:Ool00`00Oomoo`0:Ool00`00Oomoo`09
Ool01000Oomoo`002Goo00@007ooOol001Eoo`001goo00@007ooOol000Qoo`04001oogoo0004Ool0
1@00Oomoogoo00000Woo00D007ooOomoo`0001eoo`03001oogoo011oo`8005Ioo`03001oogoo00Uo
o`8000Yoo`8000aoo`8000Yoo`<000Yoo`<000Uoo`@000Yoo`8001Ioo`001goo00@007ooOol000Qo
o`04001oogoo0004Ool01@00Oomoogoo00000Woo00D007ooOomoo`0001]oo`8001Eoo`8005Aoo`03
001oogoo05Ioo`03001oogoo01Eoo`001goo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomo
ogoo0`0017oo00<007ooOol067oo00<007ooOol05goo00<007ooOol0DGoo00<007ooOol0EGoo00<0
07ooOol05Woo0007Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo01Ioo`8001]oo`80055oo`03001oogoo05Aoo`03001oogoo00Uoo`8000aoo`00
27oo0P002Woo0P0017oo0P0017oo0`000goo00<007ooOol05Goo00<007ooOol07Goo0P00C7ooH000
1Goo00@007ooOol000]oo`009Woo00<007ooOol057oo00<007ooOol087oo0P00CGoo00<007oo0000
0Woo00<007oo00000Woo00H007ooOol007oo0002Ool00`00Ool00002Ool00`00Ool00002Ool01P00
Oomoo`00Ool0009oo`03001oo`00009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<007oo
00000Woo00H007ooOol007oo0002Ool00`00Ool00002Ool00`00Ool00002Ool01P00Oomoo`00Ool0
009oo`03001oo`00009oo`03001oogoo00Eoo`03001oogoo00aoo`009Woo00<007ooOol057oo00<0
07ooOol08Woo00<007ooOol0BWoo00<007ooOol0DGoo00<007ooOol02Woo1@002goo000VOol00`00
Oomoo`0COol00`00Oomoo`0TOol00`00Oomoo`19Ool00`00Oomoo`1@Ool00`00Oomoo`0<Ool00`00
Oomoo`0<Ool002Ioo`03001oogoo01=oo`03001oogoo02Eoo`03001oogoo04Qoo`03001oogoo04mo
o`03001oogoo01aoo`009Woo00<007ooOol04Woo00<007ooOol09goo0P00B7oo00<007ooOol0CWoo
00<007ooOol07Goo0008Ool20004Ool20004Ool20003Ool50002Ool20004Ool00`00Oomoo`0BOol0
0`00Oomoo`0YOol00`00Oomoo`15Ool00`00Oomoo`1=Ool00`00Oomoo`0NOol000Moo`04001oogoo
0008Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`05001oogooOol0000COol00`00Oomoo`0[
Ool00`00Oomoo`14Ool00`00Oomoo`1<Ool00`00Oomoo`0OOol000Moo`04001oogoo0008Ool01000
Oomoo`0017oo00D007ooOomoo`00009oo`05001oogooOol0000BOol00`00Oomoo`0]Ool00`00Oomo
o`13Ool00`00Oomoo`1;Ool00`00Oomoo`0POol000Moo`04001oogoo0008Ool01000Oomoo`0017oo
00<007ooOol00Woo0P0017oo00<007ooOol047oo00<007ooOol0;Woo00<007ooOol0:goo0P0017oo
0P0017oo0P0017oo0P000goo00<007ooOol0BWoo00<007ooOol08Goo0007Ool01000Oomoo`0027oo
00@007ooOol000Aoo`05001oogooOol00002Ool01@00Oomoogoo00004Goo00<007ooOol0<7oo0P00
:Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol0BGoo00<007oo
Ool08Woo0008Ool2000:Ool20004Ool20004Ool20004Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool3
000COol3000FOol2000XOol01000Oomoo`002Woo00<007ooOol017oo00@007ooOol004Yoo`03001o
ogoo02=oo`009Woo00<007ooOol03Woo00<007ooOol01Goo00<007ooOol04Woo00@007ooOol001Ao
o`04001oo`00000WOol01000Oomoo`002goo00@007ooOomoo`8000=oo`03001oogoo04Moo`03001o
ogoo02Aoo`009Woo00<007ooOol03Woo00<007ooOol00Woo1@004goo00@007ooOol001Aoo`03001o
ogoo008002Ioo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol0AWoo
00<007ooOol09Goo000VOol00`00Oomoo`0=Ool00`00Oomoo`03Ool01000Oomoo`0057oo0`005Woo
0P000Woo00<007ooOol097oo0P002Woo0P0017oo0`000Woo00<007ooOol0AGoo00<007ooOol09Woo
000VOol00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Ool0000EOol00`00Oomoo`0DOol01000Oomo
o`000Woo0P00>goo00<007ooOol0A7oo00<007ooOol09goo000VOol00`00Oomoo`0<Ool00`00Oomo
o`06Ool2000EOol3000EOol20005Ool00`00Oomoo`0hOol00`00Oomoo`13Ool00`00Oomoo`0XOol0
02Ioo`03001oogoo00]oo`03001oogoo03ioo`8003Qoo`03001oogoo04=oo`03001oogoo02Qoo`00
9Woo00<007ooOol02goo00<007ooOol0@7oo00<007ooOol027oo0P00:goo00<007ooOol0@Woo00<0
07ooOol0:Goo000VOol00`00Oomoo`0:Ool00`00Oomoo`12Ool20007Ool01000Oomoo`00:Woo00<0
07ooOol0@Goo00<007ooOol0:Woo000GOomV0004Ool00`00Oomoo`0JOol20004Ool20005Ool30000
0goo001oo`11Ool00`00Oomoo`0[Ool002Ioo`03001oogoo00Uoo`03001oogoo04]oo`D001Qoo`04
001oogoo000;Ool01000Oomoo`00@Goo00<007ooOol0;7oo000VOol00`00Oomoo`09Ool00`00Oomo
o`1<Ool00`00Oomoo`0IOol01000Oomoo`0027oo1@0000=oo`00Ool0?goo00<007ooOol0;Goo000V
Ool00`00Oomoo`08Ool00`00Oomoo`1YOol01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo
03eoo`03001oogoo02ioo`009Woo00<007ooOol027oo00<007ooOol0JGoo00@007ooOol000Uoo`03
001oo`00009oo`03001oogoo03aoo`03001oogoo02moo`009Woo00<007ooOol01goo00<007ooOol0
Jgoo0P002goo0P000Woo00<007ooOol0>goo00<007ooOol0<7oo000VOol00`00Oomoo`07Ool00`00
Oomoo`1lOol00`00Oomoo`0jOol00`00Oomoo`0aOol002Ioo`03001oogoo00Moo`03001oogoo07ao
o`03001oogoo03Yoo`03001oogoo035oo`009Woo00<007ooOol01Woo00<007ooOol0OGoo00<007oo
Ool0>Goo00<007ooOol0<Woo0008Ool20004Ool20004Ool20003Ool40002Ool40003Ool00`00Oomo
o`06Ool00`00Oomoo`1mOol00`00Oomoo`0hOol00`00Oomoo`0cOol000Moo`04001oogoo0008Ool0
1000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol0OGoo
00<007ooOol0=goo00<007ooOol0=7oo0007Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo06Moo`8000Aoo`8000Eoo`<0009o
o`8000=oo`03001oogoo03Ioo`03001oogoo03Eoo`001goo00@007ooOol000Qoo`04001oogoo0004
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`1VOol01000Oomoo`00
2goo00@007ooOol0009oo`04001oogoo000gOol00`00Oomoo`0fOol000Moo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`1W
Ool01000Oomoo`0027oo1@0017oo00@007ooOol003Ioo`03001oogoo03Moo`0027oo0P002Woo0P00
17oo0P0017oo0P0017oo00<007ooOol017oo00<007ooOol0Igoo00@007ooOol000Qoo`04001oogoo
0003Ool20003Ool00`00Oomoo`0cOol00`00Oomoo`0hOol002Ioo`03001oogoo00Aoo`03001oogoo
06Moo`04001oogoo0009Ool00`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`0cOol00`00Oomo
o`0hOol002Ioo`03001oogoo00=oo`03001oogoo06Uoo`8000]oo`8000=oo`<0009oo`03001oogoo
039oo`03001oogoo03Uoo`009Woo00<007ooOol00goo00<007ooOol0P7oo00<007ooOol0<Goo00<0
07ooOol0>Woo000VOol00`00Oomoo`02Ool00`00Oomoo`21Ool00`00Oomoo`0`Ool00`00Oomoo`0k
Ool002Ioo`03001oogoo009oo`03001oogoo085oo`03001oogoo02moo`03001oogoo03aoo`009Woo
00<007ooOol00Woo00<007ooOol0PGoo00<007ooOol0;Woo00<007ooOol0?Goo0008Ool20004Ool2
0004Ool20003Ool40004Ool30002Ool01@00Oomoogoo0000Lgoo0P0017oo0P0017oo0P000goo00<0
07ooOol0;7oo0P00@7oo0007Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00Ioo`05
001oogooOol00003Ool00`00Oomoo`1`Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo
02]oo`03001oogoo041oo`001goo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool5
0002Ool01000Oomoo`00Lgoo00@007ooOol000]oo`04001oogoo000/Ool00`00Oomoo`11Ool000Mo
o`04001oogoo0008Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`05001oogooOol00002Ool0
0`00Oomoo`1aOol01000Oomoo`002Goo0P000goo00<007ooOol0:Goo00<007ooOol0@Woo0007Ool0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00003Ool01000Oomoo`00
Lgoo00@007ooOol000Uoo`03001oogoo009oo`03001oogoo02Qoo`03001oogoo04=oo`0027oo0P00
2Woo0P0017oo0P001Goo0P000goo00<007oo0000MGoo0P002Woo0`000Woo00<007ooOol09Woo0P00
AWoo000JOol2000:Ool00`00Ool00026Ool00`00Oomoo`0UOol00`00Oomoo`16Ool001aoo`8000Qo
o`03001oo`0008Ioo`@002=oo`03001oogoo04Moo`007Woo0P001Woo0P00Qgoo00@007ooOomoo`H0
01Yoo`<004Yoo`0087oo0`000goo0P00Qgoo00<007ooOol01goo1P0047oo1000CGoo000SOol20000
0goo001oo`27Ool00`00Oomoo`0=Ool60006Ool4001AOol002Eoo`8008Qoo`03001oogoo01=oo`H0
05Eoo`009Woo00<007ooOol0QWoo00<007ooOol0KWoo002_Ool00`00Oomoo`1^Ool00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00Y7oo0`00NGoo000SOol200000goo0000001oOol00`00Oomo
o`1fOol002Aoo`03001oo`0007ioo`<000=oo`<00003Ool00000009oo`80009oo`<006Ioo`0097oo
0`00OGoo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`1UOol0
02Aoo`04001oo`00001lOol01000Oomoo`0017oo00D007ooOomoo`00009oo`03001oogoo009oo`03
001oogoo06Eoo`0097oo00<007ooOol0OWoo10000Woo0P000Woo100017oo0P00Igoo000SOol2003k
Ool00:aoo`03001oogoo00Uoo`03001oogoo06Eoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00<Goo10001Woo0P0027oo0`001Woo0P001Woo0`002Goo00<007ooOol01Goo0P00Cgoo
100027oo0P002Woo0`0027oo0P0027oo0`002Woo00<007ooOol01goo0P007goo000aOol00`00Oomo
o`06Ool01000Oomoo`0027oo00<007ooOol017oo00@007ooOol000Eoo`04001oogoo0008Ool00`00
Oomoo`04Ool01000Oomoo`00CWoo00<007ooOol027oo00@007ooOol000Yoo`03001oogoo00Ioo`04
001oogoo0007Ool01000Oomoo`002Goo00<007ooOol01Woo00@007ooOol001ioo`00<Woo00<007oo
Ool01goo00<007ooOol017oo1@0027oo00<007ooOol00goo00@007ooOol000Qoo`03001oogoo00Ao
o`04001oogoo001?Ool00`00Oomoo`09Ool00`00Oomoo`06Ool5000:Ool00`00Oomoo`05Ool01000
Oomoo`002Goo00<007ooOol01Woo00@007ooOol001ioo`00<goo00<007ooOol01goo00<007ooOol0
0goo00@007ooOol000Moo`8000Ioo`<000Yoo`03001oogoo00Aoo`80055oo`03001oogoo00Uoo`03
001oogoo00Eoo`04001oogoo0009Ool20008Ool3000;Ool00`00Oomoo`06Ool2000OOol0035oo`04
001oogoo0005Ool01000Oomoo`001Woo00<007oo00001goo00<007ooOol01Woo00<007ooOol01Woo
00@007ooOol000Eoo`04001oogoo001>Ool01000Oomoo`001goo00@007ooOol000Qoo`03001oo`00
00Uoo`03001oogoo00Qoo`03001oogoo00Moo`04001oogoo0007Ool01000Oomoo`007Woo000bOol2
0007Ool20008Ool20007Ool30006Ool30006Ool40006Ool2001@Ool20009Ool2000:Ool20009Ool3
0008Ool30007Ool40008Ool2000OOol00?moob5oo`00Lgoo0P00Tgoo0P005Woo001bOol01000Oomo
o`00TGoo00@007ooOol001Eoo`009gooA`0017oo00<007ooOol0>gooD`0017oo00<007ooOol05Woo
001aOol5002@Ool5000EOol0079oo`03001oogoo099oo`03001oogoo01Ioo`00ogoo8Goo003oOolQ
Ool00;9oo`03001oogoo06]oo`00/Woo00<007ooOol0BWoo0P007goo002bOol00`00Oomoo`16Ool4
000QOol00;9oo`03001oogoo049oo`@002Eoo`00X7oo1@000Woo0P000goo1@0000=oo`00Ool0@7oo
0`00:Goo002ROol00`00Oomoo`09Ool01@00Oomoogoo0000?goo0P00;7oo002ROol00`00Oomoo`09
Ool01@00Oomoogoo0000?Goo0P00;Woo002ROol00`00Oomoo`09Ool01@00Oomoogoo0000>goo0P00
<7oo000YOol00`00Oomoo`1fOol00`00Oomoo`09Ool01@00Oomoogoo0000>Goo0P00<Woo000GOol5
0002Ool20004Ool20003Ool00`00Oomoo`1eOol2000:Ool20003Ool00`00Oomoo`0eOol2000dOol0
01Uoo`03001oogoo00Moo`04001oogoo0002Ool20027Ool00`00Oomoo`0cOol2000fOol001Uoo`03
001oogoo00Uoo`04001oogooOol30026Ool00`00Oomoo`0bOol00`00Oomoo`0fOol001Uoo`03001o
ogoo00Yoo`06001oogoo001oo`00QWoo00<007ooOol0<Goo00<007ooOol0=goo000IOol00`00Oomo
o`07Ool01000Oomoo`000Woo00@007ooOol008Eoo`03001oogoo02moo`8003Yoo`005goo1@000Woo
0P0017oo100000=oo`00Ool00Woo00<007ooOol0PWoo00<007ooOol0;Woo00<007ooOol0>Woo000I
Ool00`00Oomoo`0:Ool01000Oomoo`0017oo00<007ooOol0Kgoo1@000Woo0P000goo10000Woo00<0
07ooOol0;Goo00<007ooOol0>goo000IOol00`00Oomoo`07Ool500000goo00000003Ool00`00Oomo
o`1aOol00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`0[Ool2000nOol001Uoo`03001oogoo
00Moo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`1`Ool00`00Oomoo`08Ool00`00Oomo
o`02Ool00`00Oomoo`0ZOol00`00Oomoo`0nOol001Uoo`03001oogoo00Qoo`03001oo`00009oo`03
001oogoo00Aoo`03001oogoo06moo`03001oogoo00Uoo`05001oogooOol0000[Ool00`00Oomoo`0o
Ool001Moo`D0009oo`8000Aoo`<0009oo`03001oogoo00Eoo`03001oogoo06ioo`03001oogoo00Mo
o`04001oogoo0002Ool00`00Oomoo`0XOol00`00Oomoo`10Ool001Uoo`03001oogoo00Moo`04001o
ogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`1]Ool2000:Ool20003Ool00`00Oomoo`0WOol00`00
Oomoo`11Ool001Uoo`03001oogoo00Yoo`03001oogoo008000Moo`03001oogoo07eoo`03001oogoo
02Ioo`03001oogoo049oo`006Goo00<007ooOol027oo0P000goo00<007ooOol01goo00<007ooOol0
O7oo00<007ooOol09Goo00<007ooOol0@goo000IOol00`00Oomoo`08Ool00`00Oomoo`02Ool00`00
Oomoo`08Ool00`00Oomoo`1kOol00`00Oomoo`0TOol00`00Oomoo`14Ool001Qoo`8000Yoo`<0009o
o`03001oogoo00Qoo`03001oogoo07]oo`03001oogoo02=oo`03001oogoo04Eoo`005goo1@000Woo
0P000goo0`000goo00<007ooOol02Goo00<007ooOol0NWoo00<007ooOol08Woo00<007ooOol0AWoo
000IOol00`00Oomoo`07Ool01000Oomoo`000Woo00<007ooOol02Woo00<007ooOol0Igoo1@000Woo
0P0017oo0P000goo00<007ooOol08Goo00<007ooOol0Agoo000IOol00`00Oomoo`07Ool01000Oomo
o`000Woo0P002goo00<007ooOol0JGoo00<007ooOol01goo00@007ooOol0009oo`03001oogoo021o
o`03001oogoo04Qoo`006Goo00<007ooOol01goo0`000goo00<007ooOol02goo00<007ooOol0J7oo
00<007ooOol02Goo00D007ooOomoo`00025oo`03001oogoo04Uoo`006Goo00<007ooOol027oo00<0
07ooOol00Woo00<007ooOol037oo00<007ooOol0Igoo00<007ooOol02Woo00@007ooOol0021oo`03
001oogoo04Yoo`005goo1@000Woo0P0017oo0`000Woo00<007ooOol03Goo00<007ooOol0IWoo00<0
07ooOol01goo00@007ooOol0009oo`03001oogoo01eoo`03001oogoo04]oo`006Goo00<007ooOol0
2Goo00D007ooOomoo`0000moo`03001oogoo06Eoo`8000Yoo`8000=oo`03001oogoo01eoo`03001o
ogoo04]oo`006Goo00<007ooOol02Goo00@007ooOomoo`8000moo`03001oogoo07Eoo`03001oogoo
01aoo`03001oogoo04aoo`006Goo00<007ooOol02Woo00@007ooOol0015oo`03001oogoo07Aoo`03
001oogoo01]oo`03001oogoo04eoo`006Goo00<007ooOol01goo00@007ooOol0009oo`03001oogoo
00moo`03001oogoo07Aoo`03001oogoo01Yoo`03001oogoo04ioo`0067oo0P002Goo10000Woo00<0
07ooOol047oo00<007ooOol0Lgoo00<007ooOol06Woo00<007ooOol0CWoo000GOol50002Ool20004
Ool20003Ool00`00Oomoo`0AOol00`00Oomoo`1bOol00`00Oomoo`0IOol00`00Oomoo`1?Ool001Uo
o`03001oogoo00Moo`04001oogoo0002Ool00`00Oomoo`0BOol00`00Oomoo`1OOol50002Ool20005
Ool300000goo001oo`0IOol00`00Oomoo`1@Ool001Uoo`03001oogoo00Moo`04001oogoo0002Ool2
000COol00`00Oomoo`1QOol00`00Oomoo`0:Ool00`00Oomoo`02000HOol00`00Oomoo`1AOol001Uo
o`03001oogoo00Qoo`8000=oo`03001oogoo01=oo`03001oogoo061oo`03001oogoo00Moo`D00004
Ool007oo000GOol00`00Oomoo`1AOol001Uoo`03001oogoo00Moo`04001oogoo0002Ool00`00Oomo
o`0DOol00`00Oomoo`1OOol00`00Oomoo`07Ool01000Oomoo`000Woo00@007ooOol001Eoo`03001o
ogoo059oo`005goo1@000Woo0P000goo0`000goo00<007ooOol05Goo00<007ooOol0GWoo00<007oo
Ool027oo00<007oo00000Woo00D007ooOomoo`0001=oo`03001oogoo05=oo`006Goo00<007ooOol0
2Goo00D007ooOomoo`0001Qoo`03001oogoo05aoo`8000]oo`80009oo`03001oogoo009oo`03001o
ogoo00moo`03001oogoo05Aoo`006Goo00<007ooOol027oo0`000Woo0P0067oo00<007ooOol0K7oo
00<007ooOol00Woo00<007ooOol03goo00<007ooOol0E7oo000IOol00`00Oomoo`07Ool01000Oomo
o`000Woo00<007ooOol05goo00<007ooOol08goo0`00AWoo00<007ooOol00goo00<007ooOol037oo
0P00Egoo000IOol00`00Oomoo`07Ool01000Oomoo`000Woo00<007ooOol067oo00<007ooOol07Woo
1000BGoo00<007ooOol017oo00<007ooOol02Goo0P00FGoo000HOol20009Ool40002Ool00`00Oomo
o`0IOol2000JOol4001=Ool00`00Oomoo`05Ool00`00Oomoo`06Ool2001KOol002=oo`03001oogoo
00=oo`03001oogoo01]oo`8001Eoo`<0055oo`03001oogoo00Ioo`03001oogoo00=oo`8005eoo`00
97oo00<007ooOol00Woo0P007Woo0`003Woo1000E7oo00<007ooOol01goo00<007ooOol00P00Ggoo
000UOol01@00Oomoogoo00008Woo0P001Woo1P00F7oo00<007ooOol027oo0P00HGoo000SOol01000
Oomoo`000Woo00<007ooOol08Woo1P00GWoo00<007ooOol0Jgoo000TOol20003Ool00`00Oomoo`26
Ool00`00Oomoo`1[Ool00?moob5oo`00ogoo8Goo003oOolQOol002Moo`<00?Ioo`00:Woo00<007oo
Ool0lgoo000XOol30024Ool20002Ool2001[Ool002Moo`04001oogoo0025Ool01000Oomoo`00K7oo
000WOol01000Oomoo`00QGoo00@007ooOol006aoo`00:7oo1000Pgoo1000KGoo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {270.188, 0}} -> {-0.050401, -0.0470982, \
0.00731988, 0.00731988}, {{6.875, 136.938}, {263.75, 183.313}} -> {-1.67907, \
-0.0621069, 0.0800003, 0.00374459}, {{150, 280.063}, {263.75, 183.313}} -> \
{-12.7691, -0.0954775, 0.0782335, 0.0219768}, {{6.875, 136.938}, {175.25, \
94.875}} -> {-1.18196, -0.00174623, 0.0834424, 0.000173286}, {{150, 280.063}, \
{175.25, 94.875}} -> {-12.5875, -0.193716, 0.0775612, 0.00465143}, {{6.875, \
136.938}, {86.8125, 6.375}} -> {-3.41488, -2.59899, 0.10603, 0.0186243}, \
{{150, 280.063}, {86.8125, 6.375}} -> {-14.979, -0.732327, 0.089542, \
0.00895716}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(plo1 = 
      MultipleListPlot[{plou[3, 1], plou[4, 1]}, AxesLabel \[Rule] {t, g}, 
        AxesOrigin \[Rule] {1, 0.007}]\), "\[IndentingNewLine]", 
    \(plo2 = 
      MultipleListPlot[{plou[3, 2], plou[4, 2]}, AxesLabel \[Rule] {t, N}, 
        AxesOrigin \[Rule] {1, 0}, 
        PlotLegend \[Rule] {"\<\[Tau]=.05\>", "\<\[Tau]=.2\>"}, 
        LegendPosition \[Rule] {0.3, 0}, 
        LegendOrientation \[Rule] Vertical]\), "\[IndentingNewLine]", 
    \(plo3 = 
      MultipleListPlot[{plou[3, 3], plou[4, 3]}, 
        AxesLabel \[Rule] {t, "\<I\>"}, 
        AxesOrigin \[Rule] {1, 0.1}]\), "\[IndentingNewLine]", 
    \(plo4 = 
      MultipleListPlot[{plou[3, 4], plou[4, 4]}, AxesLabel \[Rule] {t, D}, 
        AxesOrigin \[Rule] {1, 0}]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 -0.247849 35.6638 [
[.02381 -0.0107 -3 -9 ]
[.02381 -0.0107 3 0 ]
[.2619 -0.0107 -3 -9 ]
[.2619 -0.0107 3 0 ]
[.5 -0.0107 -3 -9 ]
[.5 -0.0107 3 0 ]
[.7381 -0.0107 -3 -9 ]
[.7381 -0.0107 3 0 ]
[.97619 -0.0107 -3 -9 ]
[.97619 -0.0107 3 0 ]
[1.025 .0018 0 -6.28125 ]
[1.025 .0018 10 6.28125 ]
[.13036 .01963 -36 -4.5 ]
[.13036 .01963 0 4.5 ]
[.13036 .10879 -24 -4.5 ]
[.13036 .10879 0 4.5 ]
[.13036 .19795 -36 -4.5 ]
[.13036 .19795 0 4.5 ]
[.13036 .28711 -30 -4.5 ]
[.13036 .28711 0 4.5 ]
[.13036 .37627 -36 -4.5 ]
[.13036 .37627 0 4.5 ]
[.13036 .46543 -24 -4.5 ]
[.13036 .46543 0 4.5 ]
[.13036 .55459 -36 -4.5 ]
[.13036 .55459 0 4.5 ]
[.14286 .64303 -5 0 ]
[.14286 .64303 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .0018 m
.02381 .00805 L
s
[(0)] .02381 -0.0107 0 1 Mshowa
.2619 .0018 m
.2619 .00805 L
s
[(2)] .2619 -0.0107 0 1 Mshowa
.5 .0018 m
.5 .00805 L
s
[(4)] .5 -0.0107 0 1 Mshowa
.7381 .0018 m
.7381 .00805 L
s
[(6)] .7381 -0.0107 0 1 Mshowa
.97619 .0018 m
.97619 .00805 L
s
[(8)] .97619 -0.0107 0 1 Mshowa
.125 Mabswid
.08333 .0018 m
.08333 .00555 L
s
.20238 .0018 m
.20238 .00555 L
s
.32143 .0018 m
.32143 .00555 L
s
.38095 .0018 m
.38095 .00555 L
s
.44048 .0018 m
.44048 .00555 L
s
.55952 .0018 m
.55952 .00555 L
s
.61905 .0018 m
.61905 .00555 L
s
.67857 .0018 m
.67857 .00555 L
s
.79762 .0018 m
.79762 .00555 L
s
.85714 .0018 m
.85714 .00555 L
s
.91667 .0018 m
.91667 .00555 L
s
.25 Mabswid
0 .0018 m
1 .0018 L
s
gsave
1.025 .0018 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.14286 .01963 m
.14911 .01963 L
s
[(0.0075)] .13036 .01963 1 0 Mshowa
.14286 .10879 m
.14911 .10879 L
s
[(0.01)] .13036 .10879 1 0 Mshowa
.14286 .19795 m
.14911 .19795 L
s
[(0.0125)] .13036 .19795 1 0 Mshowa
.14286 .28711 m
.14911 .28711 L
s
[(0.015)] .13036 .28711 1 0 Mshowa
.14286 .37627 m
.14911 .37627 L
s
[(0.0175)] .13036 .37627 1 0 Mshowa
.14286 .46543 m
.14911 .46543 L
s
[(0.02)] .13036 .46543 1 0 Mshowa
.14286 .55459 m
.14911 .55459 L
s
[(0.0225)] .13036 .55459 1 0 Mshowa
.125 Mabswid
.14286 .03746 m
.14661 .03746 L
s
.14286 .05529 m
.14661 .05529 L
s
.14286 .07312 m
.14661 .07312 L
s
.14286 .09096 m
.14661 .09096 L
s
.14286 .12662 m
.14661 .12662 L
s
.14286 .14445 m
.14661 .14445 L
s
.14286 .16228 m
.14661 .16228 L
s
.14286 .18012 m
.14661 .18012 L
s
.14286 .21578 m
.14661 .21578 L
s
.14286 .23361 m
.14661 .23361 L
s
.14286 .25144 m
.14661 .25144 L
s
.14286 .26928 m
.14661 .26928 L
s
.14286 .30494 m
.14661 .30494 L
s
.14286 .32277 m
.14661 .32277 L
s
.14286 .3406 m
.14661 .3406 L
s
.14286 .35843 m
.14661 .35843 L
s
.14286 .3941 m
.14661 .3941 L
s
.14286 .41193 m
.14661 .41193 L
s
.14286 .42976 m
.14661 .42976 L
s
.14286 .44759 m
.14661 .44759 L
s
.14286 .48326 m
.14661 .48326 L
s
.14286 .50109 m
.14661 .50109 L
s
.14286 .51892 m
.14661 .51892 L
s
.14286 .53675 m
.14661 .53675 L
s
.14286 .0018 m
.14661 .0018 L
s
.14286 .57242 m
.14661 .57242 L
s
.14286 .59025 m
.14661 .59025 L
s
.14286 .60808 m
.14661 .60808 L
s
.25 Mabswid
.14286 0 m
.14286 .61803 L
s
gsave
.14286 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(g) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.14286 .01472 m
.2619 .51876 L
.38095 .6019 L
.5 .5706 L
.61905 .53219 L
.7381 .50396 L
.85714 .48778 L
.97619 .47844 L
s
.0001 w
.14286 .01472 -1.875 0 Mabsadd m
.14286 .01472 0 2.5 Mabsadd L
.14286 .01472 1.875 0 Mabsadd L
.14286 .01472 0 -2.5 Mabsadd L
.14286 .01472 -1.875 0 Mabsadd L closepath F
.2619 .51876 -1.875 0 Mabsadd m
.2619 .51876 0 2.5 Mabsadd L
.2619 .51876 1.875 0 Mabsadd L
.2619 .51876 0 -2.5 Mabsadd L
.2619 .51876 -1.875 0 Mabsadd L closepath F
.38095 .6019 -1.875 0 Mabsadd m
.38095 .6019 0 2.5 Mabsadd L
.38095 .6019 1.875 0 Mabsadd L
.38095 .6019 0 -2.5 Mabsadd L
.38095 .6019 -1.875 0 Mabsadd L closepath F
.5 .5706 -1.875 0 Mabsadd m
.5 .5706 0 2.5 Mabsadd L
.5 .5706 1.875 0 Mabsadd L
.5 .5706 0 -2.5 Mabsadd L
.5 .5706 -1.875 0 Mabsadd L closepath F
.61905 .53219 -1.875 0 Mabsadd m
.61905 .53219 0 2.5 Mabsadd L
.61905 .53219 1.875 0 Mabsadd L
.61905 .53219 0 -2.5 Mabsadd L
.61905 .53219 -1.875 0 Mabsadd L closepath F
.7381 .50396 -1.875 0 Mabsadd m
.7381 .50396 0 2.5 Mabsadd L
.7381 .50396 1.875 0 Mabsadd L
.7381 .50396 0 -2.5 Mabsadd L
.7381 .50396 -1.875 0 Mabsadd L closepath F
.85714 .48778 -1.875 0 Mabsadd m
.85714 .48778 0 2.5 Mabsadd L
.85714 .48778 1.875 0 Mabsadd L
.85714 .48778 0 -2.5 Mabsadd L
.85714 .48778 -1.875 0 Mabsadd L closepath F
.97619 .47844 -1.875 0 Mabsadd m
.97619 .47844 0 2.5 Mabsadd L
.97619 .47844 1.875 0 Mabsadd L
.97619 .47844 0 -2.5 Mabsadd L
.97619 .47844 -1.875 0 Mabsadd L closepath F
.001 w
[ .5 3 ] 0 Mabsdash
.14286 .03665 m
.2619 .24282 L
.38095 .42671 L
.5 .56568 L
.61905 .60332 L
.7381 .59349 L
.85714 .56124 L
.97619 .53546 L
s
.0001 w
[ ] 0 setdash
.14286 .03665 0 2.5 Mabsadd m
.14286 .03665 -0.56518 .7779 Mabsadd L
.14286 .03665 -2.37764 .77254 Mabsadd L
.14286 .03665 -0.91448 -0.29713 Mabsadd L
.14286 .03665 -1.46946 -2.02254 Mabsadd L
.14286 .03665 0 -0.96154 Mabsadd L
.14286 .03665 1.46946 -2.02254 Mabsadd L
.14286 .03665 .91448 -0.29713 Mabsadd L
.14286 .03665 2.37764 .77254 Mabsadd L
.14286 .03665 .56518 .7779 Mabsadd L
.14286 .03665 0 2.5 Mabsadd L closepath F
.2619 .24282 0 2.5 Mabsadd m
.2619 .24282 -0.56518 .7779 Mabsadd L
.2619 .24282 -2.37764 .77254 Mabsadd L
.2619 .24282 -0.91448 -0.29713 Mabsadd L
.2619 .24282 -1.46946 -2.02254 Mabsadd L
.2619 .24282 0 -0.96154 Mabsadd L
.2619 .24282 1.46946 -2.02254 Mabsadd L
.2619 .24282 .91448 -0.29713 Mabsadd L
.2619 .24282 2.37764 .77254 Mabsadd L
.2619 .24282 .56518 .7779 Mabsadd L
.2619 .24282 0 2.5 Mabsadd L closepath F
.38095 .42671 0 2.5 Mabsadd m
.38095 .42671 -0.56518 .7779 Mabsadd L
.38095 .42671 -2.37764 .77254 Mabsadd L
.38095 .42671 -0.91448 -0.29713 Mabsadd L
.38095 .42671 -1.46946 -2.02254 Mabsadd L
.38095 .42671 0 -0.96154 Mabsadd L
.38095 .42671 1.46946 -2.02254 Mabsadd L
.38095 .42671 .91448 -0.29713 Mabsadd L
.38095 .42671 2.37764 .77254 Mabsadd L
.38095 .42671 .56518 .7779 Mabsadd L
.38095 .42671 0 2.5 Mabsadd L closepath F
.5 .56568 0 2.5 Mabsadd m
.5 .56568 -0.56518 .7779 Mabsadd L
.5 .56568 -2.37764 .77254 Mabsadd L
.5 .56568 -0.91448 -0.29713 Mabsadd L
.5 .56568 -1.46946 -2.02254 Mabsadd L
.5 .56568 0 -0.96154 Mabsadd L
.5 .56568 1.46946 -2.02254 Mabsadd L
.5 .56568 .91448 -0.29713 Mabsadd L
.5 .56568 2.37764 .77254 Mabsadd L
.5 .56568 .56518 .7779 Mabsadd L
.5 .56568 0 2.5 Mabsadd L closepath F
.61905 .60332 0 2.5 Mabsadd m
.61905 .60332 -0.56518 .7779 Mabsadd L
.61905 .60332 -2.37764 .77254 Mabsadd L
.61905 .60332 -0.91448 -0.29713 Mabsadd L
.61905 .60332 -1.46946 -2.02254 Mabsadd L
.61905 .60332 0 -0.96154 Mabsadd L
.61905 .60332 1.46946 -2.02254 Mabsadd L
.61905 .60332 .91448 -0.29713 Mabsadd L
.61905 .60332 2.37764 .77254 Mabsadd L
.61905 .60332 .56518 .7779 Mabsadd L
.61905 .60332 0 2.5 Mabsadd L closepath F
.7381 .59349 0 2.5 Mabsadd m
.7381 .59349 -0.56518 .7779 Mabsadd L
.7381 .59349 -2.37764 .77254 Mabsadd L
.7381 .59349 -0.91448 -0.29713 Mabsadd L
.7381 .59349 -1.46946 -2.02254 Mabsadd L
.7381 .59349 0 -0.96154 Mabsadd L
.7381 .59349 1.46946 -2.02254 Mabsadd L
.7381 .59349 .91448 -0.29713 Mabsadd L
.7381 .59349 2.37764 .77254 Mabsadd L
.7381 .59349 .56518 .7779 Mabsadd L
.7381 .59349 0 2.5 Mabsadd L closepath F
.85714 .56124 0 2.5 Mabsadd m
.85714 .56124 -0.56518 .7779 Mabsadd L
.85714 .56124 -2.37764 .77254 Mabsadd L
.85714 .56124 -0.91448 -0.29713 Mabsadd L
.85714 .56124 -1.46946 -2.02254 Mabsadd L
.85714 .56124 0 -0.96154 Mabsadd L
.85714 .56124 1.46946 -2.02254 Mabsadd L
.85714 .56124 .91448 -0.29713 Mabsadd L
.85714 .56124 2.37764 .77254 Mabsadd L
.85714 .56124 .56518 .7779 Mabsadd L
.85714 .56124 0 2.5 Mabsadd L closepath F
.97619 .53546 0 2.5 Mabsadd m
.97619 .53546 -0.56518 .7779 Mabsadd L
.97619 .53546 -2.37764 .77254 Mabsadd L
.97619 .53546 -0.91448 -0.29713 Mabsadd L
.97619 .53546 -1.46946 -2.02254 Mabsadd L
.97619 .53546 0 -0.96154 Mabsadd L
.97619 .53546 1.46946 -2.02254 Mabsadd L
.97619 .53546 .91448 -0.29713 Mabsadd L
.97619 .53546 2.37764 .77254 Mabsadd L
.97619 .53546 .56518 .7779 Mabsadd L
.97619 .53546 0 2.5 Mabsadd L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000GOol2
000fOol4000gOol3000cOol3000gOol2000TOol001Ioo`04001oogoo000eOol00`00Oomoo`0iOol0
0`00Oomoo`0bOol01000Oomoo`00=Goo00@007ooOol002=oo`005Woo00@007ooOol003Ioo`03001o
ogoo03Eoo`D003=oo`04001oogoo000eOol01000Oomoo`008goo000FOol01000Oomoo`00=goo00<0
07ooOol0=7oo00@007ooOol003Aoo`<003Moo`8002Aoo`005Woo00@007ooOol003Eoo`04001oogoo
000fOol00`00Ool0000eOol00`00Oomoo`0eOol01000Oomoo`008goo000GOol2000gOol2000hOol2
000eOol3000fOol2000TOol00?moob5oo`00ogoo8Goo003oOolQOol00?moo`]oo`8001Aoo`00=Goo
00<007ooOol0dGoo00@007ooOol001=oo`004gookP0027oo00<007ooOol057oo000HOol00`00Oomo
o`0JOol00`00Oomoo`0IOol00`00Oomoo`0fOol00`00Oomoo`0eOol00`00Oomoo`0fOol00`00Oomo
o`0:Ool5000COol0011oo`8000Aoo`8000Aoo`8000Aoo`8000Eoo`03001oogoo009oo`8000Aoo`<0
0=9oo`03001oogoo01Aoo`003goo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`0017oo
00D007ooOomoo`00009oo`03001oogoo00@00>Uoo`003goo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`0017oo00<007ooOol017oo00@007ooOomoo`<00>Uoo`003goo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOomoo`8000Eoo`03001oogoo0>Qoo`003goo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo
00Aoo`800>Uoo`0047oo0P002Woo0P0017oo0P000goo10000goo0`000goo0`00jGoo000dOol3003Y
Ool0039oo`D00>Uoo`00=Goo00<007oo0000j7oo000eOol3003XOol003Eoo`<00>Qoo`00=Goo00<0
07oo0000j7oo000eOol01000Oomoo`00igoo000eOol01000Oomoo`00igoo000eOol200000goo001o
o`3VOol003Eoo`06001oogoo001oo`00iGoo000eOol01@00Oomoogoo0000iWoo000eOol01@00Oomo
ogoo0000iWoo000eOol01@00Oomoogoo00000Woo00<007ooOol0hGoo000eOol20002Ool00`00Oomo
o`3TOol003Eoo`05001oogooOol0003VOol001aoo`8000Aoo`8000Aoo`8000=oo`D000=oo`03001o
ogoo009oo`03001oogoo00800>5oo`006goo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`3SOol001]oo`04001oogoo0008Ool01000Oomoo`0017oo
00<007ooOol00goo0P000goo00<007ooOol0hgoo000KOol01000Oomoo`0027oo00@007ooOol000Ao
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo0=ioo`006goo00@007oo
Ool000Qoo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`3ROol001ao
o`8000Yoo`8000Aoo`8000Eoo`03001oogoo00=oo`03001oogoo0>9oo`00=Goo0P0017oo00<007oo
Ool00goo00<007ooOol0g7oo000eOol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`3LOol0
03Eoo`03001oogoo00Aoo`03001oogoo0>5oo`00=Goo00<007ooOol017oo00<007ooOol017oo00<0
07ooOol0fWoo000eOol20005Ool00`00Oomoo`04Ool00`00Oomoo`3JOol003Eoo`03001oogoo00Ao
o`03001oogoo0>5oo`00=Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0fGoo000eOol0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`3HOol003Eoo`03001oogoo00Eoo`03001oogoo
0>1oo`00=Goo0P001Woo00<007ooOol01Woo00<007ooOol0egoo000eOol00`00Oomoo`05Ool00`00
Oomoo`06Ool00`00Oomoo`3GOol003Eoo`03001oogoo00Ioo`03001oogoo0=moo`00=Goo00<007oo
Ool01Woo00<007ooOol01goo00<007ooOol0eGoo000eOol20007Ool00`00Oomoo`07Ool00`00Oomo
o`3EOol003Eoo`03001oogoo00Ioo`03001oogoo0=moo`0047oo0P0017oo0P0017oo0P000goo1@00
00=oo`0000000P000goo0P001Goo00<007ooOol01goo00<007ooOol027oo00<007ooOol0dgoo000?
Ool01000Oomoo`0027oo00@007ooOol000Aoo`05001oogooOol00005Ool01000Oomoo`0017oo00<0
07ooOol01goo00<007ooOol027oo00<007ooOol0dgoo000?Ool01000Oomoo`0027oo00@007ooOol0
00Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`8000Qoo`03001oogoo0=ioo`00
3goo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool20005Ool0
0`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`3BOol000moo`04001oogoo0008Ool01000Oomo
o`0017oo00D007ooOomoo`00009oo`05001oogooOol00006Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`3AOol0011oo`8000Yoo`8000Aoo`8000Aoo`8000Aoo`<000Aoo`03001oogoo00Qo
o`03001oogoo0=eoo`00=Goo0P002Goo00<007ooOol02Woo00<007ooOol0d7oo000eOol00`00Oomo
o`08Ool00`00Oomoo`0:Ool00`00Oomoo`3@Ool003Eoo`03001oogoo00Uoo`03001oogoo0=aoo`00
=Goo00<007ooOol02Goo00<007ooOol02goo00<007ooOol0cWoo000eOol00`00Oomoo`09Ool00`00
Oomoo`0;Ool00`00Oomoo`3>Ool003Eoo`8000Yoo`03001oogoo0=aoo`00=Goo00<007ooOol02Goo
00<007ooOol037oo0P00cWoo000eOol00`00Oomoo`0:Ool00`00Oomoo`0;Ool2003>Ool003Eoo`03
001oogoo00Yoo`03001oogoo00Yoo`@00<eoo`00=Goo0P002goo00<007ooOol03Woo00<007ooOol0
bWoo000eOol00`00Oomoo`0:Ool00`00Oomoo`0>Ool00`00Oomoo`3:Ool003Eoo`03001oogoo00]o
o`03001oogoo0=Yoo`00=Goo00<007ooOol02goo00<007ooOol03Woo00<007ooOol0bGoo000eOol2
000<Ool00`00Oomoo`0?Ool00`00Oomoo`38Ool003Eoo`03001oogoo00]oo`03001oogoo0=Yoo`00
5Woo0P0017oo0P0017oo0P000goo1@000Woo0P001Goo00<007ooOol037oo00<007ooOol03goo00<0
07ooOol0agoo000EOol01000Oomoo`0027oo00@007ooOol000Aoo`05001oogooOol00002Ool00`00
Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`0@Ool00`00Oomoo`36Ool001Eoo`04001oogoo0008
Ool01000Oomoo`0017oo00<007ooOol017oo00<007ooOol00Woo0P003Goo00<007ooOol0fGoo000E
Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo009oo`8000Eoo`03001oogoo00aoo`03
001oogoo015oo`03001oogoo0<Eoo`005Goo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomo
o`02Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`0@Ool00`00Oomoo`35Ool001Ioo`80
00Yoo`8000Aoo`8000Aoo`<000Aoo`03001oogoo00eoo`03001oogoo0=Qoo`00=Goo00<007ooOol0
3Goo00<007ooOol04Woo00<007ooOol0`goo000eOol2000>Ool00`00Oomoo`3HOol003Eoo`03001o
ogoo00eoo`03001oogoo0=Qoo`00=Goo00<007ooOol03Woo00<007ooOol04goo00<007ooOol0`Goo
000eOol00`00Oomoo`0>Ool00`00Oomoo`3GOol003Eoo`8000moo`03001oogoo0=Moo`00=Goo00<0
07ooOol03Woo00<007ooOol05Goo00<007ooOol0_goo000eOol00`00Oomoo`0?Ool00`00Oomoo`3F
Ool003Eoo`03001oogoo00moo`03001oogoo0=Ioo`00=Goo0P0047oo00<007ooOol05Woo00<007oo
Ool0_Goo000eOol00`00Oomoo`0?Ool00`00Oomoo`3FOol003Eoo`03001oogoo011oo`03001oogoo
0=Eoo`00=Goo00<007ooOol047oo00<007ooOol05goo00<007ooOol0^goo000eOol2000AOol00`00
Oomoo`3EOol003Eoo`03001oogoo011oo`03001oogoo0=Eoo`00=Goo00<007ooOol04Goo00<007oo
Ool067oo00<007ooOol0^Goo000@Ool20004Ool20004Ool20003Ool50003Ool00`00Oomoo`02Ool2
0005Ool00`00Oomoo`0AOol00`00Oomoo`3DOol000moo`04001oogoo0008Ool01000Oomoo`0017oo
00<007ooOol00goo00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo015oo`03001oogoo
0=Aoo`003goo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool2000BOol00`00Oomoo`0JOol00`00Oomoo`2gOol000moo`04001oogoo0008Ool0
1000Oomoo`0017oo00<007ooOol017oo00@007ooOomoo`8000Eoo`03001oogoo015oo`03001oogoo
0=Aoo`003goo00@007ooOol000Qoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00D007ooOomo
o`0000Ioo`03001oogoo019oo`03001oogoo0==oo`0047oo0P002Woo0P0017oo0P000goo10000goo
0`0017oo00<007ooOol04Woo00<007ooOol06Woo0P00]goo000eOol2000COol00`00Oomoo`3COol0
03Eoo`03001oogoo019oo`03001oogoo0==oo`00=Goo00<007ooOol04goo00<007ooOol06goo0P00
]Goo000eOol00`00Oomoo`0COol00`00Oomoo`3BOol003Eoo`8001Aoo`03001oogoo0=9oo`00=Goo
00<007ooOol04goo00<007ooOol07Goo00<007ooOol0/Woo000eOol00`00Oomoo`0DOol00`00Oomo
o`0MOol00`00Ool0002aOol003Eoo`03001oogoo01Aoo`03001oogoo01eoo`800;9oo`00=Goo0P00
5Goo00<007ooOol077oo1@00/7oo000eOol00`00Oomoo`0DOol00`00Oomoo`0NOol00`00Oomoo`2`
Ool003Eoo`03001oogoo01Eoo`03001oogoo01moo`03001oogoo0:ioo`00=Goo00<007ooOol05Goo
00<007ooOol087oo00<007ooOol0[Goo000eOol2000FOol00`00Oomoo`3@Ool003Eoo`03001oogoo
01Eoo`03001oogoo029oo`03001oogoo0:]oo`00=Goo00<007ooOol05Goo00<007ooOol0d7oo000L
Ool20004Ool20004Ool20003Ool40004Ool00`00Oomoo`0FOol00`00Oomoo`0SOol00`00Oomoo`2Y
Ool001]oo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol05Woo00<0
07ooOol08goo00<007ooOol0ZGoo000KOol01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
00Aoo`8001Moo`03001oogoo0<moo`006goo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomo
o`03Ool00`00Oomoo`0FOol00`00Oomoo`0UOol20023Ool00`00Oomoo`0ROol001]oo`04001oogoo
0008Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo01Moo`03001oogoo0:Qoo`<002=o
o`0077oo0P002Woo0P0017oo0P001Goo00<007ooOol05goo00<007ooOol0XWoo2@008goo000eOol2
000HOol00`00Oomoo`0WOol00`00Oomoo`1ROol00`00Oomoo`05Ool>0006Ool2000TOol003Eoo`03
001oogoo01Moo`03001oogoo08Uoo`/003Yoo`00=Goo00<007ooOol067oo00<007ooOol0:7oo00<0
07ooOol0EWoo1`000goo0P00@7oo000eOol00`00Oomoo`0HOol00`00Oomoo`0XOol00`00Oomoo`14
Ool00`00Oomoo`08Ool7000:Ool00`00Oomoo`0oOol003Eoo`8001Uoo`03001oogoo06ioo`<0009o
o`L005=oo`00=Goo00<007ooOol067oo00<007ooOol0:Woo00<007ooOol0@7oo1P00FWoo000eOol0
0`00Oomoo`0IOol00`00Oomoo`1YOol6001MOol003Eoo`03001oogoo01Qoo`8006Moo`@006=oo`00
=Goo0P0067oo1000;7oo0P00=7oo1000Igoo000eOol00`00Oomoo`0HOol4001MOol4001[Ool003Eo
o`03001oogoo01Uoo`04001oogoo000]Ool00`00Oomoo`0QOol00`00Oomoo`04Ool4001_Ool003Eo
o`03001oogoo01eoo`03001oogoo02Yoo`03001oogoo021oo`<00003Ool00000008004eoo`8002Ao
o`00=Goo00<007ooOol07Woo0P00C7oo1@00DGoo0P0097oo000eOol2000QOol00`00Oomoo`0YOol0
0`00Oomoo`0KOol5001AOol5000SOol003Eoo`03001oogoo025oo`8004Aoo`<004moo`80009oo`03
001oogoo02Qoo`0047oo0P0017oo0P0017oo0P000goo10000Woo10000goo0P001Goo00<007ooOol0
8goo00<007ooOol0?Woo0`00Cgoo0P00<7oo000?Ool01000Oomoo`0027oo00@007ooOol0009oo`03
001oogoo00=oo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`0TOol00`00Oomoo`0WOol2
000AOol3001<Ool01000Oomoo`00=7oo000?Ool01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00=oo`03001oogoo00Eoo`03001oogoo009oo`8002Ioo`8003Ioo`@004Ioo`03001oogoo009o
o`04001oogoo000hOol000moo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol00goo00<0
07ooOol00Woo0P001Goo00<007ooOol09goo00<007ooOol09Woo00<007ooOol01goo0`00BGoo00@0
07oo000003ioo`003goo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool000=oo`03001oogoo00Aoo`03001oogoo02Qoo`8002Moo`8000Aoo`<004Yoo`D003moo`0047oo
0P002Woo0P0017oo0P0017oo0P0017oo0`0017oo00<007ooOol0:Woo00<007ooOol08Woo2000Bgoo
00D007ooOomoo`00045oo`00=Goo0P00;7oo00<007ooOol08Woo10000goo00<007ooOol0A7oo0P00
B7oo000eOol00`00Oomoo`0/Ool2000NOol400000goo00000007Ool00`00Oomoo`0kOol01000Oomo
o`00C7oo000eOol00`00Oomoo`0^Ool00`00Oomoo`0GOol4000AOol2000eOol200000goo001oo`1?
Ool003Eoo`03001oogoo02moo`8001=oo`@001Uoo`03001oogoo02eoo`03001oogoo05Aoo`00=Goo
0P00<Woo00<007ooOol037oo100087oo00<007ooOol08Woo0`0000=oo`000000FGoo000eOol00`00
Oomoo`0bOol00`00Oomoo`07Ool4000TOol01000Oomoo`007Woo0P0000=oo`000000GGoo000eOol0
0`00Oomoo`0cOol30002Ool4000/Ool00`00Oomoo`0AOol00`00Oomoo`020002Ool00`00Oomoo`02
Ool5001KOol003Eoo`03001oogoo03=oo`D003=oo`03001oo`000080009oo`03001oogoo00800003
Ool00000011oo`03001oogoo05]oo`00=Goo00<007ooOol0=7oo0`00=7oo1@00N7oo000eOol2000f
Ool00`00Oomoo`2`Ool003Eoo`03001oogoo0>Qoo`00=Goo00<007ooOol0j7oo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00<goo0`00
jWoo000fOol00`00Oomoo`3WOol003Aoo`<00>Uoo`00<goo00@007ooOol00>Uoo`00<goo00@007oo
Ool00>Uoo`00=7oo1000j7oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.878633, 0.0055877, \
0.0353427, 0.000117976}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5886 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.477324 0.453515 0.294302 0.453515 [
[ 0 0 0 0 ]
[ 1 .5886 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0140144 0.930839 0.574589 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0147151 44.065 [
[.02381 .00222 -3 -9 ]
[.02381 .00222 3 0 ]
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -3 -9 ]
[.7381 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6.28125 ]
[1.025 .01472 10 6.28125 ]
[.13036 .10285 -30 -4.5 ]
[.13036 .10285 0 4.5 ]
[.13036 .19098 -30 -4.5 ]
[.13036 .19098 0 4.5 ]
[.13036 .27911 -30 -4.5 ]
[.13036 .27911 0 4.5 ]
[.13036 .36724 -30 -4.5 ]
[.13036 .36724 0 4.5 ]
[.13036 .45537 -24 -4.5 ]
[.13036 .45537 0 4.5 ]
[.13036 .5435 -30 -4.5 ]
[.13036 .5435 0 4.5 ]
[.14286 .64303 -5 0 ]
[.14286 .64303 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(0)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(2)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(4)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(6)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(8)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.08333 .01472 m
.08333 .01847 L
s
.20238 .01472 m
.20238 .01847 L
s
.32143 .01472 m
.32143 .01847 L
s
.38095 .01472 m
.38095 .01847 L
s
.44048 .01472 m
.44048 .01847 L
s
.55952 .01472 m
.55952 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.67857 .01472 m
.67857 .01847 L
s
.79762 .01472 m
.79762 .01847 L
s
.85714 .01472 m
.85714 .01847 L
s
.91667 .01472 m
.91667 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.14286 .10285 m
.14911 .10285 L
s
[(0.002)] .13036 .10285 1 0 Mshowa
.14286 .19098 m
.14911 .19098 L
s
[(0.004)] .13036 .19098 1 0 Mshowa
.14286 .27911 m
.14911 .27911 L
s
[(0.006)] .13036 .27911 1 0 Mshowa
.14286 .36724 m
.14911 .36724 L
s
[(0.008)] .13036 .36724 1 0 Mshowa
.14286 .45537 m
.14911 .45537 L
s
[(0.01)] .13036 .45537 1 0 Mshowa
.14286 .5435 m
.14911 .5435 L
s
[(0.012)] .13036 .5435 1 0 Mshowa
.125 Mabswid
.14286 .03675 m
.14661 .03675 L
s
.14286 .05878 m
.14661 .05878 L
s
.14286 .08081 m
.14661 .08081 L
s
.14286 .12488 m
.14661 .12488 L
s
.14286 .14691 m
.14661 .14691 L
s
.14286 .16894 m
.14661 .16894 L
s
.14286 .21301 m
.14661 .21301 L
s
.14286 .23504 m
.14661 .23504 L
s
.14286 .25707 m
.14661 .25707 L
s
.14286 .30114 m
.14661 .30114 L
s
.14286 .32317 m
.14661 .32317 L
s
.14286 .3452 m
.14661 .3452 L
s
.14286 .38927 m
.14661 .38927 L
s
.14286 .4113 m
.14661 .4113 L
s
.14286 .43333 m
.14661 .43333 L
s
.14286 .4774 m
.14661 .4774 L
s
.14286 .49943 m
.14661 .49943 L
s
.14286 .52146 m
.14661 .52146 L
s
.14286 .56553 m
.14661 .56553 L
s
.14286 .58756 m
.14661 .58756 L
s
.14286 .60959 m
.14661 .60959 L
s
.25 Mabswid
.14286 0 m
.14286 .61803 L
s
gsave
.14286 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.14286 .49278 m
.2619 .34737 L
.38095 .20673 L
.5 .12175 L
.61905 .07426 L
.7381 .04915 L
.85714 .03482 L
.97619 .02655 L
s
.0001 w
.14286 .49278 -1.875 0 Mabsadd m
.14286 .49278 0 2.5 Mabsadd L
.14286 .49278 1.875 0 Mabsadd L
.14286 .49278 0 -2.5 Mabsadd L
.14286 .49278 -1.875 0 Mabsadd L closepath F
.2619 .34737 -1.875 0 Mabsadd m
.2619 .34737 0 2.5 Mabsadd L
.2619 .34737 1.875 0 Mabsadd L
.2619 .34737 0 -2.5 Mabsadd L
.2619 .34737 -1.875 0 Mabsadd L closepath F
.38095 .20673 -1.875 0 Mabsadd m
.38095 .20673 0 2.5 Mabsadd L
.38095 .20673 1.875 0 Mabsadd L
.38095 .20673 0 -2.5 Mabsadd L
.38095 .20673 -1.875 0 Mabsadd L closepath F
.5 .12175 -1.875 0 Mabsadd m
.5 .12175 0 2.5 Mabsadd L
.5 .12175 1.875 0 Mabsadd L
.5 .12175 0 -2.5 Mabsadd L
.5 .12175 -1.875 0 Mabsadd L closepath F
.61905 .07426 -1.875 0 Mabsadd m
.61905 .07426 0 2.5 Mabsadd L
.61905 .07426 1.875 0 Mabsadd L
.61905 .07426 0 -2.5 Mabsadd L
.61905 .07426 -1.875 0 Mabsadd L closepath F
.7381 .04915 -1.875 0 Mabsadd m
.7381 .04915 0 2.5 Mabsadd L
.7381 .04915 1.875 0 Mabsadd L
.7381 .04915 0 -2.5 Mabsadd L
.7381 .04915 -1.875 0 Mabsadd L closepath F
.85714 .03482 -1.875 0 Mabsadd m
.85714 .03482 0 2.5 Mabsadd L
.85714 .03482 1.875 0 Mabsadd L
.85714 .03482 0 -2.5 Mabsadd L
.85714 .03482 -1.875 0 Mabsadd L closepath F
.97619 .02655 -1.875 0 Mabsadd m
.97619 .02655 0 2.5 Mabsadd L
.97619 .02655 1.875 0 Mabsadd L
.97619 .02655 0 -2.5 Mabsadd L
.97619 .02655 -1.875 0 Mabsadd L closepath F
.001 w
[ .5 3 ] 0 Mabsdash
.14286 .49278 m
.2619 .60332 L
.38095 .55423 L
.5 .40891 L
.61905 .28072 L
.7381 .18813 L
.85714 .1322 L
.97619 .09509 L
s
.0001 w
[ ] 0 setdash
.14286 .49278 0 2.5 Mabsadd m
.14286 .49278 -0.56518 .7779 Mabsadd L
.14286 .49278 -2.37764 .77254 Mabsadd L
.14286 .49278 -0.91448 -0.29713 Mabsadd L
.14286 .49278 -1.46946 -2.02254 Mabsadd L
.14286 .49278 0 -0.96154 Mabsadd L
.14286 .49278 1.46946 -2.02254 Mabsadd L
.14286 .49278 .91448 -0.29713 Mabsadd L
.14286 .49278 2.37764 .77254 Mabsadd L
.14286 .49278 .56518 .7779 Mabsadd L
.14286 .49278 0 2.5 Mabsadd L closepath F
.2619 .60332 0 2.5 Mabsadd m
.2619 .60332 -0.56518 .7779 Mabsadd L
.2619 .60332 -2.37764 .77254 Mabsadd L
.2619 .60332 -0.91448 -0.29713 Mabsadd L
.2619 .60332 -1.46946 -2.02254 Mabsadd L
.2619 .60332 0 -0.96154 Mabsadd L
.2619 .60332 1.46946 -2.02254 Mabsadd L
.2619 .60332 .91448 -0.29713 Mabsadd L
.2619 .60332 2.37764 .77254 Mabsadd L
.2619 .60332 .56518 .7779 Mabsadd L
.2619 .60332 0 2.5 Mabsadd L closepath F
.38095 .55423 0 2.5 Mabsadd m
.38095 .55423 -0.56518 .7779 Mabsadd L
.38095 .55423 -2.37764 .77254 Mabsadd L
.38095 .55423 -0.91448 -0.29713 Mabsadd L
.38095 .55423 -1.46946 -2.02254 Mabsadd L
.38095 .55423 0 -0.96154 Mabsadd L
.38095 .55423 1.46946 -2.02254 Mabsadd L
.38095 .55423 .91448 -0.29713 Mabsadd L
.38095 .55423 2.37764 .77254 Mabsadd L
.38095 .55423 .56518 .7779 Mabsadd L
.38095 .55423 0 2.5 Mabsadd L closepath F
.5 .40891 0 2.5 Mabsadd m
.5 .40891 -0.56518 .7779 Mabsadd L
.5 .40891 -2.37764 .77254 Mabsadd L
.5 .40891 -0.91448 -0.29713 Mabsadd L
.5 .40891 -1.46946 -2.02254 Mabsadd L
.5 .40891 0 -0.96154 Mabsadd L
.5 .40891 1.46946 -2.02254 Mabsadd L
.5 .40891 .91448 -0.29713 Mabsadd L
.5 .40891 2.37764 .77254 Mabsadd L
.5 .40891 .56518 .7779 Mabsadd L
.5 .40891 0 2.5 Mabsadd L closepath F
.61905 .28072 0 2.5 Mabsadd m
.61905 .28072 -0.56518 .7779 Mabsadd L
.61905 .28072 -2.37764 .77254 Mabsadd L
.61905 .28072 -0.91448 -0.29713 Mabsadd L
.61905 .28072 -1.46946 -2.02254 Mabsadd L
.61905 .28072 0 -0.96154 Mabsadd L
.61905 .28072 1.46946 -2.02254 Mabsadd L
.61905 .28072 .91448 -0.29713 Mabsadd L
.61905 .28072 2.37764 .77254 Mabsadd L
.61905 .28072 .56518 .7779 Mabsadd L
.61905 .28072 0 2.5 Mabsadd L closepath F
.7381 .18813 0 2.5 Mabsadd m
.7381 .18813 -0.56518 .7779 Mabsadd L
.7381 .18813 -2.37764 .77254 Mabsadd L
.7381 .18813 -0.91448 -0.29713 Mabsadd L
.7381 .18813 -1.46946 -2.02254 Mabsadd L
.7381 .18813 0 -0.96154 Mabsadd L
.7381 .18813 1.46946 -2.02254 Mabsadd L
.7381 .18813 .91448 -0.29713 Mabsadd L
.7381 .18813 2.37764 .77254 Mabsadd L
.7381 .18813 .56518 .7779 Mabsadd L
.7381 .18813 0 2.5 Mabsadd L closepath F
.85714 .1322 0 2.5 Mabsadd m
.85714 .1322 -0.56518 .7779 Mabsadd L
.85714 .1322 -2.37764 .77254 Mabsadd L
.85714 .1322 -0.91448 -0.29713 Mabsadd L
.85714 .1322 -1.46946 -2.02254 Mabsadd L
.85714 .1322 0 -0.96154 Mabsadd L
.85714 .1322 1.46946 -2.02254 Mabsadd L
.85714 .1322 .91448 -0.29713 Mabsadd L
.85714 .1322 2.37764 .77254 Mabsadd L
.85714 .1322 .56518 .7779 Mabsadd L
.85714 .1322 0 2.5 Mabsadd L closepath F
.97619 .09509 0 2.5 Mabsadd m
.97619 .09509 -0.56518 .7779 Mabsadd L
.97619 .09509 -2.37764 .77254 Mabsadd L
.97619 .09509 -0.91448 -0.29713 Mabsadd L
.97619 .09509 -1.46946 -2.02254 Mabsadd L
.97619 .09509 0 -0.96154 Mabsadd L
.97619 .09509 1.46946 -2.02254 Mabsadd L
.97619 .09509 .91448 -0.29713 Mabsadd L
.97619 .09509 2.37764 .77254 Mabsadd L
.97619 .09509 .56518 .7779 Mabsadd L
.97619 .09509 0 2.5 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
.61338 .2943 m
.61338 .56641 L
.97619 .56641 L
.97619 .2943 L
F
1 g
.61338 .2943 m
.61338 .56641 L
.97619 .56641 L
.97619 .2943 L
F
0 g
.001 w
[ ] 0 setdash
.61338 .2943 m
.97619 .2943 L
.97619 .56641 L
.61338 .56641 L
.61338 .2943 L
s
% Start of sub-graphic
p
0.613379 0.294302 0.97619 0.566411 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0297619 0.297619 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0535714 0.35119 0.35119 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.00468 w
[ .5 3 ] 0 Mabsdash
0 .5 m
1 .5 L
s
.00047 w
[ ] 0 setdash
.5 .5 0 2.5 Mabsadd m
.5 .5 -0.56518 .7779 Mabsadd L
.5 .5 -2.37764 .77254 Mabsadd L
.5 .5 -0.91448 -0.29713 Mabsadd L
.5 .5 -1.46946 -2.02254 Mabsadd L
.5 .5 0 -0.96154 Mabsadd L
.5 .5 1.46946 -2.02254 Mabsadd L
.5 .5 .91448 -0.29713 Mabsadd L
.5 .5 2.37764 .77254 Mabsadd L
.5 .5 .56518 .7779 Mabsadd L
.5 .5 0 2.5 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .20238 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.2) show
87.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.39881 0.35119 0.696429 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.00468 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
.00047 w
.5 .5 -1.875 0 Mabsadd m
.5 .5 0 2.5 Mabsadd L
.5 .5 1.875 0 Mabsadd L
.5 .5 0 -2.5 Mabsadd L
.5 .5 -1.875 0 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .54762 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.05) show
93.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .5886 L
0 .5886 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 169.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000ZA000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol001Uoo`80035oo`@0039oo`<002ioo`<0039oo`8003Io
o`0067oo00@007ooOol0031oo`03001oogoo03Aoo`03001oogoo02eoo`04001oogoo000`Ool01000
Oomoo`00=Goo000HOol01000Oomoo`00<Goo00<007ooOol0<7oo1@00;Woo00@007ooOol0031oo`04
001oogoo000eOol001Qoo`04001oogoo000bOol00`00Oomoo`0_Ool01000Oomoo`00;goo0`00<Woo
0P00=Woo000HOol01000Oomoo`00<7oo00@007ooOol0035oo`03001oo`00031oo`03001oogoo031o
o`04001oogoo000eOol001Uoo`80039oo`8003=oo`80031oo`<0035oo`8003Ioo`00ogoo8Goo003o
OolQOol003Aoo`03001oogoo0>Uoo`00=7oo00<007ooOol0`7oo0P009goo000dOol00`00Oomoo`2o
Ool01000Oomoo`009Woo000EOooJ0007Ool00`00Oomoo`0WOol001Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`8000]o
o`D002Ioo`00=7oo00<007ooOol0[7oo20002goo00<007ooOol09goo000dOol00`00Oomoo`2GOol2
0006Ool=0005Ool3000eOol003Aoo`03001oogoo09Aoo`/001=oo`03001oogoo03Aoo`00=7oo0P00
SGoo20000goo0`00Cgoo000dOol00`00Oomoo`1mOol20004Ool9000<Ool00`00Oomoo`1>Ool003Ao
o`03001oogoo07aoo`L006Ioo`00=7oo00<007ooOol0N7oo100000Aoo`00000006Uoo`00=7oo0P00
MGoo10001Woo00<007ooOol0J7oo000dOol00`00Oomoo`1_Ool5001eOol003Aoo`03001oogoo06Ao
o`03001oogoo00Aoo`@007Yoo`00=7oo00<007ooOol0I7oo0P0000=oo`0000000P00OWoo000dOol0
0`00Oomoo`1SOol40022Ool003Aoo`80069oo`800003Ool007oo08=oo`00=7oo00<007ooOol0GWoo
0`00R7oo000dOol00`00Oomoo`1LOol2001COol2000fOol001Ioo`8000Aoo`8000Aoo`8000Aoo`80
00=oo`@000=oo`03001oogoo05Uoo`<005Eoo`8003Ioo`005Goo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol0Egoo0P00EWoo1@00=Goo000EOol0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`03Ool3001DOol3001E
Ool2000kOol001Eoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo
009oo`03001oogoo059oo`8005Eoo`03001oogoo03eoo`005Goo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo04]oo`04001oogooOol3001COol2
0012Ool001Ioo`8000Yoo`8000Aoo`8000Aoo`8000Aoo`03001oogoo04Yoo`D005=oo`8004Eoo`00
=7oo00<007ooOol0BGoo1000DWoo00<007ooOol0Agoo000dOol2001:Ool3001;Ool300000goo0000
001<Ool003Aoo`03001oogoo04Qoo`03001oogoo04aoo`80051oo`00=7oo00<007ooOol0AWoo0P00
CWoo1000Cgoo000dOol00`00Oomoo`15Ool00`00Oomoo`1=Ool01000Oomoo`00D7oo000dOol20015
Ool00`00Oomoo`1;Ool00`00Oomoo`1DOol003Aoo`03001oogoo049oo`8004]oo`03001oogoo05Mo
o`00=7oo00<007ooOol0@Goo00<007ooOol0BWoo00<007ooOol0F7oo000dOol00`00Oomoo`0oOol2
001:Ool2001LOol003Aoo`03001oogoo03ioo`03001oogoo04Qoo`03001oogoo05eoo`00=7oo0P00
?Goo0P00BWoo00<007ooOol0GWoo000dOol00`00Oomoo`0kOol00`00Oomoo`17Ool00`00Oomoo`1Q
Ool003Aoo`03001oogoo03Uoo`8004Moo`03001oogoo06Aoo`005Woo0P0017oo0P0017oo0P0017oo
0P001Goo0`000Woo00<007ooOol0>7oo00<007ooOol0@Woo0`000Woo00<007ooOol0I7oo000EOol0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo0000>Goo00<007oo
Ool0@goo0`00JGoo000EOol01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool50002
Ool3000eOol20015Ool5001XOol001Eoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0003Ool00`00Oomoo`0dOol00`00Oomoo`15Ool00`00Ool0001ZOol001Eoo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000=oo`03001oogoo031o
o`@00;Eoo`005Woo0P002Woo0P0017oo0P001Goo0P000goo00<007ooOol0;goo1000AWoo00<007oo
Ool0KGoo000dOol00`00Oomoo`0`Ool3002fOol003Aoo`80031oo`03001oo`0004Aoo`80075oo`00
=7oo00<007ooOol0;Woo00<007ooOol0^7oo000dOol00`00Oomoo`0^Ool00`00Oomoo`13Ool00`00
Oomoo`1bOol003Aoo`03001oogoo02eoo`03001oogoo04Aoo`03001oogoo079oo`00=7oo00<007oo
Ool0;7oo00<007ooOol0@Woo00<007ooOol0MGoo000dOol2000/Ool00`00Oomoo`13Ool00`00Oomo
o`1eOol003Aoo`03001oogoo02Yoo`03001oogoo0;aoo`00=7oo00<007ooOol0:Goo00<007ooOol0
@Woo00<007ooOol0N7oo000dOol00`00Oomoo`0YOol00`00Oomoo`2mOol003Aoo`8002Uoo`03001o
ogoo041oo`8007aoo`00=7oo00<007ooOol09goo00<007ooOol0_goo000dOol00`00Oomoo`0VOol0
0`00Oomoo`0oOol2001oOol001Ioo`8000Aoo`8000Aoo`8000Aoo`8000=oo`<000Aoo`03001oogoo
02Eoo`03001oogoo0<5oo`005Goo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol000=oo`03001oogoo02Aoo`03001oogoo03eoo`<0089oo`005Goo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`<002Aoo`03001oogoo03eoo`03
001oogoo089oo`005Goo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0`0017oo
00<007ooOol08goo00<007ooOol0?7oo1@00PWoo000EOol01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0003Ool00`00Oomoo`03Ool00`00Oomoo`0ROol00`00Oomoo`0nOol20024Ool001Io
o`8000Yoo`8000Aoo`8000Aoo`<000=oo`03001oogoo025oo`03001oogoo0<Eoo`00=7oo00<007oo
Ool087oo00<007ooOol0?Woo00<007ooOol0QGoo000dOol2000POol00`00Oomoo`37Ool003Aoo`03
001oogoo01moo`03001oogoo0<Moo`00=7oo00<007ooOol07Woo00<007ooOol0?Goo0P00RGoo000d
Ool00`00Oomoo`0MOol00`00Oomoo`39Ool003Aoo`03001oogoo01aoo`03001oogoo03eoo`03001o
ogoo08Yoo`00=7oo0P0077oo00<007ooOol0bgoo000dOol00`00Oomoo`0JOol00`00Oomoo`1KOomY
0008Ool003Aoo`03001oogoo01Yoo`03001oogoo03eoo`03001oogoo01]oo`03001oogoo06Eoo`03
001oogoo00Ioo`00=7oo00<007ooOol05goo00<007oo0000GWoo00<007ooOol0IGoo00<007ooOol0
1Woo000dOol2000GOol3000oOol00`00Oomoo`0MOol00`00Oomoo`1UOol00`00Oomoo`06Ool003Ao
o`03001oogoo01Eoo`@003ioo`03001oogoo01ioo`03001oogoo06Eoo`03001oogoo00Ioo`00=7oo
00<007ooOol05Woo0P00H7oo00<007ooOol0IGoo00<007ooOol01Woo000FOol20004Ool20004Ool2
0004Ool20004Ool20004Ool00`00Oomoo`0EOol00`00Oomoo`0mOol00`00Oomoo`0POol00`00Oomo
o`1UOol00`00Oomoo`06Ool001Eoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0003Ool00`00Oomoo`0DOol00`00Oomoo`1QOol00`00Oomoo`1UOol00`00Oomoo`06
Ool001Eoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool3
000DOol00`00Oomoo`0lOol00`00Oomoo`0ROol00`00Oomoo`1UOol00`00Oomoo`06Ool001Eoo`04
001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000=oo`8000Aoo`03001oogoo01=oo`03001o
ogoo03eoo`03001oogoo029oo`03001oogoo06Eoo`03001oogoo00Ioo`005Goo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo019oo`03001oogoo
06=oo`03001oogoo06Eoo`03001oogoo00Ioo`005Woo0P002Woo0P0017oo0P0017oo0P0017oo00<0
07ooOol04Goo00<007ooOol0?7oo00<007ooOol09Goo00<007ooOol0IGoo00<007ooOol01Woo000d
Ool00`00Oomoo`0@Ool00`00Oomoo`1UOol00`00Oomoo`1UOol00`00Oomoo`06Ool003Aoo`80011o
o`03001oogoo03aoo`03001oogoo02Moo`03001oogoo06Eoo`03001oogoo00Ioo`00=7oo00<007oo
Ool03goo00<007ooOol0?7oo00<007ooOol09goo00<007ooOol0IGoo00<007ooOol01Woo000dOol0
0`00Oomoo`0>Ool00`00Oomoo`1WOol00`00Oomoo`1UOol00`00Oomoo`06Ool003Aoo`03001oogoo
00eoo`03001oogoo03Yoo`<002]oo`03001oogoo06Eoo`03001oogoo00Ioo`00=7oo00<007ooOol0
37oo00<007ooOol0>goo0P00;7oo00<007ooOol0IGoo00<007ooOol01Woo000dOol2000<Ool00`00
Oomoo`0jOol5000[Ool00`00Oomoo`1UOol00`00Oomoo`06Ool003Aoo`03001oogoo00Yoo`03001o
ogoo03aoo`03001oogoo02aoo`03001oogoo06Eoo`03001oogoo00Ioo`00=7oo00<007ooOol02Woo
00<007ooOol0Jgoo00<007ooOol04Woo0P005Woo0`002Goo0P000goo10009Woo00<007ooOol01Woo
000dOol00`00Oomoo`09Ool00`00Oomoo`0kOol00`00Oomoo`0^Ool00`00Oomoo`03Ool20002Ool0
0`00Oomoo`020002Ool00`00Oomoo`020002Ool00`00Oomoo`020002Ool00`00Oomoo`020009Ool0
0`00Oomoo`02Ool40008Ool00`00Oomoo`0WOol00`00Oomoo`06Ool003Aoo`8000Uoo`03001oogoo
03aoo`03001oogoo02ioo`03001oogoo011oo`D001Eoo`03001oogoo00moo`03001oogoo02Ioo`03
001oogoo00Ioo`00=7oo00<007ooOol01goo00<007ooOol0KWoo00<007ooOol04Woo00<007ooOol0
5Woo00@007ooOomoo`@000Yoo`03001oogoo02Eoo`03001oogoo00Ioo`00=7oo00<007ooOol01Woo
00<007ooOol0?7oo00<007ooOol0<7oo00<007ooOol0:Goo10003Woo00@007ooOol002Ioo`03001o
ogoo00Ioo`0077oo0P0017oo0P0017oo0P000goo1@000Woo00<007ooOol01Goo00<007ooOol0?Goo
00<007ooOol0<7oo00<007ooOol0?7oo0P009goo00<007ooOol01Woo000KOol01000Oomoo`0027oo
00@007ooOol000Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo071oo`03001oogoo06Eo
o`03001oogoo00Ioo`006goo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`02Ool30004
Ool00`00Oomoo`0kOol2000dOol00`00Oomoo`1UOol00`00Oomoo`06Ool001]oo`04001oogoo0008
Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0LWoo00<007ooOol0
IGoo00<007ooOol01Woo000KOol01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo009oo`03
001oogoo009oo`03001oogoo07=oo`03001oogoo06Eoo`03001oogoo00Ioo`0077oo0P002Woo0P00
17oo0P0017oo00D007ooOomoo`0003ioo`8003Ioo`03001oogoo06Eoo`03001oogoo00Ioo`00=7oo
00@007ooOol007Moo`03001oogoo06Eoo`03001oogoo00Ioo`00=7oo0P0000=oo`00Ool0?7oo00<0
07ooOol0=goo00<007ooOol0IGoo00<007ooOol01Woo000dOol00`00Ool0000nOol00`00Oomoo`0g
Ool00`00Oomoo`1UOol00`00Oomoo`06Ool003=oo`<007Uoo`03001oogoo06Eoo`03001oogoo00Io
o`00<Woo1000?Goo00<007ooOol0>Goo00<007ooOol0IGoo00<007ooOol01Woo000bOol5001hOol0
0`00Oomoo`1UOol00`00Oomoo`06Ool003Aoo`8007Uoo`03001oogoo06Eoo`03001oogoo00Ioo`00
=7oo00@007ooOol003Uoo`03001oogoo03]oo`03001oogoo06Eoo`03001oogoo00Ioo`00=7oo00<0
07ooOol0N7oo00<007ooOol0IGoo00<007ooOol01Woo000dOol00`00Oomoo`02Ool2000dOol00`00
Oomoo`0mOol00`00Oomoo`1UOol00`00Oomoo`06Ool003Aoo`03001oogoo03Moo`03001oogoo03io
o`03001oogoo06Eoo`03001oogoo00Ioo`00=7oo0P00NGoo00<007ooOol0IGoo00<007ooOol01Woo
000dOol00`00Oomoo`05Ool00`00Oomoo`0]Ool00`00Oomoo`10Ool00`00Oomoo`1UOol00`00Oomo
o`06Ool001Ioo`8000Aoo`8000Aoo`8000=oo`D00003Ool00000008000=oo`03001oogoo07Qoo`03
001oogoo06Eoo`03001oogoo00Ioo`005Goo00@007ooOol000Qoo`04001oogoo0004Ool01@00Oomo
ogoo00001Woo00<007ooOol01goo0P00Kgoo00<007ooOol0IGoo00<007ooOol01Woo000EOol01000
Oomoo`0027oo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo00=oo`<003=oo`03001oogoo
049oo`03001oogoo06Eoo`03001oogoo00Ioo`005Goo00@007ooOol000Qoo`04001oogoo0004Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`1[Ool00`00Oomoo`1UOol0
0`00Oomoo`06Ool001Eoo`04001oogoo0008Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`05
001oogooOol0000<Ool00`00Oomoo`0SOol20016Ool00`00Oomoo`1UOol00`00Oomoo`06Ool001Io
o`8000Yoo`8000Aoo`8000Aoo`8000Aoo`03001oogoo02ioo`D004Eoo`03001oogoo06Eoo`03001o
ogoo00Ioo`00=7oo00<007ooOol03Goo00<007ooOol07Goo0P00BGoo00<007ooOol0IGoo00<007oo
Ool01Woo000dOol2000[Ool2001<Ool00`00Oomoo`1UOol00`00Oomoo`06Ool003Aoo`03001oogoo
00moo`03001oogoo06Ioo`03001oogoo06Eoo`03001oogoo00Ioo`00=7oo00<007ooOol09goo00<0
07ooOol0CWoo00<007ooOol0IGoo00<007ooOol01Woo000dOol00`00Oomoo`0BOol00`00Oomoo`0?
Ool00`00Oomoo`1AOol00`00Oomoo`1UOol00`00Oomoo`06Ool003Aoo`03001oogoo019oo`03001o
ogoo00]oo`8005Ioo`03001oogoo06Eoo`03001oogoo00Ioo`00=7oo0P00NGoo00<007ooOol04Woo
00<007ooOol05Goo0`002Goo0P0017oo0P0017oo0P008Goo00<007ooOol01Woo000dOol00`00Oomo
o`0DOol20007Ool2001IOol00`00Oomoo`03OolP0007Ool00`00Oomoo`02Ool40008Ool01000Oomo
o`000Woo00@007ooOol0021oo`03001oogoo00Ioo`00=7oo00<007ooOol05Woo0`0000=oo`00Ool0
G7oo00<007ooOol04Woo0P005Woo00<007ooOol03Woo00@007ooOol000Eoo`03001oogoo01ioo`03
001oogoo00Ioo`00=7oo00<007ooOol05Woo0P00H7oo00<007ooOol04Woo00<007ooOol05Woo00@0
07ooOomoo`@000Qoo`04001oogoo0003Ool2000QOol00`00Oomoo`06Ool003Aoo`03001oogoo01Eo
o`@005moo`03001oogoo02Uoo`@000ioo`04001oogoo0003Ool00`00Oomoo`0POol00`00Oomoo`06
Ool003Aoo`8001Qoo`03001oogoo05ioo`03001oogoo03aoo`8000Aoo`<0021oo`03001oogoo00Io
o`00=7oo00<007ooOol0N7oo00<007ooOol0IGoo00<007ooOol01Woo000dOol00`00Oomoo`1hOol0
0`00Oomoo`1UOol00`00Oomoo`06Ool00:moo`03001oogoo06Eoo`03001oogoo00Ioo`00[goo00<0
07ooOol0IGoo00<007ooOol01Woo002_Ool00`00Oomoo`1UOol00`00Oomoo`06Ool00:moo`03001o
ogoo06Eoo`03001oogoo00Ioo`00[goo00<007ooOol0IGoo00<007ooOol01Woo002_Ool00`00Oomo
o`1UOol00`00Oomoo`06Ool00:moo`03001oogoo06Eoo`03001oogoo00Ioo`00[goo00<007ooOol0
IGoo00<007ooOol01Woo002_Ool00`00Oomoo`1UOol00`00Oomoo`06Ool0035oo`<00003Ool007oo
07Qoo`03001oogoo06Eoo`03001oogoo00Ioo`00<Woo00@007oo000007Uoo`03001oogoo06Eoo`03
001oogoo00Ioo`00<Woo00@007oo000007Uoo`03001oogoo06Eoo`03001oogoo00Ioo`00<Woo0P00
00=oo`00Ool0N7oo00<007ooOol0IGoo00<007ooOol01Woo000bOol200000goo001oo`1hOol00`00
Oomoo`1UOol00`00Oomoo`06Ool0035oo`800004Ool00000001hOomY0008Ool00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {168.5, 0}} -> {-1.05531, -0.648942, \
0.00770252, 0.00770252}, {{7.125, 266.813}, {164.438, 4}} -> {-1.04406, \
-0.00165149, 0.0387603, 0.000104717}, {{175.938, 279.813}, {84.25, 6.3125}} -> \
{-5.79105, -2.82574, 0.0323469, 0.0323469}, {{181.5, 212.375}, {78.625, \
47.75}} -> {-12.7572, -6.82193, 0.064778, 0.064778}, {{181.5, 212.375}, \
{42.75, 11.875}} -> {-12.7572, -9.14584, 0.064778, 0.064778}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 -0.126123 1.34819 [
[.02381 -0.0038 -3 -9 ]
[.02381 -0.0038 3 0 ]
[.2619 -0.0038 -3 -9 ]
[.2619 -0.0038 3 0 ]
[.5 -0.0038 -3 -9 ]
[.5 -0.0038 3 0 ]
[.7381 -0.0038 -3 -9 ]
[.7381 -0.0038 3 0 ]
[.97619 -0.0038 -3 -9 ]
[.97619 -0.0038 3 0 ]
[1.025 .0087 0 -6.28125 ]
[1.025 .0087 10 6.28125 ]
[.13036 .14351 -18 -4.5 ]
[.13036 .14351 0 4.5 ]
[.13036 .27833 -18 -4.5 ]
[.13036 .27833 0 4.5 ]
[.13036 .41315 -18 -4.5 ]
[.13036 .41315 0 4.5 ]
[.13036 .54797 -18 -4.5 ]
[.13036 .54797 0 4.5 ]
[.14286 .64303 -5 0 ]
[.14286 .64303 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .0087 m
.02381 .01495 L
s
[(0)] .02381 -0.0038 0 1 Mshowa
.2619 .0087 m
.2619 .01495 L
s
[(2)] .2619 -0.0038 0 1 Mshowa
.5 .0087 m
.5 .01495 L
s
[(4)] .5 -0.0038 0 1 Mshowa
.7381 .0087 m
.7381 .01495 L
s
[(6)] .7381 -0.0038 0 1 Mshowa
.97619 .0087 m
.97619 .01495 L
s
[(8)] .97619 -0.0038 0 1 Mshowa
.125 Mabswid
.08333 .0087 m
.08333 .01245 L
s
.20238 .0087 m
.20238 .01245 L
s
.32143 .0087 m
.32143 .01245 L
s
.38095 .0087 m
.38095 .01245 L
s
.44048 .0087 m
.44048 .01245 L
s
.55952 .0087 m
.55952 .01245 L
s
.61905 .0087 m
.61905 .01245 L
s
.67857 .0087 m
.67857 .01245 L
s
.79762 .0087 m
.79762 .01245 L
s
.85714 .0087 m
.85714 .01245 L
s
.91667 .0087 m
.91667 .01245 L
s
.25 Mabswid
0 .0087 m
1 .0087 L
s
gsave
1.025 .0087 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.14286 .14351 m
.14911 .14351 L
s
[(0.2)] .13036 .14351 1 0 Mshowa
.14286 .27833 m
.14911 .27833 L
s
[(0.3)] .13036 .27833 1 0 Mshowa
.14286 .41315 m
.14911 .41315 L
s
[(0.4)] .13036 .41315 1 0 Mshowa
.14286 .54797 m
.14911 .54797 L
s
[(0.5)] .13036 .54797 1 0 Mshowa
.125 Mabswid
.14286 .03566 m
.14661 .03566 L
s
.14286 .06262 m
.14661 .06262 L
s
.14286 .08959 m
.14661 .08959 L
s
.14286 .11655 m
.14661 .11655 L
s
.14286 .17048 m
.14661 .17048 L
s
.14286 .19744 m
.14661 .19744 L
s
.14286 .22441 m
.14661 .22441 L
s
.14286 .25137 m
.14661 .25137 L
s
.14286 .3053 m
.14661 .3053 L
s
.14286 .33226 m
.14661 .33226 L
s
.14286 .35923 m
.14661 .35923 L
s
.14286 .38619 m
.14661 .38619 L
s
.14286 .44012 m
.14661 .44012 L
s
.14286 .46708 m
.14661 .46708 L
s
.14286 .49404 m
.14661 .49404 L
s
.14286 .52101 m
.14661 .52101 L
s
.14286 .57494 m
.14661 .57494 L
s
.14286 .6019 m
.14661 .6019 L
s
.25 Mabswid
.14286 0 m
.14286 .61803 L
s
gsave
.14286 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(I) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.14286 .57547 m
.2619 .48286 L
.38095 .39709 L
.5 .2956 L
.61905 .19887 L
.7381 .12126 L
.85714 .06057 L
.97619 .01472 L
s
.0001 w
.14286 .57547 -1.875 0 Mabsadd m
.14286 .57547 0 2.5 Mabsadd L
.14286 .57547 1.875 0 Mabsadd L
.14286 .57547 0 -2.5 Mabsadd L
.14286 .57547 -1.875 0 Mabsadd L closepath F
.2619 .48286 -1.875 0 Mabsadd m
.2619 .48286 0 2.5 Mabsadd L
.2619 .48286 1.875 0 Mabsadd L
.2619 .48286 0 -2.5 Mabsadd L
.2619 .48286 -1.875 0 Mabsadd L closepath F
.38095 .39709 -1.875 0 Mabsadd m
.38095 .39709 0 2.5 Mabsadd L
.38095 .39709 1.875 0 Mabsadd L
.38095 .39709 0 -2.5 Mabsadd L
.38095 .39709 -1.875 0 Mabsadd L closepath F
.5 .2956 -1.875 0 Mabsadd m
.5 .2956 0 2.5 Mabsadd L
.5 .2956 1.875 0 Mabsadd L
.5 .2956 0 -2.5 Mabsadd L
.5 .2956 -1.875 0 Mabsadd L closepath F
.61905 .19887 -1.875 0 Mabsadd m
.61905 .19887 0 2.5 Mabsadd L
.61905 .19887 1.875 0 Mabsadd L
.61905 .19887 0 -2.5 Mabsadd L
.61905 .19887 -1.875 0 Mabsadd L closepath F
.7381 .12126 -1.875 0 Mabsadd m
.7381 .12126 0 2.5 Mabsadd L
.7381 .12126 1.875 0 Mabsadd L
.7381 .12126 0 -2.5 Mabsadd L
.7381 .12126 -1.875 0 Mabsadd L closepath F
.85714 .06057 -1.875 0 Mabsadd m
.85714 .06057 0 2.5 Mabsadd L
.85714 .06057 1.875 0 Mabsadd L
.85714 .06057 0 -2.5 Mabsadd L
.85714 .06057 -1.875 0 Mabsadd L closepath F
.97619 .01472 -1.875 0 Mabsadd m
.97619 .01472 0 2.5 Mabsadd L
.97619 .01472 1.875 0 Mabsadd L
.97619 .01472 0 -2.5 Mabsadd L
.97619 .01472 -1.875 0 Mabsadd L closepath F
.001 w
[ .5 3 ] 0 Mabsdash
.14286 .57547 m
.2619 .58747 L
.38095 .60332 L
.5 .58058 L
.61905 .51436 L
.7381 .42213 L
.85714 .33399 L
.97619 .25353 L
s
.0001 w
[ ] 0 setdash
.14286 .57547 0 2.5 Mabsadd m
.14286 .57547 -0.56518 .7779 Mabsadd L
.14286 .57547 -2.37764 .77254 Mabsadd L
.14286 .57547 -0.91448 -0.29713 Mabsadd L
.14286 .57547 -1.46946 -2.02254 Mabsadd L
.14286 .57547 0 -0.96154 Mabsadd L
.14286 .57547 1.46946 -2.02254 Mabsadd L
.14286 .57547 .91448 -0.29713 Mabsadd L
.14286 .57547 2.37764 .77254 Mabsadd L
.14286 .57547 .56518 .7779 Mabsadd L
.14286 .57547 0 2.5 Mabsadd L closepath F
.2619 .58747 0 2.5 Mabsadd m
.2619 .58747 -0.56518 .7779 Mabsadd L
.2619 .58747 -2.37764 .77254 Mabsadd L
.2619 .58747 -0.91448 -0.29713 Mabsadd L
.2619 .58747 -1.46946 -2.02254 Mabsadd L
.2619 .58747 0 -0.96154 Mabsadd L
.2619 .58747 1.46946 -2.02254 Mabsadd L
.2619 .58747 .91448 -0.29713 Mabsadd L
.2619 .58747 2.37764 .77254 Mabsadd L
.2619 .58747 .56518 .7779 Mabsadd L
.2619 .58747 0 2.5 Mabsadd L closepath F
.38095 .60332 0 2.5 Mabsadd m
.38095 .60332 -0.56518 .7779 Mabsadd L
.38095 .60332 -2.37764 .77254 Mabsadd L
.38095 .60332 -0.91448 -0.29713 Mabsadd L
.38095 .60332 -1.46946 -2.02254 Mabsadd L
.38095 .60332 0 -0.96154 Mabsadd L
.38095 .60332 1.46946 -2.02254 Mabsadd L
.38095 .60332 .91448 -0.29713 Mabsadd L
.38095 .60332 2.37764 .77254 Mabsadd L
.38095 .60332 .56518 .7779 Mabsadd L
.38095 .60332 0 2.5 Mabsadd L closepath F
.5 .58058 0 2.5 Mabsadd m
.5 .58058 -0.56518 .7779 Mabsadd L
.5 .58058 -2.37764 .77254 Mabsadd L
.5 .58058 -0.91448 -0.29713 Mabsadd L
.5 .58058 -1.46946 -2.02254 Mabsadd L
.5 .58058 0 -0.96154 Mabsadd L
.5 .58058 1.46946 -2.02254 Mabsadd L
.5 .58058 .91448 -0.29713 Mabsadd L
.5 .58058 2.37764 .77254 Mabsadd L
.5 .58058 .56518 .7779 Mabsadd L
.5 .58058 0 2.5 Mabsadd L closepath F
.61905 .51436 0 2.5 Mabsadd m
.61905 .51436 -0.56518 .7779 Mabsadd L
.61905 .51436 -2.37764 .77254 Mabsadd L
.61905 .51436 -0.91448 -0.29713 Mabsadd L
.61905 .51436 -1.46946 -2.02254 Mabsadd L
.61905 .51436 0 -0.96154 Mabsadd L
.61905 .51436 1.46946 -2.02254 Mabsadd L
.61905 .51436 .91448 -0.29713 Mabsadd L
.61905 .51436 2.37764 .77254 Mabsadd L
.61905 .51436 .56518 .7779 Mabsadd L
.61905 .51436 0 2.5 Mabsadd L closepath F
.7381 .42213 0 2.5 Mabsadd m
.7381 .42213 -0.56518 .7779 Mabsadd L
.7381 .42213 -2.37764 .77254 Mabsadd L
.7381 .42213 -0.91448 -0.29713 Mabsadd L
.7381 .42213 -1.46946 -2.02254 Mabsadd L
.7381 .42213 0 -0.96154 Mabsadd L
.7381 .42213 1.46946 -2.02254 Mabsadd L
.7381 .42213 .91448 -0.29713 Mabsadd L
.7381 .42213 2.37764 .77254 Mabsadd L
.7381 .42213 .56518 .7779 Mabsadd L
.7381 .42213 0 2.5 Mabsadd L closepath F
.85714 .33399 0 2.5 Mabsadd m
.85714 .33399 -0.56518 .7779 Mabsadd L
.85714 .33399 -2.37764 .77254 Mabsadd L
.85714 .33399 -0.91448 -0.29713 Mabsadd L
.85714 .33399 -1.46946 -2.02254 Mabsadd L
.85714 .33399 0 -0.96154 Mabsadd L
.85714 .33399 1.46946 -2.02254 Mabsadd L
.85714 .33399 .91448 -0.29713 Mabsadd L
.85714 .33399 2.37764 .77254 Mabsadd L
.85714 .33399 .56518 .7779 Mabsadd L
.85714 .33399 0 2.5 Mabsadd L closepath F
.97619 .25353 0 2.5 Mabsadd m
.97619 .25353 -0.56518 .7779 Mabsadd L
.97619 .25353 -2.37764 .77254 Mabsadd L
.97619 .25353 -0.91448 -0.29713 Mabsadd L
.97619 .25353 -1.46946 -2.02254 Mabsadd L
.97619 .25353 0 -0.96154 Mabsadd L
.97619 .25353 1.46946 -2.02254 Mabsadd L
.97619 .25353 .91448 -0.29713 Mabsadd L
.97619 .25353 2.37764 .77254 Mabsadd L
.97619 .25353 .56518 .7779 Mabsadd L
.97619 .25353 0 2.5 Mabsadd L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000DOol2
000fOol4000gOol3000dOol3000gOol2000VOol001=oo`04001oogoo000eOol00`00Oomoo`0iOol0
0`00Oomoo`0cOol01000Oomoo`00=Goo00@007ooOol002Eoo`004goo00@007ooOol003Ioo`03001o
ogoo03Eoo`D003Aoo`04001oogoo000eOol01000Oomoo`009Goo000COol01000Oomoo`00=goo00<0
07ooOol0=7oo00@007ooOol003Eoo`<003Moo`8002Ioo`004goo00@007ooOol003Eoo`04001oogoo
000fOol00`00Ool0000fOol00`00Oomoo`0eOol01000Oomoo`009Goo000DOol2000gOol2000hOol2
000fOol3000fOol2000VOol00?moob5oo`00ogoo8Goo000aOol00`00Oomoo`3/Ool0035oo`03001o
ogoo0=Eoo`8001Eoo`00<Goo00<007ooOol0e7oo00@007ooOol001Aoo`003gool@0027oo00<007oo
Ool05Goo000EOol00`00Oomoo`0IOol00`00Oomoo`0JOol00`00Oomoo`0fOol00`00Oomoo`0fOol0
0`00Oomoo`0eOol3000<Ool5000DOol0035oo`03001oogoo0<9oo`800003Ool0000000eoo`03001o
ogoo01Eoo`00<Goo00<007ooOol0_goo0`000goo00<007ooOol097oo000aOol00`00Oomoo`2mOol2
000]Ool0035oo`03001oogoo0;Yoo`<002moo`00<Goo0P00^Goo0P00<Woo000aOol00`00Oomoo`2e
Ool3000dOol0035oo`03001oogoo0;9oo`<003Moo`00<Goo00<007ooOol0/7oo0P00>Woo000aOol0
0`00Oomoo`2]Ool3000lOol0035oo`03001oogoo0:Qoo`800003Ool0000003moo`00<Goo00<007oo
Ool0Ygoo1000@Goo000aOol2002XOol40011Ool0035oo`03001oogoo0:Eoo`80009oo`03001oogoo
041oo`00<Goo00<007ooOol0Xgoo0P00Agoo000aOol00`00Oomoo`2QOol20019Ool0035oo`03001o
ogoo09moo`8004]oo`00<Goo00<007ooOol0WGoo0P00CGoo000aOol2002LOol2001?Ool0035oo`03
001oogoo09Uoo`80055oo`00<Goo00<007ooOol0Ugoo0P00Dgoo000aOol00`00Oomoo`2EOol2001E
Ool0035oo`03001oogoo09=oo`8005Moo`00<Goo00<007ooOol0TGoo0P00FGoo000aOol2002=Ool0
0`00Oomoo`02001KOol0035oo`03001oogoo08]oo`@005eoo`00<Goo00<007ooOol0RWoo1000GWoo
000aOol00`00Oomoo`2:Ool3001OOol0035oo`03001oogoo08Uoo`03001oogoo061oo`007Woo0P00
17oo0P000goo100017oo00<007ooOol0Qgoo0P00Hgoo000MOol01000Oomoo`0027oo00<007ooOol0
1Goo00<007ooOol0QWoo00<007ooOol0Hgoo000MOol01000Oomoo`002Goo00<007ooOol017oo0`00
Q7oo0P00IWoo000MOol01000Oomoo`002Woo00<007ooOol00goo00<007ooOol0PWoo0P00J7oo000M
Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo085oo`03001oogoo06Qoo`007Woo0P00
2Woo0P001Goo00<007ooOol0Ogoo0P00Jgoo000aOol00`00Oomoo`1nOol00`00Oomoo`1[Ool0035o
o`03001oogoo07aoo`8006ioo`00<Goo0P00O7oo00<007ooOol0KWoo000aOol00`00Oomoo`1iOol2
001aOol0035oo`03001oogoo07Qoo`03001oogoo075oo`00<Goo00<007ooOol0MWoo0P00M7oo000a
Ool00`00Oomoo`1dOol2001fOol0035oo`03001oogoo07=oo`03001oogoo07Ioo`00<Goo00<007oo
Ool0Kgoo1000NGoo000aOol2001_Ool3001kOol0035oo`03001oogoo06moo`8007]oo`00<Goo00<0
07ooOol0KGoo0P0000=oo`00Ool0NWoo000aOol00`00Oomoo`1/Ool00`00Oomoo`1mOol0035oo`03
001oogoo06]oo`03001oogoo07ioo`00<Goo00<007ooOol0JWoo00<007ooOol0Ogoo000aOol2001Y
Ool20022Ool0035oo`03001oogoo06Moo`03001oogoo089oo`00<Goo00<007ooOol0IWoo00<007oo
Ool0Pgoo000aOol00`00Oomoo`1UOol00`00Oomoo`24Ool0035oo`03001oogoo06=oo`8008Moo`00
<Goo00<007ooOol0HWoo00<007ooOol0Qgoo000aOol00`00Oomoo`1QOol00`00Oomoo`1POol3000U
Ool0035oo`80061oo`8006=oo`8002Ioo`00<Goo00<007ooOol0GWoo00<007ooOol0HWoo1@0097oo
000aOol00`00Oomoo`1MOol00`00Oomoo`1UOol00`00Oomoo`0TOol0035oo`03001oogoo05aoo`03
001oogoo069oo`03001oogoo02Qoo`007Woo0P0017oo0P0017oo0P001Goo00<007ooOol0FWoo0P00
T7oo000MOol01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo05Uoo`03001oogoo069oo`80
02aoo`007Goo00@007ooOol000Yoo`03001oogoo00=oo`<005Qoo`03001oogoo095oo`007Goo00@0
07ooOol000]oo`03001oogoo009oo`03001oogoo05Moo`03001oogoo065oo`8002moo`007Goo00@0
07ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`1EOol2002EOol001ioo`8000Yoo`8000Eoo`03
001oogoo059oo`<006=oo`80039oo`00<Goo00<007ooOol0DGoo1000Ugoo000aOol00`00Oomoo`1B
Ool3001POol2000eOol0035oo`03001oogoo055oo`03001oo`0009Qoo`00<Goo0P00D7oo0P00HWoo
00<007ooOol0=Woo000aOol00`00Oomoo`1>Ool00`00Oomoo`2KOol0035oo`03001oogoo04eoo`03
001oogoo061oo`03001oogoo03Uoo`00<Goo00<007ooOol0C7oo00<007ooOol0WGoo000aOol00`00
Oomoo`1;Ool00`00Oomoo`1OOol00`00Oomoo`0lOol0035oo`03001oogoo04Yoo`03001oogoo09mo
o`00<Goo0P00BGoo0P00GWoo0`00@Goo000aOol00`00Oomoo`17Ool00`00Oomoo`1LOol50011Ool0
035oo`03001oogoo04Ioo`03001oogoo05ioo`03001oogoo049oo`00<Goo00<007ooOol0AGoo00<0
07ooOol0Y7oo000aOol00`00Oomoo`14Ool00`00Oomoo`1MOol20016Ool0035oo`03001oogoo04=o
o`03001oogoo0:Ioo`00<Goo00<007ooOol0@Woo00<007ooOol0G7oo0P00BGoo000aOol20011Ool2
002ZOol0035oo`03001oogoo03moo`03001oogoo05eoo`03001oogoo04Yoo`00<Goo00<007ooOol0
?Woo00<007ooOol0Zgoo000aOol00`00Oomoo`0mOol00`00Oomoo`1LOol00`00Oomoo`1=Ool0035o
o`03001oogoo03aoo`03001oogoo0:eoo`00<Goo00<007ooOol0>goo00<007ooOol0Fgoo00<007oo
Ool0D7oo000aOol2000jOol2002aOol0035oo`03001oogoo03Ioo`03001oo`0005ioo`03001oogoo
059oo`00<Goo00<007ooOol0=Woo0P00GWoo00<007ooOol0Dgoo000aOol00`00Oomoo`0eOol3001L
Ool00`00Oomoo`1EOol0035oo`03001oogoo03Aoo`<005aoo`03001oogoo05Ioo`007Woo0P0017oo
0P001Goo0`000goo00<007ooOol0<goo00<007ooOol0Fgoo00<007ooOol0F7oo000MOol01000Oomo
o`002goo00<007ooOol00Woo00<007ooOol0<Woo00<007ooOol0G7oo00<007ooOol0F7oo000MOol0
1000Oomoo`0027oo1@000goo0`00<7oo0P00G7oo00<007ooOol0Fgoo000MOol01000Oomoo`0027oo
00@007ooOol000Aoo`03001oogoo02moo`03001oogoo05Uoo`@005eoo`007Goo00@007ooOol000Uo
o`03001oo`0000Aoo`03001oogoo02eoo`8005aoo`8005moo`007Woo0P002goo0P0017oo00<007oo
Ool0;7oo00<007ooOol0Fgoo1@00GGoo000aOol00`00Oomoo`0[Ool00`00Oomoo`2nOol0035oo`03
001oogoo02Uoo`8005eoo`80069oo`00<Goo0P00:Goo00<007ooOol0`Goo000aOol00`00Oomoo`0V
Ool2001MOol2001UOol0035oo`03001oogoo02Eoo`03001oogoo0<Aoo`00<Goo00<007ooOol097oo
00<007ooOol0G7oo00<007ooOol0IWoo000aOol00`00Oomoo`0ROol20038Ool0035oo`03001oogoo
025oo`03001oogoo05aoo`03001oogoo06Uoo`00<Goo00<007ooOol07goo0P00bgoo000aOol2000O
Ool00`00Oomoo`1LOol00`00Oomoo`1/Ool0035oo`03001oogoo01eoo`03001oogoo05eoo`03001o
ogoo06aoo`00<Goo00<007ooOol06Goo1000GWoo00<007ooOol0KWoo000aOol00`00Oomoo`0HOol4
001NOol00`00Oomoo`1_Ool0035oo`03001oogoo01Uoo`<00=1oo`00<Goo00<007ooOol05goo0P00
00=oo`00Ool0G7oo00<007ooOol0LGoo000aOol2000GOol00`00Oomoo`3COol0035oo`03001oogoo
01Eoo`03001oogoo05eoo`03001oogoo07Aoo`00<Goo00<007ooOol057oo00<007ooOol0eGoo000a
Ool00`00Oomoo`0BOol2001NOol00`00Oomoo`1gOol0035oo`03001oogoo015oo`03001oogoo05]o
o`8007]oo`00<Goo00<007ooOol047oo00<007ooOol0G7oo0P00Ngoo000aOol00`00Oomoo`0?Ool0
0`00Oomoo`1KOol5001jOol0035oo`8000ioo`8005eoo`8007ioo`00<Goo00<007ooOol037oo00<0
07ooOol0Fgoo00<007ooOol0Ogoo000aOol00`00Oomoo`0;Ool00`00Oomoo`1KOol00`00Oomoo`20
Ool0035oo`03001oogoo00Uoo`8005]oo`03001oogoo08=oo`007Woo0P0017oo0P0017oo0P001Goo
00<007ooOol027oo00<007ooOol0hGoo000MOol01000Oomoo`0027oo00@007ooOol000Aoo`03001o
ogoo00Moo`03001oogoo05Uoo`03001oogoo08Ioo`007Goo00@007ooOol000]oo`03001oogoo009o
o`<000Ioo`03001oogoo0>=oo`007Goo00@007ooOol000Uoo`8000Eoo`03001oogoo00Aoo`8005Yo
o`03001oogoo08Uoo`007Goo00@007ooOol000Uoo`03001oogoo00Aoo`03001oogoo00=oo`03001o
ogoo05Moo`03001oogoo08aoo`007Woo0P002Woo0`0017oo00<007ooOol00Woo00<007ooOol0igoo
000aOol01@00Oomoogoo0000F7oo00<007ooOol0Sgoo000aOol01000Ool00000jgoo000`Ool3001H
Ool00`00Oomoo`2BOol002moo`D00004Ool007ooOol2001<Ool3002GOol0031oo`8000Yoo`03001o
ogoo008004=oo`D009Moo`00<Goo00<007ooOol03goo00<007ooOol00P000Woo00<007ooOol00P00
<Woo00@007ooOomoo`@009Moo`00<Goo00<007ooOol05goo1@0000Eoo`00Oomoo`0002Eoo`03001o
ogoo00800:5oo`00<Goo00<007ooOol087oo00<007ooOol00P000Woo00<007ooOol06Goo00<007oo
Ool0YWoo000aOol00`00Oomoo`0ZOol20002Ool00`00Oomoo`04Ool30004Ool00`00Oomoo`02002[
Ool0035oo`80039oo`80009oo`800003Ool000000;9oo`00<Goo00<007ooOol0=7oo1@00/goo000a
Ool00`00Oomoo`0fOol00`00Oomoo`2cOol0035oo`03001oogoo0>aoo`00<Goo00<007ooOol0k7oo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol0031oo`<00>eoo`00<Goo00<007ooOol0k7oo000aOol00`00Oomo
o`3/Ool0035oo`03001oogoo0>aoo`00<Goo00<007ooOol0k7oo000`Ool3003]Ool00?moob5oo`00
ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.738309, 0.0629378, \
0.0349696, 0.00308789}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0147151 0.210128 [
[.02381 .00222 -3 -9 ]
[.02381 .00222 3 0 ]
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -3 -9 ]
[.7381 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6.28125 ]
[1.025 .01472 10 6.28125 ]
[.13036 .11978 -18 -4.5 ]
[.13036 .11978 0 4.5 ]
[.13036 .22484 -6 -4.5 ]
[.13036 .22484 0 4.5 ]
[.13036 .32991 -18 -4.5 ]
[.13036 .32991 0 4.5 ]
[.13036 .43497 -6 -4.5 ]
[.13036 .43497 0 4.5 ]
[.13036 .54004 -18 -4.5 ]
[.13036 .54004 0 4.5 ]
[.14286 .64303 -5 0 ]
[.14286 .64303 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(0)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(2)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(4)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(6)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(8)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.08333 .01472 m
.08333 .01847 L
s
.20238 .01472 m
.20238 .01847 L
s
.32143 .01472 m
.32143 .01847 L
s
.38095 .01472 m
.38095 .01847 L
s
.44048 .01472 m
.44048 .01847 L
s
.55952 .01472 m
.55952 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.67857 .01472 m
.67857 .01847 L
s
.79762 .01472 m
.79762 .01847 L
s
.85714 .01472 m
.85714 .01847 L
s
.91667 .01472 m
.91667 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.14286 .11978 m
.14911 .11978 L
s
[(0.5)] .13036 .11978 1 0 Mshowa
.14286 .22484 m
.14911 .22484 L
s
[(1)] .13036 .22484 1 0 Mshowa
.14286 .32991 m
.14911 .32991 L
s
[(1.5)] .13036 .32991 1 0 Mshowa
.14286 .43497 m
.14911 .43497 L
s
[(2)] .13036 .43497 1 0 Mshowa
.14286 .54004 m
.14911 .54004 L
s
[(2.5)] .13036 .54004 1 0 Mshowa
.125 Mabswid
.14286 .03573 m
.14661 .03573 L
s
.14286 .05674 m
.14661 .05674 L
s
.14286 .07775 m
.14661 .07775 L
s
.14286 .09877 m
.14661 .09877 L
s
.14286 .14079 m
.14661 .14079 L
s
.14286 .16181 m
.14661 .16181 L
s
.14286 .18282 m
.14661 .18282 L
s
.14286 .20383 m
.14661 .20383 L
s
.14286 .24586 m
.14661 .24586 L
s
.14286 .26687 m
.14661 .26687 L
s
.14286 .28788 m
.14661 .28788 L
s
.14286 .30889 m
.14661 .30889 L
s
.14286 .35092 m
.14661 .35092 L
s
.14286 .37193 m
.14661 .37193 L
s
.14286 .39295 m
.14661 .39295 L
s
.14286 .41396 m
.14661 .41396 L
s
.14286 .45598 m
.14661 .45598 L
s
.14286 .477 m
.14661 .477 L
s
.14286 .49801 m
.14661 .49801 L
s
.14286 .51902 m
.14661 .51902 L
s
.14286 .56105 m
.14661 .56105 L
s
.14286 .58206 m
.14661 .58206 L
s
.14286 .60307 m
.14661 .60307 L
s
.25 Mabswid
.14286 0 m
.14286 .61803 L
s
gsave
.14286 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.14286 .59931 m
.2619 .34449 L
.38095 .20047 L
.5 .13286 L
.61905 .09615 L
.7381 .07514 L
.85714 .06081 L
.97619 .0504 L
s
.0001 w
.14286 .59931 -1.875 0 Mabsadd m
.14286 .59931 0 2.5 Mabsadd L
.14286 .59931 1.875 0 Mabsadd L
.14286 .59931 0 -2.5 Mabsadd L
.14286 .59931 -1.875 0 Mabsadd L closepath F
.2619 .34449 -1.875 0 Mabsadd m
.2619 .34449 0 2.5 Mabsadd L
.2619 .34449 1.875 0 Mabsadd L
.2619 .34449 0 -2.5 Mabsadd L
.2619 .34449 -1.875 0 Mabsadd L closepath F
.38095 .20047 -1.875 0 Mabsadd m
.38095 .20047 0 2.5 Mabsadd L
.38095 .20047 1.875 0 Mabsadd L
.38095 .20047 0 -2.5 Mabsadd L
.38095 .20047 -1.875 0 Mabsadd L closepath F
.5 .13286 -1.875 0 Mabsadd m
.5 .13286 0 2.5 Mabsadd L
.5 .13286 1.875 0 Mabsadd L
.5 .13286 0 -2.5 Mabsadd L
.5 .13286 -1.875 0 Mabsadd L closepath F
.61905 .09615 -1.875 0 Mabsadd m
.61905 .09615 0 2.5 Mabsadd L
.61905 .09615 1.875 0 Mabsadd L
.61905 .09615 0 -2.5 Mabsadd L
.61905 .09615 -1.875 0 Mabsadd L closepath F
.7381 .07514 -1.875 0 Mabsadd m
.7381 .07514 0 2.5 Mabsadd L
.7381 .07514 1.875 0 Mabsadd L
.7381 .07514 0 -2.5 Mabsadd L
.7381 .07514 -1.875 0 Mabsadd L closepath F
.85714 .06081 -1.875 0 Mabsadd m
.85714 .06081 0 2.5 Mabsadd L
.85714 .06081 1.875 0 Mabsadd L
.85714 .06081 0 -2.5 Mabsadd L
.85714 .06081 -1.875 0 Mabsadd L closepath F
.97619 .0504 -1.875 0 Mabsadd m
.97619 .0504 0 2.5 Mabsadd L
.97619 .0504 1.875 0 Mabsadd L
.97619 .0504 0 -2.5 Mabsadd L
.97619 .0504 -1.875 0 Mabsadd L closepath F
.001 w
[ .5 3 ] 0 Mabsdash
.14286 .59931 m
.2619 .60332 L
.38095 .44952 L
.5 .29842 L
.61905 .20538 L
.7381 .14761 L
.85714 .11268 L
.97619 .09258 L
s
.0001 w
[ ] 0 setdash
.14286 .59931 0 2.5 Mabsadd m
.14286 .59931 -0.56518 .7779 Mabsadd L
.14286 .59931 -2.37764 .77254 Mabsadd L
.14286 .59931 -0.91448 -0.29713 Mabsadd L
.14286 .59931 -1.46946 -2.02254 Mabsadd L
.14286 .59931 0 -0.96154 Mabsadd L
.14286 .59931 1.46946 -2.02254 Mabsadd L
.14286 .59931 .91448 -0.29713 Mabsadd L
.14286 .59931 2.37764 .77254 Mabsadd L
.14286 .59931 .56518 .7779 Mabsadd L
.14286 .59931 0 2.5 Mabsadd L closepath F
.2619 .60332 0 2.5 Mabsadd m
.2619 .60332 -0.56518 .7779 Mabsadd L
.2619 .60332 -2.37764 .77254 Mabsadd L
.2619 .60332 -0.91448 -0.29713 Mabsadd L
.2619 .60332 -1.46946 -2.02254 Mabsadd L
.2619 .60332 0 -0.96154 Mabsadd L
.2619 .60332 1.46946 -2.02254 Mabsadd L
.2619 .60332 .91448 -0.29713 Mabsadd L
.2619 .60332 2.37764 .77254 Mabsadd L
.2619 .60332 .56518 .7779 Mabsadd L
.2619 .60332 0 2.5 Mabsadd L closepath F
.38095 .44952 0 2.5 Mabsadd m
.38095 .44952 -0.56518 .7779 Mabsadd L
.38095 .44952 -2.37764 .77254 Mabsadd L
.38095 .44952 -0.91448 -0.29713 Mabsadd L
.38095 .44952 -1.46946 -2.02254 Mabsadd L
.38095 .44952 0 -0.96154 Mabsadd L
.38095 .44952 1.46946 -2.02254 Mabsadd L
.38095 .44952 .91448 -0.29713 Mabsadd L
.38095 .44952 2.37764 .77254 Mabsadd L
.38095 .44952 .56518 .7779 Mabsadd L
.38095 .44952 0 2.5 Mabsadd L closepath F
.5 .29842 0 2.5 Mabsadd m
.5 .29842 -0.56518 .7779 Mabsadd L
.5 .29842 -2.37764 .77254 Mabsadd L
.5 .29842 -0.91448 -0.29713 Mabsadd L
.5 .29842 -1.46946 -2.02254 Mabsadd L
.5 .29842 0 -0.96154 Mabsadd L
.5 .29842 1.46946 -2.02254 Mabsadd L
.5 .29842 .91448 -0.29713 Mabsadd L
.5 .29842 2.37764 .77254 Mabsadd L
.5 .29842 .56518 .7779 Mabsadd L
.5 .29842 0 2.5 Mabsadd L closepath F
.61905 .20538 0 2.5 Mabsadd m
.61905 .20538 -0.56518 .7779 Mabsadd L
.61905 .20538 -2.37764 .77254 Mabsadd L
.61905 .20538 -0.91448 -0.29713 Mabsadd L
.61905 .20538 -1.46946 -2.02254 Mabsadd L
.61905 .20538 0 -0.96154 Mabsadd L
.61905 .20538 1.46946 -2.02254 Mabsadd L
.61905 .20538 .91448 -0.29713 Mabsadd L
.61905 .20538 2.37764 .77254 Mabsadd L
.61905 .20538 .56518 .7779 Mabsadd L
.61905 .20538 0 2.5 Mabsadd L closepath F
.7381 .14761 0 2.5 Mabsadd m
.7381 .14761 -0.56518 .7779 Mabsadd L
.7381 .14761 -2.37764 .77254 Mabsadd L
.7381 .14761 -0.91448 -0.29713 Mabsadd L
.7381 .14761 -1.46946 -2.02254 Mabsadd L
.7381 .14761 0 -0.96154 Mabsadd L
.7381 .14761 1.46946 -2.02254 Mabsadd L
.7381 .14761 .91448 -0.29713 Mabsadd L
.7381 .14761 2.37764 .77254 Mabsadd L
.7381 .14761 .56518 .7779 Mabsadd L
.7381 .14761 0 2.5 Mabsadd L closepath F
.85714 .11268 0 2.5 Mabsadd m
.85714 .11268 -0.56518 .7779 Mabsadd L
.85714 .11268 -2.37764 .77254 Mabsadd L
.85714 .11268 -0.91448 -0.29713 Mabsadd L
.85714 .11268 -1.46946 -2.02254 Mabsadd L
.85714 .11268 0 -0.96154 Mabsadd L
.85714 .11268 1.46946 -2.02254 Mabsadd L
.85714 .11268 .91448 -0.29713 Mabsadd L
.85714 .11268 2.37764 .77254 Mabsadd L
.85714 .11268 .56518 .7779 Mabsadd L
.85714 .11268 0 2.5 Mabsadd L closepath F
.97619 .09258 0 2.5 Mabsadd m
.97619 .09258 -0.56518 .7779 Mabsadd L
.97619 .09258 -2.37764 .77254 Mabsadd L
.97619 .09258 -0.91448 -0.29713 Mabsadd L
.97619 .09258 -1.46946 -2.02254 Mabsadd L
.97619 .09258 0 -0.96154 Mabsadd L
.97619 .09258 1.46946 -2.02254 Mabsadd L
.97619 .09258 .91448 -0.29713 Mabsadd L
.97619 .09258 2.37764 .77254 Mabsadd L
.97619 .09258 .56518 .7779 Mabsadd L
.97619 .09258 0 2.5 Mabsadd L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000COol2
000fOol4000hOol3000eOol3000gOol2000UOol0019oo`04001oogoo000eOol00`00Oomoo`0jOol0
0`00Oomoo`0dOol01000Oomoo`00=Goo00@007ooOol002Aoo`004Woo00@007ooOol003Ioo`03001o
ogoo03Ioo`D003Eoo`04001oogoo000eOol01000Oomoo`0097oo000BOol01000Oomoo`00=goo00<0
07ooOol0=Goo00@007ooOol003Ioo`<003Moo`8002Eoo`004Woo00@007ooOol003Eoo`04001oogoo
000gOol00`00Ool0000gOol00`00Oomoo`0eOol01000Oomoo`0097oo000COol2000gOol2000iOol2
000gOol3000fOol2000UOol00?moob5oo`00<7oo00<007ooOol0kGoo000`Ool00`00Oomoo`3]Ool0
031oo`03001oogoo0=Moo`8001Aoo`00<7oo00<007ooOol0eWoo00@007ooOol001=oo`003Wool`00
27oo00<007ooOol057oo000DOol00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00
Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00
Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00
Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool5000COol0031oo`03001o
ogoo0=Ioo`03001oogoo01Aoo`00<7oo00<007ooOol0kGoo000`Ool00`00Oomoo`3]Ool0031oo`80
0>ioo`00<7oo00<007ooOol0kGoo000`Ool00`00Oomoo`37Ool00`00Oomoo`0SOol0031oo`03001o
ogoo0<=oo`H002Aoo`00<7oo00<007ooOol0Zgoo00<007ooOol037oo2@0017oo0P0097oo000`Ool2
002[Ool20004Ool:000=Ool00`00Oomoo`0SOol0031oo`03001oogoo0:Moo`T003eoo`00<7oo00<0
07ooOol0WGoo2P000goo0P00@Goo000`Ool00`00Oomoo`2=Ool20004Ool:001@Ool0031oo`03001o
ogoo08aoo`L005Yoo`00<7oo0P00Qgoo1P0000Aoo`00000005eoo`00<7oo00<007ooOol0P7oo1P00
27oo00<007ooOol0G7oo000`Ool00`00Oomoo`1jOol60018Ool00`00Oomoo`0ROol0031oo`03001o
ogoo071oo`80009oo`H004eoo`03001oogoo02=oo`00<7oo00<007ooOol0Kgoo1@00CWoo00<007oo
Ool01@008goo000`Ool2001^Ool6001;Ool20007Ool00`00Oomoo`0SOol0031oo`03001oogoo06Uo
o`@000Aoo`03001oogoo04=oo`80009oo`03001oogoo02moo`00<7oo00<007ooOol0IWoo0`00@Goo
0P001Goo00@007ooOol003Qoo`007Goo0P0017oo0P0017oo0P001Goo00<007ooOol0Hgoo0`00A7oo
00<007ooOol00P00?Woo000LOol01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo061oo`<0
04Aoo`H0041oo`0077oo00@007ooOol000]oo`03001oogoo009oo`<005eoo`<004=oo`04001oogoo
0016Ool001aoo`04001oogoo0009Ool20005Ool00`00Oomoo`1IOol40013Ool01000Oomoo`00BGoo
000LOol01000Oomoo`002Goo00<007ooOol017oo00<007ooOol0Dgoo0P0000Aoo`00000004Aoo`04
001oogoo001<Ool001eoo`8000Yoo`<000Aoo`03001oogoo059oo`@004=oo`04001oogoo001@Ool0
031oo`03001oogoo059oo`@0041oo`04001oogoo001COol0031oo`80055oo`80009oo`03001oogoo
03aoo`04001oogoo001FOol0031oo`03001oogoo04moo`03001oogoo03]oo`<0009oo`03001oogoo
05Qoo`00<7oo00<007ooOol0CGoo0P00?Woo0`00GGoo000`Ool00`00Oomoo`1;Ool2000nOol5001M
Ool0031oo`03001oogoo04Uoo`8003eoo`8006=oo`00<7oo0P00BGoo00<007ooOol0XWoo000`Ool0
0`00Oomoo`16Ool2000mOol2001VOol0031oo`03001oogoo04Aoo`8003aoo`8006Uoo`00<7oo00<0
07ooOol0@goo00<007ooOol0Ygoo000`Ool00`00Oomoo`11Ool2000lOol00`00Oomoo`1[Ool0031o
o`80041oo`8003]oo`03001oogoo06ioo`00<7oo00<007ooOol0?Goo0P00?Goo00<007ooOol0KWoo
000`Ool00`00Oomoo`0lOol00`00Oomoo`0jOol00`00Oomoo`1aOol0031oo`03001oogoo03Moo`03
001oogoo008003Yoo`03001oogoo07Aoo`00<7oo00<007ooOol0=Woo1000?7oo00<007ooOol0M7oo
000`Ool2000fOol4000gOol4001iOol0031oo`03001oogoo03Ioo`8003Qoo`8007]oo`00<7oo00<0
07ooOol0=Goo00<007ooOol0=Woo1@00NWoo000`Ool00`00Oomoo`0eOol00`00Oomoo`2eOol002Qo
o`D000=oo`03001oogoo03Aoo`03001oogoo03Ioo`03001oogoo07eoo`00:Woo00<007ooOol00goo
00<007ooOol0<goo00<007ooOol0]goo000ZOol00`00Oomoo`03Ool3000bOol00`00Oomoo`0eOol0
0`00Oomoo`20Ool002Yoo`03001oogoo00=oo`03001oogoo035oo`03001oogoo0;Uoo`00:Woo00<0
07ooOol00goo00<007ooOol0<7oo00<007ooOol0=7oo0P00Q7oo000YOol20005Ool00`00Oomoo`0`
Ool00`00Oomoo`2jOol0031oo`03001oogoo02moo`03001oogoo03=oo`03001oogoo08Eoo`00<7oo
0P00;goo00<007ooOol0<goo00<007ooOol0QWoo000`Ool00`00Oomoo`0]Ool00`00Oomoo`0bOol0
0`00Oomoo`28Ool0031oo`03001oogoo02aoo`03001oogoo03=oo`03001oogoo08Qoo`00<7oo00<0
07ooOol0:goo00<007ooOol0_goo000`Ool00`00Oomoo`0[Ool00`00Oomoo`0aOol00`00Oomoo`2;
Ool0031oo`8002]oo`03001oogoo0<1oo`00<7oo00<007ooOol0:Goo00<007ooOol0<7oo0P00Sgoo
000`Ool00`00Oomoo`0XOol00`00Oomoo`32Ool0031oo`03001oogoo02Moo`03001oogoo02moo`80
099oo`00<7oo00<007ooOol09Woo00<007ooOol0a7oo000`Ool2000WOol00`00Oomoo`0^Ool00`00
Oomoo`2COol0031oo`03001oogoo02Eoo`03001oogoo02]oo`8009Qoo`00<7oo00<007ooOol097oo
00<007ooOol0;7oo0P00V7oo000`Ool00`00Oomoo`0SOol00`00Oomoo`0/Ool4002GOol0031oo`03
001oogoo029oo`03001oogoo02moo`03001oogoo09Ioo`00<7oo0P008Woo00<007ooOol0;Woo00<0
07ooOol0V7oo000`Ool00`00Oomoo`0QOol00`00Oomoo`39Ool0031oo`03001oogoo021oo`03001o
ogoo0<Yoo`0077oo1@000Woo0P0017oo0P001Goo00<007ooOol07goo00<007ooOol0;Woo00<007oo
Ool0VWoo000NOol00`00Oomoo`07Ool01000Oomoo`0017oo00<007ooOol07Woo00<007ooOol0c7oo
000NOol00`00Oomoo`0:Ool00`00Oomoo`02Ool3000MOol00`00Oomoo`0^Ool00`00Oomoo`2LOol0
01ioo`03001oogoo00Qoo`8000Eoo`03001oogoo01aoo`03001oogoo02ioo`03001oogoo09eoo`00
7Woo00<007ooOol027oo00<007ooOol017oo00<007ooOol06Woo00<007oo0000d7oo000MOol2000:
Ool30004Ool00`00Oomoo`0IOol3000`Ool00`00Oomoo`2NOol0031oo`03001oogoo01Qoo`@002mo
o`03001oogoo09moo`00<7oo0P006Woo0P00dWoo000`Ool00`00Oomoo`0IOol00`00Oomoo`0]Ool0
0`00Oomoo`2QOol0031oo`03001oogoo01Uoo`03001oogoo0=5oo`00<7oo00<007ooOol067oo00<0
07ooOol0dWoo000`Ool00`00Oomoo`0HOol00`00Oomoo`0/Ool00`00Oomoo`2SOol0031oo`8001Qo
o`03001oogoo0==oo`00<7oo00<007ooOol05goo00<007ooOol0:goo00<007ooOol0YGoo000`Ool0
0`00Oomoo`0FOol00`00Oomoo`0/Ool00`00Oomoo`2UOol0031oo`03001oogoo01Ioo`03001oogoo
0=Aoo`00<7oo00<007ooOol05Goo00<007ooOol0:goo00<007ooOol0Ygoo000`Ool2000FOol00`00
Oomoo`0[Ool00`00Oomoo`2WOol0031oo`03001oogoo01Aoo`03001oogoo0=Ioo`00<7oo00<007oo
Ool057oo00<007ooOol0:Goo0P00Zgoo000`Ool00`00Oomoo`0COol00`00Oomoo`3GOol0031oo`03
001oogoo01=oo`03001oogoo0=Moo`00<7oo0P004goo00<007ooOol0:Goo0P00[Goo000`Ool00`00
Oomoo`0BOol00`00Oomoo`3HOol0031oo`03001oogoo015oo`03001oogoo02Qoo`03001oogoo0:io
o`00:7oo100017oo00<007ooOol04Goo00<007ooOol0:7oo00<007ooOol0[Woo000XOol00`00Oomo
o`05Ool00`00Oomoo`0@Ool00`00Oomoo`3JOol002Uoo`03001oogoo00Aoo`<0011oo`03001oogoo
02Moo`03001oogoo0;1oo`00:Woo00<007ooOol00goo00<007ooOol047oo00<007ooOol0fWoo000X
Ool01000Oomoo`0017oo00<007ooOol03goo00<007ooOol0fgoo000YOol20005Ool00`00Oomoo`0?
Ool00`00Oomoo`0TOol3002dOol0031oo`03001oogoo00ioo`03001oogoo02Eoo`800;Eoo`00<7oo
00<007ooOol03Woo00<007ooOol097oo1000]7oo000`Ool2000>Ool00`00Oomoo`0VOol2002eOol0
031oo`03001oogoo00eoo`03001oogoo0=eoo`00<7oo00<007ooOol037oo00<007ooOol09Goo00<0
07ooOol0]Woo000`Ool00`00Oomoo`0<Ool00`00Oomoo`0TOol00`00Oomoo`2gOol0031oo`03001o
ogoo00]oo`03001oogoo0=moo`00<7oo0P0037oo00<007ooOol097oo00<007ooOol0^7oo000`Ool0
0`00Oomoo`0:Ool00`00Oomoo`0TOol00`00Oomoo`2iOol0031oo`03001oogoo00Yoo`03001oogoo
0>1oo`00<7oo00<007ooOol02Goo00<007ooOol08goo00<007ooOol0^goo000`Ool00`00Oomoo`09
Ool00`00Oomoo`3QOol0031oo`8000Uoo`03001oogoo0>9oo`00<7oo00<007ooOol027oo00<007oo
Ool08Woo00<007ooOol0_Goo000`Ool00`00Oomoo`07Ool00`00Oomoo`3SOol0031oo`03001oogoo
00Moo`03001oogoo025oo`03001oogoo0;moo`00<7oo00<007ooOol01goo00<007ooOol08Goo00<0
07ooOol0_goo000`Ool20007Ool00`00Oomoo`3TOol0031oo`03001oogoo00Ioo`03001oogoo021o
o`03001oogoo0<5oo`00<7oo00<007ooOol01Goo00<007ooOol08Goo00<007ooOol0`Goo000LOol4
0003Ool20004Ool20005Ool00`00Oomoo`05Ool00`00Oomoo`3UOol001aoo`03001oogoo00Uoo`04
001oogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`0POol00`00Oomoo`33Ool001eoo`03001oogoo
00]oo`03001oogoo009oo`<000Aoo`03001oogoo0>Ioo`007Woo00<007ooOol027oo0P001Goo00<0
07ooOol00goo00<007ooOol0igoo000LOol01000Oomoo`002Goo00<007ooOol017oo00<007ooOol0
0goo00<007ooOol07Woo0P00agoo000MOol2000:Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`3X
Ool0031oo`03001oogoo009oo`03001oogoo0>Qoo`00<7oo0P000Woo00<007ooOol07Woo0P00bGoo
000`Ool01@00Oomoogoo0000jgoo000`Ool01000Oomoo`007goo00<007ooOol0bWoo000`Ool01000
Oomoo`007goo00<007ooOol0bWoo000`Ool00`00Ool0003]Ool0031oo`<001ioo`03001oogoo0<ao
o`00<7oo0P00kWoo000`Ool2003^Ool002moo`<001eoo`03001oogoo0<ioo`00;goo0`000Woo00<0
07ooOol05Goo0`00dGoo000^Ool5000017oo001oogoo0P000Woo00<007ooOol00P000Woo00<007oo
Ool00P000Woo00<007ooOol00P00dWoo000`Ool00`00Oomoo`0HOol5003@Ool0031oo`03001oogoo
01Yoo`03001oogoo0=1oo`00<7oo00<007ooOol0kGoo000`Ool00`00Oomoo`3]Ool00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00;Goo1000kgoo000^Ool01000Oomoo`00kWoo000^Ool01000Oomoo`00kWoo000^
Ool01000Oomoo`00kWoo000^Ool01000Oomoo`00kWoo000]Ool4003_Ool00?moob5oo`00ogoo8Goo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.693233, -0.236128, \
0.0346442, 0.0196277}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\(plo5 = 
      MultipleListPlot[{plou[2, 1], plou[4, 1]}, AxesLabel \[Rule] {t, g}, 
        AxesOrigin \[Rule] {1, 0.005}, 
        PlotLegend \[Rule] {"\<\[Kappa]=1-\[Tau]\>", "\<\[Kappa]=0.1\>"}, 
        LegendOrientation \[Rule] Vertical]\)\(\[IndentingNewLine]\)
    \)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42623 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.352217 0.328407 0.213115 0.328407 [
[ 0 0 0 0 ]
[ 1 .42623 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0101483 0.680624 0.416082 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 -0.171424 32.4615 [
[.02381 -0.02162 -3 -9 ]
[.02381 -0.02162 3 0 ]
[.2619 -0.02162 -3 -9 ]
[.2619 -0.02162 3 0 ]
[.5 -0.02162 -3 -9 ]
[.5 -0.02162 3 0 ]
[.7381 -0.02162 -3 -9 ]
[.7381 -0.02162 3 0 ]
[.97619 -0.02162 -3 -9 ]
[.97619 -0.02162 3 0 ]
[1.025 -0.00912 0 -6.28125 ]
[1.025 -0.00912 10 6.28125 ]
[.13036 .07204 -36 -4.5 ]
[.13036 .07204 0 4.5 ]
[.13036 .15319 -24 -4.5 ]
[.13036 .15319 0 4.5 ]
[.13036 .23435 -36 -4.5 ]
[.13036 .23435 0 4.5 ]
[.13036 .3155 -30 -4.5 ]
[.13036 .3155 0 4.5 ]
[.13036 .39665 -36 -4.5 ]
[.13036 .39665 0 4.5 ]
[.13036 .47781 -24 -4.5 ]
[.13036 .47781 0 4.5 ]
[.13036 .55896 -36 -4.5 ]
[.13036 .55896 0 4.5 ]
[.14286 .64303 -5 0 ]
[.14286 .64303 5 12.5625 ]
[ 0 -0.00912 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 -0.00912 m
.02381 -0.00287 L
s
[(0)] .02381 -0.02162 0 1 Mshowa
.2619 -0.00912 m
.2619 -0.00287 L
s
[(2)] .2619 -0.02162 0 1 Mshowa
.5 -0.00912 m
.5 -0.00287 L
s
[(4)] .5 -0.02162 0 1 Mshowa
.7381 -0.00912 m
.7381 -0.00287 L
s
[(6)] .7381 -0.02162 0 1 Mshowa
.97619 -0.00912 m
.97619 -0.00287 L
s
[(8)] .97619 -0.02162 0 1 Mshowa
.125 Mabswid
.08333 -0.00912 m
.08333 -0.00537 L
s
.20238 -0.00912 m
.20238 -0.00537 L
s
.32143 -0.00912 m
.32143 -0.00537 L
s
.38095 -0.00912 m
.38095 -0.00537 L
s
.44048 -0.00912 m
.44048 -0.00537 L
s
.55952 -0.00912 m
.55952 -0.00537 L
s
.61905 -0.00912 m
.61905 -0.00537 L
s
.67857 -0.00912 m
.67857 -0.00537 L
s
.79762 -0.00912 m
.79762 -0.00537 L
s
.85714 -0.00912 m
.85714 -0.00537 L
s
.91667 -0.00912 m
.91667 -0.00537 L
s
.25 Mabswid
0 -0.00912 m
1 -0.00912 L
s
gsave
1.025 -0.00912 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.14286 .07204 m
.14911 .07204 L
s
[(0.0075)] .13036 .07204 1 0 Mshowa
.14286 .15319 m
.14911 .15319 L
s
[(0.01)] .13036 .15319 1 0 Mshowa
.14286 .23435 m
.14911 .23435 L
s
[(0.0125)] .13036 .23435 1 0 Mshowa
.14286 .3155 m
.14911 .3155 L
s
[(0.015)] .13036 .3155 1 0 Mshowa
.14286 .39665 m
.14911 .39665 L
s
[(0.0175)] .13036 .39665 1 0 Mshowa
.14286 .47781 m
.14911 .47781 L
s
[(0.02)] .13036 .47781 1 0 Mshowa
.14286 .55896 m
.14911 .55896 L
s
[(0.0225)] .13036 .55896 1 0 Mshowa
.125 Mabswid
.14286 .08827 m
.14661 .08827 L
s
.14286 .1045 m
.14661 .1045 L
s
.14286 .12073 m
.14661 .12073 L
s
.14286 .13696 m
.14661 .13696 L
s
.14286 .16942 m
.14661 .16942 L
s
.14286 .18565 m
.14661 .18565 L
s
.14286 .20188 m
.14661 .20188 L
s
.14286 .21811 m
.14661 .21811 L
s
.14286 .25058 m
.14661 .25058 L
s
.14286 .26681 m
.14661 .26681 L
s
.14286 .28304 m
.14661 .28304 L
s
.14286 .29927 m
.14661 .29927 L
s
.14286 .33173 m
.14661 .33173 L
s
.14286 .34796 m
.14661 .34796 L
s
.14286 .36419 m
.14661 .36419 L
s
.14286 .38042 m
.14661 .38042 L
s
.14286 .41288 m
.14661 .41288 L
s
.14286 .42911 m
.14661 .42911 L
s
.14286 .44535 m
.14661 .44535 L
s
.14286 .46158 m
.14661 .46158 L
s
.14286 .49404 m
.14661 .49404 L
s
.14286 .51027 m
.14661 .51027 L
s
.14286 .5265 m
.14661 .5265 L
s
.14286 .54273 m
.14661 .54273 L
s
.14286 .05581 m
.14661 .05581 L
s
.14286 .03958 m
.14661 .03958 L
s
.14286 .02335 m
.14661 .02335 L
s
.14286 .00711 m
.14661 .00711 L
s
.14286 .57519 m
.14661 .57519 L
s
.14286 .59142 m
.14661 .59142 L
s
.14286 .60765 m
.14661 .60765 L
s
.25 Mabswid
.14286 0 m
.14286 .61803 L
s
gsave
.14286 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(g) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.14286 .08753 m
.2619 .01472 L
.38095 .01708 L
.5 .10482 L
.61905 .20744 L
.7381 .2899 L
.85714 .34364 L
.97619 .38372 L
s
.0001 w
.14286 .08753 -1.875 0 Mabsadd m
.14286 .08753 0 2.5 Mabsadd L
.14286 .08753 1.875 0 Mabsadd L
.14286 .08753 0 -2.5 Mabsadd L
.14286 .08753 -1.875 0 Mabsadd L closepath F
.2619 .01472 -1.875 0 Mabsadd m
.2619 .01472 0 2.5 Mabsadd L
.2619 .01472 1.875 0 Mabsadd L
.2619 .01472 0 -2.5 Mabsadd L
.2619 .01472 -1.875 0 Mabsadd L closepath F
.38095 .01708 -1.875 0 Mabsadd m
.38095 .01708 0 2.5 Mabsadd L
.38095 .01708 1.875 0 Mabsadd L
.38095 .01708 0 -2.5 Mabsadd L
.38095 .01708 -1.875 0 Mabsadd L closepath F
.5 .10482 -1.875 0 Mabsadd m
.5 .10482 0 2.5 Mabsadd L
.5 .10482 1.875 0 Mabsadd L
.5 .10482 0 -2.5 Mabsadd L
.5 .10482 -1.875 0 Mabsadd L closepath F
.61905 .20744 -1.875 0 Mabsadd m
.61905 .20744 0 2.5 Mabsadd L
.61905 .20744 1.875 0 Mabsadd L
.61905 .20744 0 -2.5 Mabsadd L
.61905 .20744 -1.875 0 Mabsadd L closepath F
.7381 .2899 -1.875 0 Mabsadd m
.7381 .2899 0 2.5 Mabsadd L
.7381 .2899 1.875 0 Mabsadd L
.7381 .2899 0 -2.5 Mabsadd L
.7381 .2899 -1.875 0 Mabsadd L closepath F
.85714 .34364 -1.875 0 Mabsadd m
.85714 .34364 0 2.5 Mabsadd L
.85714 .34364 1.875 0 Mabsadd L
.85714 .34364 0 -2.5 Mabsadd L
.85714 .34364 -1.875 0 Mabsadd L closepath F
.97619 .38372 -1.875 0 Mabsadd m
.97619 .38372 0 2.5 Mabsadd L
.97619 .38372 1.875 0 Mabsadd L
.97619 .38372 0 -2.5 Mabsadd L
.97619 .38372 -1.875 0 Mabsadd L closepath F
.001 w
[ .5 3 ] 0 Mabsdash
.14286 .08753 m
.2619 .27519 L
.38095 .44256 L
.5 .56906 L
.61905 .60332 L
.7381 .59437 L
.85714 .56502 L
.97619 .54156 L
s
.0001 w
[ ] 0 setdash
.14286 .08753 0 2.5 Mabsadd m
.14286 .08753 -0.56518 .7779 Mabsadd L
.14286 .08753 -2.37764 .77254 Mabsadd L
.14286 .08753 -0.91448 -0.29713 Mabsadd L
.14286 .08753 -1.46946 -2.02254 Mabsadd L
.14286 .08753 0 -0.96154 Mabsadd L
.14286 .08753 1.46946 -2.02254 Mabsadd L
.14286 .08753 .91448 -0.29713 Mabsadd L
.14286 .08753 2.37764 .77254 Mabsadd L
.14286 .08753 .56518 .7779 Mabsadd L
.14286 .08753 0 2.5 Mabsadd L closepath F
.2619 .27519 0 2.5 Mabsadd m
.2619 .27519 -0.56518 .7779 Mabsadd L
.2619 .27519 -2.37764 .77254 Mabsadd L
.2619 .27519 -0.91448 -0.29713 Mabsadd L
.2619 .27519 -1.46946 -2.02254 Mabsadd L
.2619 .27519 0 -0.96154 Mabsadd L
.2619 .27519 1.46946 -2.02254 Mabsadd L
.2619 .27519 .91448 -0.29713 Mabsadd L
.2619 .27519 2.37764 .77254 Mabsadd L
.2619 .27519 .56518 .7779 Mabsadd L
.2619 .27519 0 2.5 Mabsadd L closepath F
.38095 .44256 0 2.5 Mabsadd m
.38095 .44256 -0.56518 .7779 Mabsadd L
.38095 .44256 -2.37764 .77254 Mabsadd L
.38095 .44256 -0.91448 -0.29713 Mabsadd L
.38095 .44256 -1.46946 -2.02254 Mabsadd L
.38095 .44256 0 -0.96154 Mabsadd L
.38095 .44256 1.46946 -2.02254 Mabsadd L
.38095 .44256 .91448 -0.29713 Mabsadd L
.38095 .44256 2.37764 .77254 Mabsadd L
.38095 .44256 .56518 .7779 Mabsadd L
.38095 .44256 0 2.5 Mabsadd L closepath F
.5 .56906 0 2.5 Mabsadd m
.5 .56906 -0.56518 .7779 Mabsadd L
.5 .56906 -2.37764 .77254 Mabsadd L
.5 .56906 -0.91448 -0.29713 Mabsadd L
.5 .56906 -1.46946 -2.02254 Mabsadd L
.5 .56906 0 -0.96154 Mabsadd L
.5 .56906 1.46946 -2.02254 Mabsadd L
.5 .56906 .91448 -0.29713 Mabsadd L
.5 .56906 2.37764 .77254 Mabsadd L
.5 .56906 .56518 .7779 Mabsadd L
.5 .56906 0 2.5 Mabsadd L closepath F
.61905 .60332 0 2.5 Mabsadd m
.61905 .60332 -0.56518 .7779 Mabsadd L
.61905 .60332 -2.37764 .77254 Mabsadd L
.61905 .60332 -0.91448 -0.29713 Mabsadd L
.61905 .60332 -1.46946 -2.02254 Mabsadd L
.61905 .60332 0 -0.96154 Mabsadd L
.61905 .60332 1.46946 -2.02254 Mabsadd L
.61905 .60332 .91448 -0.29713 Mabsadd L
.61905 .60332 2.37764 .77254 Mabsadd L
.61905 .60332 .56518 .7779 Mabsadd L
.61905 .60332 0 2.5 Mabsadd L closepath F
.7381 .59437 0 2.5 Mabsadd m
.7381 .59437 -0.56518 .7779 Mabsadd L
.7381 .59437 -2.37764 .77254 Mabsadd L
.7381 .59437 -0.91448 -0.29713 Mabsadd L
.7381 .59437 -1.46946 -2.02254 Mabsadd L
.7381 .59437 0 -0.96154 Mabsadd L
.7381 .59437 1.46946 -2.02254 Mabsadd L
.7381 .59437 .91448 -0.29713 Mabsadd L
.7381 .59437 2.37764 .77254 Mabsadd L
.7381 .59437 .56518 .7779 Mabsadd L
.7381 .59437 0 2.5 Mabsadd L closepath F
.85714 .56502 0 2.5 Mabsadd m
.85714 .56502 -0.56518 .7779 Mabsadd L
.85714 .56502 -2.37764 .77254 Mabsadd L
.85714 .56502 -0.91448 -0.29713 Mabsadd L
.85714 .56502 -1.46946 -2.02254 Mabsadd L
.85714 .56502 0 -0.96154 Mabsadd L
.85714 .56502 1.46946 -2.02254 Mabsadd L
.85714 .56502 .91448 -0.29713 Mabsadd L
.85714 .56502 2.37764 .77254 Mabsadd L
.85714 .56502 .56518 .7779 Mabsadd L
.85714 .56502 0 2.5 Mabsadd L closepath F
.97619 .54156 0 2.5 Mabsadd m
.97619 .54156 -0.56518 .7779 Mabsadd L
.97619 .54156 -2.37764 .77254 Mabsadd L
.97619 .54156 -0.91448 -0.29713 Mabsadd L
.97619 .54156 -1.46946 -2.02254 Mabsadd L
.97619 .54156 0 -0.96154 Mabsadd L
.97619 .54156 1.46946 -2.02254 Mabsadd L
.97619 .54156 .91448 -0.29713 Mabsadd L
.97619 .54156 2.37764 .77254 Mabsadd L
.97619 .54156 .56518 .7779 Mabsadd L
.97619 .54156 0 2.5 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
.71346 .08175 m
.71346 .2788 L
.97619 .2788 L
.97619 .08175 L
F
1 g
.71346 .08175 m
.71346 .2788 L
.97619 .2788 L
.97619 .08175 L
F
0 g
.001 w
[ ] 0 setdash
.71346 .08175 m
.97619 .08175 L
.97619 .2788 L
.71346 .2788 L
.71346 .08175 L
s
% Start of sub-graphic
p
0.713465 0.0817523 0.97619 0.278797 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0297619 0.297619 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0535714 0.35119 0.35119 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.00468 w
[ .5 3 ] 0 Mabsdash
0 .5 m
1 .5 L
s
.00047 w
[ ] 0 setdash
.5 .5 0 2.5 Mabsadd m
.5 .5 -0.56518 .7779 Mabsadd L
.5 .5 -2.37764 .77254 Mabsadd L
.5 .5 -0.91448 -0.29713 Mabsadd L
.5 .5 -1.46946 -2.02254 Mabsadd L
.5 .5 0 -0.96154 Mabsadd L
.5 .5 1.46946 -2.02254 Mabsadd L
.5 .5 .91448 -0.29713 Mabsadd L
.5 .5 2.37764 .77254 Mabsadd L
.5 .5 .56518 .7779 Mabsadd L
.5 .5 0 2.5 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .20238 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
93.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.39881 0.35119 0.696429 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.00468 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
.00047 w
.5 .5 -1.875 0 Mabsadd m
.5 .5 0 2.5 Mabsadd L
.5 .5 1.875 0 Mabsadd L
.5 .5 0 -2.5 Mabsadd L
.5 .5 -1.875 0 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .54762 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
81.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
87.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
93.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .42623 L
0 .42623 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{415, 176.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006O0000/1000`40O003h00OogooX7oo003oOonP
Ool00?mooj1oo`00ogooX7oo003oOonPOol002Aoo`80035oo`@0039oo`<0031oo`<0039oo`800:Qo
o`008goo00@007ooOol0031oo`03001oogoo03Aoo`03001oogoo02moo`04001oogoo000`Ool01000
Oomoo`00Ygoo000SOol01000Oomoo`00<Goo00<007ooOol0<7oo1@00<7oo00@007ooOol0031oo`04
001oogoo002WOol002=oo`04001oogoo000bOol00`00Oomoo`0_Ool01000Oomoo`00<Goo0`00<Woo
0P00Z7oo000SOol01000Oomoo`00<7oo00@007ooOol0035oo`03001oo`00039oo`03001oogoo031o
o`04001oogoo002WOol002Aoo`80039oo`8003=oo`80039oo`<0035oo`800:Qoo`00ogooX7oo003o
OonPOol00?mooj1oo`00ogoo1Woo0P00V7oo003oOol5Ool01000Oomoo`00Ugoo000POooL0008Ool0
0`00Oomoo`2HOol002Eoo`03001oogoo035oo`03001oogoo035oo`03001oogoo039oo`03001oogoo
035oo`03001oogoo00Yoo`D009Moo`00?goo00<007ooOol0`Woo00<007ooOol0V7oo000oOol2000H
Ool00`00Oomoo`3oOom4Ool003moo`03001oogoo01Ioo`<001Moo`800?moobaoo`00?goo00<007oo
Ool05Goo7P00ogoo:goo000oOol00`00Oomoo`0EOol3000HOol3003oOol[Ool003moo`8001Aoo`80
01aoo`04001oo`00003oOolYOol003moo`03001oogoo019oo`03001oogoo021oo`03001oogoo0?mo
obIoo`00?goo00<007ooOol047oo0P0097oo00<007ooOol0ogoo9Goo000oOol2000@Ool00`00Oomo
o`0UOol2003oOolUOol003moo`03001oogoo00eoo`8002Yoo`03001oogoo0?moob9oo`00?goo00<0
07ooOol02goo0P00;Goo00<007ooOol0ogoo8Goo000oOol00`00Oomoo`0:Ool00`00Oomoo`0^Ool2
003oOolQOol003moo`8000Uoo`8003=oo`03001oogoo0?mooaioo`006Woo0P0017oo0P0017oo0P00
17oo0P001Goo00<007ooOol00Woo0P001Goo00<007ooOol01Woo0P00=Woo00<007ooOol0ogoo7Goo
000IOol01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0004Ool01@00Oomoogoo00000Woo
00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0=goo00<007ooOol0ogoo77oo000IOol01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`02Ool2
0004Ool2000kOol2002SOom]000;Ool001Uoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool000Eoo`04001oogooOol20005Ool00`00Oomoo`02Ool00`00Oomoo`0mOol00`00Oomoo`2POol0
0`00Oomoo`1YOol00`00Oomoo`09Ool001Uoo`04001oogoo0008Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`020011Ool00`00Oomoo`2OOol0
0`00Oomoo`1YOol00`00Oomoo`09Ool001Yoo`8000Yoo`8000Aoo`8000=oo`@000=oo`<000=oo`@0
04Aoo`8009moo`03001oogoo06Uoo`03001oogoo00Uoo`00?Goo1000Agoo00<007ooOol0W7oo00<0
07ooOol0JGoo00<007ooOol02Goo000mOol40018Ool00`00Oomoo`2KOol00`00Oomoo`1YOol00`00
Oomoo`09Ool003moo`03001oogoo04Qoo`800003Ool007oo09Qoo`03001oogoo06Uoo`03001oogoo
00Uoo`00?goo00<007oo0000BWoo0`00V7oo00<007ooOol0JGoo00<007ooOol02Goo000oOol2001;
Ool3002HOol00`00Oomoo`1YOol00`00Oomoo`09Ool003moo`03001oogoo04]oo`8009Qoo`03001o
ogoo06Uoo`03001oogoo00Uoo`00?goo00D007ooOomoo`0004]oo`8009Ioo`03001oogoo06Uoo`03
001oogoo00Uoo`00?goo0P00D7oo00<007ooOol0Tgoo00<007ooOol0JGoo00<007ooOol02Goo000o
Ool00`00Oomoo`1@Ool00`00Oomoo`2BOol00`00Oomoo`1YOol00`00Oomoo`09Ool003moo`03001o
ogoo00=oo`03001oogoo04]oo`03001oogoo095oo`03001oogoo06Uoo`03001oogoo00Uoo`00?goo
00<007ooOol0DWoo00<007ooOol0T7oo00<007ooOol0JGoo00<007ooOol02Goo000oOol2001DOol2
002@Ool00`00Oomoo`1YOol00`00Oomoo`09Ool002Ioo`8000Aoo`8000Aoo`8000=oo`D000=oo`03
001oogoo00Eoo`03001oogoo04eoo`03001oogoo08eoo`03001oogoo06Uoo`03001oogoo00Uoo`00
9Goo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`1FOol00`00Oomo
o`2<Ool00`00Oomoo`1YOol00`00Oomoo`09Ool002Eoo`04001oogoo0008Ool01000Oomoo`0017oo
00<007ooOol00goo0P00F7oo00<007ooOol0Rgoo00<007ooOol0JGoo00<007ooOol02Goo000UOol0
1000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00Ioo`80051oo`8008]o
o`03001oogoo06Uoo`03001oogoo00Uoo`009Goo00@007ooOol000Qoo`04001oogoo0004Ool00`00
Oomoo`03Ool00`00Oomoo`1JOol00`00Oomoo`28Ool00`00Oomoo`1YOol00`00Oomoo`09Ool002Io
o`8000Yoo`8000Aoo`8000Eoo`03001oogoo05]oo`03001oogoo08Moo`03001oogoo019oo`8001Eo
o`8000=oo`03001oogoo00Ioo`8000Aoo`8000=oo`D0029oo`03001oogoo00Uoo`00?goo0P002Goo
0P00DWoo00<007ooOol0QWoo00<007ooOol00Woo0P000Woo00<007ooOol00P000Woo00<007ooOol0
0`0000Aoo`00Oomoo`80009oo`03001oogoo0080009oo`03001oogoo00Eoo`04001oogoo0002Ool4
0002Ool01000Oomoo`002Woo00<007ooOol08Woo00<007ooOol02Goo000oOol00`00Oomoo`1MOol2
0026Ool00`00Oomoo`0@Ool5000EOol30009Ool01000Oomoo`002Woo00<007ooOol08Woo00<007oo
Ool02Goo000oOol00`00Oomoo`0:Ool00`00Oomoo`1BOol00`00Oomoo`23Ool00`00Oomoo`0BOol0
0`00Oomoo`0FOol20003Ool40002Ool01000Oomoo`002Woo00<007ooOol08Woo00<007ooOol02Goo
000oOol2000;Ool00`00Oomoo`1COol00`00Oomoo`22Ool00`00Oomoo`0ZOol200000goo00000007
Ool01000Oomoo`002Woo00<007ooOol08Woo00<007ooOol02Goo000oOol00`00Oomoo`1QOol00`00
Oomoo`21Ool00`00Oomoo`0gOol2000:Ool2000TOol00`00Oomoo`09Ool003moo`03001oogoo00ao
o`03001oogoo05=oo`03001oogoo081oo`03001oogoo06Uoo`03001oogoo00Uoo`00?goo00<007oo
Ool037oo00<007ooOol0E7oo0P00P7oo00<007ooOol0JGoo00<007ooOol02Goo000oOol2001VOol2
001nOol00`00Oomoo`1YOol00`00Oomoo`09Ool003moo`03001oogoo00ioo`03001oogoo05=oo`<0
07ioo`03001oogoo06Uoo`03001oogoo00Uoo`00?goo00<007ooOol03Woo00<007ooOol0E7oo1000
O7oo00<007ooOol0JGoo00<007ooOol02Goo000oOol2001WOol01000Oomoo`00Ngoo00<007ooOol0
JGoo00<007ooOol02Goo000oOol00`00Oomoo`0@Ool00`00Oomoo`1GOol2001iOol00`00Oomoo`1Y
Ool00`00Oomoo`09Ool001Yoo`8000Aoo`8000Aoo`8000=oo`D00003Ool00000008000=oo`8000Eo
o`03001oogoo011oo`03001oogoo05Uoo`03001oogoo07Ioo`03001oogoo06Uoo`03001oogoo00Uo
o`006Goo00@007ooOol000Qoo`04001oogoo0004Ool01@00Oomoogoo00001Goo00@007ooOol000Ao
o`03001oogoo06eoo`03001oogoo07Eoo`03001oogoo06Uoo`03001oogoo00Uoo`006Goo00@007oo
Ool000Qoo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool2000C
Ool00`00Oomoo`1IOol2001eOol00`00Oomoo`1YOol00`00Oomoo`09Ool001Uoo`04001oogoo0008
Ool01000Oomoo`0017oo00<007ooOol00goo00<007ooOol00Woo0P001Goo00<007ooOol04Woo00<0
07ooOol0Fgoo00<007ooOol0LWoo00<007ooOol0JGoo00<007ooOol02Goo000IOol01000Oomoo`00
27oo00@007ooOol000Aoo`05001oogooOol00002Ool01@00Oomoogoo00001Woo00<007ooOol0LGoo
0P00LWoo00<007ooOol0JGoo00<007ooOol02Goo000JOol2000:Ool20004Ool20004Ool20004Ool3
0004Ool00`00Oomoo`0COol00`00Oomoo`1MOol00`00Oomoo`1_Ool00`00Oomoo`1YOol00`00Oomo
o`09Ool003moo`8001Eoo`03001oogoo05eoo`8006moo`03001oogoo06Uoo`03001oogoo00Uoo`00
?goo00<007ooOol0MWoo00<007ooOol0K7oo00<007ooOol0JGoo00<007ooOol02Goo000oOol00`00
Oomoo`0EOol00`00Oomoo`1OOol2001/Ool00`00Oomoo`1YOol00`00Oomoo`09Ool003moo`8001Mo
o`03001oogoo061oo`03001oogoo06Uoo`03001oogoo06Uoo`03001oogoo00Uoo`00?goo00<007oo
Ool05Woo0`00HGoo00<007ooOol0J7oo00<007ooOol0JGoo00<007ooOol02Goo000oOol00`00Oomo
o`0FOol2001SOol2001XOol00`00Oomoo`1YOol00`00Oomoo`09Ool003moo`03001oogoo01Eoo`D0
06=oo`03001oogoo06Eoo`03001oogoo06Uoo`03001oogoo00Uoo`00?goo0P00Ogoo0`00I7oo00<0
07ooOol0JGoo00<007ooOol02Goo000oOol00`00Oomoo`0IOol2001SOol4001SOol00`00Oomoo`1Y
Ool00`00Oomoo`09Ool003moo`03001oogoo07moo`D0065oo`03001oogoo06Uoo`03001oogoo00Uo
o`00?goo0P00PGoo00@007ooOomoo`8005moo`03001oogoo06Uoo`03001oogoo00Uoo`00?goo00<0
07ooOol06goo0P00JGoo0P00GGoo00<007ooOol0JGoo00<007ooOol02Goo000POol20004Ool20004
Ool20003Ool50002Ool20005Ool00`00Oomoo`28Ool2001KOol00`00Oomoo`1YOol00`00Oomoo`09
Ool001moo`04001oogoo0008Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`03001oogoo009o
o`03001oogoo08Yoo`8005Uoo`03001oogoo06Uoo`03001oogoo00Uoo`007goo00@007ooOol000Qo
o`04001oogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`02Ool2000NOol2001]Ool3001FOol00`00
Oomoo`1YOol00`00Oomoo`09Ool001moo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol0
0Woo0P001Goo00<007ooOol0Sgoo0P00E7oo00<007ooOol0JGoo00<007ooOol02Goo000OOol01000
Oomoo`0027oo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo095oo`80
059oo`03001oogoo06Uoo`03001oogoo00Uoo`0087oo0P002Woo0P0017oo0P0017oo0`0017oo0P00
87oo0P00LWoo0P00D7oo00<007ooOol0JGoo00<007ooOol02Goo000oOol00`00Oomoo`2EOol2001>
Ool00`00Oomoo`0BOol00`00Oomoo`0DOol20003Ool00`00Oomoo`05Ool50008Ool3000SOol00`00
Oomoo`09Ool003moo`03001oogoo025oo`03001oogoo07=oo`@004Yoo`03001oogoo019oo`8001Io
o`04001oogoo0002Ool40004Ool00`00Oomoo`08Ool00`00Oomoo`0SOol00`00Oomoo`09Ool003mo
o`03001oogoo029oo`03001oogoo07=oo`@004Uoo`03001oogoo009oob8000Ioo`<000]oo`04001o
ogooOol40003Ool00`00Oomoo`0SOol00`00Oomoo`09Ool003moo`8009Yoo`H004Ioo`03001oogoo
019oo`03001oogoo01Ioo`8000=oo`@000Aoo`03001oogoo00Uoo`03001oogoo029oo`03001oogoo
00Uoo`00?goo00<007ooOol08goo00<007ooOol0M7oo00<007ooOol00Woo0`00@goo00<007ooOol0
:Woo0P0000=oo`0000002Goo00<007ooOol01goo10008goo00<007ooOol02Goo000oOol00`00Oomo
o`0TOol00`00Oomoo`1kOol30010Ool00`00Oomoo`0gOol2000`Ool00`00Oomoo`09Ool003moo`03
001oogoo0:Eoo`8003ioo`03001oogoo06Uoo`03001oogoo00Uoo`00?goo0P009Woo00<007ooOol0
Ogoo0`00>goo00<007ooOol0JGoo00<007ooOol02Goo000oOol00`00Oomoo`0VOol00`00Oomoo`21
Ool3000hOol00`00Oomoo`1YOol00`00Oomoo`09Ool003moo`03001oogoo0:eoo`<000Aoo`03001o
ogoo02ioo`03001oogoo06Uoo`03001oogoo00Uoo`00?goo0P00:7oo0P00Qgoo1P00;goo00<007oo
Ool0JGoo00<007ooOol02Goo000oOol00`00Oomoo`2bOol4000_Ool00`00Oomoo`1YOol00`00Oomo
o`09Ool001Yoo`8000Aoo`8000Aoo`8000=oo`D000=oo`03001oogoo009oo`8000Eoo`03001oogoo
0;=oo`80031oo`03001oogoo06Uoo`03001oogoo00Uoo`006Goo00@007ooOol000Qoo`04001oogoo
0004Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol0:Woo00<0
07ooOol0^7oo00<007ooOol0JGoo00<007ooOol02Goo000IOol01000Oomoo`0027oo00@007ooOol0
00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo009oo`800>Ioo`03001oogoo06Uoo`03
001oogoo00Uoo`006Goo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`04Ool01000Oomo
ogoo0P001Goo00<007ooOol0iGoo00<007ooOol0JGoo00<007ooOol02Goo000IOol01000Oomoo`00
27oo00@007ooOol000Aoo`05001oogooOol00002Ool01@00Oomoogoo00001Woo00<007ooOol0;7oo
00<007ooOol0]Woo00<007ooOol0JGoo00<007ooOol02Goo000JOol2000:Ool20004Ool20003Ool4
0003Ool30004Ool2003VOol00`00Oomoo`1YOol00`00Oomoo`09Ool003moo`03001oogoo0>Eoo`03
001oogoo06Uoo`03001oogoo00Uoo`00?goo00<007ooOol0;Woo00<007ooOol0]7oo00<007ooOol0
JGoo00<007ooOol02Goo000oOol00`00Oomoo`3UOol00`00Oomoo`1YOol00`00Oomoo`09Ool003mo
o`80035oo`03001oogoo0;9oo`03001oogoo06Uoo`03001oogoo00Uoo`00?goo00<007ooOol0<7oo
00<007ooOol0/Woo00<007ooOol0JGoo00<007ooOol02Goo000oOol00`00Oomoo`0`Ool2002cOol0
0`00Oomoo`1YOol00`00Oomoo`09Ool003moo`80035oo`<00;9oofd000]oo`00?goo00<007ooOol0
;goo1@00ogoo:Woo000oOol00`00Oomoo`3oOomNOol003moo`03001oogoo03Aoo`03001oogoo0?mo
obMoo`00?goo0P00ogooGgoo000VOol20004Ool20004Ool20003Ool40004Ool00`00Oomoo`0fOol0
0`00Oomoo`3oOolUOol002Eoo`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
07ooOol0=goo00<007ooOol0ogoo97oo000UOol01000Oomoo`0027oo00@007ooOol000=oo`03001o
ogoo00Aoo`800?mooemoo`009Goo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`03Ool0
0`00Oomoo`0iOol00`00Oomoo`3oOolROol002Eoo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`03001oogoo0?mooeioo`009Woo0P002Woo0P0017oo0P001Goo00<007ooOol0>goo
00<007ooOol0ogoo87oo000oOol2000mOol00`00Oomoo`3oOolOOol003moo`03001oogoo0?mooeio
o`00?goo00<007ooOol0?Woo00<007ooOol0ogoo7Goo000oOol00`00Oomoo`3oOomNOol003moo`80
0?mooemoo`00?goo00<007ooOol0@7oo00<007ooOol0ogoo6goo000oOol00`00Oomoo`3oOomNOol0
03moo`8004=oo`800?mooaYoo`00?goo00<007ooOol0ogooGWoo000oOol00`00Oomoo`2cOol00`00
Oomoo`2WOol003moo`03001oogoo04Eoo`03001oogoo06]oo`800:Qoo`00?goo0P00/Goo00<007oo
00000`00Ygoo000JOol20004Ool20004Ool20003Ool40002Ool40003Ool20005Ool00`00Oomoo`17
Ool00`00Oomoo`1ROol20006Ool00`00Oomoo`2VOol001Uoo`04001oogoo0008Ool01000Oomoo`00
0Woo00<007ooOol00goo00<007ooOol00goo00@007ooOol000Aoo`03001oogoo04Qoo`03001oogoo
05Yoo`80009oo`03001oogoo0;5oo`006Goo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomo
o`03Ool00`00Oomoo`05Ool00`00Oomoo`02Ool2002SOol00`00Oomoo`2hOol001Uoo`04001oogoo
0008Ool01000Oomoo`0017oo00<007ooOol00goo00<007ooOol00Woo0P001Goo00<007ooOol0BWoo
00<007oo0000C7oo0`000Woo0P00_Goo000IOol01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`000goo00<007ooOol017oo00<007ooOol0Bgoo00<007ooOol0BGoo1@00
`Goo000JOol2000:Ool20004Ool20004Ool20004Ool30004Ool00`00Oomoo`19Ool50016Ool20037
Ool003moo`8004aoo`03001oogoo009oo`03001oogoo03ioo`03001oogoo0<Uoo`00?goo00<007oo
Ool0Dgoo0P00=Goo00<007ooOol00P00cWoo000oOol00`00Oomoo`1FOol2000_Ool01000Oomoo`00
dWoo000oOol2001KOol00`00Oomoo`0ROol20002Ool2003HOol003moo`03001oogoo05eoo`8001eo
o`800003Ool000000=aoo`00?goo00<007ooOol0HGoo00@007ooOomoo`8000Moo`80009oo`03001o
ogoo0080009oo`04001oogooOol5003KOol003moo`03001oogoo06Aoo`800003Ool00000009oo`03
001oogoo0>moo`00?goo0P00I7oo1@00mGoo000oOol00`00Oomoo`3oOomNOol003moo`03001oogoo
0?mooeioo`00ogooX7oo003oOonPOol00?mooj1oo`00ogooX7oo003oOonPOol00?mooj1oo`00ogoo
X7oo000mOol3003oOomPOol0041oo`03001oogoo0?mooeeoo`00?Woo0`00ogooGgoo000mOol01000
Oomoo`00ogooGgoo000mOol01000Oomoo`00ogooGgoo000nOol4003oOomNOol00?mooj1oo`00ogoo
X7oo003oOonPOol00?mooj1oo`00ogooX7oo003oOonPOol00?mooj1oo`00ogooX7oo003oOonPOol0
0001\
\>"],
  ImageRangeCache->{{{0, 414}, {175.875, 0}} -> {-1.07757, -0.648942, \
0.00737958, 0.00737958}, {{10.5, 281.5}, {171.688, 4.1875}} -> {-1.43033, \
0.00276449, 0.0382568, 0.000140301}, {{295.063, 403.438}, {142.125, 60.8125}} -> \
{-9.24807, -1.14687, 0.0310038, 0.0310038}, {{300.813, 333.063}, {136.25, \
104}} -> {-19.6552, -3.4574, 0.0620161, 0.0620161}, {{300.813, 333.063}, \
{98.875, 66.625}} -> {-19.6552, -5.77525, 0.0620161, 0.0620161}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(SetDirectory["\<d:/paper/matthias\>"];\)\), "\[IndentingNewLine]", 
    \(\(Display["\<pict1.eps\>", 
        plo1, "\<EPS\>"];\)\), "\[IndentingNewLine]", 
    \(\(Display["\<pict2.eps\>", 
        plo2, "\<EPS\>"];\)\), "\[IndentingNewLine]", 
    \(\(Display["\<pict3.eps\>", 
        plo3, "\<EPS\>"];\)\), "\[IndentingNewLine]", 
    \(\(Display["\<pict4.eps\>", 
        plo4, "\<EPS\>"];\)\), "\[IndentingNewLine]", 
    \(\(Display["\<pict5.eps\>", plo5, "\<EPS\>"];\)\)}], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowSize->{1016, 320},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 82, 3, 170, "Title"],
Cell[1812, 57, 45, 3, 93, "Subtitle"],
Cell[1860, 62, 43, 0, 64, "Subtitle"],
Cell[1906, 64, 375, 6, 130, "Input"],
Cell[2284, 72, 209, 3, 50, "Input"],

Cell[CellGroupData[{
Cell[2518, 79, 30, 0, 64, "Subtitle"],

Cell[CellGroupData[{
Cell[2573, 83, 41, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[2639, 87, 962, 16, 210, "Input"],
Cell[3604, 105, 179, 3, 24, "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3832, 114, 49, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[3906, 118, 3396, 73, 442, "Input"],
Cell[7305, 193, 193, 3, 24, "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7547, 202, 37, 0, 59, "Section"],
Cell[7587, 204, 3628, 62, 795, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11252, 271, 26, 0, 59, "Section"],
Cell[11281, 273, 1332, 23, 190, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12662, 302, 32, 0, 64, "Subtitle"],
Cell[12697, 304, 398, 7, 110, "Input"],
Cell[13098, 313, 36, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[13159, 317, 57, 0, 53, "Subsubtitle"],
Cell[13219, 319, 56, 1, 30, "Input"],
Cell[13278, 322, 50, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[13353, 327, 273, 4, 74, "Input"],
Cell[13629, 333, 160, 3, 24, "Message"],
Cell[13792, 338, 212, 4, 25, "Print"],
Cell[14007, 344, 228, 4, 25, "Print"],
Cell[14238, 350, 273, 6, 25, "Print"],
Cell[14514, 358, 234, 5, 25, "Print"],
Cell[14751, 365, 273, 6, 25, "Print"],
Cell[15027, 373, 131, 3, 25, "Print"],
Cell[15161, 378, 214, 4, 25, "Print"],
Cell[15378, 384, 230, 4, 25, "Print"],
Cell[15611, 390, 275, 6, 25, "Print"],
Cell[15889, 398, 236, 5, 25, "Print"],
Cell[16128, 405, 273, 6, 25, "Print"],
Cell[16404, 413, 131, 3, 25, "Print"],
Cell[16538, 418, 214, 4, 25, "Print"],
Cell[16755, 424, 230, 4, 25, "Print"],
Cell[16988, 430, 273, 6, 25, "Print"],
Cell[17264, 438, 234, 5, 25, "Print"],
Cell[17501, 445, 269, 6, 25, "Print"],
Cell[17773, 453, 131, 3, 25, "Print"],
Cell[17907, 458, 212, 4, 25, "Print"],
Cell[18122, 464, 228, 4, 25, "Print"],
Cell[18353, 470, 269, 6, 25, "Print"],
Cell[18625, 478, 225, 4, 25, "Print"],
Cell[18853, 484, 269, 6, 25, "Print"],
Cell[19125, 492, 131, 3, 25, "Print"],
Cell[19259, 497, 212, 4, 25, "Print"],
Cell[19474, 503, 228, 4, 25, "Print"],
Cell[19705, 509, 269, 6, 25, "Print"],
Cell[19977, 517, 225, 4, 25, "Print"],
Cell[20205, 523, 269, 6, 25, "Print"],
Cell[20477, 531, 131, 3, 25, "Print"],
Cell[20611, 536, 212, 4, 25, "Print"],
Cell[20826, 542, 228, 4, 25, "Print"],
Cell[21057, 548, 269, 6, 25, "Print"],
Cell[21329, 556, 225, 4, 25, "Print"],
Cell[21557, 562, 269, 6, 25, "Print"],
Cell[21829, 570, 131, 3, 25, "Print"],
Cell[21963, 575, 212, 4, 25, "Print"],
Cell[22178, 581, 228, 4, 25, "Print"],
Cell[22409, 587, 273, 6, 25, "Print"],
Cell[22685, 595, 234, 5, 25, "Print"],
Cell[22922, 602, 269, 6, 25, "Print"],
Cell[23194, 610, 131, 3, 25, "Print"],
Cell[23328, 615, 212, 4, 25, "Print"],
Cell[23543, 621, 228, 4, 25, "Print"],
Cell[23774, 627, 273, 6, 25, "Print"],
Cell[24050, 635, 234, 5, 25, "Print"],
Cell[24287, 642, 260, 5, 25, "Print"],
Cell[24550, 649, 131, 3, 25, "Print"],
Cell[24684, 654, 50366, 2037, 280, 27033, 1744, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75087, 2696, 327, 6, 94, "Input"],
Cell[75417, 2704, 160, 3, 24, "Message"],
Cell[75580, 2709, 210, 4, 25, "Print"],
Cell[75793, 2715, 226, 4, 25, "Print"],
Cell[76022, 2721, 269, 6, 25, "Print"],
Cell[76294, 2729, 225, 4, 25, "Print"],
Cell[76522, 2735, 269, 6, 25, "Print"],
Cell[76794, 2743, 131, 3, 25, "Print"],
Cell[76928, 2748, 212, 4, 25, "Print"],
Cell[77143, 2754, 228, 4, 25, "Print"],
Cell[77374, 2760, 269, 6, 25, "Print"],
Cell[77646, 2768, 225, 4, 25, "Print"],
Cell[77874, 2774, 269, 6, 25, "Print"],
Cell[78146, 2782, 131, 3, 25, "Print"],
Cell[78280, 2787, 212, 4, 25, "Print"],
Cell[78495, 2793, 228, 4, 25, "Print"],
Cell[78726, 2799, 273, 6, 25, "Print"],
Cell[79002, 2807, 234, 5, 25, "Print"],
Cell[79239, 2814, 269, 6, 25, "Print"],
Cell[79511, 2822, 131, 3, 25, "Print"],
Cell[79645, 2827, 212, 4, 25, "Print"],
Cell[79860, 2833, 228, 4, 25, "Print"],
Cell[80091, 2839, 273, 6, 25, "Print"],
Cell[80367, 2847, 234, 5, 25, "Print"],
Cell[80604, 2854, 269, 6, 25, "Print"],
Cell[80876, 2862, 131, 3, 25, "Print"],
Cell[81010, 2867, 212, 4, 25, "Print"],
Cell[81225, 2873, 226, 4, 25, "Print"],
Cell[81454, 2879, 273, 6, 25, "Print"],
Cell[81730, 2887, 234, 5, 25, "Print"],
Cell[81967, 2894, 260, 5, 25, "Print"],
Cell[82230, 2901, 131, 3, 25, "Print"],
Cell[82364, 2906, 210, 4, 25, "Print"],
Cell[82577, 2912, 224, 4, 25, "Print"],
Cell[82804, 2918, 269, 6, 25, "Print"],
Cell[83076, 2926, 225, 4, 25, "Print"],
Cell[83304, 2932, 269, 6, 25, "Print"],
Cell[83576, 2940, 131, 3, 25, "Print"],
Cell[83710, 2945, 212, 4, 25, "Print"],
Cell[83925, 2951, 228, 4, 25, "Print"],
Cell[84156, 2957, 273, 6, 25, "Print"],
Cell[84432, 2965, 234, 5, 25, "Print"],
Cell[84669, 2972, 269, 6, 25, "Print"],
Cell[84941, 2980, 131, 3, 25, "Print"],
Cell[85075, 2985, 212, 4, 25, "Print"],
Cell[85290, 2991, 228, 4, 25, "Print"],
Cell[85521, 2997, 273, 6, 25, "Print"],
Cell[85797, 3005, 234, 5, 25, "Print"],
Cell[86034, 3012, 260, 5, 25, "Print"],
Cell[86297, 3019, 131, 3, 25, "Print"],
Cell[86431, 3024, 52240, 2135, 280, 28297, 1834, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[138708, 5164, 247, 4, 74, "Input"],
Cell[138958, 5170, 160, 3, 24, "Message"],
Cell[139121, 5175, 212, 4, 25, "Print"],
Cell[139336, 5181, 228, 4, 25, "Print"],
Cell[139567, 5187, 273, 6, 25, "Print"],
Cell[139843, 5195, 234, 5, 25, "Print"],
Cell[140080, 5202, 269, 6, 25, "Print"],
Cell[140352, 5210, 131, 3, 25, "Print"],
Cell[140486, 5215, 212, 4, 25, "Print"],
Cell[140701, 5221, 228, 4, 25, "Print"],
Cell[140932, 5227, 273, 6, 25, "Print"],
Cell[141208, 5235, 234, 5, 25, "Print"],
Cell[141445, 5242, 260, 5, 25, "Print"],
Cell[141708, 5249, 131, 3, 25, "Print"],
Cell[141842, 5254, 210, 4, 25, "Print"],
Cell[142055, 5260, 228, 4, 25, "Print"],
Cell[142286, 5266, 273, 6, 25, "Print"],
Cell[142562, 5274, 234, 5, 25, "Print"],
Cell[142799, 5281, 269, 6, 25, "Print"],
Cell[143071, 5289, 131, 3, 25, "Print"],
Cell[143205, 5294, 212, 4, 25, "Print"],
Cell[143420, 5300, 228, 4, 25, "Print"],
Cell[143651, 5306, 269, 6, 25, "Print"],
Cell[143923, 5314, 225, 4, 25, "Print"],
Cell[144151, 5320, 269, 6, 25, "Print"],
Cell[144423, 5328, 131, 3, 25, "Print"],
Cell[144557, 5333, 212, 4, 25, "Print"],
Cell[144772, 5339, 226, 4, 25, "Print"],
Cell[145001, 5345, 273, 6, 25, "Print"],
Cell[145277, 5353, 234, 5, 25, "Print"],
Cell[145514, 5360, 260, 5, 25, "Print"],
Cell[145777, 5367, 131, 3, 25, "Print"],
Cell[145911, 5372, 210, 4, 25, "Print"],
Cell[146124, 5378, 226, 4, 25, "Print"],
Cell[146353, 5384, 269, 6, 25, "Print"],
Cell[146625, 5392, 225, 4, 25, "Print"],
Cell[146853, 5398, 269, 6, 25, "Print"],
Cell[147125, 5406, 131, 3, 25, "Print"],
Cell[147259, 5411, 212, 4, 25, "Print"],
Cell[147474, 5417, 226, 4, 25, "Print"],
Cell[147703, 5423, 273, 6, 25, "Print"],
Cell[147979, 5431, 234, 5, 25, "Print"],
Cell[148216, 5438, 269, 6, 25, "Print"],
Cell[148488, 5446, 131, 3, 25, "Print"],
Cell[148622, 5451, 212, 4, 25, "Print"],
Cell[148837, 5457, 228, 4, 25, "Print"],
Cell[149068, 5463, 273, 6, 25, "Print"],
Cell[149344, 5471, 234, 5, 25, "Print"],
Cell[149581, 5478, 269, 6, 25, "Print"],
Cell[149853, 5486, 131, 3, 25, "Print"],
Cell[149987, 5491, 52106, 2119, 280, 28226, 1819, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[202130, 7615, 782, 16, 110, "Input"],
Cell[202915, 7633, 19641, 556, 186, 9117, 422, "GraphicsData", "PostScript", \
"Graphics"],
Cell[222559, 8191, 130, 3, 29, "Output"],
Cell[222692, 8196, 26713, 835, 178, 14416, 679, "GraphicsData", "PostScript", \
"Graphics"],
Cell[249408, 9033, 130, 3, 29, "Output"],
Cell[249541, 9038, 16599, 489, 186, 8809, 388, "GraphicsData", "PostScript", \
"Graphics"],
Cell[266143, 9529, 130, 3, 29, "Output"],
Cell[266276, 9534, 17137, 504, 186, 8708, 395, "GraphicsData", "PostScript", \
"Graphics"],
Cell[283416, 10040, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[283583, 10048, 338, 6, 90, "Input"],
Cell[283924, 10056, 28291, 893, 185, 15380, 729, "GraphicsData", \
"PostScript", "Graphics"],
Cell[312218, 10951, 130, 3, 29, "Output"]
}, Open  ]],
Cell[312363, 10957, 513, 10, 130, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

