(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     93414,       2359]*)
(*NotebookOutlinePosition[     94119,       2383]*)
(*  CellTagsIndexPosition[     94075,       2379]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Inequality and growth:
Why fertility differential matters\
\>", "Title"],

Cell["\<\

Dynamic analysis\
\>", "Subtitle"],

Cell["Loading useful packages", "Subtitle"],

Cell[BoxData[{
    \(<< Statistics`ContinuousDistributions`\), "\[IndentingNewLine]", 
    \(<< Graphics`FilledPlot`\), "\[IndentingNewLine]", 
    \(<< Graphics`Graphics`\), "\[IndentingNewLine]", 
    \(<< Graphics`Graphics3D`\), "\[IndentingNewLine]", 
    \(<< Graphics`MultipleListPlot`\), "\[IndentingNewLine]", 
    \(<< Statistics`DescriptiveStatistics`\)}], "Input"],

Cell[BoxData[{
    \(\(SetOptions[ListPlot, PlotRange \[Rule] All, 
        PlotJoined \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[MultipleListPlot, PlotJoined \[Rule] True];\)\)}], "Input"],

Cell[CellGroupData[{

Cell["Procedures", "Subtitle"],

Cell[CellGroupData[{

Cell["Defining the variables", "Section"],

Cell[BoxData[
    \(defvar := 
      Module[{a}, \[IndentingNewLine]Clear[cN, cNf, cn, cx, cxf, ce, pN, pn, 
          px, pe, growth, cap, popgrowth, income, ginix, fd, 
          cfd]; \[IndentingNewLine]Clear[Nh, Nhf, n, x, xf, e, plN, pln, plx, 
          ple, gag, k, nag, inc, gix, ct, pct, gdp]; \[IndentingNewLine]cN = 
          Array[Nh, dim]; 
        cNf = Array[Nhf, dim]; \[IndentingNewLine]cn = Array[n, dim]; 
        cx = Array[x, dim]; cxf = Array[xf, dim]; \ 
        ce = Array[e, dim]; \[IndentingNewLine]income = 
          Array[inc, dim]; \[IndentingNewLine]pN = Array[plN, steps]; 
        pn = Array[pln, steps]; 
        ct = Array[pct, steps]; \[IndentingNewLine]px = Array[plx, steps]; 
        pe = Array[ple, steps]; \[IndentingNewLine]growth = 
          Array[gag, steps]; popgrowth = Array[nag, steps]; 
        cap = Array[k, steps + 1]; \[IndentingNewLine]ginix = 
          Array[gix, steps]; cfd = Array[fd, steps];]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Setting the initial conditions", "Section"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"initcond", ":=", 
        RowBox[{"Module", "[", 
          RowBox[{\({scal, cxtemp, glt, Nlt}\), ",", "\[IndentingNewLine]", 
            
            RowBox[{\(Do[Nh[i] = 1/dim, {i, 1, dim}]\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"gdist", "=", 
                StyleBox[\(LogNormalDistribution[0, \[Sigma]]\),
                  "MR"]}], ";", 
              "\[IndentingNewLine]", \(cdfunction = CDF[gdist, y]\), ";", 
              "\[IndentingNewLine]", \(pdfunction = PDF[gdist, y]\), ";", 
              "\[IndentingNewLine]", \(inversecdf[z_] = 
                y /. \(Solve[cdfunction \[Equal] z, y]\)[\([1]\)]\), ";", 
              "\[IndentingNewLine]", \(Do[
                x[i] = inversecdf[\((i -  .5)\)/dim]\ , {i, 1, dim}]\), ";", 
              "\[IndentingNewLine]", \(scal = Sum[x[i]\ Nh[i], {i, 1, dim}]\),
               ";", "\[IndentingNewLine]", \(Do[
                x[i] = x[i]/scal\ , {i, 1, dim}]\), ";", 
              "\[IndentingNewLine]", \(Nlt = \(\((1 - \[Eta])\) \
\[Gamma]\)\/\(\((\[Phi] - \[Theta])\) \((1 + \[Beta] + \[Gamma])\)\)\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"glt", "=", 
                RowBox[{
                  StyleBox["B",
                    
                    FontWeight->
                      "Plain"], \(\((\(\[Eta] \((\[Phi] - \[Theta])\)\)\/\(1 \
- \[Eta]\))\)\^\[Eta]\)}]}], ";", 
              "\[IndentingNewLine]", \(k[
                  1] = \((\(\[Beta]\/\(1 + \[Beta]\)\) \(1\/\(glt\ Nlt\)\) \
\((1 - \[Alpha])\))\)\^\(1\/\(1 - \[Alpha]\)\)\), ";", "\[IndentingNewLine]", 
              
              RowBox[{\(hh[1]\), "=", 
                RowBox[{"If", "[", 
                  RowBox[{\(\[Kappa] < 1 - \[Tau]\), ",", 
                    RowBox[{
                      FractionBox[
                        StyleBox["B",
                          FontWeight->"Plain"], 
                        "glt"], \(\((\(\[Eta] \((\[Phi] - \[Theta])\)\)\/\(1 \
- \[Eta]\))\)\^\[Eta]\)}], ",", "1"}], "]"}]}], ";"}]}], "]"}]}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"pictdist", ":=", 
      RowBox[{"Module", "[", 
        RowBox[{\({dis1, dis2}\), ",", "\[IndentingNewLine]", 
          
          RowBox[{\(dis1 = 
              FilledPlot[pdfunction, {y, 0, 4}, PlotRange \[Rule] All, 
                DisplayFunction \[Rule] Identity]\), ";", 
            "\[IndentingNewLine]", 
            RowBox[{"dis2", "=", 
              RowBox[{"Histogram", "[", 
                RowBox[{"cx", ",", 
                  RowBox[{
                    StyleBox["HistogramScale",
                      "MR"], " ", 
                    StyleBox["->",
                      "MR"], 
                    StyleBox["1",
                      "MR"]}], 
                  StyleBox[",",
                    "MR"], 
                  StyleBox[\(HistogramRange -> {0, 4}\),
                    "MR"], ",", \(DisplayFunction \[Rule] Identity\)}], 
                "]"}]}], ";", 
            "\[IndentingNewLine]", \(Show[dis1, dis2, 
              DisplayFunction \[Rule] $DisplayFunction]\), ";"}]}], 
        "]"}]}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dynamic simulation", "Section"],

Cell[BoxData[
    \(simul := 
      Module[{a, 
          q}, \[IndentingNewLine]Do[\[IndentingNewLine]Do[
            n[i] = If[
                x[i] > \[Theta]/\((\[Eta]\ \[Phi])\), \(\((1 - \[Eta])\)\ \
\[Gamma]\ x[i]\)\/\(\((\[Phi]\ x[i] - \[Theta])\) \((1 + \[Beta] + \
\[Gamma])\)\), \(\(\[Gamma]\)\(\ \)\)\/\(\[Phi]\ \((1 + \[Beta] + \[Gamma])\)\
\)], {i, 1, dim}]; \[IndentingNewLine]\[IndentingNewLine]gdp[j] = 
            k[j]\^\[Alpha]\ \[Alpha]\ \(1 + \[Beta]\)\/\(1 + \[Beta] + \
\[Gamma]\) + \((1 - \[Alpha])\) 
                k[j]\^\[Alpha]\ \((1 - \[Phi]\ Sum[
                        n[i]\ x[i]\ \ Nh[i], {i, 1, 
                          dim}])\); \[IndentingNewLine]nsort = 
            Sort[Array[n, dim]]; \[IndentingNewLine]fd[
              j] = \(-Mean[Take[nsort, dim/5]]\) + 
              Mean[Take[nsort, \(-dim\)/5]]; \[IndentingNewLine]nag[j] = 
            Sum[n[i]\ Nh[i], {i, 1, dim}]; \[IndentingNewLine]Do[
            Nhf[i] = n[i]\/nag[j]\ Nh[i], {i, 1, dim}]; \[IndentingNewLine]Do[
            e[i] = Max[\(\[Eta]\ \[Phi]\ x[i] - \[Theta]\)\/\(1 - \[Eta]\), 
                0], {i, 1, dim}]; \[IndentingNewLine]gag[j] = 
            Sum[\ Nhf[
                  i]\ B\ \(\((\[Theta] + e[i])\)\^\[Eta]\) \(x[i]\^\[Tau]\) 
                hh[j]\^\(\[Kappa] + \[Tau] - 1\), {i, 1, 
                dim}]; \[IndentingNewLine]hh[j + 1] = 
            hh[j]\ gag[j]/\((1 + \[CurlyRho])\); \[IndentingNewLine]Do[
            inc[i] = \((x[i] \((1 - \[Phi]\ n[i])\) - 
                    e[i] n[i])\) \((1 - \[Alpha])\) k[j]\^\[Alpha], {i, 1, 
              dim}]; \[IndentingNewLine]sd = 
            Sort[income]; \[IndentingNewLine]gix[j] = 
            N[\(Length[
                      sd]\/\((Length[sd] - 
                        1)\)\) \(2  Apply[Plus, Table[\((2  q - Length[sd] - \
1)\) sd[\([q]\)], {q, 1, Length[sd]}]]\)\/\(2\ Length[sd]\^2\ Mean[sd]\)]; \
\[IndentingNewLine]k[
              j + 1] = \(\[Beta]\/\(1 + \[Beta]\)\) \(1\/\(gag[j]\ nag[
                      j]\)\) \((1 - \[Alpha])\) 
              k[j]\^\[Alpha]; \[IndentingNewLine]pct[j] = 
            Sum[If[x[i] < \[Theta]/\((\[Eta]\ \[Phi])\), Nh[i], 0]\ , {i, 1, 
                dim}]; \[IndentingNewLine]Do[
            xf[i] = B\ \(\((\[Theta] + e[i])\)\^\[Eta]\) 
                x[i]\^\[Tau]\ hh[j]\^\(\[Kappa] + \[Tau] - 1\)/\ gag[j], {i, 
              1, dim}]; \[IndentingNewLine]Clear[tp]; \[IndentingNewLine]tp = 
            Dot[Transpose[{Array[xf, dim]}], {{1, 0}}] + 
              Dot[Transpose[{Array[Nhf, dim]}], {{0, 
                    1}}]; \[IndentingNewLine]tp2 = 
            Transpose[Sort[tp]]; \[IndentingNewLine]Do[
            Nhf[i] = \(tp2[\([2]\)]\)[\([i]\)]; 
            xf[i] = \(tp2[\([1]\)]\)[\([i]\)], {i, 1, 
              dim}]; \[IndentingNewLine]Clear[
            CuNhf]; \[IndentingNewLine]CuNhf[1] = 
            Nhf[1]; \[IndentingNewLine]Do[
            CuNhf[i] = CuNhf[i - 1] + Nhf[i], {i, 2, 
              dim}]; \[IndentingNewLine]Do[
            zNh[i] = 1/dim; \[IndentingNewLine]Clear[z1, tp]; 
            tp = Random[]; \[IndentingNewLine]z1 = \(Ordering[
                  Abs[Table[tp, {dim}] - Array[CuNhf, dim]], 
                  1]\)[\([1]\)]; \[IndentingNewLine]zx[i] = xf[z1], {i, 1, 
              dim}]; \[IndentingNewLine]corr = 
            Sum[zx[i] zNh[i], {i, 1, 
                dim}]; \[IndentingNewLine]Print["\<step\>", \ 
            j]; \[IndentingNewLine]Do[x[i] = zx[i]/corr; 
            Nh[i] = zNh[i], {i, 1, dim}], {j, 1, steps}]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dynamic simulation with fixed fertility", "Section"],

Cell[BoxData[
    \(simuln := 
      Module[{a}, \[IndentingNewLine]Do[
          plN[j] = 
            ListPlot[cN, DisplayFunction \[Rule] Identity, 
              PlotStyle \[Rule] Hue[j/steps]]; 
          plx[j] = 
            ListPlot[cx, DisplayFunction \[Rule] Identity, 
              PlotStyle \[Rule] Hue[j/steps]]; \[IndentingNewLine]Do[
            n[i] = 1, {i, 1, dim}]; \[IndentingNewLine]pln[j] = 
            ListPlot[cn, DisplayFunction \[Rule] Identity, 
              PlotStyle \[Rule] Hue[j/steps]]; \[IndentingNewLine]nag[j] = 
            Sum[n[i]\ Nh[i], {i, 1, dim}]; \[IndentingNewLine]Do[
            Nhf[i] = n[i]\/nag[j]\ Nh[i], {i, 1, dim}]; \[IndentingNewLine]Do[
            e[i] = Max[\(\((1 - n[i]\ \[Phi])\)\ x[i]\ \[Eta]\ \[Gamma] - \
n[i]\ \((1 + \[Beta])\)\ \[Theta]\)\/\(n\ [i] \((1 + \[Beta] + \[Eta]\ \
\[Gamma])\)\), 0], {i, 1, dim}]; \[IndentingNewLine]ple[j] = 
            ListPlot[ce, DisplayFunction \[Rule] Identity, 
              PlotStyle \[Rule] Hue[j/steps]]; \[IndentingNewLine]gag[j] = 
            Sum[\ Nhf[i]\ B\ \(\((\[Theta] + e[i])\)\^\[Eta]\) 
                x[i]\^\[Tau], {i, 1, dim}]; \[IndentingNewLine]Do[
            inc[i] = \((x[i] \((1 - \[Phi]\ n[i])\) - 
                    e[i] n[i])\) \((1 - \[Alpha])\) k[j]\^\[Alpha], {i, 1, 
              dim}]; \[IndentingNewLine]sd = 
            Sort[income]; \[IndentingNewLine]gix[j] = 
            N[\(Length[
                      sd]\/\((Length[sd] - 
                        1)\)\) \(2  Apply[Plus, Table[\((2  q - Length[sd] - \
1)\) sd[\([q]\)], {q, 1, Length[sd]}]]\)\/\(2\ Length[sd]\^2\ Mean[sd]\)]; \
\[IndentingNewLine]k[
              j + 1] = \(\[Beta]\/\(1 + \[Beta]\)\) \(1\/\(gag[j]\ nag[
                      j]\)\) \((1 - \[Alpha])\) 
              k[j]\^\[Alpha]; \[IndentingNewLine]Do[
            xf[i] = B\ \(\((\[Theta] + e[i])\)\^\[Eta]\) 
                x[i]\^\[Tau]\ /\ gag[j], {i, 1, dim}]; \[IndentingNewLine]Do[
            x[i] = xf[i]; Nh[i] = Nhf[i], {i, 1, dim}], {j, 1, 
            steps}]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Results", "Section"],

Cell[BoxData[
    \(result2 := 
      Module[{p1, p2, p3, p4}, \[IndentingNewLine]Clear[p5, p6, p7, p8, p9, 
          p10]; \[IndentingNewLine]p5 = 
          ListPlot[growth, PlotJoined \[Rule] True, AxesLabel \[Rule] {t, g}, 
            DisplayFunction \[Rule] Identity, 
            AxesOrigin \[Rule] {1, 1}]; \[IndentingNewLine]p6 = 
          ListPlot[popgrowth, PlotJoined \[Rule] True, 
            AxesLabel \[Rule] {t, n}, DisplayFunction \[Rule] Identity, 
            AxesOrigin \[Rule] {1, 1}]; \[IndentingNewLine]p7 = 
          ListPlot[cap, PlotJoined \[Rule] True, 
            AxesLabel \[Rule] {t, "\<k\>"}, 
            DisplayFunction \[Rule] Identity]; \[IndentingNewLine]p8 = 
          ListPlot[ginix, PlotJoined \[Rule] True, 
            AxesLabel \[Rule] {t, "\<gini\>"}, 
            DisplayFunction \[Rule] Identity]; \[IndentingNewLine]p9 = 
          ListPlot[ct, PlotJoined \[Rule] True, 
            AxesLabel \[Rule] {t, "\<% const\>"}, 
            DisplayFunction \[Rule] Identity, 
            AxesOrigin \[Rule] {1, 0}]; \[IndentingNewLine]p10 = 
          ListPlot[cfd, PlotJoined \[Rule] True, 
            AxesLabel \[Rule] {t, "\<dif fert\>"}, 
            DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[
          GraphicsArray[{{p5, p6}, {p7, p8}, {p9, p10}}]]]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Main program", "Subtitle"],

Cell[BoxData[{
    \(\[IndentingNewLine]\[Phi] =  .15/
        2; \[Eta] =  .634522; \[Beta] =  .99\^120; \[Alpha] = 1/3; \[Theta] = 
      0.01187433277439054; \[Gamma] = 
      0.2712867133790373;\), "\[IndentingNewLine]", 
    \(B = 7.3667967472312402219159866854; \[CurlyRho] = 
      1.02\^30 - 1;\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(ou = Array[plou, {4, 4}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell["Basis Simulations", "Section"],

Cell[BoxData[
    \(dim = 1000; steps = 1;\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Effet of \[Sigma]", "Subsubtitle"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Tau] =  .2; \[Kappa] =  .1;\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 1/10;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simul; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", 
      2  fd[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1, "\< \>", \[Beta]/\((1 + \[Beta] + \[Gamma])\)\ \ \((1 - \
\[Alpha])\) k[1]\^\[Alpha]/gdp[1]]\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 3/4;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simul; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", 
      2  fd[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1, "\< \>", \[Beta]/\((1 + \[Beta] + \[Gamma])\)\ \((1 - \[Alpha])\) 
        k[1]\^\[Alpha]/gdp[1]]\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 1;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simul; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", 
      2  fd[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1, "\< \>", \[Beta]/\((1 + \[Beta] + \[Gamma])\)\ \((1 - \[Alpha])\) 
        k[1]\^\[Alpha]/gdp[1]]\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 1.5;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simul; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", 
      2  fd[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1, "\< \>", \[Beta]/\((1 + \[Beta] + \[Gamma])\)\ \ \((1 - \
\[Alpha])\) k[1]\^\[Alpha]/gdp[1]]\)}], "Input"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(0.019906775052761505`\[InvisibleSpace]" "\
\[InvisibleSpace]0.00007516838909227275`\[InvisibleSpace]" \
"\[InvisibleSpace]0.056409899596603905`\[InvisibleSpace]" \
"\[InvisibleSpace]0.10715196482038247`\[InvisibleSpace]" \
"\[InvisibleSpace]0.046685627243973515`\[InvisibleSpace]" \
"\[InvisibleSpace]0.14239154352551472`\),
      SequenceForm[ .019906775052761505, " ", .000075168389092272747, 
        " ", .056409899596603905, " ", .10715196482038247, 
        " ", .046685627243973515, " ", .14239154352551472],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(0.012603692760648766`\[InvisibleSpace]" "\
\[InvisibleSpace]0.006614738259893338`\[InvisibleSpace]" \
"\[InvisibleSpace]0.40403991799058087`\[InvisibleSpace]" \
"\[InvisibleSpace]1.9733409443742866`\[InvisibleSpace]" \
"\[InvisibleSpace]0.046685627243973515`\[InvisibleSpace]" \
"\[InvisibleSpace]0.14261353873808483`\),
      SequenceForm[ .012603692760648766, " ", .006614738259893338, 
        " ", .40403991799058087, " ", 1.9733409443742866, 
        " ", .046685627243973515, " ", .14261353873808483],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(0.008011895732116914`\[InvisibleSpace]" "\
\[InvisibleSpace]0.01082849876483194`\[InvisibleSpace]" \
"\[InvisibleSpace]0.5199764685890028`\[InvisibleSpace]" \
"\[InvisibleSpace]2.78149843263088`\[InvisibleSpace]" \
"\[InvisibleSpace]0.046685627243973515`\[InvisibleSpace]" \
"\[InvisibleSpace]0.142671083709657`\),
      SequenceForm[ .0080118957321169137, " ", .01082849876483194, 
        " ", .51997646858900282, " ", 2.78149843263088, 
        " ", .046685627243973515, " ", .142671083709657],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(0.0005751131490139283`\[InvisibleSpace]" "\
\[InvisibleSpace]0.017116439482417256`\[InvisibleSpace]" \
"\[InvisibleSpace]0.7085638372158375`\[InvisibleSpace]" \
"\[InvisibleSpace]2.7905463606355836`\[InvisibleSpace]" \
"\[InvisibleSpace]0.046685627243973515`\[InvisibleSpace]" \
"\[InvisibleSpace]0.1425287192838937`\),
      SequenceForm[ .00057511314901392829, " ", .017116439482417256, 
        " ", .70856383721583749, " ", 2.7905463606355836, 
        " ", .046685627243973515, " ", .14252871928389371],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sensitivity analysis", "Subsubtitle"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Tau] =  .05;\)\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 1/10;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simul; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", 
      2  fd[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1]\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 3/4;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simul; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", 
      2  fd[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1]\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 1;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simul; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", 
      2  fd[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1]\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 1.5;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simul; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", 
      2  fd[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1]\)}], "Input"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(0.019897080416094726`\[InvisibleSpace]" "\
\[InvisibleSpace]0.00007516838909227275`\[InvisibleSpace]" \
"\[InvisibleSpace]0.056409899596603905`\[InvisibleSpace]" \
"\[InvisibleSpace]0.10715196482038247`\[InvisibleSpace]" \
"\[InvisibleSpace]0.046685627243973515`\),
      SequenceForm[ .019897080416094726, " ", .000075168389092272747, 
        " ", .056409899596603905, " ", .10715196482038247, 
        " ", .046685627243973515],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(0.012174943922265147`\[InvisibleSpace]" "\
\[InvisibleSpace]0.006614738259893338`\[InvisibleSpace]" \
"\[InvisibleSpace]0.40403991799058087`\[InvisibleSpace]" \
"\[InvisibleSpace]1.9733409443742866`\[InvisibleSpace]" \
"\[InvisibleSpace]0.046685627243973515`\),
      SequenceForm[ .012174943922265147, " ", .006614738259893338, 
        " ", .40403991799058087, " ", 1.9733409443742866, 
        " ", .046685627243973515],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(0.007400315085145159`\[InvisibleSpace]" "\
\[InvisibleSpace]0.01082849876483194`\[InvisibleSpace]" \
"\[InvisibleSpace]0.5199764685890028`\[InvisibleSpace]" \
"\[InvisibleSpace]2.78149843263088`\[InvisibleSpace]" \
"\[InvisibleSpace]0.046685627243973515`\),
      SequenceForm[ .0074003150851451593, " ", .01082849876483194, 
        " ", .51997646858900282, " ", 2.78149843263088, 
        " ", .046685627243973515],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(\(-0.0002397542750344206`\)\[InvisibleSpace]" "\
\[InvisibleSpace]0.017116439482417256`\[InvisibleSpace]" \
"\[InvisibleSpace]0.7085638372158375`\[InvisibleSpace]" \
"\[InvisibleSpace]2.7905463606355836`\[InvisibleSpace]" \
"\[InvisibleSpace]0.046685627243973515`\),
      SequenceForm[ -.00023975427503442059, " ", .017116439482417256, 
        " ", .70856383721583749, " ", 2.7905463606355836, 
        " ", .046685627243973515],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Tau] =  .3;\)\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 1/10;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simul; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", 
      2  fd[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1]\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 3/4;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simul; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", 
      2  fd[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1]\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 1;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simul; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", 
      2  fd[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1]\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 1.5;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simul; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", 
      2  fd[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1]\)}], "Input"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(0.01991748542710048`\[InvisibleSpace]" "\
\[InvisibleSpace]0.00007516838909227275`\[InvisibleSpace]" \
"\[InvisibleSpace]0.056409899596603905`\[InvisibleSpace]" \
"\[InvisibleSpace]0.10715196482038247`\[InvisibleSpace]" \
"\[InvisibleSpace]0.046685627243973515`\),
      SequenceForm[ .019917485427100479, " ", .000075168389092272747, 
        " ", .056409899596603905, " ", .10715196482038247, 
        " ", .046685627243973515],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(0.013144336197419282`\[InvisibleSpace]" "\
\[InvisibleSpace]0.006614738259893338`\[InvisibleSpace]" \
"\[InvisibleSpace]0.40403991799058087`\[InvisibleSpace]" \
"\[InvisibleSpace]1.9733409443742866`\[InvisibleSpace]" \
"\[InvisibleSpace]0.046685627243973515`\),
      SequenceForm[ .013144336197419282, " ", .006614738259893338, 
        " ", .40403991799058087, " ", 1.9733409443742866, 
        " ", .046685627243973515],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(0.008899282461540148`\[InvisibleSpace]" "\
\[InvisibleSpace]0.01082849876483194`\[InvisibleSpace]" \
"\[InvisibleSpace]0.5199764685890028`\[InvisibleSpace]" \
"\[InvisibleSpace]2.78149843263088`\[InvisibleSpace]" \
"\[InvisibleSpace]0.046685627243973515`\),
      SequenceForm[ .0088992824615401478, " ", .01082849876483194, 
        " ", .51997646858900282, " ", 2.78149843263088, 
        " ", .046685627243973515],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(0.0023307674722770066`\[InvisibleSpace]" "\
\[InvisibleSpace]0.017116439482417256`\[InvisibleSpace]" \
"\[InvisibleSpace]0.7085638372158375`\[InvisibleSpace]" \
"\[InvisibleSpace]2.7905463606355836`\[InvisibleSpace]" \
"\[InvisibleSpace]0.046685627243973515`\),
      SequenceForm[ .0023307674722770066, " ", .017116439482417256, 
        " ", .70856383721583749, " ", 2.7905463606355836, 
        " ", .046685627243973515],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Effet of \[Sigma] at given fertiltiy", "Subsubtitle"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Tau] =  .2;\)\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 1/10;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simuln; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1]\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 3/4;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simuln; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1]\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 1;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simuln; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1]\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 1.5;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simuln; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1]\), "\[IndentingNewLine]", 
    \(\(\[Tau] =  .05;\)\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 1/10;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simuln; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1]\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 3/4;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simuln; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1]\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 1;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simuln; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1]\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 1.5;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simuln; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1]\), "\[IndentingNewLine]", 
    \(\(\[Tau] =  .3;\)\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 1/10;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simuln; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1]\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 3/4;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simuln; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1]\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 1;\)\), "\[IndentingNewLine]", 
    \(defvar; initcond; simuln; 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1]\), "\[IndentingNewLine]", 
    \(\(\[Sigma] = 1.5;\)\), "\[IndentingNewLine]", 
    \(\(\(\(\(defvar\) \); \(\(initcond\) \); \(\(simuln\) \); 
    Print[\@\(gag[1]\)\%30 - 1, "\< \>", \@\(nag[1]\)\%30 - 1, "\< \>", 
      gix[1], "\< \>", \@\(\[Alpha]\ k[1]\^\(\[Alpha] - 1\)\)\%30 - 
        1]\)\(\[IndentingNewLine]\)
    \)\)}], "Input"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\(0.01997698797342684`\[InvisibleSpace]" "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]0.05569493719860892`\
\[InvisibleSpace]" "\[InvisibleSpace]0.046685627243973515`\),
      SequenceForm[ .019976987973426841, " ", 0, " ", .055694937198608921, 
        " ", .046685627243973515],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\(0.018715025246430317`\[InvisibleSpace]" "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]0.39892865389835874`\
\[InvisibleSpace]" "\[InvisibleSpace]0.046685627243973515`\),
      SequenceForm[ .018715025246430317, " ", 0, " ", .39892865389835874, 
        " ", .046685627243973515],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\(0.017753698846796562`\[InvisibleSpace]" "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]0.5135668209520142`\
\[InvisibleSpace]" "\[InvisibleSpace]0.046685627243973515`\),
      SequenceForm[ .017753698846796562, " ", 0, " ", .51356682095201422, 
        " ", .046685627243973515],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\(0.015290353406283597`\[InvisibleSpace]" "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]0.7015607441666998`\
\[InvisibleSpace]" "\[InvisibleSpace]0.046685627243973515`\),
      SequenceForm[ .015290353406283597, " ", 0, " ", .70156074416669978, 
        " ", .046685627243973515],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\(0.01996418095321073`\[InvisibleSpace]" "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]0.05569493719860892`\
\[InvisibleSpace]" "\[InvisibleSpace]0.046685627243973515`\),
      SequenceForm[ .019964180953210731, " ", 0, " ", .055694937198608921, 
        " ", .046685627243973515],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\(0.018001294181714256`\[InvisibleSpace]" "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]0.39892865389835874`\
\[InvisibleSpace]" "\[InvisibleSpace]0.046685627243973515`\),
      SequenceForm[ .018001294181714256, " ", 0, " ", .39892865389835874, 
        " ", .046685627243973515],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\(0.016509872355037647`\[InvisibleSpace]" "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]0.5135668209520142`\
\[InvisibleSpace]" "\[InvisibleSpace]0.046685627243973515`\),
      SequenceForm[ .016509872355037647, " ", 0, " ", .51356682095201422, 
        " ", .046685627243973515],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\(0.012769131772199405`\[InvisibleSpace]" "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]0.7015607441666998`\
\[InvisibleSpace]" "\[InvisibleSpace]0.046685627243973515`\),
      SequenceForm[ .012769131772199405, " ", 0, " ", .70156074416669978, 
        " ", .046685627243973515],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\(0.019989770440448806`\[InvisibleSpace]" "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]0.05569493719860892`\
\[InvisibleSpace]" "\[InvisibleSpace]0.046685627243973515`\),
      SequenceForm[ .019989770440448806, " ", 0, " ", .055694937198608921, 
        " ", .046685627243973515],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\(0.019429426074888845`\[InvisibleSpace]" "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]0.39892865389835874`\
\[InvisibleSpace]" "\[InvisibleSpace]0.046685627243973515`\),
      SequenceForm[ .019429426074888845, " ", 0, " ", .39892865389835874, 
        " ", .046685627243973515],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\(0.01900933078971523`\[InvisibleSpace]" "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]0.5135668209520142`\
\[InvisibleSpace]" "\[InvisibleSpace]0.046685627243973515`\),
      SequenceForm[ .019009330789715229, " ", 0, " ", .51356682095201422, 
        " ", .046685627243973515],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\(0.017971186987894683`\[InvisibleSpace]" "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]0.7015607441666998`\
\[InvisibleSpace]" "\[InvisibleSpace]0.046685627243973515`\),
      SequenceForm[ .017971186987894683, " ", 0, " ", .70156074416669978, 
        " ", .046685627243973515],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The relationship gini vs growth\
\>", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(steps = 1; dim = 1000; \[Tau] =  .2;\), "\[IndentingNewLine]", 
    \(\(Clear[ss1, ss2, se1, se2];\)\), "\[IndentingNewLine]", 
    \(\(ss1 = Array[se1, {20, 2}];\)\), "\[IndentingNewLine]", 
    \(\(ss2 = Array[se2, {20, 2}];\)\), "\[IndentingNewLine]", 
    \(Do[\[Sigma] = jj/10; \[IndentingNewLine]defvar; initcond; 
      simul; \[IndentingNewLine]se1[jj, 2] = \@\(gag[1]\)\%30 - 1; 
      se1[jj, 1] = 
        gix[1]; \[IndentingNewLine]Print["\<\[Sigma]=\>", \[Sigma], "\< \
GDP=\>", gdp[1], "\< Gini=\>", gix[1], "\< growth=\>", se1[jj, 2]], {jj, 1, 
        20}]\), "\[IndentingNewLine]", 
    \(Do[\[Sigma] = jj/10; \[IndentingNewLine]defvar; initcond; simuln; 
      se2[jj, 2] = \@\(gag[1]\)\%30 - 1; 
      se2[jj, 1] = gix[1], {jj, 1, 20}]\)}], "Input"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("\[Sigma]="\[InvisibleSpace]1\/10\[InvisibleSpace]" \
GDP="\[InvisibleSpace]0.2598718332256989`\[InvisibleSpace]" Gini="\
\[InvisibleSpace]0.056409899596603905`\[InvisibleSpace]" growth="\
\[InvisibleSpace]0.019906775052761505`\),
      SequenceForm[ "\[Sigma]=", 
        Rational[ 1, 10], " GDP=", .2598718332256989, 
        " Gini=", .056409899596603905, " growth=", .019906775052761505],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("\[Sigma]="\[InvisibleSpace]1\/5\[InvisibleSpace]" \
GDP="\[InvisibleSpace]0.2598554376363029`\[InvisibleSpace]" Gini="\
\[InvisibleSpace]0.11253395807375234`\[InvisibleSpace]" growth="\
\[InvisibleSpace]0.01961740692884617`\),
      SequenceForm[ "\[Sigma]=", 
        Rational[ 1, 5], " GDP=", .25985543763630292, 
        " Gini=", .11253395807375234, " growth=", .019617406928846171],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Solve :: \"ifun\"\) will be suppressed during \
this calculation."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("\[Sigma]="\[InvisibleSpace]3\/10\[InvisibleSpace]" \
GDP="\[InvisibleSpace]0.25982507067918387`\[InvisibleSpace]" Gini="\
\[InvisibleSpace]0.16809033583858343`\[InvisibleSpace]" growth="\
\[InvisibleSpace]0.019097455940688457`\),
      SequenceForm[ "\[Sigma]=", 
        Rational[ 3, 10], " GDP=", .25982507067918387, 
        " Gini=", .16809033583858343, " growth=", .019097455940688457],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("\[Sigma]="\[InvisibleSpace]2\/5\[InvisibleSpace]" \
GDP="\[InvisibleSpace]0.2597737456656459`\[InvisibleSpace]" Gini="\
\[InvisibleSpace]0.2228051190674258`\[InvisibleSpace]" growth="\
\[InvisibleSpace]0.018260542549363823`\),
      SequenceForm[ "\[Sigma]=", 
        Rational[ 2, 5], " GDP=", .25977374566564593, 
        " Gini=", .22280511906742581, " growth=", .018260542549363823],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("\[Sigma]="\[InvisibleSpace]1\/2\[InvisibleSpace]" \
GDP="\[InvisibleSpace]0.2596969588011342`\[InvisibleSpace]" Gini="\
\[InvisibleSpace]0.27641609198533734`\[InvisibleSpace]" growth="\
\[InvisibleSpace]0.01701903864859422`\),
      SequenceForm[ "\[Sigma]=", 
        Rational[ 1, 2], " GDP=", .25969695880113419, 
        " Gini=", .27641609198533734, " growth=", .01701903864859422],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("\[Sigma]="\[InvisibleSpace]3\/5\[InvisibleSpace]" \
GDP="\[InvisibleSpace]0.259602145755882`\[InvisibleSpace]" Gini="\
\[InvisibleSpace]0.32867628727266673`\[InvisibleSpace]" growth="\
\[InvisibleSpace]0.015398037299456213`\),
      SequenceForm[ "\[Sigma]=", 
        Rational[ 3, 5], " GDP=", .25960214575588197, 
        " Gini=", .32867628727266673, " growth=", .015398037299456213],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("\[Sigma]="\[InvisibleSpace]7\/10\[InvisibleSpace]" \
GDP="\[InvisibleSpace]0.2595083644086294`\[InvisibleSpace]" Gini="\
\[InvisibleSpace]0.37935725084111155`\[InvisibleSpace]" growth="\
\[InvisibleSpace]0.01355594044033448`\),
      SequenceForm[ "\[Sigma]=", 
        Rational[ 7, 10], " GDP=", .2595083644086294, 
        " Gini=", .37935725084111155, " growth=", .01355594044033448],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("\[Sigma]="\[InvisibleSpace]4\/5\[InvisibleSpace]" \
GDP="\[InvisibleSpace]0.2594321396520908`\[InvisibleSpace]" Gini="\
\[InvisibleSpace]0.428251963821358`\[InvisibleSpace]" growth="\
\[InvisibleSpace]0.011651536894719872`\),
      SequenceForm[ "\[Sigma]=", 
        Rational[ 4, 5], " GDP=", .25943213965209078, 
        " Gini=", .42825196382135799, " growth=", .011651536894719872],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("\[Sigma]="\[InvisibleSpace]9\/10\[InvisibleSpace]" \
GDP="\[InvisibleSpace]0.25938262776709076`\[InvisibleSpace]" Gini="\
\[InvisibleSpace]0.47517737079793027`\[InvisibleSpace]" growth="\
\[InvisibleSpace]0.009787157343846387`\),
      SequenceForm[ "\[Sigma]=", 
        Rational[ 9, 10], " GDP=", .25938262776709076, 
        " Gini=", .47517737079793027, " growth=", .0097871573438463866],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("\[Sigma]="\[InvisibleSpace]1\[InvisibleSpace]" GDP="\
\[InvisibleSpace]0.25936265772759204`\[InvisibleSpace]" Gini="\
\[InvisibleSpace]0.5199764685890028`\[InvisibleSpace]" growth="\
\[InvisibleSpace]0.008011895732116914`\),
      SequenceForm[ 
      "\[Sigma]=", 1, " GDP=", .25936265772759204, 
        " Gini=", .51997646858900282, " growth=", .0080118957321169137],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("\[Sigma]="\[InvisibleSpace]11\/10\[InvisibleSpace]" \
GDP="\[InvisibleSpace]0.2593711878098574`\[InvisibleSpace]" Gini="\
\[InvisibleSpace]0.5625199141983557`\[InvisibleSpace]" growth="\
\[InvisibleSpace]0.006341335509856272`\),
      SequenceForm[ "\[Sigma]=", 
        Rational[ 11, 10], " GDP=", .25937118780985741, 
        " Gini=", .56251991419835567, " growth=", .0063413355098562718],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("\[Sigma]="\[InvisibleSpace]6\/5\[InvisibleSpace]" \
GDP="\[InvisibleSpace]0.2594051861909257`\[InvisibleSpace]" Gini="\
\[InvisibleSpace]0.6027071145768975`\[InvisibleSpace]" growth="\
\[InvisibleSpace]0.004773299178016277`\),
      SequenceForm[ "\[Sigma]=", 
        Rational[ 6, 5], " GDP=", .25940518619092567, 
        " Gini=", .60270711457689752, " growth=", .004773299178016277],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("\[Sigma]="\[InvisibleSpace]13\/10\[InvisibleSpace]" \
GDP="\[InvisibleSpace]0.2594608575738426`\[InvisibleSpace]" Gini="\
\[InvisibleSpace]0.6404667656904319`\[InvisibleSpace]" growth="\
\[InvisibleSpace]0.003297894869481066`\),
      SequenceForm[ "\[Sigma]=", 
        Rational[ 13, 10], " GDP=", .25946085757384257, 
        " Gini=", .64046676569043193, " growth=", .0032978948694810661],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("\[Sigma]="\[InvisibleSpace]7\/5\[InvisibleSpace]" \
GDP="\[InvisibleSpace]0.2595342757432227`\[InvisibleSpace]" Gini="\
\[InvisibleSpace]0.6757568155942462`\[InvisibleSpace]" growth="\
\[InvisibleSpace]0.0019026399377695125`\),
      SequenceForm[ "\[Sigma]=", 
        Rational[ 7, 5], " GDP=", .25953427574322269, 
        " Gini=", .67575681559424616, " growth=", .0019026399377695125],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("\[Sigma]="\[InvisibleSpace]3\/2\[InvisibleSpace]" \
GDP="\[InvisibleSpace]0.25962172141677237`\[InvisibleSpace]" Gini="\
\[InvisibleSpace]0.7085638372158376`\[InvisibleSpace]" growth="\
\[InvisibleSpace]0.0005751131490139283`\),
      SequenceForm[ "\[Sigma]=", 
        Rational[ 3, 2], " GDP=", .25962172141677237, 
        " Gini=", .7085638372158376, " growth=", .00057511314901392829],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("\[Sigma]="\[InvisibleSpace]8\/5\[InvisibleSpace]" \
GDP="\[InvisibleSpace]0.2597198463125645`\[InvisibleSpace]" Gini="\
\[InvisibleSpace]0.7389018123121914`\[InvisibleSpace]" growth="\
\[InvisibleSpace]\(-0.0006958007723332216`\)\),
      SequenceForm[ "\[Sigma]=", 
        Rational[ 8, 5], " GDP=", .25971984631256451, 
        " Gini=", .73890181231219143, " growth=", -.00069580077233322157],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("\[Sigma]="\[InvisibleSpace]17\/10\[InvisibleSpace]" \
GDP="\[InvisibleSpace]0.2598256801393712`\[InvisibleSpace]" Gini="\
\[InvisibleSpace]0.7668103486761397`\[InvisibleSpace]" growth="\
\[InvisibleSpace]\(-0.0019197331439880783`\)\),
      SequenceForm[ "\[Sigma]=", 
        Rational[ 17, 10], " GDP=", .25982568013937118, 
        " Gini=", .76681034867613973, " growth=", -.0019197331439880783],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("\[Sigma]="\[InvisibleSpace]9\/5\[InvisibleSpace]" \
GDP="\[InvisibleSpace]0.25993666230504264`\[InvisibleSpace]" Gini="\
\[InvisibleSpace]0.7923523770630804`\[InvisibleSpace]" growth="\
\[InvisibleSpace]\(-0.0031046027750737393`\)\),
      SequenceForm[ "\[Sigma]=", 
        Rational[ 9, 5], " GDP=", .25993666230504264, 
        " Gini=", .79235237706308037, " growth=", -.0031046027750737393],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("\[Sigma]="\[InvisibleSpace]19\/10\[InvisibleSpace]" \
GDP="\[InvisibleSpace]0.26005061923283385`\[InvisibleSpace]" Gini="\
\[InvisibleSpace]0.8156114003178677`\[InvisibleSpace]" growth="\
\[InvisibleSpace]\(-0.004256735478668117`\)\),
      SequenceForm[ "\[Sigma]=", 
        Rational[ 19, 10], " GDP=", .26005061923283385, 
        " Gini=", .81561140031786772, " growth=", -.0042567354786681166],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("step"\[InvisibleSpace]1\),
      SequenceForm[ "step", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("\[Sigma]="\[InvisibleSpace]2\[InvisibleSpace]" GDP="\
\[InvisibleSpace]0.2601656882868731`\[InvisibleSpace]" \
Gini="\[InvisibleSpace]0.8366883918025393`\[InvisibleSpace]" growth="\
\[InvisibleSpace]\(-0.005381261875954002`\)\),
      SequenceForm[ 
      "\[Sigma]=", 2, " GDP=", .26016568828687309, 
        " Gini=", .83668839180253929, " growth=", -.0053812618759540021],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ss3 = 
        Table[{x, 
            0.03 -  .036\ x}, {x,  .22,  .64,  .06}];\)\), "\
\[IndentingNewLine]", 
    \(plo5 = 
      MultipleListPlot[{ss1, ss2, ss3}, 
        AxesLabel \[Rule] {"\<Gini\>", "\<Growth\>"}, AspectRatio \[Rule] 1, 
        SymbolShape \[Rule] {None, None, None}, 
        PlotLegend \[Rule] {"\<Endog. fertility\>", "\<Exo. fertility\>", \
"\<Barro's reg. slope\>"}, LegendSize \[Rule] {1.3,  .3}, 
        LegendPosition \[Rule] { .4,  .4}, LegendBorder \[Rule] None, 
        AxesOrigin \[Rule] {0, 0}]\)}], "Input"],

Cell[BoxData[
    \(Graphics::"gprim" \(\(:\)\(\ \)\) 
      "\!\(None\) was encountered where a \!\(Graphics\) primitive or \
directive was expected."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74074 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.376543 0.352734 0.37037 0.352734 [
[ 0 0 0 0 ]
[ 1 .74074 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0176367 0.729277 0.723104 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0441076 1.21945 0.210436 34.6809 [
[.19978 .19794 -9 -9 ]
[.19978 .19794 9 0 ]
[.44367 .19794 -9 -9 ]
[.44367 .19794 9 0 ]
[.68756 .19794 -9 -9 ]
[.68756 .19794 9 0 ]
[.93145 .19794 -9 -9 ]
[.93145 .19794 9 0 ]
[1.025 .21044 0 -6.28125 ]
[1.025 .21044 28 6.28125 ]
[-0.05661 .03703 -36 -4.5 ]
[-0.05661 .03703 0 4.5 ]
[-0.05661 .38384 -30 -4.5 ]
[-0.05661 .38384 0 4.5 ]
[-0.05661 .55725 -24 -4.5 ]
[-0.05661 .55725 0 4.5 ]
[-0.05661 .73065 -30 -4.5 ]
[-0.05661 .73065 0 4.5 ]
[-0.05661 .90405 -24 -4.5 ]
[-0.05661 .90405 0 4.5 ]
[-0.04411 1.025 -20 0 ]
[-0.04411 1.025 20 12.5625 ]
[ -0.04411 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.19978 .21044 m
.19978 .21669 L
s
[(0.2)] .19978 .19794 0 1 Mshowa
.44367 .21044 m
.44367 .21669 L
s
[(0.4)] .44367 .19794 0 1 Mshowa
.68756 .21044 m
.68756 .21669 L
s
[(0.6)] .68756 .19794 0 1 Mshowa
.93145 .21044 m
.93145 .21669 L
s
[(0.8)] .93145 .19794 0 1 Mshowa
.125 Mabswid
.26075 .21044 m
.26075 .21419 L
s
.32173 .21044 m
.32173 .21419 L
s
.3827 .21044 m
.3827 .21419 L
s
.50464 .21044 m
.50464 .21419 L
s
.56562 .21044 m
.56562 .21419 L
s
.62659 .21044 m
.62659 .21419 L
s
.74853 .21044 m
.74853 .21419 L
s
.80951 .21044 m
.80951 .21419 L
s
.87048 .21044 m
.87048 .21419 L
s
.13881 .21044 m
.13881 .21419 L
s
.07784 .21044 m
.07784 .21419 L
s
.01686 .21044 m
.01686 .21419 L
s
.99242 .21044 m
.99242 .21419 L
s
.25 Mabswid
0 .21044 m
1 .21044 L
s
gsave
1.025 .21044 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Gini) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
-0.04411 .03703 m
-0.03786 .03703 L
s
[(-0.005)] -0.05661 .03703 1 0 Mshowa
-0.04411 .38384 m
-0.03786 .38384 L
s
[(0.005)] -0.05661 .38384 1 0 Mshowa
-0.04411 .55725 m
-0.03786 .55725 L
s
[(0.01)] -0.05661 .55725 1 0 Mshowa
-0.04411 .73065 m
-0.03786 .73065 L
s
[(0.015)] -0.05661 .73065 1 0 Mshowa
-0.04411 .90405 m
-0.03786 .90405 L
s
[(0.02)] -0.05661 .90405 1 0 Mshowa
.125 Mabswid
-0.04411 .07171 m
-0.04036 .07171 L
s
-0.04411 .10639 m
-0.04036 .10639 L
s
-0.04411 .14107 m
-0.04036 .14107 L
s
-0.04411 .17576 m
-0.04036 .17576 L
s
-0.04411 .24512 m
-0.04036 .24512 L
s
-0.04411 .2798 m
-0.04036 .2798 L
s
-0.04411 .31448 m
-0.04036 .31448 L
s
-0.04411 .34916 m
-0.04036 .34916 L
s
-0.04411 .41852 m
-0.04036 .41852 L
s
-0.04411 .4532 m
-0.04036 .4532 L
s
-0.04411 .48788 m
-0.04036 .48788 L
s
-0.04411 .52256 m
-0.04036 .52256 L
s
-0.04411 .59193 m
-0.04036 .59193 L
s
-0.04411 .62661 m
-0.04036 .62661 L
s
-0.04411 .66129 m
-0.04036 .66129 L
s
-0.04411 .69597 m
-0.04036 .69597 L
s
-0.04411 .76533 m
-0.04036 .76533 L
s
-0.04411 .80001 m
-0.04036 .80001 L
s
-0.04411 .83469 m
-0.04036 .83469 L
s
-0.04411 .86937 m
-0.04036 .86937 L
s
-0.04411 .00235 m
-0.04036 .00235 L
s
-0.04411 .93874 m
-0.04036 .93874 L
s
-0.04411 .97342 m
-0.04036 .97342 L
s
.25 Mabswid
-0.04411 0 m
-0.04411 1 L
s
gsave
-0.04411 1.025 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Growth) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.02468 .90082 m
.09312 .89079 L
.16087 .87275 L
.22759 .84373 L
.29297 .80067 L
.3567 .74445 L
.4185 .68057 L
.47812 .61452 L
.53535 .54986 L
.58998 .4883 L
.64186 .43036 L
.69086 .37598 L
.73691 .32481 L
.77994 .27642 L
.81995 .23038 L
.85694 .18631 L
.89098 .14386 L
.92213 .10277 L
.95049 .06281 L
.97619 .02381 L
s
[ .5 3 ] 0 Mabsdash
.02381 .90326 m
.09138 .90086 L
.15827 .89688 L
.22415 .89131 L
.2887 .88416 L
.35162 .87543 L
.41264 .86517 L
.47153 .85345 L
.52809 .8404 L
.58216 .82615 L
.63361 .81085 L
.68232 .79459 L
.72823 .77746 L
.77127 .75949 L
.81141 .74072 L
.84865 .72118 L
.88302 .70088 L
.91458 .67986 L
.9434 .65816 L
.96959 .63583 L
s
[ .5 4 5 4 ] 0 Mabsdash
.22417 .97619 m
.29734 .90128 L
.3705 .82637 L
.44367 .75146 L
.51684 .67655 L
.59001 .60164 L
.66317 .52673 L
.73634 .45182 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 g
.51764 .51146 m
.51764 .61728 L
.97619 .61728 L
.97619 .51146 L
F
1 g
.51764 .51146 m
.51764 .61728 L
.97619 .61728 L
.97619 .51146 L
F
.5 Mabswid
[ ] 0 setdash
.51764 .51146 m
.97619 .51146 L
.97619 .61728 L
.51764 .61728 L
.51764 .51146 L
s
% Start of sub-graphic
p
0.517637 0.511464 0.97619 0.617284 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0062709 0.062709 [
[ 0 0 0 0 ]
[ 1 .23077 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .23077 L
0 .23077 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0112876 0.35119 0.0739967 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.00432 w
[ .5 4 5 4 ] 0 Mabsdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .04264 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Barro) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(') show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
111.000 12.813 moveto
(reg) show
129.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
141.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(slope) show
171.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.0840301 0.35119 0.146739 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.00432 w
[ .5 3 ] 0 Mabsdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .11538 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Exo) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(fertility) show
147.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.156773 0.35119 0.219482 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.00432 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .18813 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Endog) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(fertility) show
159.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .74074 L
0 .74074 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{564.875, 418.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008d0001XQ000`40O003h00Oogooogoo=Woo003o
OoooOolfOol00?mooomoocIoo`00ogooogoo=Woo003oOoooOolfOol00?mooomoocIoo`00ogooogoo
=Woo003oOoooOolfOol00?mooomoocIoo`00ogooogoo=Woo003oOoooOolfOol00?mooomoocIoo`00
ogooogoo=Woo003oOoooOolfOol00?mooomoocIoo`00ogooogoo=Woo003oOoooOolfOol00?mooomo
ocIoo`00ogooogoo=Woo003oOoooOolfOol00?mooomoocIoo`00ogooogoo=Woo003oOoooOolfOol0
0?mooomoocIoo`00ogooogoo=Woo003oOoooOolfOol00?mooomoocIoo`00ogooogoo=Woo003oOooo
OolfOol00?mooomoocIoo`00ogooogoo=Woo003oOoooOolfOol00?mooomoocIoo`00ogooogoo=Woo
003oOoooOolfOol00?mooomoocIoo`00ogooogoo=Woo003oOoooOolfOol00?mooomoocIoo`00ogoo
ogoo=Woo003oOoooOolfOol00?mooomoocIoo`00ogooogoo=Woo003oOoooOolfOol003Eoo`03001o
ogoo0?moooeoo`00=Goo0P00ogoooWoo000eOol00`00Oomoo`3oOoomOol003Eoo`03001oogoo0?mo
ooeoo`00=Goo00<007ooOol0ogoooGoo000eOol00`00Oomoo`3oOoomOol003Eoo`03001oogoo0?mo
ooeoo`00=Goo00<007ooOol0ogoooGoo000eOol00`00Oomoo`3oOoliOol00`00Oomoo`31Ool003Eo
o`03001oogoo0?moocQoo`03001oogoo0<9oo`005Goo0P0017oo0P0017oo0P0017oo0P0017oo0P00
1Woo00<007ooOol0ogoo>7oo00<007ooOol0`Woo000DOol01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0ogoo=goo00<007ooOol0`goo000DOol0
1000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`03Ool3003oOolfOol0
0`00Oomoo`34Ool000ioo`@0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000=o
o`8000Ioo`03001oogoo0?moocIoo`03001oogoo0<Aoo`0057oo00@007ooOol000Qoo`04001oogoo
0002Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0ogoo=Goo00<007ooOol0aGoo000E
Ool2000:Ool20004Ool20004Ool30005Ool00`00Oomoo`3oOoldOol00`00Oomoo`36Ool003Eoo`03
001oogoo0?moocAoo`03001oogoo0<Ioo`00=Goo00<007ooOol0ogoo<goo00<007ooOol0agoo000e
Ool00`00Oomoo`3oOolbOol00`00Oomoo`38Ool003Eoo`03001oogoo0?mooc9oo`03001oogoo0<Qo
o`00=Goo00<007ooOol0ogoo<Goo00<007ooOol0bGoo000eOol00`00Oomoo`3oOol`Ool00`00Oomo
o`3:Ool003Eoo`03001oogoo0?moobmoo`03001oogoo0<]oo`00=Goo0P00ogoo<7oo00<007ooOol0
bgoo000eOol00`00Oomoo`3oOol^Ool00`00Oomoo`3<Ool003Eoo`03001oogoo0?moobeoo`03001o
ogoo0<eoo`00=Goo00<007ooOol0ogoo;7oo00<007ooOol0cWoo000eOol00`00Oomoo`3oOol/Ool0
0`00Oomoo`3>Ool003Eoo`03001oogoo0?moob]oo`03001oogoo0<moo`00=Goo00<007ooOol0ogoo
:Woo00<007ooOol0d7oo000eOol00`00Oomoo`3oOolYOol00`00Oomoo`3AOol003Eoo`03001oogoo
0?moobUoo`03001oogoo0=5oo`00=Goo00<007ooOol0ogoo:7oo00<007ooOol0dWoo000eOol2003o
OolXOol00`00Oomoo`3COol003Eoo`03001oogoo0?moobIoo`03001oogoo0=Aoo`00=Goo00<007oo
Ool0ogoo9Woo00<007ooOol0e7oo000eOol00`00Oomoo`3oOolUOol00`00Oomoo`3EOol003Eoo`03
001oogoo0?moobAoo`03001oogoo0=Ioo`00=Goo00<007ooOol0ogoo8goo00<007ooOol0egoo000e
Ool00`00Oomoo`3oOolSOol00`00Oomoo`3GOol003Eoo`03001oogoo0?moob9oo`03001oogoo0=Qo
o`00=Goo00<007ooOol0ogoo8Goo00<007ooOol0fGoo000eOol00`00Oomoo`3oOolPOol00`00Oomo
o`3JOol003Eoo`03001oogoo0?moob1oo`03001oogoo0=Yoo`00=Goo0P00ogoo87oo00<007ooOol0
fgoo000eOol00`00Oomoo`3oOolNOol00`00Oomoo`3LOol003Eoo`03001oogoo0?mooaeoo`03001o
ogoo0=eoo`00=Goo00<007ooOol0ogoo77oo00<007ooOol0gWoo000eOol00`00Oomoo`3oOolLOol0
0`00Oomoo`3NOol003Eoo`03001oogoo0?mooa]oo`03001oogoo0=moo`00=Goo00<007ooOol0ogoo
6Woo00<007ooOol0h7oo000eOol00`00Oomoo`3oOolIOol00`00Oomoo`3QOol003Eoo`03001oogoo
0?mooaUoo`03001oogoo0>5oo`00=Goo00<007ooOol0ogoo67oo00<007ooOol0hWoo000eOol00`00
Oomoo`11Ool20004Ool20003Ool4000lOol20004Ool20005Ool3000lOol20004Ool20003Ool3000`
Ool00`00Oomoo`0:Ool20004Ool20004Ool2003;Ool003Eoo`80045oo`04001oogoo0008Ool00`00
Oomoo`0lOol01000Oomoo`002goo00<007ooOol0>Woo00@007ooOol000Qoo`04001oogoo000^Ool0
0`00Oomoo`0:Ool01000Oomoo`0027oo00@007ooOol00<Yoo`00=Goo00<007ooOol0@7oo00@007oo
Ool000Uoo`03001oogoo03]oo`04001oogoo0008Ool5000kOol01000Oomoo`0027oo00@007ooOol0
02ioo`03001oogoo00Yoo`04001oogoo0008Ool01000Oomoo`00bWoo000eOol00`00Oomoo`10Ool0
1000Oomoo`002Woo00<007ooOol0>Woo00@007ooOol000Qoo`04001oogoo000lOol01000Oomoo`00
27oo0`00;Woo00<007ooOol02goo00@007ooOol000Uoo`800<]oo`00=Goo00<007ooOol0@7oo00@0
07ooOol000Qoo`04001oogoo000kOol01000Oomoo`002Goo00<007oo0000?7oo00@007ooOol000Uo
o`03001oogoo02aoo`03001oogoo00aoo`04001oogoo0008Ool01000Oomoo`00bWoo000eOol00`00
Oomoo`11Ool2000:Ool2000mOol2000;Ool2000mOol2000:Ool3000[Ool00`00Oomoo`0>Ool2000:
Ool2003;Ool003Eoo`03001oogoo0?mooa9oo`03001oogoo0>Qoo`00=Goo00<007ooOol0ogoo4Goo
00<007ooOol0jGoo000eOol00`00Oomoo`3oOolAOol00`00Oomoo`3YOol003Eoo`03001oogoo0?mo
oa1oo`03001oogoo0>Yoo`00=Goo00<007ooOol0ogoo3goo00<007ooOol0>Woo0P0017oo0`0000=o
o`0000000Woo0P000Woo0`00W7oo000eOol00`00Oomoo`0;Oooo000f000:Ool01000Oomoo`0017oo
00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo09]oo`00=Goo00<007ooOol047oo00<0
07ooOol047oo00<007ooOol03goo00<007ooOol047oo00<007ooOol047oo00<007ooOol047oo00<0
07ooOol047oo00<007ooOol03goo00<007ooOol047oo00<007ooOol047oo00<007ooOol047oo00<0
07ooOol047oo00<007ooOol03goo00<007ooOol047oo00<007ooOol01Goo00<007ooOol027oo00<0
07ooOol047oo00<007ooOol047oo00<007ooOol02Woo00<007oo00000P000goo00D007ooOomoo`00
009oo`03001oogoo009oo`03001oogoo09]oo`00=Goo00<007ooOol047oo00<007ooOol047oo00<0
07ooOol03goo00<007ooOol047oo00<007ooOol047oo00<007ooOol047oo00<007ooOol047oo00<0
07ooOol03goo00<007ooOol047oo00<007ooOol047oo00<007ooOol047oo00<007ooOol047oo00<0
07ooOol03goo00<007ooOol047oo00<007ooOol017oo00<007ooOol02Goo00<007ooOol047oo00<0
07ooOol047oo00<007ooOol02Woo00<007ooOol017oo0P000Woo100017oo0P00WGoo000eOol00`00
Oomoo`3oOol;Ool00`00Oomoo`0mOol00`00Oomoo`2_Ool003Eoo`03001oogoo0?moo`]oo`03001o
ogoo03ioo`<000Aoo`03001oogoo00Uoo`03001oogoo09]oo`00=Goo00<007ooOol0ogoo2Woo00<0
07ooOol0l7oo000eOol00`00Oomoo`3oOol9Ool00`00Oomoo`3aOol003Eoo`03001oogoo0?moo`Qo
o`03001oogoo0?9oo`00=Goo00<007ooOol0ogoo1goo00<007ooOol0lgoo000eOol00`00Oomoo`3o
Ool6Ool00`00Oomoo`3dOol003Eoo`03001oogoo0?moo`Eoo`03001oogoo0?Eoo`00=Goo0P00ogoo
1Woo00<007ooOol0mGoo000eOol00`00Oomoo`3oOol4Ool00`00Oomoo`3fOol003Eoo`03001oogoo
0?moo`=oo`03001oogoo0?Moo`00=Goo00<007ooOol0ogoo0Woo00<007ooOol0n7oo000eOol00`00
Oomoo`3oOol1Ool00`00Oomoo`3iOol003Eoo`03001oogoo0?moo`03001oogoo0?Yoo`00=Goo00<0
07ooOol0oWoo00<007ooOol0ngoo000eOol00`00Oomoo`3nOol00`00Oomoo`3kOol003Eoo`03001o
ogoo0?eoo`03001oogoo0?aoo`00=Goo00<007ooOol0o7oo00<007ooOol0oGoo000eOol00`00Oomo
o`3kOol00`00Oomoo`3nOol003Eoo`800?]oo`03001oogoo0?moo`00=Goo00<007ooOol0nGoo00<0
07ooOol0ogoo0Goo000eOol00`00Oomoo`3hOol00`00Oomoo`3oOol2Ool003Eoo`03001oogoo0?Qo
o`03001oogoo0?moo`9oo`00=Goo00<007ooOol0mgoo00<007ooOol0ogoo0goo000eOol00`00Oomo
o`3fOol00`00Oomoo`3oOol4Ool003Eoo`03001oogoo0?Eoo`03001oogoo0?moo`Eoo`00=Goo00<0
07ooOol0m7oo00<007ooOol0ogoo1Woo000eOol00`00Oomoo`3cOol00`00Oomoo`3oOol7Ool003Eo
o`03001oogoo0?9oo`03001oogoo0?moo`Qoo`00=Goo0P00lWoo00<007ooOol0ogoo2Goo000eOol0
0`00Oomoo`3aOol00`00Oomoo`3oOol9Ool003Eoo`03001oogoo0?1oo`03001oogoo0?moo`Yoo`00
=Goo00<007ooOol0kgoo00<007ooOol0ogoo2goo000eOol00`00Oomoo`3^Ool00`00Oomoo`3oOol<
Ool003Eoo`03001oogoo0>eoo`03001oogoo0?moo`eoo`00=Goo00<007ooOol0k7oo00<007ooOol0
ogoo3Woo000eOol00`00Oomoo`3[Ool00`00Oomoo`3oOol?Ool003Eoo`03001oogoo0>Yoo`03001o
ogoo0?mooa1oo`00=Goo00<007ooOol0jGoo00<007ooOol0ogoo4Goo000eOol00`00Oomoo`3XOol0
0`00Oomoo`3oOolBOol003Eoo`800>Qoo`03001oogoo0?mooa=oo`00=Goo00<007ooOol0igoo00<0
07ooOol0ogoo4goo000eOol00`00Oomoo`3VOol00`00Oomoo`3oOolDOol003Eoo`03001oogoo0>Eo
o`03001oogoo0?mooaEoo`00=Goo00<007ooOol0i7oo00<007ooOol0ogoo5Woo000eOol00`00Oomo
o`3SOol00`00Oomoo`3oOolGOol003Eoo`03001oogoo0>9oo`03001oogoo0?mooaQoo`00=Goo00<0
07ooOol0hGoo00<007ooOol0ogoo6Goo000eOol00`00Oomoo`3POol00`00Oomoo`3oOolJOol001Eo
o`8000Aoo`8000Aoo`8000Aoo`8000Aoo`8000Ioo`03001oogoo0=moo`03001oogoo0?mooa]oo`00
57oo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo0=ioo`03001oogoo0?mooaaoo`0057oo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomo
o`001Goo00<007ooOol00goo0`00gGoo00<007ooOol0ogoo7Goo000DOol01000Oomoo`0027oo00@0
07ooOol0009oo`04001oogoo0003Ool20006Ool00`00Oomoo`3LOol00`00Oomoo`3oOolNOol001Ao
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
0=]oo`03001oogoo0?mooamoo`005Goo0P002Woo0P0017oo0P0017oo0`001Goo00<007ooOol0fWoo
00<007ooOol0ogoo87oo000eOol00`00Oomoo`3IOol00`00Oomoo`3oOolQOol003Eoo`03001oogoo
0=Qoo`03001oogoo0?moob9oo`00=Goo00<007ooOol0f7oo00<007ooOol0ogoo8Woo000eOol00`00
Oomoo`3GOol00`00Oomoo`3oOolSOol003Eoo`03001oogoo0=Ioo`03001oogoo0?moobAoo`00=Goo
00<007ooOol0eGoo00<007ooOol0ogoo9Goo000eOol00`00Oomoo`3DOol00`00Oomoo`3oOolVOol0
03Eoo`800=Aoo`03001oogoo0?moobMoo`00=Goo00<007ooOol0dWoo00<007ooOol0ogoo:7oo000e
Ool00`00Oomoo`3AOol00`00Oomoo`3oOolYOol003Eoo`03001oogoo0=1oo`03001oogoo0?moobYo
o`00=Goo00<007ooOol0cgoo00<007ooOol0ogoo:goo000eOol00`00Oomoo`3>Ool00`00Oomoo`3o
Ool/Ool003Eoo`03001oogoo0<eoo`03001oogoo0?moobeoo`00=Goo00<007ooOol0c7oo00<007oo
Ool0ogoo;Woo000eOol00`00Oomoo`3<Ool00`00Oomoo`3oOol^Ool003Eoo`03001oogoo0<]oo`03
001oogoo0?moobmoo`00=Goo0P00bgoo00<007ooOol087oo00<007ooOol0ogoo3Goo000eOol00`00
Oomoo`39Ool00`00Oomoo`0POol00`00Oomoo`3oOol>Ool003Eoo`03001oogoo0<Qoo`03001oogoo
021oo`03001oogoo0?moo`moo`00=Goo00<007ooOol0agoo00<007ooOol08Goo00<007ooOol0ogoo
3goo000eOol00`00Oomoo`36Ool00`00Oomoo`0QOol00`00Oomoo`3oOol@Ool003Eoo`03001oogoo
0<Eoo`03001oogoo0?moocEoo`00=Goo00<007ooOol0a7oo00<007ooOol0ogoo=Woo000eOol00`00
Oomoo`34Ool00`00Oomoo`0POol00`00Oomoo`3oOolCOol003Eoo`03001oogoo0<=oo`03001oogoo
0?moocMoo`00=Goo00<007ooOol0`Woo00<007ooOol0ogoo>7oo000eOol00`00Oomoo`31Ool00`00
Oomoo`0POol00`00Oomoo`3oOolFOol003Eoo`800<5oo`03001oogoo021oo`03001oogoo0?mooaMo
o`00=Goo00<007ooOol0_goo00<007ooOol07goo0P00ogoo6Woo000eOol00`00Oomoo`2nOol00`00
Oomoo`0OOol00`00Oomoo`3oOolJOol003Eoo`03001oogoo0;eoo`03001oogoo0?mooceoo`00=Goo
00<007ooOol0_Goo00<007ooOol0ogoo?Goo000eOol00`00Oomoo`2lOol00`00Oomoo`0NOol00`00
Oomoo`3oOolMOol003Eoo`03001oogoo0;]oo`03001oogoo01moo`03001oogoo0?mooaeoo`00=Goo
00<007ooOol0^Woo00<007ooOol0ogoo@7oo000eOol00`00Oomoo`2iOol00`00Oomoo`3oOom1Ool0
03Eoo`03001oogoo0;Qoo`03001oogoo01moo`03001oogoo0?moob1oo`00=Goo00<007ooOol0^7oo
00<007ooOol07Woo00<007ooOol0ogoo8Goo000eOol2002hOol00`00Oomoo`0NOol00`00Oomoo`3o
OolROol003Eoo`03001oogoo0;Ioo`03001oogoo01ioo`03001oogoo0?moob=oo`00=Goo00<007oo
Ool0]Goo00<007ooOol0ogooAGoo000eOol00`00Oomoo`2dOol00`00Oomoo`3oOom6Ool003Eoo`03
001oogoo0;=oo`03001oogoo01ioo`03001oogoo0?moobIoo`00=Goo00<007ooOol0/goo00<007oo
Ool0ogooAgoo000eOol00`00Oomoo`2bOol00`00Oomoo`3oOom8Ool003Eoo`03001oogoo0;5oo`03
001oogoo01eoo`03001oogoo0?moobUoo`006goo0P0017oo0P0017oo0P000goo1@0017oo00<007oo
Ool0/7oo00<007ooOol07Goo00<007ooOol0ogoo:Woo000JOol01000Oomoo`0027oo00@007ooOol0
00Aoo`03001oogoo00Aoo`03001oogoo0:moo`03001oogoo01eoo`03001oogoo0?moob]oo`006Woo
00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`04Ool3002^Ool00`00Oomoo`0MOol00`00
Oomoo`3oOol/Ool001Yoo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol017oo00<007oo
Ool0[Goo00<007ooOol07Goo00<007ooOol0ogoo;Goo000JOol01000Oomoo`0027oo00@007ooOol0
00Aoo`03001oogoo00Aoo`03001oogoo0:aoo`03001oogoo0?moodioo`006goo0P002Woo0P0017oo
0P001Woo00<007ooOol0Zgoo00<007ooOol0ogooCgoo000eOol00`00Oomoo`2[Ool00`00Oomoo`0L
Ool2003oOolaOol003Eoo`03001oogoo0:Yoo`03001oogoo0?mooe1oo`00=Goo00<007ooOol0ZGoo
00<007ooOol0ogooDGoo000eOol00`00Oomoo`2XOol00`00Oomoo`0LOol00`00Oomoo`3oOolcOol0
03Eoo`03001oogoo0:Moo`03001oogoo01aoo`03001oogoo0?moocAoo`00=Goo00<007ooOol0YWoo
00<007ooOol077oo00<007ooOol0ogoo=Goo000eOol00`00Oomoo`2UOol00`00Oomoo`0LOol00`00
Oomoo`3oOolfOol003Eoo`800:Eoo`03001oogoo0?mooeIoo`00=Goo00<007ooOol0Xgoo00<007oo
Ool0ogooEgoo000eOol00`00Oomoo`2ROol00`00Oomoo`0LOol00`00Oomoo`3oOoliOol003Eoo`03
001oogoo0:9oo`03001oogoo01aoo`03001oogoo0?moocUoo`00=Goo00<007ooOol0XGoo00<007oo
Ool0ogooFGoo000eOol00`00Oomoo`2POol00`00Oomoo`3oOomJOol003Eoo`03001oogoo09moo`03
001oogoo01aoo`03001oogoo0?moocaoo`00=Goo00<007ooOol0WWoo00<007ooOol077oo00<007oo
Ool0ogoo?Goo000eOol00`00Oomoo`2MOol00`00Oomoo`0LOol00`00Oomoo`3oOolnOol003Eoo`03
001oogoo09aoo`03001oogoo01aoo`03001oogoo0?moocmoo`00=Goo00<007ooOol0Vgoo00<007oo
Ool0ogooGgoo000eOol2002KOol00`00Oomoo`3oOomPOol003Eoo`03001oogoo09Uoo`03001oogoo
01]oo`800?moodAoo`00=Goo00<007ooOol0VGoo00<007ooOol0ogooHGoo000eOol00`00Oomoo`2H
Ool00`00Oomoo`2JOol00`00Oomoo`34Ool003Eoo`03001oogoo09Moo`03001oogoo01]oo`03001o
ogoo0?moodEoo`00=Goo00<007ooOol0UWoo00<007ooOol06goo00<007ooOol0Ngoo0P00b7oo000e
Ool00`00Oomoo`2EOol00`00Oomoo`0KOol00`00Oomoo`3oOom7Ool003Eoo`03001oogoo09Aoo`03
001oogoo01]oo`03001oogoo07]oo`03001oogoo0<Uoo`00=Goo00<007ooOol0Tgoo00<007ooOol0
6goo00<007ooOol0O7oo00<007ooOol0bGoo000eOol00`00Oomoo`2BOol00`00Oomoo`2HOol2003=
Ool003Eoo`80099oo`03001oogoo09Uoo`03001oogoo0<aoo`00=Goo00<007ooOol0T7oo00<007oo
Ool06goo00<007ooOol0ogooC7oo000eOol00`00Oomoo`2@Ool00`00Oomoo`2GOol2003@Ool003Eo
o`03001oogoo08moo`03001oogoo0?moof]oo`00=Goo00<007ooOol0SWoo00<007ooOol06Woo00<0
07ooOol0NGoo0P00dgoo000eOol00`00Oomoo`2=Ool00`00Oomoo`0JOol00`00Oomoo`3oOom@Ool0
03Eoo`03001oogoo08aoo`03001oogoo01Yoo`03001oogoo07Uoo`03001oogoo0=Aoo`00=Goo00<0
07ooOol0Rgoo00<007ooOol06Woo00<007ooOol0ogooDWoo000eOol00`00Oomoo`2:Ool00`00Oomo
o`2EOol00`00Oomoo`3GOol003Eoo`03001oogoo08Uoo`03001oogoo0?moog5oo`00=Goo00<007oo
Ool0R7oo00<007ooOol06Woo00<007ooOol0Mgoo00<007ooOol0fWoo000eOol20028Ool00`00Oomo
o`0KOol00`00Oomoo`3oOomEOol003Eoo`03001oogoo08Ioo`03001oogoo09=oo`03001oogoo0=eo
o`00=Goo00<007ooOol0QGoo00<007ooOol06Woo00<007ooOol0M7oo00<007ooOol0h7oo000eOol0
0`00Oomoo`24Ool00`00Oomoo`0JOol00`00Oomoo`1eOol00`00Oomoo`3POol003Eoo`03001oogoo
08=oo`03001oogoo01Yoo`03001oogoo07=oo`03001oogoo0>=oo`00=Goo00<007ooOol0PWoo00<0
07ooOol06Woo00<007ooOol0M7oo00<007ooOol0hgoo000eOol00`00Oomoo`22Ool00`00Oomoo`0I
Ool00`00Oomoo`1bOol00`00Oomoo`3VOol003Eoo`03001oogoo085oo`03001oogoo0?moogUoo`00
=Goo00<007ooOol0P7oo00<007ooOol0SGoo00<007ooOol0jGoo000EOol20004Ool20004Ool20003
Ool50002Ool20006Ool00`00Oomoo`1oOol00`00Oomoo`0IOol00`00Oomoo`1_Ool00`00Oomoo`3/
Ool001Aoo`04001oogoo0008Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`03001oogoo00=o
o`03001oogoo07ioo`03001oogoo08aoo`03001oogoo0>aoo`0057oo00@007ooOol000Qoo`04001o
ogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`03Ool3001mOol00`00Oomoo`2:Ool00`00Oomoo`3_
Ool001Aoo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol00Woo0P001Woo00<007ooOol0
O7oo00<007ooOol06Goo00<007ooOol0ogooHWoo000DOol01000Oomoo`0027oo00@007ooOol000Ao
o`03001oogoo009oo`03001oogoo00Eoo`03001oogoo07]oo`03001oogoo01Uoo`03001oogoo06eo
o`03001oogoo0?9oo`005Goo0P002Woo0P0017oo0P0017oo0`001Goo00<007ooOol0NWoo00<007oo
Ool06Goo00<007ooOol0Jgoo00<007ooOol0mGoo000eOol00`00Oomoo`1iOol00`00Oomoo`0JOol0
0`00Oomoo`1[Ool00`00Oomoo`3eOol003Eoo`03001oogoo07Qoo`03001oogoo01Yoo`03001oogoo
06Qoo`800?Yoo`00=Goo00<007ooOol0Mgoo00<007ooOol0Pgoo0P00oGoo000eOol00`00Oomoo`1e
Ool2003oOon6Ool003Eoo`03001oogoo07Aoo`03001oogoo01]oo`03001oogoo06Eoo`03001oogoo
0?moo`00=Goo00<007ooOol0Lgoo00<007ooOol0PGoo00<007ooOol0ogoo0goo000eOol2001cOol0
0`00Oomoo`3oOon8Ool003Eoo`03001oogoo075oo`03001oogoo01]oo`03001oogoo069oo`03001o
ogoo0?moo`Ioo`00=Goo00<007ooOol0L7oo00<007ooOol06goo00<007ooOol0Ggoo0P00ogoo2goo
000eOol00`00Oomoo`1^Ool2000LOol2001OOol2003oOol>Ool003Eoo`03001oogoo06eoo`03001o
ogoo01]oo`03001oogoo0?moofmoo`00=Goo00<007ooOol0K7oo00<007ooOol0Ngoo00<007ooOol0
ogoo47oo000eOol00`00Oomoo`1[Ool00`00Oomoo`1iOol00`00Oomoo`3oOolCOol003Eoo`03001o
ogoo06Yoo`03001oogoo01aoo`03001oogoo05Moo`800?mooaQoo`00=Goo00<007ooOol0J7oo0P00
7Woo00<007ooOol0EGoo00<007ooOol0ogoo6Woo000eOol00`00Oomoo`1WOol00`00Oomoo`1cOol0
0`00Oomoo`3oOolMOol003Eoo`03001oogoo06Ioo`03001oogoo01aoo`03001oogoo05Eoo`03001o
ogoo0?mooaeoo`00=Goo0P00IWoo00<007ooOol077oo00<007ooOol0DWoo0P00ogoo8Woo000eOol0
0`00Oomoo`1SOol2000NOol00`00Oomoo`1@Ool2003oOolUOol003Eoo`03001oogoo069oo`03001o
ogoo01ioo`03001oogoo04eoo`03001oogoo0?moobMoo`00=Goo00<007ooOol0HGoo00<007ooOol0
7Woo00<007ooOol0BWoo0P00ogoo;7oo000eOol00`00Oomoo`1OOol2001[Ool2003oOol_Ool003Eo
o`03001oogoo05ioo`03001oogoo06Qoo`03001oogoo0<=oo`<0021oo`<004Moo`00=Goo00<007oo
Ool0G7oo0P008Goo00<007ooOol0@goo0P00bgoo00<007ooOol07Woo00<007ooOol0AWoo000eOol0
0`00Oomoo`1KOol00`00Oomoo`1TOol2002>Ool40003Ool500000goo000000020002Ool40003Ool2
0009Ool30009Ool40003Ool30003Ool30003Ool20009Ool30003Ool30004Ool20003Ool30004Ool3
000oOol003Eoo`03001oogoo05Uoo`8006Aoo`03001oogoo05Ioo`04001oogooOol60003Ool2000/
Ool01000Oomoo`000Woo10000goo00<007ooOol00goo00<007ooOol00Woo00@007ooOol000]oo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo00=oo`04001oogoo000AOol01@00Oomoogoo0000
17oo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`10Ool003Eoo`03001oogoo05Qoo`03
001oogoo025oo`03001oogoo03aoo`8009Ioo`04001oogoo0005Ool01@00Oomoogoo00001Goo00<0
07ooOol00Woo00@007ooOol000Qoo`<000Yoo`03001oogoo009oo`@0009oo`04001oogoo000>Ool3
0004Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0009oo`@003moo`00=Goo00<007oo
Ool0Egoo00<007ooOol08Goo00<007ooOol0>Woo00<007ooOol0V7oo0`0017oo0`000Woo10000Woo
10000goo0P001Goo00@007ooOomoo`@000Qoo`@000=oo`8000Aoo`@000eoo`@000=oo`03001oogoo
00=oo`80009oo`@000Aoo`80041oo`00=Goo0P00EWoo0P008goo00<007ooOol0>7oo00<007ooOol0
Vgoo00@007ooOol001aoo`03001oogoo039oo`03001oogoo055oo`00=Goo00<007ooOol0E7oo00<0
07ooOol08goo00<007ooOol0<Goo00<007ooOol00P00Wgoo10007Goo00<007ooOol0<Goo0P00Dgoo
000eOol00`00Oomoo`1BOol2000UOol00`00Oomoo`0^Ool20002Ool00`00Oomoo`3oOom<Ool003Eo
o`03001oogoo051oo`8005Eoo`03001oogoo0?mooe=oo`00=Goo00<007ooOol0CWoo0P00E7oo00<0
07ooOol0ogooEWoo000eOol00`00Oomoo`1<Ool2000WOol2000VOol00`00Oomoo`02003oOomKOol0
03Eoo`03001oogoo04Uoo`<004eoo`80009oo`03001oogoo0?mooeeoo`00=Goo00<007ooOol0Agoo
0P00BWoo00@007ooOol00?moofIoo`00=Goo00<007ooOol0AGoo0P00;7oo00<007ooOol06Goo0P00
00=oo`00Ool0ogooJGoo000eOol00`00Oomoo`12Ool3000]Ool00`00Oomoo`0DOol01000Oomoo`00
ogooL7oo000eOol00`00Oomoo`10Ool2000^Ool2000COol01000Oomoo`00ogooM7oo000eOol2000o
Ool2000_Ool00`00Oomoo`0<Ool00`00Oomoo`02003oOomjOol003Eoo`03001oogoo03Yoo`@003Uo
o`03001oogoo00800?mooh5oo`00=Goo00<007ooOol0=Woo1000=Woo00<007ooOol00P000Woo00<0
07ooOol0ogoo:7oo0P00FGoo000eOol00`00Oomoo`0bOol4000cOol200000goo0000003oOoleOol0
0`00Oomoo`1GOol003Eoo`03001oogoo02ioo`@0031oo`80009oo`03001oogoo00=oo`03001oogoo
0>=oo`D00004Ool00000Ool20003Ool20004Ool20009Ool40003Ool30002Ool40003Ool20004Ool3
0002Ool30004Ool30003Ool20005Ool00`00Oomoo`1FOol003Eoo`03001oogoo02Yoo`@002Yoo`03
001oogoo0080009oo`03001oogoo0;Ioo`03001oogoo0080009oo`03001oogoo0080009oo`03001o
ogoo02Yoo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`003goo00<007ooOol00Woo00<0
07ooOol017oo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo00Aoo`05
001oogooOol00002Ool01`00Oomoogoo001oo`0005Moo`00=Goo00<007ooOol097oo1P009goo00<0
07ooOol00P004goo00<007ooOol0igoo00<007ooOol017oo00<007ooOol00Woo00@007ooOol000mo
o`03001oogoo009oo`@000=oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`03001o
ogoo00Aoo`05001oogooOol00005Ool01000Oomoo`00Egoo000eOol00`00Oomoo`0MOol7000OOol0
0`00Oomoo`020002Ool00`00Oomoo`02000IOol00`00Oomoo`3XOol20003Ool200000goo00000003
Ool2000?Ool40003Ool20003Ool400000goo000000030003Ool20004Ool00`00Oomoo`03Ool20002
Ool500001Goo00000000Ool00P00EWoo000KOol20004Ool20004Ool20003Ool40005Ool00`00Oomo
o`0FOol7000HOol00`00Oomoo`020002Ool00`00Oomoo`02000VOol00`00Oomoo`3YOol01000Oomo
o`006goo00<007ooOol03Woo00<007ooOol02Woo00<007ooOol027oo00<007ooOol0GWoo000JOol0
1000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00Ioo`03001oogoo019oo`@000eoo`80009o
o`03001oogoo0080009oo`03001oogoo008003=oo`03001oogoo0>Uoo`D001aoo`8001Ioo`04001o
ogooOol20006Ool00`00Oomoo`1ROol001Yoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool01Goo0`004Woo00<007ooOol00P000Woo00<007ooOol00P000Woo00<007ooOol0@goo00<007oo
Ool0ogooU7oo000JOol01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo00Aoo`03001oogoo
0?moooeoo`006Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol0
ogoooGoo000KOol2000:Ool20004Ool20006Ool00`00Oomoo`1ROol2003oOonIOol003Eoo`03001o
ogoo0?moooeoo`00=Goo00<007ooOol0ogoooGoo000eOol00`00Oomoo`1POol00`00Oomoo`3oOonJ
Ool003Eoo`03001oogoo05moo`03001oogoo0?mooi]oo`00=Goo00<007ooOol0GWoo00<007ooOol0
ogooW7oo000eOol00`00Oomoo`1MOol00`00Oomoo`3oOonMOol003Eoo`03001oogoo05aoo`03001o
ogoo0?moo`eoo`<003moo`8004eoo`00=Goo0P00ogooL7oo00<007ooOol0?Goo00<007ooOol0Bgoo
000eOol00`00Oomoo`3oOomCOol500000goo00000002Ool20002Ool40002Ool20004Ool30003Ool2
0009Ool40003Ool30002Ool40003Ool20004Ool30002Ool30004Ool30003Ool20005Ool00`00Oomo
o`1:Ool003Eoo`03001oogoo05Uoo`03001oogoo0?Moo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`003goo00<007ooOol00Woo00<007ooOol0
17oo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo00Aoo`05001oogoo
Ool00002Ool01`00Oomoogoo001oo`0004]oo`00=Goo00<007ooOol0ogoo6Goo4@00:Woo00<007oo
Ool00goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000moo`03
001oogoo009oo`@000=oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo
00Aoo`05001oogooOol00005Ool01000Oomoo`00Bgoo000eOol00`00Oomoo`3oOomDOol20003Ool4
0004Ool30003Ool20004Ool4000=Ool40003Ool20003Ool400000goo000000030003Ool20004Ool0
0`00Oomoo`03Ool20002Ool500001Goo00000000Ool00P00BWoo000eOol00`00Oomoo`1FOol00`00
Oomoo`3jOol01000Oomoo`002goo00<007ooOol06Goo00<007ooOol03Woo00<007ooOol02Woo00<0
07ooOol027oo00<007ooOol0DWoo000eOol00`00Oomoo`1EOol00`00Oomoo`3jOol5000:Ool2000L
Ool2000FOol01000Oomoogoo0P001Woo00<007ooOol0EWoo000eOol00`00Oomoo`1DOol00`00Oomo
o`3oOonVOol003Eoo`03001oogoo05=oo`03001oogoo0?moojMoo`00=Goo00<007ooOol0ogoooGoo
000eOol00`00Oomoo`3oOoomOol003Eoo`80055oo`03001oogoo0?moojYoo`00=Goo00<007ooOol0
D7oo00<007ooOol0ogooZWoo000eOol00`00Oomoo`3oOoomOol003Eoo`03001oogoo0?moooeoo`00
=Goo00<007ooOol0ogoooGoo000eOol00`00Oomoo`3oOoomOol003Eoo`03001oogoo0?moooeoo`00
=Goo00<007ooOol0ogoooGoo000eOol00`00Oomoo`3oOoomOol00?mooomoocIoo`00ogooogoo=Woo
003oOoooOolfOol00?mooomoocIoo`00ogooogoo=Woo003oOoooOolfOol00?mooomoocIoo`00ogoo
ogoo=Woo003oOoooOolfOol00?mooomoocIoo`00ogooogoo=Woo000UOol20003Ool40003Ool20004
Ool00`00Ool00003Ool20002Ool300000goo0000003oOoo^Ool002Aoo`04001oogoo0003Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00L007oo001oo`00Ool00002Ool01000Oomoo`000Woo00<007oo
Ool0ogookGoo000TOol00`00Ool000020002Ool00`00Oomoo`02Ool01000Oomoo`000Woo00L007oo
001oo`00Ool00005Ool01000Oomoo`00ogookgoo000TOol00`00Oomoo`03Ool40003Ool20002Ool3
00000goo000000050002Ool3003oOoo`Ool002Aoo`03001oogoo01Eoo`03001oogoo00=oo`03001o
ogoo0?mooo1oo`009Goo0`006Goo0P00ogoolWoo003oOoooOolfOol00?mooomoocIoo`00ogooogoo
=Woo003oOoooOolfOol00?mooomoocIoo`00ogooogoo=Woo003oOoooOolfOol00?mooomoocIoo`00
ogooogoo=Woo003oOoooOolfOol00?mooomoocIoo`00ogooogoo=Woo003oOoooOolfOol00?mooomo
ocIoo`00ogooogoo=Woo003oOoooOolfOol00?mooomoocIoo`00ogooogoo=Woo003oOoooOolfOol0
0?mooomoocIoo`00ogooogoo=Woo003oOoooOolfOol00?mooomoocIoo`00ogooogoo=Woo003oOooo
OolfOol00?mooomoocIoo`00ogooogoo=Woo003oOoooOolfOol00?mooomoocIoo`00ogooogoo=Woo
003oOoooOolfOol00?mooomoocIoo`00ogooogoo=Woo003oOoooOolfOol00?mooomoocIoo`00ogoo
ogoo=Woo003oOoooOolfOol00?mooomoocIoo`00ogooogoo=Woo003oOoooOolfOol00?mooomoocIo
o`00ogooogoo=Woo003oOoooOolfOol00?mooomoocIoo`00ogooogoo=Woo003oOoooOolfOol00?mo
oomoocIoo`00\
\>"],
  ImageRangeCache->{{{0, 563.875}, {417.438, 0}} -> {-1.06835, -1.05001, \
0.00503073, 0.00503073}, {{13.5625, 411.125}, {407.438, 9.9375}} -> \
{-0.142048, -0.0102208, 0.00265909, 9.34991*^-05}, {{291.875, 550.25}, \
{129.188, 69.5625}} -> {-3.89572, -17.8908, 0.0130045, 0.0617199}, {{305.688, \
382.563}, {126.25, 110.063}} -> {-42.5178, -36.9772, 0.123553, 0.123553}, \
{{305.688, 382.563}, {107.438, 91.25}} -> {-42.5178, -39.3016, 0.123553, \
0.123553}, {{305.688, 382.563}, {88.625, 72.4375}} -> {-42.5178, -41.6259, \
0.123553, 0.123553}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Export["\<plot5.eps\>", plo5, "\<EPS\>"];\)\)], "Input"],

Cell[BoxData[
    \(Graphics::"gprim" \(\(:\)\(\ \)\) 
      "\!\(None\) was encountered where a \!\(Graphics\) primitive or \
directive was expected."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      "\[IndentingNewLine]", \(\[Sigma] = 1;\)}], "\[IndentingNewLine]", \(Do[
        Nh[i] = 1/dim, {i, 1, dim}];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"gdist", "=", 
        StyleBox[\(LogNormalDistribution[0, \[Sigma]]\),
          "MR"]}], 
      ";"}], "\[IndentingNewLine]", \(cdfunction = 
        CDF[gdist, y];\), "\[IndentingNewLine]", \(pdfunction = 
        PDF[gdist, y];\), "\[IndentingNewLine]", \(inversecdf[z_] = 
        y /. \(Solve[cdfunction \[Equal] z, 
              y]\)[\([1]\)];\), "\[IndentingNewLine]", \(Do[
        x[i] = inversecdf[\((i -  .5)\)/dim]\ , {i, 1, 
          dim}];\), "\[IndentingNewLine]", \(scal = 
        Sum[x[i]\ Nh[i], {i, 1, dim}];\), "\[IndentingNewLine]", \(Do[
        x[i] = x[i]/scal\ , {i, 1, 
          dim}];\), "\[IndentingNewLine]", \(Nlt = \(\((1 - \[Eta])\) \
\[Gamma]\)\/\(\((\[Phi] - \[Theta])\) \((1 + \[Beta] + \[Gamma])\)\);\), "\
\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"glt", "=", 
        RowBox[{
          StyleBox["B",
            
            FontWeight->
              "Plain"], \(\((\(\[Eta] \((\[Phi] - \[Theta])\)\)\/\(1 - \[Eta]\
\))\)\^\[Eta]\)}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{\(k[
            1] = \((\(\[Beta]\/\(1 + \[Beta]\)\) \(1\/\(glt\ Nlt\)\) \((1 - \
\[Alpha])\))\)\^\(1\/\(1 - \[Alpha]\)\);\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(hh[1]\), "=", 
          RowBox[{"If", "[", 
            RowBox[{\(\[Kappa] < 1 - \[Tau]\), ",", 
              RowBox[{
                FractionBox[
                  StyleBox["B",
                    FontWeight->"Plain"], 
                  "glt"], \(\((\(\[Eta] \((\[Phi] - \[Theta])\)\)\/\(1 - \
\[Eta]\))\)\^\[Eta]\)}], ",", "1"}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(j = 1;\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(Do[
        n[i] = If[
            x[i] > \[Theta]/\((\[Eta]\ \[Phi])\), \(\((1 - \[Eta])\)\ \
\[Gamma]\ x[i]\)\/\(\((\[Phi]\ x[i] - \[Theta])\) \((1 + \[Beta] + \
\[Gamma])\)\), \(\(\[Gamma]\)\(\ \)\)\/\(\[Phi]\ \((1 + \[Beta] + \[Gamma])\)\
\)], {i, 1, dim}];\), "\[IndentingNewLine]", \(hh[1] = 
        hhh\  /. 
          FindRoot[\((k[1]\^\[Alpha]\ \[Alpha]\ \(1 + \[Beta]\)\/\(1 + \
\[Beta] + \[Gamma]\) + \((1 - \[Alpha])\) 
                      k[1]\^\[Alpha]\ \((1 - \[Phi]\ Sum[
                              n[i]\ x[i]\ \ Nh[i], {i, 1, dim}])\))\) 
                hhh == \[InvisibleSpace]0.25987, {hhh,  .9, 
              1.1}];\), "\[IndentingNewLine]", \(gdp[j] = 
        k[j]\^\[Alpha]\ \[Alpha]\ \(1 + \[Beta]\)\/\(1 + \[Beta] + \[Gamma]\) \
+ \((1 - \[Alpha])\) 
            k[j]\^\[Alpha]\ \((1 - \[Phi]\ Sum[
                    n[i]\ x[i]\ \ Nh[i], {i, 1, 
                      dim}])\);\), "\[IndentingNewLine]", \(nsort = 
        Sort[Array[n, dim]];\), "\[IndentingNewLine]", \(fd[
          j] = \(-Mean[Take[nsort, dim/5]]\) + 
          Mean[Take[nsort, \(-dim\)/5]];\), "\[IndentingNewLine]", \(nag[j] = 
        Sum[n[i]\ Nh[i], {i, 1, dim}];\), "\[IndentingNewLine]", \(Do[
        Nhf[i] = n[i]\/nag[j]\ Nh[i], {i, 1, 
          dim}];\), "\[IndentingNewLine]", \(Do[
        e[i] = Max[\(\[Eta]\ \[Phi]\ x[i] - \[Theta]\)\/\(1 - \[Eta]\), 
            0], {i, 1, dim}];\), "\[IndentingNewLine]", \(gag[j] = 
        Sum[\ Nhf[i]\ B\ \(\((\[Theta] + e[i])\)\^\[Eta]\) \(x[i]\^\[Tau]\) 
            hh[j]\^\(\[Kappa] + \[Tau] - 1\), {i, 1, 
            dim}];\), "\[IndentingNewLine]", \(hh[j + 1] = 
        hh[j]\ gag[j]/\((1 + \[CurlyRho])\);\), "\[IndentingNewLine]", \(Do[
        inc[i] = \((x[i] \((1 - \[Phi]\ n[i])\) - 
                e[i] n[i])\) \((1 - \[Alpha])\) k[j]\^\[Alpha], {i, 1, 
          dim}];\), "\[IndentingNewLine]", \(sd = 
        Sort[income];\), "\[IndentingNewLine]", 
    RowBox[{\(gix[j] = 
          N[\(Length[
                    sd]\/\((Length[sd] - 
                      1)\)\) \(2  Apply[Plus, Table[\((2  q - Length[sd] - 1)\
\) sd[\([q]\)], {q, 1, Length[sd]}]]\)\/\(2\ Length[sd]\^2\ Mean[sd]\)];\), 
      "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \
\(Print["\<\[Sigma]=\>", \[Sigma], "\< GDP=\>", gdp[1], "\< Gini=\>", 
      gix[1], "\< growth=\>", \@\(gag[1]\)\%30 - 1]\)}], "Input"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("\[Sigma]="\[InvisibleSpace]1\[InvisibleSpace]" GDP="\
\[InvisibleSpace]0.25936265772759204`\[InvisibleSpace]" Gini="\
\[InvisibleSpace]0.5199764685890028`\[InvisibleSpace]" growth="\
\[InvisibleSpace]0.007965933435116535`\),
      SequenceForm[ 
      "\[Sigma]=", 1, " GDP=", .25936265772759204, 
        " Gini=", .51997646858900282, " growth=", .0079659334351165345],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowSize->{863, 602},
WindowMargins->{{0, Automatic}, {0, Automatic}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 82, 3, 170, "Title"],
Cell[1812, 57, 45, 3, 93, "Subtitle"],
Cell[1860, 62, 43, 0, 64, "Subtitle"],
Cell[1906, 64, 375, 6, 130, "Input"],
Cell[2284, 72, 209, 3, 50, "Input"],

Cell[CellGroupData[{
Cell[2518, 79, 30, 0, 64, "Subtitle"],

Cell[CellGroupData[{
Cell[2573, 83, 41, 0, 59, "Section"],
Cell[2617, 85, 967, 16, 210, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3621, 106, 49, 0, 59, "Section"],
Cell[3673, 108, 3201, 69, 442, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6911, 182, 37, 0, 59, "Section"],
Cell[6951, 184, 3549, 62, 751, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10537, 251, 58, 0, 59, "Section"],
Cell[10598, 253, 2059, 36, 397, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12694, 294, 26, 0, 59, "Section"],
Cell[12723, 296, 1332, 23, 230, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14104, 325, 32, 0, 64, "Subtitle"],
Cell[14139, 327, 398, 7, 110, "Input"],

Cell[CellGroupData[{
Cell[14562, 338, 36, 0, 59, "Section"],
Cell[14601, 340, 55, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14693, 346, 40, 0, 53, "Subsubtitle"],

Cell[CellGroupData[{
Cell[14758, 350, 1609, 29, 317, "Input"],
Cell[16370, 381, 160, 3, 24, "Message"],
Cell[16533, 386, 131, 3, 25, "Print"],
Cell[16667, 391, 587, 10, 25, "Print"],
Cell[17257, 403, 160, 3, 24, "Message"],
Cell[17420, 408, 131, 3, 25, "Print"],
Cell[17554, 413, 579, 10, 25, "Print"],
Cell[18136, 425, 160, 3, 24, "Message"],
Cell[18299, 430, 131, 3, 25, "Print"],
Cell[18433, 435, 569, 10, 25, "Print"],
Cell[19005, 447, 160, 3, 24, "Message"],
Cell[19168, 452, 131, 3, 25, "Print"],
Cell[19302, 457, 580, 10, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[19931, 473, 43, 0, 53, "Subsubtitle"],

Cell[CellGroupData[{
Cell[19999, 477, 1216, 25, 239, "Input"],
Cell[21218, 504, 160, 3, 24, "Message"],
Cell[21381, 509, 131, 3, 25, "Print"],
Cell[21515, 514, 503, 9, 25, "Print"],
Cell[22021, 525, 160, 3, 24, "Message"],
Cell[22184, 530, 131, 3, 25, "Print"],
Cell[22318, 535, 495, 9, 25, "Print"],
Cell[22816, 546, 160, 3, 24, "Message"],
Cell[22979, 551, 131, 3, 25, "Print"],
Cell[23113, 556, 489, 9, 25, "Print"],
Cell[23605, 567, 160, 3, 24, "Message"],
Cell[23768, 572, 131, 3, 25, "Print"],
Cell[23902, 577, 503, 9, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24442, 591, 1215, 25, 239, "Input"],
Cell[25660, 618, 160, 3, 24, "Message"],
Cell[25823, 623, 131, 3, 25, "Print"],
Cell[25957, 628, 502, 9, 25, "Print"],
Cell[26462, 639, 160, 3, 24, "Message"],
Cell[26625, 644, 131, 3, 25, "Print"],
Cell[26759, 649, 495, 9, 25, "Print"],
Cell[27257, 660, 160, 3, 24, "Message"],
Cell[27420, 665, 131, 3, 25, "Print"],
Cell[27554, 670, 489, 9, 25, "Print"],
Cell[28046, 681, 160, 3, 24, "Message"],
Cell[28209, 686, 131, 3, 25, "Print"],
Cell[28343, 691, 496, 9, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[28888, 706, 59, 0, 53, "Subsubtitle"],

Cell[CellGroupData[{
Cell[28972, 710, 3407, 64, 642, "Input"],
Cell[32382, 776, 160, 3, 24, "Message"],
Cell[32545, 781, 363, 6, 25, "Print"],
Cell[32911, 789, 160, 3, 24, "Message"],
Cell[33074, 794, 363, 6, 25, "Print"],
Cell[33440, 802, 160, 3, 24, "Message"],
Cell[33603, 807, 362, 6, 25, "Print"],
Cell[33968, 815, 160, 3, 24, "Message"],
Cell[34131, 820, 362, 6, 25, "Print"],
Cell[34496, 828, 160, 3, 24, "Message"],
Cell[34659, 833, 363, 6, 25, "Print"],
Cell[35025, 841, 160, 3, 24, "Message"],
Cell[35188, 846, 363, 6, 25, "Print"],
Cell[35554, 854, 160, 3, 24, "Message"],
Cell[35717, 859, 362, 6, 25, "Print"],
Cell[36082, 867, 160, 3, 24, "Message"],
Cell[36245, 872, 362, 6, 25, "Print"],
Cell[36610, 880, 160, 3, 24, "Message"],
Cell[36773, 885, 364, 6, 25, "Print"],
Cell[37140, 893, 160, 3, 24, "Message"],
Cell[37303, 898, 363, 6, 25, "Print"],
Cell[37669, 906, 160, 3, 24, "Message"],
Cell[37832, 911, 361, 6, 25, "Print"],
Cell[38196, 919, 160, 3, 24, "Message"],
Cell[38359, 924, 362, 6, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38758, 935, 58, 2, 59, "Section"],

Cell[CellGroupData[{
Cell[38841, 941, 789, 13, 223, "Input"],
Cell[39633, 956, 160, 3, 24, "Message"],
Cell[39796, 961, 131, 3, 25, "Print"],
Cell[39930, 966, 464, 8, 38, "Print"],
Cell[40397, 976, 160, 3, 24, "Message"],
Cell[40560, 981, 131, 3, 25, "Print"],
Cell[40694, 986, 460, 8, 38, "Print"],
Cell[41157, 996, 160, 3, 24, "Message"],
Cell[41320, 1001, 163, 3, 24, "Message"],
Cell[41486, 1006, 131, 3, 25, "Print"],
Cell[41620, 1011, 464, 8, 38, "Print"],
Cell[42087, 1021, 131, 3, 25, "Print"],
Cell[42221, 1026, 460, 8, 38, "Print"],
Cell[42684, 1036, 131, 3, 25, "Print"],
Cell[42818, 1041, 459, 8, 38, "Print"],
Cell[43280, 1051, 131, 3, 25, "Print"],
Cell[43414, 1056, 460, 8, 38, "Print"],
Cell[43877, 1066, 131, 3, 25, "Print"],
Cell[44011, 1071, 460, 8, 38, "Print"],
Cell[44474, 1081, 131, 3, 25, "Print"],
Cell[44608, 1086, 459, 8, 38, "Print"],
Cell[45070, 1096, 131, 3, 25, "Print"],
Cell[45204, 1101, 465, 8, 38, "Print"],
Cell[45672, 1111, 131, 3, 25, "Print"],
Cell[45806, 1116, 443, 8, 25, "Print"],
Cell[46252, 1126, 131, 3, 25, "Print"],
Cell[46386, 1131, 465, 8, 38, "Print"],
Cell[46854, 1141, 131, 3, 25, "Print"],
Cell[46988, 1146, 460, 8, 38, "Print"],
Cell[47451, 1156, 131, 3, 25, "Print"],
Cell[47585, 1161, 465, 8, 38, "Print"],
Cell[48053, 1171, 131, 3, 25, "Print"],
Cell[48187, 1176, 462, 8, 38, "Print"],
Cell[48652, 1186, 131, 3, 25, "Print"],
Cell[48786, 1191, 463, 8, 38, "Print"],
Cell[49252, 1201, 131, 3, 25, "Print"],
Cell[49386, 1206, 469, 8, 38, "Print"],
Cell[49858, 1216, 131, 3, 25, "Print"],
Cell[49992, 1221, 472, 8, 38, "Print"],
Cell[50467, 1231, 131, 3, 25, "Print"],
Cell[50601, 1236, 469, 8, 38, "Print"],
Cell[51073, 1246, 131, 3, 25, "Print"],
Cell[51207, 1251, 472, 8, 38, "Print"],
Cell[51682, 1261, 131, 3, 25, "Print"],
Cell[51816, 1266, 448, 8, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52301, 1279, 570, 12, 110, "Input"],
Cell[52874, 1293, 166, 3, 24, "Message"],
Cell[53043, 1298, 34892, 931, 427, 11582, 638, "GraphicsData", "PostScript", \
"Graphics"],
Cell[87938, 2231, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[88105, 2239, 78, 1, 30, "Input"],
Cell[88186, 2242, 166, 3, 24, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[88389, 2250, 4352, 87, 884, "Input"],
Cell[92744, 2339, 160, 3, 24, "Message"],
Cell[92907, 2344, 443, 8, 25, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

